<?php
/**
 * Display per page and per post options - meta_boxes.
 *
 * @since Version 4
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}
// Admin panel that gets added to the page edit page for per page options


// ========================================== PER PAGE & POST OPTION DEFINITIONS FOLLOW ====================================


function absolute_weaver_pp_isp_true( $val ) {
	if ( $val ) {
		return true;
	}

	return false;
}

function absolute_weaver_pp_page_extras() {
	// ------------------------------- Display Per Page Options on WP Page editor -------------------
	global $post;

	$opts = absolute_weaver_get_theme_settings(); // need to fetch Absolute Weaver options

	if ( ! ( current_user_can( 'edit_themes' )
	         || ( current_user_can( 'edit_theme_options' ) && ! isset( $opts['_hide_mu_admin_per'] ) )  // multi-site regular admin
	         || ( current_user_can( 'edit_pages' ) && ! isset( $opts['_hide_editor_per'] ) )    // Editor
	         || ( current_user_can( 'edit_posts' ) && ! isset( $opts['_hide_author_per'] ) ) )    // Author/Contributor
	) {
		if ( isset( $opts['_show_per_post_all'] ) && $opts['_show_per_post_all'] ) {
			echo '<p>' .
			     esc_html__( 'You can enable Absolute Weaver Per Page Options for Custom Post Types on the Absolute Weaver:Advanced Options:Admin Options tab.', 'absolute-weaver' ) .
			     '</p>';
		} else {
			echo '<p>' . esc_html__( 'Absolute Weaver Per Page Options not available for your User Role.', 'absolute-weaver' ) . '</p>';
		}

		return; // don't show per post panel
	}

	echo( "<div style=\"line-height:150%;border: 1px solid #888;list-style-type: none;\"><p>\n" );
	if ( get_the_ID() == get_option( 'page_on_front' ) ) { ?>
		<div style="padding:2px; border:2px solid yellow; background:#FF8;">
			<?php esc_html_e( 'Information: This page has been set to serve as your front page in the "Dashboard:Settings:Reading" \'Front page:\' option.', 'absolute-weaver' ); ?>
		</div><br/>
		<?php
	}

	if ( get_the_ID() == get_option( 'page_for_posts' ) ) {
		?>
		<div style="padding:2px; border:2px solid red; background:#FAA;">
			<?php
			absolute_weaver_markdown(
				__(
					'**WARNING!**
You have the *Dashboard:Settings:Reading Posts page:* option set to this page.
You may intend to do this, but note this means that *only* this page\'s Title will be used
on the default WordPress blog page, and any content you may have entered above is *not* used.
If you want this page to serve as your blog page, and enable Absolute Weaver Per Page options,
including the option of using the Page with Posts page template,
then the *Settings:Reading:Posts page* selection **must** be set to
the *&mdash; Select &mdash;* default value.',
					'absolute-weaver'
				)
			);
			?>
		</div><br/>
		<?php
		return;
	}

	absolute_weaver_check_editor_style();       // see if we need an update...

	echo '<strong>' . esc_html__( 'Page Templates', 'absolute-weaver' ) . '</strong>';
	absolute_weaver_help_link( 'help.html#PageTemplates', esc_html__( 'Help for Absolute Weaver Page Templates', 'absolute-weaver' ) );
	echo '<span style="float:right;">( ' . esc_html__( 'This Page\'s ID: ', 'absolute-weaver' );
	the_ID();
	echo ' )</span>';
	absolute_weaver_html_br();
	esc_html_e( 'Please click the ( ? ) for more information about all the Absolute Weaver Page Templates.', 'absolute-weaver' );
	if ( ! ! get_post_meta( get_the_ID(), '_elementor_edit_mode', true ) ) {
		absolute_weaver_html_br();
		esc_html_e( 'NOTE: This page has been created with "Elementor". You may want to consider using the "For Your Page Builder Plugin" Page Template to display this page.', 'absolute-weaver' );
	}

	$template = ! empty( $post->page_template ) ? $post->page_template : 'Default Template';
	$raw_template = in_array( $template, array( 'paget-raw.php' ) );

	absolute_weaver_html_br();

	absolute_weaver_showtabs( $raw_template, $template );
	?>
	<div style="clear:both;"></div>
	<input type='hidden' id='post_meta' name='post_meta' value='post_meta'/>
	</div>
	<?php
}

function absolute_weaver_showtabs( $raw_template = false, $template = 'default' ) {
	?>
	<div id="tabwrap-per-page" style="padding-left:4px;">
		<div id="tab-container-page" style="border:1px solid #888;padding: 2px 1% 2px 1%; width:97.9%;" class='yetiisub'>
			<ul id="tab-container-page-nav" style="border-bottom:2px solid #999;" class='yetiisub'>
				<?php
				absolute_weaver_pp_elink( '#pp-layout', esc_html__( 'Settings for Per Page Layout', 'absolute-weaver' ), esc_html__( 'Layout', 'absolute-weaver' ), '<li>', '</li>' );

				absolute_weaver_pp_elink( '#pp-pwp', esc_html__( 'Settings for Page with Posts.', 'absolute-weaver' ), esc_html__( 'Page with Posts', 'absolute-weaver' ), '<li>', '</li>' );

				absolute_weaver_pp_elink( '#pp-builder', esc_html__( 'Settings for Page Builders.', 'absolute-weaver' ), esc_html__( 'Page Builders', 'absolute-weaver' ), '<li>', '</li>' );
				?>
			</ul>

			<div id="pp-layout" class="tab_mainopt">        <!-- *** layout *** -->
				<?php
				absolute_weaver_pp_pg_layout( $raw_template );
				?>
			</div>                                            <!-- *** /layout *** -->


			<div id="pp-pwp" class="tab_mainopt">            <!-- *** PWP *** -->
				<?php absolute_weaver_pp_page_with_posts_opts( $raw_template, $template ); ?>
			</div>                                            <!-- *** /PWP *** -->

			<div id="pp-builder" class="tab_mainopt">            <!-- *** PWP *** -->
				<?php absolute_weaver_pp_page_builder_opts( 'page' ); ?>
			</div>                                            <!-- *** /PWP *** -->


		</div> <!-- #tab-container-page -->
	</div>    <!-- #tabwrap-per-page -->

	<script type="text/javascript">
		var tabberMainOpts = new Yetii({
			id: 'tab-container-page',
			tabclass: 'tab_mainopt',
			persist: true
		});
	</script>
	<?php
}

function absolute_weaver_pp_elink( $href, $title, $label, $before = '', $after = '' ) {
	// Use wp_kses_post since this text has markup in it
	echo wp_kses_post( $before . '<a href="' . esc_url( $href ) . '" title="' . $title . '">' . $label . '</a>' . $after );
}


function absolute_weaver_pp_pg_layout( $raw_template = false ) {
	// ------------------------------- Page Layout -------------------

	echo '<span style="font-weight:bold;font-size:140%;">' . esc_html__( 'Layout', 'absolute-weaver' ) . '</span><br/>';
	esc_html_e( 'These settings let you control layout + page title on a per page basis.', 'absolute-weaver' );

	absolute_weaver_html_br( 2 );
	if ( $raw_template ) {
		esc_html_e( 'Not options when using the RAW Page Template', 'absolute-weaver' );

		return;
	}

	absolute_weaver_pp_page_title( esc_html__( 'Sidebars &amp; Widgets', 'absolute-weaver' ), 80, 1 );
	absolute_weaver_pp_page_layout();

	absolute_weaver_pp_page_title( esc_html__( 'Featured Image', 'absolute-weaver' ), 80, 1 );

	$opts3 = array(
		'id'    => '_pp_fi_location',
		'info'  => esc_html__( 'How to display Page FI on this page', 'absolute-weaver' ),
		'value' => array(
			array(
				'val'  => '',
				'desc' => esc_html__( 'Default Blog FI', 'absolute-weaver' ),
			),
			array(
				'val'  => 'content-top',
				'desc' => esc_html__( 'With Content - top', 'absolute-weaver' ),
			),
			array(
				'val'  => 'content-bottom',
				'desc' => esc_html__( 'With Content - bottom', 'absolute-weaver' ),
			),
			array(
				'val'  => 'title-before',
				'desc' => esc_html__( 'With Title', 'absolute-weaver' ),
			),
			array(
				'val'  => 'title-banner',
				'desc' => esc_html__( 'Banner above Title', 'absolute-weaver' ),
			),
			array(
				'val'  => 'header-image',
				'desc' => esc_html__( 'Header Image Replacement', 'absolute-weaver' ),
			),
			array(
				'val'  => 'post-before',
				'desc' => esc_html__( 'Beside Page, no wrap', 'absolute-weaver' ),
			),
			array(
				'val'  => 'post-bg',
				'desc' => esc_html__( 'As BG Image, Tile', 'absolute-weaver' ),
			),
			array(
				'val'  => 'post-bg-cover',
				'desc' => esc_html__( 'As BG Image, Cover', 'absolute-weaver' ),
			),
			array(
				'val'  => 'post-bg-parallax',
				'desc' => esc_html__( 'As BG Image, Parallax', 'absolute-weaver' ),
			),
			array(
				'val'  => 'post-bg-parallax-full',
				'desc' => esc_html__( 'As BG Image, Parallax Full', 'absolute-weaver' ),
			),
			array(
				'val'  => 'hide',
				'desc' => esc_html__( 'Hide FI for this Post', 'absolute-weaver' ),
			),
		),
	);
	absolute_weaver_pp_pp_select_id( $opts3 );
	absolute_weaver_html_br( 2 );
	absolute_weaver_pp_page_title( esc_html__( 'Page Title', 'absolute-weaver' ), 80, 1 );
	absolute_weaver_pp_page_checkbox( '_pp_hide_page_title', esc_html__( 'Hide Page Title', 'absolute-weaver' ), 50, 2 );
}

// ------------------------------- Page with Post Options -------------------

function absolute_weaver_pp_page_with_posts_opts( $raw_template, $template ) {
	global $post;
	?>
	<span style="font-weight:bold;font-size:120%;">
	<?php
	esc_html_e( 'Settings for "Page with Posts" Template', 'absolute-weaver' );
	?>
	</span>
	<?php
	absolute_weaver_help_link( 'help.html#PerPostTemplate', esc_html__( 'Help for Page with Posts Template', 'absolute-weaver' ) );

	$template = ! empty( $post->page_template ) ? $post->page_template : 'Default Template';
	if ( in_array( $template, apply_filters( 'absolute_weaver_paget_posts', array( 'paget-posts.php' ) ) ) ) {
		?>
		<p>
			<?php
			esc_html_e(
				'These settings are optional, and can filter which posts are displayed when you use the "Page with Posts" template.
Use commas to separate items in lists. The settings will be combined for the final filtered list of posts displayed.
(If you make mistakes in your settings, it won\'t be apparent until you display the page.)',
				'absolute-weaver'
			);
			?>
		</p>

		<input type="text" size="30" id="_pp_category" name="_pp_category"
		       value="<?php echo esc_attr( get_post_meta( $post->ID, '_pp_category', true ) ); ?>"/>
		<?php esc_html_e( 'Category - Enter list of category slugs of posts to include. (-slug will exclude specified category)', 'absolute-weaver' ); ?>
		<br/>

		<input type="text" size="30" id="_pp_tag" name="_pp_tag"
		       value="<?php echo esc_attr( get_post_meta( $post->ID, '_pp_tag', true ) ); ?>"/>
		<?php esc_html_e( 'Tags - Enter list of tag slugs of posts to include.', 'absolute-weaver' ); ?> <br/>

		<input type="text" size="30" id="_pp_onepost" name="_pp_onepost"
		       value="<?php echo esc_attr( get_post_meta( $post->ID, '_pp_onepost', true ) ); ?>"/>
		<?php esc_html_e( 'Single Post - Enter post slug of a single post to display.', 'absolute-weaver' ); ?> <br/>

		<input type="text" size="30" id="_pp_orderby" name="_pp_orderby"
		       value="<?php echo esc_attr( get_post_meta( $post->ID, '_pp_orderby', true ) ); ?>"/>
		<?php esc_html_e( 'Order by - Enter method to order posts by: author, date, title, or rand.', 'absolute-weaver' ); ?> <br/>

		<input type="text" size="30" id="_pp_sort_order" name="_pp_sort_order"
		       value="<?php echo esc_attr( get_post_meta( $post->ID, '_pp_sort_order', true ) ); ?>"/>
		<?php esc_html_e( 'Sort order - Enter ASC or DESC for sort order.', 'absolute-weaver' ); ?> <br/>

		<input type="text" size="30" id="_pp_posts_per_page" name="_pp_posts_per_page"
		       value="<?php echo esc_attr( get_post_meta( $post->ID, '_pp_posts_per_page', true ) ); ?>"/>
		<?php esc_html_e( 'Posts per Page - Enter maximum number of posts per page.', 'absolute-weaver' ); ?> <br/>

		<input type="text" size="30" id="_pp_author" name="_pp_author"
		       value="<?php echo esc_attr( get_post_meta( $post->ID, '_pp_author', true ) ); ?>"/>
		<?php esc_html_e( 'Author - Enter author ( use username, including spaces ), or list of author IDs', 'absolute-weaver' ); ?> <br/>

		<input type="text" size="30" id="_pp_post_type" name="_pp_post_type"
		       value="<?php echo esc_attr( get_post_meta( $post->ID, '_pp_post_type', true ) ); ?>"/>
		<?php esc_html_e( 'Custom Post Type - Enter slug of one custom post type to display', 'absolute-weaver' ); ?> <br/>

		<?php absolute_weaver_pp_pwp_type(); ?><br/>

		<input type="text" size="5" id="_pp_fullposts" name="_pp_fullposts"
		       value="<?php echo esc_attr( get_post_meta( $post->ID, '_pp_fullposts', true ) ); ?>"/>
		<?php esc_html_e( "Don't excerpt 1st \"n\" Posts - Display the non-excerpted post for the first \"n\" posts.", 'absolute-weaver' ); ?>
		<br/>

		<input type="text" size="5" id="_pp_hide_n_posts" name="_pp_hide_n_posts"
		       value="<?php echo esc_attr( get_post_meta( $post->ID, '_pp_hide_n_posts', true ) ); ?>"/>
		<?php
		echo '<span class="dashicons dashicons-visibility"></span>' .
		     esc_html__(
			     'Hide first "n" posts - Start with post n+1.
Useful with plugin that will display first n posts using a shortcode. (e.g., Post slider)',
			     'absolute-weaver'
		     );
		?>

		<br/><br/>

		<?php absolute_weaver_pp_page_checkbox( '_pp_hide_infotop', esc_html__( 'Hide post top info line', 'absolute-weaver' ), 40 ); ?>
		<?php absolute_weaver_pp_page_checkbox( '_pp_hide_infobottom', esc_html__( 'Hide post bottom info line', 'absolute-weaver' ), 40, 1 ); ?>
		<?php absolute_weaver_pp_page_checkbox( '_pp_hide_sticky', esc_html__( 'No special treatment for Sticky Posts', 'absolute-weaver' ), 40 ); ?>

		<div style="clear:both;"></div>

		<?php
	} else {    // NOT a page with posts
		?>
		<p>
			<?php
			echo wp_kses_post( absolute_weaver_markdown(
				__( '**Note:** After you choose the "Page with Posts" template from the *Template<*
option in the *Page Attributes* box, **and** *Publish*, *Save Draft*, or *Refresh the editor*,
settings for *Page with Posts* will be displayed here. Current page template:',
					'absolute-weaver' ) ) );
			echo esc_html( $template );
			?>
		</p>
		<?php
	}    // End if().
}


function absolute_weaver_pp_page_builder_opts( $post_type = 'page' ) {

	global $post;

	echo '<span style="font-weight:bold;font-size:140%;">' . esc_html__( 'Page Builder Header/Footer Replacement', 'absolute-weaver' /*adm*/ ) . '</span><br/>';
	if ( $post_type == 'page' ) {
		echo esc_html__( 'These settings let you replace the header or footer areas with content from a page builder page. They override the global replacement settings.', 'absolute-weaver' /*adm*/ );
	} else {
		echo esc_html__( 'These settings let you replace the header or footer areas of the Single Page Post view with content from a page builder page. They override the global replacement settings.', 'absolute-weaver' /*adm*/ );
	}
	absolute_weaver_html_br( 2 );

	// HEADER ----------------

	absolute_weaver_pp_page_title( esc_html__( 'Header Area Replacement', 'absolute-weaver' ), 80, 1 );
	?>
	<p>
		<?php
		$cur = get_post_meta( get_the_ID(), '_pp_pb_header_hide_menus', true );
		?>

		<select id="_pp_pb_header_hide_menus" name="_pp_pb_header_hide_menus">
			<option value='' <?php echo $cur == '' ? ' selected="selected"' : ''; ?>><?php esc_html_e( 'Global Visibility', 'absolute-weaver' ); ?></option>
			<option value='hide' <?php echo $cur == 'hide' ? ' selected="selected"' : ''; ?>><?php esc_html_e( 'Hide Menus', 'absolute-weaver' ); ?></option>
			<option value='show' <?php echo $cur == 'show' ? ' selected="selected"' : ''; ?>><?php esc_html_e( 'Show Menus', 'absolute-weaver' ); ?></option>
		</select>
		<?php esc_html_e( 'Hide or Show Menus - Select how to display menus with Header Replacement.', 'absolute-weaver' ); ?>
	</p>

	<input type="text" size="10" id='_pp_pb_header_replace_page_id' name='_pp_pb_header_replace_page_id'
	       value="<?php echo esc_attr( get_post_meta( $post->ID, '_pp_pb_header_replace_page_id', true ) ); ?>"/>
	<?php esc_html_e( 'Specify any page or post ID to serve as header replacement. Overrides list selection below.', 'absolute-weaver' ); ?>
	<br style="clear:both;"/>

	<?php
	if ( defined( 'ELEMENTOR_VERSION' ) ) {             // only provide if elementor is active
		// Elementor selection
		$pargs = array(
			'post_type' => 'page',
		);
		$posts = get_pages( $pargs );
		?>
		<p>
			<?php esc_html_e( 'Select an Elementor Page. (Override this selection in Page/Post field above to select Page OR Post by ID.)', 'absolute-weaver' ); ?><br/>
			<select id="_pp_elementor_header_replacement" name="_pp_elementor_header_replacement">
				<option value=''>&nbsp;</option>
				<?php
				$cur = get_post_meta( get_the_ID(), '_pp_elementor_header_replacement', true );
				foreach ( $posts as $cur_post ) {
					if ( ! ! get_post_meta( $cur_post->ID, '_elementor_edit_mode', true ) ) {
						$selected = $cur == $cur_post->ID ? ' selected="selected"' : '';
						echo '<option' . esc_attr( $selected ) . ' value="' . esc_attr( $cur_post->ID ) . '">' . esc_html( substr( $cur_post->post_title, 0, 60 ) ) . '</option>';        // make the title fit, more or less
					}
				}
				$cur = get_post_meta( get_the_ID(), '_pp_elementor_header_replacement', true );
				foreach ( $posts as $cur_post ) {
					if ( ! ! get_post_meta( $cur_post->ID, '_elementor_edit_mode', true ) ) {
						$selected = ( $cur == $cur_post->ID ) ? ' selected="selected"' : '';
						echo '<option' . esc_attr( $selected ) . ' value="' . esc_attr( $cur_post->ID ) . '">' . esc_html( substr( $cur_post->post_title, 0, 60 ) ) . '</option>';        // make the title fit, more or less
					}
				}

				$posts = get_posts( array( 'post_type' => 'post' ) );
				foreach ( $posts as $cur_post ) {
					if ( ! ! get_post_meta( $cur_post->ID, '_elementor_edit_mode', true ) ) {
						$selected = ( $cur == $cur_post->ID ) ? ' selected="selected"' : '';
						echo '<option' . esc_attr( $selected ) . ' value="' . esc_attr( $cur_post->ID ) . '">' . esc_html( substr( $cur_post->post_title, 0, 60 ) ) .
						     ' ' . esc_html__( '(post)', 'absolute-weaver' ) . '</option>';        // make the title fit, more or less
					}
				}
				?>
			</select>
		</p>
		<?php
	}

	$posts = '';
	if ( defined( 'SITEORIGIN_PANELS_VERSION' ) ) :     // only provide if siteorigins is active

		// SiteOrigin selection
		$pargs = array(
			'post_type' => 'page',
		);
		$posts = get_pages( $pargs );
		?>
		<p>
			<?php esc_html_e( 'Select a SiteOrigin Page Builder Page. (Override this selection in Page/Post field above to select Page OR Post by ID.)', 'absolute-weaver' ); ?><br/>
			<select id="_pp_siteorigin_header_replacement" name="_pp_siteorigin_header_replacement">
				<option value=''>&nbsp;</option>
				<?php
				foreach ( $posts as $cur_post ) {
					$cur = get_post_meta( get_the_ID(), '_pp_siteorigin_header_replacement', true );
					if ( ! ! get_post_meta( $cur_post->ID, 'panels_data', true ) ) {
						$selected = $cur == $cur_post->ID ? ' selected="selected"' : '';
						echo '<option' . esc_attr( $selected ) . ' value="' . esc_attr( $cur_post->ID ) . '">' . esc_html( substr( $cur_post->post_title, 0, 60 ) ) . '</option>';        // make the title fit, more or less
					}
				}
				$posts = get_posts( array( 'post_type' => 'post' ) );
				foreach ( $posts as $cur_post ) {
					if ( ! ! get_post_meta( $cur_post->ID, 'panels_data', true ) ) {
						$selected = ( $cur == $cur_post->ID ) ? ' selected="selected"' : '';
						echo '<option' . esc_attr( $selected ) . ' value="' . esc_attr( $cur_post->ID ) . '">' . esc_html( substr( $cur_post->post_title, 0, 60 ) ) .
						     ' ' . esc_html__( '(post)', 'absolute-weaver' ) . '</option>';        // make the title fit, more or less
					}
				}
				?>
			</select>
		</p>
	<?php
	endif; // SiteOrigin

	if ( ! defined( 'ELEMENTOR_VERSION' ) && ! defined( 'SITEORIGIN_PANELS_VERSION' ) ) {
		echo '<p>';
		esc_html_e( 'Sorry, Weaver can only list page builder pages from Elementor or SiteOrigin Page Builder. Please install and activate one of those plugins.', 'absolute-weaver' );
		echo '</p>';
	}

	// FOOTER -----------------

	absolute_weaver_html_br( 1 );
	absolute_weaver_pp_page_title( esc_html__( 'Footer Area Replacement', 'absolute-weaver' ), 80, 1 );
	?>
	<input type="text" size="10" id='_pp_pb_footer_replace_page_id' name='_pp_pb_footer_replace_page_id'
	       value="<?php echo esc_attr( get_post_meta( $post->ID, '_pp_pb_footer_replace_page_id', true ) ); ?>"/>
	<?php esc_html_e( 'Specify any page or post ID to serve as footer replacement. Overrides list selection below.', 'absolute-weaver' ); ?>
	<br style="clear:both;"/>
	<?php

	if ( defined( 'ELEMENTOR_VERSION' ) ) :             // only provide if elementor is active
		// Elementor selection
		$pargs = array(
			'post_type' => 'page',
		);
		$posts = get_pages( $pargs );
		?>
		<p>
			<?php esc_html_e( 'Select an Elementor Page. (Override this selection in Page/Post field above to select Page OR Post by ID.)', 'absolute-weaver' ); ?><br/>
			<select id="_pp_elementor_footer_replacement" name="_pp_elementor_footer_replacement">
				<option value=''>&nbsp;</option>
				<?php
				$cur = get_post_meta( get_the_ID(), '_pp_elementor_footer_replacement', true );
				foreach ( $posts as $cur_post ) {
					if ( ! ! get_post_meta( $cur_post->ID, '_elementor_edit_mode', true ) ) {
						$selected = $cur == $cur_post->ID ? ' selected="selected"' : '';
						echo '<option' . esc_attr( $selected ) . ' value="' . esc_attr( $cur_post->ID ) . '">' . esc_html( substr( $cur_post->post_title, 0, 60 ) ) . '</option>';        // make the title fit, more or less
					}
				}
				$posts = get_posts( array( 'post_type' => 'post' ) );
				foreach ( $posts as $cur_post ) {
					if ( ! ! get_post_meta( $cur_post->ID, '_elementor_edit_mode', true ) ) {
						$selected = ( $cur == $cur_post->ID ) ? ' selected="selected"' : '';
						echo '<option' . esc_attr( $selected ) . ' value="' . esc_attr( $cur_post->ID ) . '">' . esc_html( substr( $cur_post->post_title, 0, 54 ) ) .
						     ' ' . esc_html__( '(post)', 'absolute-weaver' ) . '</option>';        // make the title fit, more or less
					}
				}
				?>
			</select>
		</p>
	<?php
	endif;
	$posts = '';
	if ( defined( 'SITEORIGIN_PANELS_VERSION' ) ) :     // only provide if siteorigins is active

		// SiteOrigin selection
		$pargs = array(
			'post_type' => 'page',
		);
		$posts = get_pages( $pargs );
		?>
		<p>
			<?php esc_html_e( 'Select a SiteOrigin Page Builder Page. (Override this selection in Page/Post field above to select Page OR Post by ID.)', 'absolute-weaver' ); ?><br/>
			<select id="_pp_siteorigin_footer_replacement" name="_pp_siteorigin_footer_replacement">
				<option value=''>&nbsp;</option>
				<?php
				foreach ( $posts as $cur_post ) {
					$cur = get_post_meta( get_the_ID(), '_pp_siteorigin_footer_replacement', true );
					if ( ! ! get_post_meta( $cur_post->ID, 'panels_data', true ) ) {
						$selected = $cur == $cur_post->ID ? ' selected="selected"' : '';
						echo '<option' . esc_attr( $selected ) . ' value="' . esc_attr( $cur_post->ID ) . '">' . esc_html( substr( $cur_post->post_title, 0, 60 ) ) . '</option>';        // make the title fit, more or less
					}
				}
				$posts = get_posts( array( 'post_type' => 'post' ) );
				foreach ( $posts as $cur_post ) {
					if ( ! ! get_post_meta( $cur_post->ID, 'panels_data', true ) ) {
						$selected = ( $cur == $cur_post->ID ) ? ' selected="selected"' : '';
						echo '<option' . esc_attr( $selected ) . ' value="' . esc_attr( $cur_post->ID ) . '">' . esc_html( substr( $cur_post->post_title, 0, 54 ) ) .
						     ' ' . esc_html__( '(post)', 'absolute-weaver' ) . '</option>';        // make the title fit, more or less
					}
				}
				?>
			</select>
		</p>
	<?php
	endif; // SiteOrigin
	if ( ! defined( 'ELEMENTOR_VERSION' ) && ! defined( 'SITEORIGIN_PANELS_VERSION' ) ) {
		echo '<p>';
		esc_html_e( 'Sorry, Weaver can only list page builder pages from Elementor or SiteOrigin Page Builder. Please install and activate one of those plugins.', 'absolute-weaver' );
		echo '</p>';
	}
	echo '<div style="clear:both;"></div>';
}


function absolute_weaver_pp_page_layout( $page = 'page' ) {

	if ( $page == 'page' ) {
		$msg = esc_html__( 'Select "Sidebar Layout" for this page - overrides default Page layout.', 'absolute-weaver' );
	} else {
		$msg = __( 'Select Single Page View "Sidebar Layout" for this post - overrides default Single View layout.', 'absolute-weaver' );
	}

	$opts = array(
		'id'    => '_pp_page_layout',
		'info'  => $msg,
		'value' => array(
			array(
				'val'  => '',
				'desc' => esc_html__( 'Use Default', 'absolute-weaver' ),
			),
			array(
				'val'  => 'right',
				'desc' => esc_html__( 'Sidebars on Right', 'absolute-weaver' ),
			),
			array(
				'val'  => 'right-top',
				'desc' => esc_html__( 'Sidebars on Right (stack top)', 'absolute-weaver' ),
			),
			array(
				'val'  => 'left',
				'desc' => esc_html__( 'Sidebars on Left', 'absolute-weaver' ),
			),
			array(
				'val'  => 'left-top',
				'desc' => esc_html__( 'Sidebars on Left (stack top)', 'absolute-weaver' ),
			),
			array(
				'val'  => 'split',
				'desc' => esc_html__( 'Split - Sidebars on Right and Left', 'absolute-weaver' ),
			),
			array(
				'val'  => 'split-top',
				'desc' => esc_html__( 'Split (stack top)', 'absolute-weaver' ),
			),
			array(
				'val'  => 'one-column',
				'desc' => esc_html__( 'No sidebars, content only', 'absolute-weaver' ),
			),
		),
	);
	absolute_weaver_pp_pp_select_id( $opts );
}

//--


function absolute_weaver_pp_pp_select_id( $value ) {
	global $post;

	if ( isset( $value['name'] ) && $value['name'] != '' ) {
		echo "\n" . esc_html( $value['name'] ) . "&nbsp;&nbsp;&nbsp;\n";
	}

	echo "\n<select name=\"" . esc_attr( $value['id'] ) . '" id="' . esc_attr( $value['id'] ) . "\">\n";

	foreach ( $value['value'] as $option ) {
		if ( $option['val'] == '' ) {
			echo '<option value="">';
		} else {
			echo ' <option value="' . esc_attr( $option['val'] ) . '"';
			selected( absolute_weaver_pp_isp_true( get_post_meta( $post->ID, $value['id'], true ) == $option['val'] ) );
			echo '>';
		}
		echo esc_html( $option['desc'] ) . "</option>\n";
	}
	echo '</select>&nbsp;' . esc_html( $value['info'] ) . "\n";
}

//--


function absolute_weaver_pp_pwp_type() {
	$opts = array(
		'name'  => esc_html__( 'Display posts as:', 'absolute-weaver' ),
		'id'    => '_pp_wvrx_pwp_type',
		'info'  => esc_html__( 'How to display posts on this Page with Posts (Default: global Full Post/Excerpt setting)', 'absolute-weaver' ),
		'value' => array(
			array(
				'val'  => '',
				'desc' => '&nbsp;',
			),
			array(
				'val'  => 'full',
				'desc' => esc_html__( 'Full post', 'absolute-weaver' ),
			),
			array(
				'val'  => 'excerpt',
				'desc' => esc_html__( 'Excerpt', 'absolute-weaver' ),
			),
			array(
				'val'  => 'title',
				'desc' => esc_html__( 'Title only', 'absolute-weaver' ),
			),
			array(
				'val'  => 'title_featured',
				'desc' => esc_html__( 'Title + Featured Image', 'absolute-weaver' ),
			),
		),
	);
	absolute_weaver_pp_pp_select_id( $opts );
}


//================================================================ Per Post Options ========================================================


function absolute_weaver_pp_post_extras() {

	$opts = absolute_weaver_get_theme_settings(); // need to fetch Absolute Weaver options

	if ( ! ( current_user_can( 'edit_themes' )
	         || ( current_user_can( 'edit_theme_options' ) && ! isset( $opts['_hide_mu_admin_per'] ) )  // multi-site regular admin
	         || ( current_user_can( 'edit_pages' ) && ! isset( $opts['_hide_editor_per'] ) )    // Editor
	         || ( current_user_can( 'edit_posts' ) && ! isset( $opts['_hide_author_per'] ) ) ) // Author/Contributor
	) {
		echo '<p>' . esc_html__( 'Absolute Weaver Per Post Options not available for your User Role.', 'absolute-weaver' ) . '</p>';

		return; // don't show per post panel
	}
	?>
	<div style="line-height:150%;border: 1px solid #888;list-style-type: none;">
		<p>
			<?php
			absolute_weaver_check_editor_style();       // see if we need an update...

			echo '<strong>' . esc_html__( 'Per Post Options', 'absolute-weaver' ) . '</strong>';
			absolute_weaver_help_link( 'help.html#PerPage', esc_html__( 'Help for Per Post Options', 'absolute-weaver' ) );
			echo '<span style="float:right;">( ' . esc_html__( 'This Post\'s ID: ', 'absolute-weaver' );
			the_ID();
			echo ' )</span>';
			absolute_weaver_html_br();
			esc_html_e( 'These settings let you control display of this individual post. These options override global options set on the Absolute Weaver options.', 'absolute-weaver' );
			absolute_weaver_html_br();

			absolute_weaver_show_post_tabs();
			?>

			<input type='hidden' id='post_meta' name='post_meta' value='post_meta'/>
		<div style="clear:both;"></div>
	</div>
	<?php
}

function absolute_weaver_show_post_tabs() {
	?>
	<div id="tabwrap-per-post" style="padding-left:4px;">
		<div id="tab-container-post" style="border:1px solid #888;padding: 2px 1% 2px 1%; width:97.9%;" class='yetiisub'>
			<ul id="tab-container-post-nav" style="border-bottom:2px solid #999;" class='yetiisub'>
				<?php
				absolute_weaver_pp_elink( '#pp-post-blog', esc_html__( 'Per Post options when displayed in blog or archive.', 'absolute-weaver' ), esc_html__( 'Post Blog/Archive Options', 'absolute-weaver' ), '<li>', '</li>' );
				absolute_weaver_pp_elink( '#pp-post-single', esc_html__( 'Per Post options for single page view.', 'absolute-weaver' ), esc_html__( 'Post Single Page Options', 'absolute-weaver' ), '<li>', '</li>' );
				?>
			</ul>

			<div id="pp-post-blog" class="tab_mainopt">  <!-- ******************* blog/archive ********************* -->
				<?php
				absolute_weaver_post_blog_opts();
				?>
			</div>                                            <!-- ******************* /blog-archive ********************* -->

			<div id="pp-post-single" class="tab_mainopt">        <!-- ******************* single page ********************* -->
				<?php
				absolute_weaver_post_single_opts();
				?>
			</div>                                            <!-- ******************* /single page ********************* -->


		</div> <!-- #tab-container-post -->
	</div>    <!-- #tabwrap-per-post -->


	<script type="text/javascript">
		var tabberMainOpts = new Yetii({
			id: 'tab-container-post',
			tabclass: 'tab_mainopt',
			persist: true
		});
	</script>
	<?php
}


function absolute_weaver_post_blog_opts() {
	?>
	<strong><?php esc_html_e( 'Per Post Options when displayed on Blog or Archive-like view', 'absolute-weaver' ); ?></strong><br/>

	<strong><p>
		<?php esc_html_e( 'Post Blog/Archive View: Featured Image', 'absolute-weaver' ); ?></strong></p>
	<?php
	$opts3 = array(
		'id'    => '_pp_post_fi_location',
		'info'  => __( "Override <em>Post</em> setting for where to display FI ( for both excerpt and full content ). Don't forget Single view, too.", 'absolute-weaver' ),
		'value' => array(
			array(
				'val'  => '',
				'desc' => esc_html__( 'Default Blog FI', 'absolute-weaver' ),
			),
			array(
				'val'  => 'content-top',
				'desc' => esc_html__( 'With Content - top', 'absolute-weaver' ),
			),
			array(
				'val'  => 'content-bottom',
				'desc' => esc_html__( 'With Content - bottom', 'absolute-weaver' ),
			),
			array(
				'val'  => 'title-before',
				'desc' => esc_html__( 'With Title', 'absolute-weaver' ),
			),
			array(
				'val'  => 'title-banner',
				'desc' => esc_html__( 'Banner above Title', 'absolute-weaver' ),
			),
			array(
				'val'  => 'header-image',
				'desc' => esc_html__( 'Header Image Replacement', 'absolute-weaver' ),
			),
			array(
				'val'  => 'post-before',
				'desc' => esc_html__( 'Beside Post, no wrap', 'absolute-weaver' ),
			),
			array(
				'val'  => 'post-bg',
				'desc' => esc_html__( 'As BG Image, Tile', 'absolute-weaver' ),
			),
			array(
				'val'  => 'post-bg-cover',
				'desc' => esc_html__( 'As BG Image, Cover', 'absolute-weaver' ),
			),
			array(
				'val'  => 'post-bg-parallax',
				'desc' => esc_html__( 'As BG Image, Parallax', 'absolute-weaver' ),
			),
			array(
				'val'  => 'post-bg-parallax-full',
				'desc' => esc_html__( 'As BG Image, Parallax Full', 'absolute-weaver' ),
			),
			array(
				'val'  => 'hide',
				'desc' => esc_html__( 'Hide FI for this Post', 'absolute-weaver' ),
			),
		),
	);
	absolute_weaver_pp_pp_select_id( $opts3 );

	absolute_weaver_html_br( 2 );
	absolute_weaver_pp_page_title( esc_html__( 'Post Title', 'absolute-weaver' ), 80, 1 );
	absolute_weaver_pp_page_checkbox( '_pp_hide_post_title', esc_html__( 'Hide post title (all views)', 'absolute-weaver' ), 40, 2 );

	echo '<div style="clear:both;" ></div>';

}

function absolute_weaver_post_single_opts() {
	global $post;
	?>
	<strong><?php esc_html_e( 'Single Page View: Sidebars', 'absolute-weaver' ); ?></strong><br/><br/>

	<?php
	absolute_weaver_pp_page_layout( 'post' );
	?>
	</p>
	<p><strong><?php esc_html_e( 'Single Page View: Featured Image', 'absolute-weaver' ); ?></strong></p>
	<?php
	$opts3 = array(
		'id'    => '_pp_fi_location',
		'info'  => __( "Override <em>Single Page</em> setting for where to display FI. Don't forget blog view, too.", 'absolute-weaver' ),
		'value' => array(
			array(
				'val'  => '',
				'desc' => esc_html__( 'Default Blog FI', 'absolute-weaver' ),
			),
			array(
				'val'  => 'content-top',
				'desc' => esc_html__( 'With Content - top', 'absolute-weaver' ),
			),
			array(
				'val'  => 'content-bottom',
				'desc' => esc_html__( 'With Content - bottom', 'absolute-weaver' ),
			),
			array(
				'val'  => 'title-before',
				'desc' => esc_html__( 'With Title', 'absolute-weaver' ),
			),
			array(
				'val'  => 'title-banner',
				'desc' => esc_html__( 'Banner above Title', 'absolute-weaver' ),
			),
			array(
				'val'  => 'header-image',
				'desc' => esc_html__( 'Header Image Replacement', 'absolute-weaver' ),
			),
			array(
				'val'  => 'post-before',
				'desc' => esc_html__( 'Beside Page, no wrap', 'absolute-weaver' ),
			),
			array(
				'val'  => 'post-bg',
				'desc' => esc_html__( 'As BG Image, Tile', 'absolute-weaver' ),
			),
			array(
				'val'  => 'post-bg-cover',
				'desc' => esc_html__( 'As BG Image, Cover', 'absolute-weaver' ),
			),
			array(
				'val'  => 'post-bg-parallax',
				'desc' => esc_html__( 'As BG Image, Parallax', 'absolute-weaver' ),
			),
			array(
				'val'  => 'post-bg-parallax-full',
				'desc' => esc_html__( 'As BG Image, Parallax Full', 'absolute-weaver' ),
			),
			array(
				'val'  => 'hide',
				'desc' => esc_html__( 'Hide FI for this Post', 'absolute-weaver' ),
			),
		),
	);
	absolute_weaver_pp_pp_select_id( $opts3 );

	do_action( 'absolute_weaver_ts_pp_fi_link', $post->ID );

	echo '<div style="clear:both;"></div>';
}


function absolute_weaver_pp_simple_checkbox( $opt, $msg ) {
	global $post;
	?>
	<label><input type="checkbox" id="<?php echo esc_attr( $opt ); ?>" name="<?php echo esc_attr( $opt ); ?>"
			<?php
			checked( absolute_weaver_pp_isp_true( get_post_meta( $post->ID, $opt, true ) ) ); ?> /><?php echo esc_html( $msg ); ?>
	</label>
	<?php
}

function absolute_weaver_pp_page_checkbox( $opt, $msg, $width = 33, $br = 0 ) {
	if ( $width != 'auto' ) {
		$width = "{$width}%";
	}
	?>
	<div style="float:left;width:<?php echo esc_attr( $width ); ?>">
		<?php
		absolute_weaver_pp_simple_checkbox( $opt, $msg ); ?>
	</div>'
	<?php
	for ( $i = 0; $i < $br; $i ++ ) {
		echo '<br class="page_checkbox" style="clear:both;" />';
	}
}

function absolute_weaver_pp_page_title( $msg, $width = 33, $br = 0 ) {
	if ( $width != 'auto' ) {
		$width = "{$width}%";
	}
	?>
	<div style="float:left;font-weight:bold;font-style:italic;width:<?php echo esc_attr( $width ); ?>">
		<?php
		echo esc_html( $msg ); ?>
	</div>
	<?php
	for ( $i = 0; $i < $br; $i ++ ) {
		echo '<br class="page_checkbox" style="clear:both;" />';
	}
}


function absolute_weaver_pp_save_post_fields_action( $post_id ) {

	// some of these options will be fully implemented in the Absolute Weaver Plus plugin

	$default_post_fields = array(
		'_pp_category',
		'_pp_tag',
		'_pp_onepost',
		'_pp_orderby',
		'_pp_sort_order',
		'_pp_author',
		'_pp_posts_per_page',
		'_pp_post_type',
		'_pp_hide_sticky',
		'_pp_fi_link',
		'_pp_fi_location',
		'_pp_post_fi_location',
		'_pp_post_styles',
		'_pp_hide_page_title',
		'_pp_hide_post_title',
		'_pp_hide_infotop',
		'_pp_hide_infobottom',
		'_pp_page_layout',
		'_pp_wvrx_pwp_type',
		'_pp_wvrx_pwp_cols',
		'_pp_hide_n_posts',
		'_pp_fullposts',
		'_pp_container_full',
		'_pp_header_html',
		'_pp_footer_html',
		'_pp_elementor_header_replacement',
		'_pp_elementor_footer_replacement',
		'_pp_siteorigin_header_replacement',
		'_pp_elementor_footer_replacement',
		'_pp_pb_header_hide_menus',
		'_pp_pb_header_replace_page_id',
		'_pp_pb_footer_replace_page_id',
	);

	$all_post_fields = $default_post_fields;

	// A significant portion of the per page/post options can have html.
	// Rather than use esc_html on some, and wp_kses_post on others,
	// we just use wp_kses_post on them all - the results are the same.

	if ( isset( $_POST['post_meta'] ) ) {
		foreach ( $all_post_fields as $post_field ) {
			if ( isset( $_POST[ $post_field ] ) ) {
				$data = sanitize_text_field( wp_unslash( $_POST[ $post_field ] ) );
				if ( $post_field != '_pp_post_styles' ) {
					$data = stripslashes( $data );        // passed via post, so strip slashes
				}

				if ( get_post_meta( $post_id, $post_field ) == '' ) {
					add_post_meta( $post_id, $post_field, wp_kses_post( $data ), true );
				} elseif ( $data != get_post_meta( $post_id, $post_field, true ) ) {
					update_post_meta( $post_id, $post_field, wp_kses_post( $data ) );
				} elseif ( $data == '' ) {
					delete_post_meta( $post_id, $post_field, get_post_meta( $post_id, $post_field, true ) );
				}
			} else {
				delete_post_meta( $post_id, $post_field, get_post_meta( $post_id, $post_field, true ) );
			}
		}
	}
}


function absolute_weaver_html_br( $count = 1 ) {
	for ( $i = 0; $i < $count; $i ++ ) {
		echo ' <br /> ';
	}
}
	add_action( 'save_post', 'absolute_weaver_pp_save_post_fields_action' );
	add_action( 'publish_post', 'absolute_weaver_pp_save_post_fields_action' );

