<?php
/**
 * Display per page and per post options.
 *
 * @since 12/10/14
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}
// Admin panel that gets added to the page edit page for per page options


add_action( 'admin_menu', 'absolute_weaver_pp_add_page_fields_action', 11 );  // allow X-Plus to override us
/**
 * Add per page and per post meta_boxes
 *
 */
function absolute_weaver_pp_add_page_fields_action() {

	$per_post_label = defined( 'ABSOLUTE_WEAVER_XPLUS_VERSION' ) ? esc_html__( ' (with Absolute Weaver Plus Options)', 'absolute-weaver' ) : '';
	add_meta_box(
		'page-box',
		esc_html__( 'Absolute Weaver Options For This Page', 'absolute-weaver' ) . $per_post_label,
		'absolute_weaver_pp_page_extras_load',
		'page',
		'normal',
		'high'
	);

	add_meta_box( 'post-box', esc_html__( 'Absolute Weaver  Options For This Post', 'absolute-weaver' ) . $per_post_label, 'absolute_weaver_pp_post_extras_load', 'post', 'normal', 'high' );

	$i = 1;
	$args = array(
		'public'   => true,
		'_builtin' => false,
	);
	$post_types = get_post_types( $args, 'names', 'and' );
	foreach ( $post_types as $post_type ) {
		add_meta_box(
			'post-box' . $i,
			esc_html__( 'Absolute Weaver Options For This Post Type', 'absolute-weaver' ) . $per_post_label,
			'absolute_weaver_pp_post_extras_pt',
			$post_type,
			'normal',
			'high'
		);
		$i++;
	}

	require_once( get_template_directory() . ABSOLUTE_WEAVER_ADMIN_DIR . '/admin-core/admin-page-posts-meta-boxes.php' ); // per page-posts admin - optimize: needs to be here. ( Not a template file )
}

function absolute_weaver_pp_page_extras_load() {
	absolute_weaver_pp_page_extras();
}

function absolute_weaver_pp_post_extras_load() {
	absolute_weaver_pp_post_extras();
}

function absolute_weaver_pp_post_extras_pt() {
	// special handling for non-Weaver Custom Post Types
	$opts = absolute_weaver_get_theme_settings();
	if ( ( isset( $opts['_show_per_post_all'] ) && $opts['_show_per_post_all'] ) || function_exists( 'atw_slider_plugins_loaded' ) ) {
		absolute_weaver_pp_post_extras();
	} else {
		echo '<p>' . esc_html__( 'You can enable Absolute Weaver Per Post Options for Custom Post Types on the Absolute Weaver:Advanced Options:Admin Options tab.', 'absolute-weaver' ) . '</p>';
	}
}

add_action( 'admin_enqueue_scripts', 'absolute_weaver_pp_enqueue_admin_scripts_action' );

function absolute_weaver_pp_enqueue_admin_scripts_action( $hook ) {

	if ( $hook != 'appearance_page_AbsoluteWeaver' && $hook != 'post.php' && $hook != 'post-new.php' ) {     // only load script if on my admin page or page/post editor
		return;
	}

	wp_enqueue_script( 'yetii', get_template_directory_uri() . '/inc/admin/admin-core/assets/js/yetii/yetii.js', false, ABSOLUTE_WEAVER_VERSION );
	wp_enqueue_style( 'yetii-weaver-css', get_template_directory_uri() . '/inc/admin/admin-core/assets/js/yetii/yetii-weaver' . ABSOLUTE_WEAVER_MINIFY . '.css', false, ABSOLUTE_WEAVER_VERSION );
}
