<?php

add_action( 'absolute_weaver_enqueue_load_scripts', 'absolute_weaver_enqueue_load_scripts_action' );

function absolute_weaver_enqueue_load_scripts_action() {
	// Save/Restore scripts
	Absolute_Weaver_Load_WA_Subtheme::enqueue_scripts();
	Absolute_Weaver_Save_WV_Settings::enqueue_scripts();
	Absolute_Weaver_Restore_WV_Settings::enqueue_scripts();
}

if ( ! has_action( 'absolute_weaver_ts_load_save' ) ) {

	if ( class_exists( 'WP_Customize_Control' ) && ! class_exists( 'Absolute_Weaver_Save_WV_Settings' ) ) {
		/**
		 * Class Absolute_Weaver_Save_Settings
		 *
		 * Save Absolute Weaver Settings
		 *
		 */
		class Absolute_Weaver_Save_WV_Settings extends WP_Customize_Control {

			public $description = '';

			public function render_content() {

				$a_pro = ( absolute_weaver_cz_is_plus() ) ? '-plus' : '';
				echo '<h3 style="color:green;">' . esc_html__( 'Absolute Weaver Theme Support Plugin required for Save/Restore', 'absolute-weaver' ) . '</h3>';

				echo '<h4>' . wp_kses_post( absolute_weaver_markdown( __( 'Please install the free *Absolute Weaver Theme Support Plugin* from the WordPress Plugin repository to enable saving and restoring your theme settings to your own computer.
 This will allow you to save different versions of your designs, or transfer them to other sites.', 'absolute-weaver' ) ) ) . '</h4>';


				echo '<span class="customize-control-title" style="color:blue;font-size:110%;">' . esc_html( $this->label ) . '</span>';
			}

			static public function process_save( $wp_customize ) {

			}

			static private function _absolute_weaver_filter_strip_default( $var ) {
				if ( ! is_string( $var ) ) {
					return true;
				}

				return strlen( $var ) && $var != 'default';
			}


			static private function _save_settings( $wp_customize, $ext ) {

				// Note: a $_REQUEST based nonce has been verified before this function called
			}


			static public function enqueue_scripts() {
				// Register
				// no-op
			}

		}
	}


	if ( class_exists( 'WP_Customize_Control' ) && ! class_exists( 'Absolute_Weaver_Restore_WV_Settings' ) ) {

		class Absolute_Weaver_Restore_WV_Settings extends WP_Customize_Control {

			public $description = '';
			static private $wvrx_error = '';

			/**
			 */
			public function render_content() {

				echo '<span class="customize-control-title" style="color:blue;font-size:110%;">' . esc_html( $this->label ) . '</span>';

			}

			static public function process_restore( $wp_customize ) {

			}

			static private function _restore( $wp_customize ) {

			}

			static public function reset_options( $contents, $ext ) {

				return true;
			}


			static public function enqueue_scripts() {

			}

			static public function controls_print_scripts() {
				if ( self::$wvrx_error ) {
					echo '<script> alert( "' . esc_html( self::$wvrx_error ) . '" ); </script>';
				}
			}
		}
	}
} else {  // there is a plugin
	//
	do_action( 'absolute_weaver_ts_load_save',
		array( ABSOLUTE_WEAVER_VERSION ) );

}

if ( class_exists( 'WP_Customize_Control' ) && ! class_exists( 'Absolute_Weaver_Load_WA_Subtheme' ) ) {

	class Absolute_Weaver_Load_WA_Subtheme extends WP_Customize_Control {

		public $description = '';
		static private $wvrx_error = '';

		/**
		 */
		public function render_content() {

			$cur_theme = absolute_weaver_getopt( 'theme_filename' );

			echo '<span class="customize-control-title">' . esc_html( $this->label ) . '</span>';
			if ( '' !== $this->description ) {
				echo '<span class="description customize-control-description">' . esc_html( $this->description ) . '</span>';
			}

			$theme_list = array(
				'absolutely',
				'ajax',
				'arctic-white',
				'black-and-white',
				'blank',
				'cosmic-latte',
				'full-width-dark',
				'go-basic-traditional',
				'go-basic-full',
				'go-basic-stretched',
				'go-blue',
				'go-green',
				'kitchen-sink',
				'magazine',
				'pioneer',
				'plain-full-width',
				'raw',
				'transparent-dark',
				'transparent-light',
			);

			?>
			<div class="wvrx-settings-load-subtheme">
			<input class="button-primary" type="button" name="wvrx_select_subtheme" value="<?php esc_attr_e( 'Set to Selected Subtheme', 'absolute-weaver' ); ?>"/>
			<p class="description customize-control-description">
				<?php echo wp_kses_data( absolute_weaver_markdown( __( '**Click "Set to Selected Subtheme" to pick new selected subtheme.** Selecting a subtheme will *reset* all existing theme settings. Site settings (&diams;) will not be changed.', 'absolute-weaver' ) ) ); ?>
			</p>
			<?php
			$thumbs = absolute_weaver_relative_url( '/assets/subthemes/' );

			foreach ( $theme_list as $addon ) {
			$name = ucwords( str_replace( '-', ' ', $addon ) );
			?>
			<div style="float:left; width:48%;margin-right:2%;font-size:80%;">
				<label><input type="radio" name="subtheme_picked"
				<?php echo 'value="' . esc_attr( $addon ) . '" ' . ( $cur_theme == $addon ? 'checked' : '' ) . ' /><strong>' . esc_html( $name ) . '</strong><br />';
				if ( ! absolute_weaver_getopt( '_hide_theme_thumbs' ) ) {
					echo '<img style="border: 1px solid gray; margin: 5px 0px 7px 0px;" src="' . esc_url( $thumbs . $addon . '.jpg' ) . '" alt="' . esc_attr__( 'thumbnail image', 'absolute-weaver' ) . '" /></label></div>' . "\n";
				} else {
					echo "</label></div>\n";
				}
				}

				wp_nonce_field( 'wvrx_select_subtheme', 'wvrx-upload-subtheme' ); ?>
			</div>
			<div class="wvrx-uploading"><?php esc_html_e( 'Uploading...', 'absolute-weaver' ); ?></div>
			<input type="button" class="button-primary" name="wvrx_select_subtheme" value="<?php esc_attr_e( 'Set to Selected Subtheme', 'absolute-weaver' ); ?>"/>

			<p style="font-weight:bold;">
				<?php esc_html_e( 'Please remember: these subthemes are only starting points!
You can use the Customizer to change virtually any part of these subthemes.
You can change colors, sidebar layouts, font family and sizes, borders, spacing - really, everything.', 'absolute-weaver' );
				?>
			</p>
			<?php

		}

		static public function process_load_theme( $wp_customize ) {
			if ( current_user_can( 'edit_theme_options' ) ) {
				if ( isset( $_REQUEST['wvrx-upload-subtheme'] ) ) {
					self::_load_theme( $wp_customize );
				}

			}
		}

		static private function _load_theme( $wp_customize ) {
			// Make sure we have a valid nonce.
			if ( ! isset( $_REQUEST['wvrx-upload-subtheme'] ) || ! wp_verify_nonce( $_REQUEST['wvrx-upload-subtheme'], 'wvrx_select_subtheme' ) ) {
				unset( $_POST['wvrx-upload-subtheme'] );
				unset( $_REQUEST['wvrx-upload-subtheme'] );
				absolute_weaver_alert( esc_html__( 'Invalid security token for upload.', 'absolute-weaver' ) );

				return false;
			}
			unset( $_POST['wvrx-upload-subtheme'] );
			unset( $_REQUEST['wvrx-upload-subtheme'] );
			if ( ! isset( $_POST['subtheme_picked'] ) ) {

				absolute_weaver_alert( esc_html__( 'Please select a subtheme to upload.', 'absolute-weaver' ) );

				return false;
			}
			$theme = sanitize_key( $_POST['subtheme_picked'] );

			$filename = get_template_directory() . '/assets/subthemes/' . $theme . '.json';

			if ( ! absolute_weaver_f_exists( $filename ) ) {
				absolute_weaver_alert( esc_html__( 'Sorry, unable to upload the subtheme.', 'absolute-weaver' ) );

				return false;
			}
			$contents = implode( '', file( $filename ) );    // works if no newlines in the file...

			if ( empty( $contents ) ) {
				return false;
			}

			if ( ! self::reset_options( $contents, $theme ) ) {
				return false;
			}
			return true;
		}

		static public function reset_options( $contents, $theme ) {

			$opts = json_decode( $contents, true );

			if ( empty( $opts ) ) {
				print_r( $contents );
				self::$wvrx_error = esc_html__( "Loading of theme settings file failed", 'absolute-weaver' );
				absolute_weaver_alert( self::$wvrx_error );

				return false;
			}

			$version = absolute_weaver_getopt( 'absolute_weaver_version_id' );    // get something to force load of existing settings
			$new_opts = array();

			global $absolute_weaver_opts_cache;

			// need to clear some settings
			// first, pickup the per-site settings that aren't theme related...

			// Before anything else, restore WP CSS settings

			if ( isset( $opts['wp_css'] ) ) {
				wp_update_custom_css_post( $opts['wp_css'] );   // replace with saved version
				unset ( $opts['wp_css'] );
			} else {
				wp_update_custom_css_post( '' );   // wipe previous settings from other subtheme
			}


			foreach ( $absolute_weaver_opts_cache as $key => $val ) {
				if ( isset( $key[0] ) && $key[0] == '_' )    // these are non-theme specific settings
				{
					$new_opts[ $key ] = $val;
				}    // keep
			}

			foreach ( $opts as $key => $val ) {             // now, add theme settings from loaded settings
				if ( isset( $key[0] ) && $key[0] != '_' ) {
					$new_opts[ $key ] = $val;
				}    // and add rest from restore
			}

			$new_opts['style_date'] = date( 'Y-m-d-H:i:s' );
			$new_opts['theme_filename'] = $theme;

			remove_theme_mod( 'absolute_weaver_settings' );

			set_theme_mod( 'absolute_weaver_settings', $new_opts );

			$absolute_weaver_opts_cache = $new_opts;               // and this loads the new settings into our cache

			absolute_weaver_save_generated_style();

			do_action( 'absolute_weaver_save_mcecss' );        // theme support plugin saved editor css in file
			do_action( 'absolute_weaver_save_gutenberg_css' );
			do_action( 'absolute_weaver_update_additional_css' );

			return true;
		}


		static public function enqueue_scripts() {
			// Register
			wp_register_style( 'wvrx-ldth-css', get_template_directory_uri() . '/inc/admin/customizer/load-subthemes/load-subthemes' . ABSOLUTE_WEAVER_MINIFY . '.css', array(), ABSOLUTE_WEAVER_VERSION );
			wp_register_script( 'wvrx-ldth-js', get_template_directory_uri() . '/inc/admin/customizer/load-subthemes/load-subthemes' . ABSOLUTE_WEAVER_MINIFY . '.js', array( 'jquery' ), ABSOLUTE_WEAVER_VERSION, true );

			// Localize
			wp_localize_script( 'wvrx-ldth-js', 'WVRXl10n', array(
				'emptyImport' => esc_html__( 'Please choose a file to import.', 'absolute-weaver' ),
			) );

			// Config
			wp_localize_script( 'wvrx-ldth-js', 'WVRXConfig', array(
				'customizerURL' => admin_url( 'customize.php' ),
				'exportNonce'   => wp_create_nonce( 'wvrx-settings-saving' ),
			) );

			// Enqueue
			wp_enqueue_style( 'wvrx-ldth-css' );
			wp_enqueue_script( 'wvrx-ldth-js' );
		}

		static public function controls_print_scripts() {

			if ( self::$wvrx_error ) {
				echo '<script> alert( "' . esc_html( self::$wvrx_error ) . '" ); </script>';
			}
		}
	}
}

