<?php

/**
 * Define the sections and settings for the Site Colors panel
 * Customize_Alpha_Color_Control
 * WP_Customize_Color_Control
 */


function absolute_weaver_customizer_define_colorscheme_sections() {
	$panel = 'absolute_weaver_colors';
	$colorscheme_sections = array();

	/**
	 * General
	 */
	$colorscheme_sections['color-wrapping'] = array(
		'panel'       => $panel,
		'title'       => __( 'Wrapping Areas', 'absolute-weaver' ),
		'description' => 'Set colors. Use Typography to set fonts.',
		'options'     => absolute_weaver_controls_colors_wrapping(),
	);


	/**
	 * Links
	 */
	$colorscheme_sections['color-links'] = array(
		'panel'       => $panel,
		'title'       => __( 'Links', 'absolute-weaver' ),
		'description' => 'Set colors for links. Use Typography to set fonts.',
		'options'     => absolute_weaver_controls_colors_links(),
	);

	/**
	 * Site Header
	 */
	$colorscheme_sections['color-header'] = array(
		'panel'   => $panel,
		'title'   => __( 'Header Area', 'absolute-weaver' ),
		'options' => absolute_weaver_controls_colors_header(),
	);


	/**
	 * Main Menu
	 */

	define( 'ABSOLUTE_WEAVER_MENU_UPDATE', 'refresh' );

	$colorscheme_sections['color-menus'] = array(
		'panel'       => $panel,
		'title'       => __( 'Menus', 'absolute-weaver' ),
		'description' => __( 'Set text, background, and hover colors for menus.', 'absolute-weaver' ),
		'options'     => absolute_weaver_controls_colors_menus(),
	);


	/**
	 * Info Bar
	 */
	$colorscheme_sections['color-info-bar'] = array(
		'panel'       => $panel,
		'title'       => __( 'Info Bar', 'absolute-weaver' ),
		'description' => __( 'Info Bar has breadcrumbs and paged navigation displayed under Primary Menu.', 'absolute-weaver' ),
		'options'     => absolute_weaver_controls_colors_infobar(),
	);

	/**
	 * Content
	 */
	$colorscheme_sections['color-content'] = array(
		'panel'       => $panel,
		'title'       => __( 'Content', 'absolute-weaver' ),
		'description' => __( 'Colors for general page and post content. You can override post specific colors on the "Post Specific Colors" panel.', 'absolute-weaver' ),
		'options'     => absolute_weaver_controls_colors_content(),
	);

	/**
	 * Post Specific
	 */
	$colorscheme_sections['color-post-specific'] = array(
		'panel'       => $panel,
		'title'       => __( 'Post Specific', 'absolute-weaver' ),
		'description' => __( 'Post Specific Colors - override Content colors.', 'absolute-weaver' ),
		'options'     => absolute_weaver_controls_colors_postspecific(),
	);


	/**
	 * Sidebars
	 */
	$colorscheme_sections['color-sidebars'] = array(
		'panel'       => $panel,
		'title'       => __( 'Sidebars', 'absolute-weaver' ),
		'description' => __( 'Colors for Primary and Secondary Sidebars.', 'absolute-weaver' ),
		'options'     => absolute_weaver_controls_colors_sidebars(),
	);

	/**
	 * Widgets
	 */
	$colorscheme_sections['color-widgets'] = array(
		'panel'       => $panel,
		'title'       => __( 'Individual Widgets', 'absolute-weaver' ),
		'description' => 'Properties for individual widgets (e.g., Text, Recent Posts, etc.)',
		'options'     => absolute_weaver_controls_colors_widgets(),
	);


	/**
	 * Footer
	 */
	$colorscheme_sections['color-footer'] = array(
		'panel'   => $panel,
		'title'   => __( 'Footer Area', 'absolute-weaver' ),
		'options' => absolute_weaver_controls_colors_footer(),
	);


	return $colorscheme_sections;
}

// define controls for sections

function absolute_weaver_controls_colors_wrapping() {
	$opts = array();

	$opts['body_bgcolor'] = absolute_weaver_cz_color(
		'body_bgcolor',
		__( 'Site Background Color', 'absolute-weaver' ),
		__( 'Background color for &lt;body&gt;, wraps entire page.', 'absolute-weaver' ) );

	$opts['wrapper_color'] = absolute_weaver_cz_color(
		'wrapper_color',
		__( 'Wrapper Text Color', 'absolute-weaver' ),
		absolute_weaver_markdown( __( '**Global Text Color** - You can override other text colors for individual areas and items below.', 'absolute-weaver' ) ) );

	$opts['wrapper_bgcolor'] = absolute_weaver_cz_color(
		'wrapper_bgcolor',
		__( 'Wrapper BG Color', 'absolute-weaver' ),
		absolute_weaver_markdown( __( '**Background Color** - wraps entire content area. To override, set BG colors for individual areas.', 'absolute-weaver' ) ) );

	$opts['container_color'] = absolute_weaver_cz_color(
		'container_color',
		__( 'Container Text Color', 'absolute-weaver' ),
		__( 'Container ( #container div ) wraps content and sidebars.', 'absolute-weaver' ) );

	$opts['container_bgcolor'] = absolute_weaver_cz_color(
		'container_bgcolor',
		__( 'Container BG Color', 'absolute-weaver' ) );

	$opts['color-border-heading'] = absolute_weaver_cz_line();

	$opts['color-border-headingbc'] = absolute_weaver_cz_heading( __( 'Border Color', 'absolute-weaver' ),
		__( 'Border Color option found on *Style &rarr; Wrapping Areas* panel.', 'absolute-weaver' ) );

	return $opts;
}

function absolute_weaver_controls_colors_links() {
	$opts = array();

	$opts['link_color'] = absolute_weaver_cz_color(
		'link_color',
		__( 'Standard Links', 'absolute-weaver' ),
		__( 'Sitewide default color for links. To override for links in specific areas, set colors for individual links below.', 'absolute-weaver' ), 'refresh' );

	$opts['link_hover_color'] = absolute_weaver_cz_color(
		'link_hover_color',
		__( 'Standard Link Hover Color', 'absolute-weaver' ),
		'', 'refresh' );

	// info bar
	$opts['color-info-line-1'] = absolute_weaver_cz_line();

	$opts['ibarlink_color'] = absolute_weaver_cz_color(
		'ibarlink_color',
		__( 'Info Bar Link Color', 'absolute-weaver' ),
		'', 'refresh' );

	$opts['ibarlink_hover_color'] = absolute_weaver_cz_color(
		'ibarlink_hover_color',
		__( 'Info Bar Link Hover Color', 'absolute-weaver' ),
		'', 'refresh' );

	$opts['color-info-line-2'] = absolute_weaver_cz_line();

	// content

	$opts['contentlink_color'] = absolute_weaver_cz_color(
		'contentlink_color',
		__( 'Content Links Color', 'absolute-weaver' ),
		'', 'refresh' );

	$opts['contentlink_hover_color'] = absolute_weaver_cz_color(
		'contentlink_hover_color',
		__( 'Content Links Hover Color', 'absolute-weaver' ),
		'', 'refresh' );

	$opts['color-info-line-3'] = absolute_weaver_cz_line();

	// post meta info bar
	$opts['ilink_color'] = absolute_weaver_cz_color(
		'ilink_color',
		__( 'Post Meta Info Link Color', 'absolute-weaver' ),
		'', 'refresh' );

	$opts['ilink_hover_color'] = absolute_weaver_cz_color(
		'ilink_hover_color',
		__( 'Post Meta Info Link Hover Color', 'absolute-weaver' ),
		'', 'refresh' );

	$opts['color-info-line-4'] = absolute_weaver_cz_line();

	// individual widgets

	$opts['wlink_color'] = absolute_weaver_cz_color(
		'wlink_color',
		__( 'Individual Widgets Link Color', 'absolute-weaver' ),
		'', 'refresh' );

	$opts['wlink_hover_color'] = absolute_weaver_cz_color(
		'wlink_hover_color',
		__( 'Individual Widgets Link Hover Color', 'absolute-weaver' ),
		'', 'refresh' );

	$opts['color-info-line-5'] = absolute_weaver_cz_line();

	$opts['footerlink_color'] = absolute_weaver_cz_color(
		'footerlink_color',
		__( 'Footer Links Color', 'absolute-weaver' ),
		'', 'refresh' );

	$opts['footerlink_hover_color'] = absolute_weaver_cz_color(
		'footerlink_hover_color',
		__( 'Footer Links Hover Color', 'absolute-weaver' ),
		'', 'refresh' );


	return $opts;
}

function absolute_weaver_controls_colors_header() {
	$opts = array();

	$opts['header_color'] = absolute_weaver_cz_color(
		'header_color',
		__( 'Header Text Color', 'absolute-weaver' ),
		'' );

	$opts['header_bgcolor'] = absolute_weaver_cz_color(
		'header_bgcolor',
		__( 'Header Area BG Color', 'absolute-weaver' ),
		'The Header BG Color is used for full width BG color on header.' );

	$opts['site_title_color'] = absolute_weaver_cz_color(
		'site_title_color',
		__( 'Site Title Text Color', 'absolute-weaver' ),
		'' );

	$opts['site_title_bgcolor'] = absolute_weaver_cz_color(
		'site_title_bgcolor',
		__( 'Site Title BG Color', 'absolute-weaver' ),
		__( 'Site Title BG Color', 'absolute-weaver' ) );

	$opts['tagline_color'] = absolute_weaver_cz_color(
		'tagline_color',
		__( 'Site Tagline Text Color', 'absolute-weaver' ),
		'' );

	$opts['tagline_bgcolor'] = absolute_weaver_cz_color(
		'tagline_bgcolor',
		__( 'Site Tagline BG Color', 'absolute-weaver' ),
		'' );

	$opts['title_tagline_bgcolor'] = absolute_weaver_cz_color(
		'title_tagline_bgcolor',
		__( 'Title/Tagline Area BG', 'absolute-weaver' ),
		__( 'BG Color for the Title, Tagline, and Search area.', 'absolute-weaver' ) );

	$opts['hdrarea-cline2'] = absolute_weaver_cz_line();

	$opts['header_sb_color'] = absolute_weaver_cz_color(
		'header_sb_color',
		__( 'Header Widget Area Text Color', 'absolute-weaver' ),
		'' );

	$opts['header_sb_bgcolor'] = absolute_weaver_cz_color(
		'header_sb_bgcolor',
		__( 'Header Widget Area BG Color', 'absolute-weaver' ),
		'' );



	if ( function_exists( 'absolute_weaver_ts_installed' ) ) {

		$opts['hdrarea-cline3'] = absolute_weaver_cz_line();

		$opts['header_html_color'] = absolute_weaver_cz_color(
			'header_html_color',
			__( 'Header HTML Area Text Color', 'absolute-weaver' ) );

		$opts['header_html_bgcolor'] = absolute_weaver_cz_color(
			'header_html_bgcolor',
			__( 'Header HTML Area BG Color', 'absolute-weaver' ) );
	}


	return $opts;
}

function absolute_weaver_controls_colors_menus() {
	$opts = array();

	$opts['color-mm-heading'] = absolute_weaver_cz_group_title( __( 'Primary Menu Colors', 'absolute-weaver' ) );

	$opts['m_primary_color'] = absolute_weaver_cz_color(
		'm_primary_color',
		__( 'Primary Menu Bar Text Color', 'absolute-weaver' ),
		__( 'Text Color for Entire menu bar.', 'absolute-weaver' ), ABSOLUTE_WEAVER_MENU_UPDATE );

	$opts['m_primary_bgcolor'] = absolute_weaver_cz_color(
		'm_primary_bgcolor',
		__( 'Primary Menu Bar BG Color', 'absolute-weaver' ),
		__( 'Background Color for Entire menu bar.', 'absolute-weaver' ), ABSOLUTE_WEAVER_MENU_UPDATE );

	$opts['m_primary_link_bgcolor'] = absolute_weaver_cz_color(
		'm_primary_link_bgcolor',
		__( 'Item BG Color', 'absolute-weaver' ),
		__( 'Background Color for menu bar items.', 'absolute-weaver' ), ABSOLUTE_WEAVER_MENU_UPDATE );

	$opts['m_primary_hover_color'] = absolute_weaver_cz_color(
		'm_primary_hover_color',
		__( 'Primary Menu Bar Hover Text Color', 'absolute-weaver' ),
		'', 'refresh' );

	$opts['m_primary_hover_bgcolor'] = absolute_weaver_cz_color(
		'm_primary_hover_bgcolor',
		__( 'Primary Menu Bar Hover BG Color', 'absolute-weaver' ),
		'', 'refresh' );

	if ( function_exists( 'absolute_weaver_ts_installed' ) ) {
		$opts['m_primary_html_color'] = absolute_weaver_cz_color(
			'm_primary_html_color',
			__( 'HTML: Text Color', 'absolute-weaver' ),
			__( 'Text Color for Left/Right Menu Bar HTML.', 'absolute-weaver' ), ABSOLUTE_WEAVER_MENU_UPDATE
		);
	}

	$opts['m_primary_sub_color'] = absolute_weaver_cz_color(
		'm_primary_sub_color',
		__( 'Primary Sub-Menu Text Color', 'absolute-weaver' ),
		'', ABSOLUTE_WEAVER_MENU_UPDATE );

	$opts['m_primary_sub_bgcolor'] = absolute_weaver_cz_color(
		'm_primary_sub_bgcolor',
		__( 'Primary Sub-Menu BG Color', 'absolute-weaver' ),
		'', ABSOLUTE_WEAVER_MENU_UPDATE );

	$opts['m_primary_sub_hover_color'] = absolute_weaver_cz_color(
		'm_primary_sub_hover_color',
		__( 'Primary Sub-Menu Hover Text Color', 'absolute-weaver' ),
		'', 'refresh' );

	$opts['m_primary_sub_hover_bgcolor'] = absolute_weaver_cz_color(
		'm_primary_sub_hover_bgcolor',
		__( 'Primary Sub-Menu Hover BG Color', 'absolute-weaver' ),
		'', 'refresh' );

	$opts['m_primary_clickable_bgcolor'] = absolute_weaver_cz_color(
		'm_primary_clickable_bgcolor',
		__( 'Open Submenu Arrow BG', 'absolute-weaver' ),
		__( 'Clickable mobile open submenu arrow BG. Contrasting BG color required for proper user interface. Not used by SmartMenus. (Default: rgba( 255,255,255,0.2)', 'absolute-weaver' ), 'refresh' );

	$opts['m_primary_dividers_color'] = absolute_weaver_cz_color(
		'm_primary_dividers_color',
		__( 'Dividers between menu items', 'absolute-weaver' ),
		__( 'Add colored dividers between menu items. Leave blank for none.', 'absolute-weaver' ),
		'refresh', 'plus'
	);


	$opts['color-minim-heading'] = absolute_weaver_cz_group_title( __( 'Header Mini Menu Colors', 'absolute-weaver' ),
		__( 'You must define a Header Menu from the Custom Menus Content menu.', 'absolute-weaver' ) );

	$opts['m_header_mini_color'] = absolute_weaver_cz_color( 'm_header_mini_color',
		__( 'Header Mini Menu Text Color', 'absolute-weaver' ), '', ABSOLUTE_WEAVER_MENU_UPDATE );

	$opts['m_header_mini_bgcolor'] = absolute_weaver_cz_color( 'm_header_mini_bgcolor',
		__( 'Header Mini Menu BG Color', 'absolute-weaver' ), '', ABSOLUTE_WEAVER_MENU_UPDATE );

	$opts['m_header_mini_hover_color'] = absolute_weaver_cz_color( 'm_header_mini_hover_color',
		__( 'Header Mini Menu Hover Text Color', 'absolute-weaver' ),
		'', 'refresh' );


	$opts['color-allmenus-heading'] = absolute_weaver_cz_group_title( __( 'Colors For All Menus', 'absolute-weaver' ),
		__( 'These options specify current page attributes for all menus.', 'absolute-weaver' ) );

	$opts['menubar_curpage_color'] = absolute_weaver_cz_color( 'menubar_curpage_color',
		__( 'Menus Current Page Text Color', 'absolute-weaver' ), '', ABSOLUTE_WEAVER_MENU_UPDATE );

	$opts['menubar_curpage_bgcolor'] = absolute_weaver_cz_color( 'menubar_curpage_bgcolor',
		__( 'Menus Current Page BG Color', 'absolute-weaver' ), '', ABSOLUTE_WEAVER_MENU_UPDATE );


	$opts['m_retain_hover'] = absolute_weaver_cz_checkbox(
		__( 'Retain Menu Bar Hover BG Color', 'absolute-weaver' ),
		__( 'Retain the menu bar item hover BG color when sub-menus are opened.', 'absolute-weaver' )
	);


	return $opts;
}

function absolute_weaver_controls_colors_infobar() {
	$opts = array();

	$opts['infobar_color'] = absolute_weaver_cz_color(
		'infobar_color',
		__( 'Info Bar Text Color', 'absolute-weaver' )
	);

	$opts['infobar_bgcolor'] = absolute_weaver_cz_color(
		'infobar_bgcolor',
		__( 'Info Bar BG Color', 'absolute-weaver' )
	);

	return $opts;
}

function absolute_weaver_controls_colors_content() {
	$opts = array();


	$opts['content_color'] = absolute_weaver_cz_color(
		'content_color',
		__( 'Content Area Text Color', 'absolute-weaver' )
	);

	$opts['content_bgcolor'] = absolute_weaver_cz_color(
		'content_bgcolor',
		__( 'Content Area BG Color', 'absolute-weaver' )
	);

	$opts['page_title_color'] = absolute_weaver_cz_color(
		'page_title_color',
		__( 'Page Title Text Color', 'absolute-weaver' ),
		__( 'Page titles, including pages, post single pages, and archive-like pages.', 'absolute-weaver' )
	);

	$opts['page_title_bgcolor'] = absolute_weaver_cz_color(
		'page_title_bgcolor',
		__( 'Page Title BG Color', 'absolute-weaver' )
	);

	$opts['archive_title_color'] = absolute_weaver_cz_color(
		'archive_title_color',
		__( 'Archive Pages Title Text Color', 'absolute-weaver' ),
		__( 'Archive-like page titles: archives, categories, tags, searches.', 'absolute-weaver' )
	);

	$opts['archive_title_bgcolor'] = absolute_weaver_cz_color(
		'archive_title_bgcolor',
		__( 'Archive Pages Title BG Color', 'absolute-weaver' )
	);

	$opts['content_h_color'] = absolute_weaver_cz_color(
		'content_h_color',
		__( 'Content Headings Text Color', 'absolute-weaver' ),
		__( 'Headings ( &lt;h1&gt;-&lt;h6&gt; ) in page and post content.', 'absolute-weaver' )
	);

	$opts['content_h_bgcolor'] = absolute_weaver_cz_color(
		'content_h_bgcolor',
		__( 'Content Headings BG', 'absolute-weaver' ),
		__( 'Headings ( &lt;h1&gt;-&lt;h6&gt; ) in page and post content.', 'absolute-weaver' )
	);

	$opts['content-line1'] = absolute_weaver_cz_line();

	$opts['input_color'] = absolute_weaver_cz_color(
		'input_color',
		__( 'Text Input Areas Color', 'absolute-weaver' )
	);

	$opts['input_bgcolor'] = absolute_weaver_cz_color(
		'input_bgcolor',
		__( 'Text Input Areas BG Color', 'absolute-weaver' )
	);

	$opts['search_color'] = absolute_weaver_cz_color(
		'search_color',
		__( 'Search Input Text Color', 'absolute-weaver' )
	);

	$opts['search_bgcolor'] = absolute_weaver_cz_color(
		'search_bgcolor',
		__( 'Search Input BG Color', 'absolute-weaver' )
	);

	$opts['search_icon_msg'] = absolute_weaver_cz_heading( __( 'Search Icon Color', 'absolute-weaver' ),
		__( 'The Search Icon color is inherited from wrapping areas text color, including the header area and menu bar.', 'absolute-weaver' ) );

	$opts['content-line1a'] = absolute_weaver_cz_line();

	$opts['hr_color'] = absolute_weaver_cz_color(
		'hr_color',
		__( '&lt;HR&gt; color', 'absolute-weaver' ),
		__( 'Color of horizontal ( &lt;hr&gt; ) lines in posts and pages. Use the "Custom CSS &rarr; Content" panel to customize the style of the &lt;hr&gt;.', 'absolute-weaver' )
	);

	$opts['content-line1b'] = absolute_weaver_cz_line();

	$opts['comment_headings_color'] = absolute_weaver_cz_color(
		'comment_headings_color',
		__( 'Color for headings in comment form', 'absolute-weaver' )
	);

	$opts['comment_content_bgcolor'] = absolute_weaver_cz_color(
		'comment_content_bgcolor',
		__( 'Comment content area BG Color', 'absolute-weaver' )
	);

	$opts['comment_submit_bgcolor'] = absolute_weaver_cz_color(
		'comment_submit_bgcolor',
		__( '"Post Comment" submit button BG Color', 'absolute-weaver' )
	);

	$opts['content-line2'] = absolute_weaver_cz_line();

	$opts['editor_bgcolor'] = absolute_weaver_cz_color(
		'editor_bgcolor',
		__( 'Page/Post Editor BG', 'absolute-weaver' ),
		__( "Alternative Background Color to use for Page/Post editor if you're using transparent or image backgrounds.", 'absolute-weaver' ),
		'refresh'
	);


	return $opts;
}

function absolute_weaver_controls_colors_postspecific() {
	$opts = array();


	$opts['color-post-heading'] = absolute_weaver_cz_heading( __( 'Post Specific', 'absolute-weaver' ) );

	$opts['post_color'] = absolute_weaver_cz_color(
		'post_color',
		__( 'Post Area Text Color', 'absolute-weaver' )
	);

	$opts['post_bgcolor'] = absolute_weaver_cz_color(
		'post_bgcolor',
		__( 'Post Area BG Color', 'absolute-weaver' )
	);

	$opts['stickypost_bgcolor'] = absolute_weaver_cz_color(
		'stickypost_bgcolor',
		__( 'Sticky Post Area BG Color', 'absolute-weaver' )
	);

	$opts['post_title_color'] = absolute_weaver_cz_color(
		'post_title_color',
		__( 'Post Title Text Color', 'absolute-weaver' )
	);

	$opts['post_title_bgcolor'] = absolute_weaver_cz_color(
		'post_title_bgcolor',
		__( 'Post Title BG Color', 'absolute-weaver' )
	);

	$opts['post_title_hover_color'] = absolute_weaver_cz_color(
		'post_title_hover_color',
		__( 'Post Title Hover Color', 'absolute-weaver' ),
		__( 'Color if you want the Post Title to show alternate color for hover.', 'absolute-weaver' ),
		'refresh'
	);

	$opts['post_info_top_color'] = absolute_weaver_cz_color(
		'post_info_top_color',
		__( 'Top Post Meta Info Text Color', 'absolute-weaver' )
	);

	$opts['post_info_top_bgcolor'] = absolute_weaver_cz_color(
		'post_info_top_bgcolor',
		__( 'Top Post Meta Info BG Color', 'absolute-weaver' )
	);

	$opts['post_info_bottom_color'] = absolute_weaver_cz_color(
		'post_info_bottom_color',
		__( 'Bottom Post Meta Info Text Color', 'absolute-weaver' )
	);

	$opts['post_info_bottom_bgcolor'] = absolute_weaver_cz_color(
		'post_info_bottom_bgcolor',
		__( 'Bottom Post Meta Info BG Color', 'absolute-weaver' )
	);

	$opts['post_icons_color'] = absolute_weaver_cz_color(
		'post_icons_color',
		__( 'Post Font Icons Color', 'absolute-weaver' ),
		__( 'Set Font Icon color if Font Icons on Info Lines specified on the *Style &rarr; Post Specific* panel.', 'absolute-weaver' )
	);

	$opts['post_author_bgcolor'] = absolute_weaver_cz_color(
		'post_author_bgcolor',
		__( 'Author Info BG Color', 'absolute-weaver' ),
		__( 'Background color used for Author Bio.', 'absolute-weaver' )
	);

	return $opts;
}

function absolute_weaver_controls_colors_sidebars() {
	$opts = array();


	$opts['color-primary-widget-heading'] = absolute_weaver_cz_group_title( __( 'Primary Sidebar (Widget Area)', 'absolute-weaver' ) );

	$opts['primary_color'] = absolute_weaver_cz_color(
		'primary_color',
		__( 'Primary Sidebar Text Color', 'absolute-weaver' )
	);

	$opts['primary_bgcolor'] = absolute_weaver_cz_color(
		'primary_bgcolor',
		__( 'Primary Sidebar BG Color', 'absolute-weaver' )
	);

	$opts['color-secondary-widget-heading'] = absolute_weaver_cz_group_title( __( 'Secondary Sidebar (Widget Area)', 'absolute-weaver' ) );

	$opts['secondary_color'] = absolute_weaver_cz_color(
		'secondary_color',
		__( 'Secondary Sidebar Text Color', 'absolute-weaver' )
	);

	$opts['secondary_bgcolor'] = absolute_weaver_cz_color(
		'secondary_bgcolor',
		__( 'Secondary Sidebar BG Color', 'absolute-weaver' )
	);

	$opts['flow_color'] = absolute_weaver_cz_checkbox(
		__( 'Flow Color to Bottom', 'absolute-weaver' ),
		__( 'If checked, Content and Sidebar bg colors will flow to bottom of the Container ( that is, equal heights ). You must provide background colors for the Content and Sidebars or the default bg color will be used.',  'absolute-weaver'),
		'plus'
	);


	return $opts;
}

function absolute_weaver_controls_colors_widgets() {
	$opts = array();

	$opts['widget_color'] = absolute_weaver_cz_color(
		'widget_color',
		__( 'Individual Widgets Text Color', 'absolute-weaver' )
	);

	$opts['widget_bgcolor'] = absolute_weaver_cz_color(
		'widget_bgcolor',
		__( 'Individual Widgets BG Color', 'absolute-weaver' )
	);

	$opts['widget_title_color'] = absolute_weaver_cz_color(
		'widget_title_color',
		__( 'Individual Widgets Title Text Color', 'absolute-weaver' )
	);

	$opts['widget_title_bgcolor'] = absolute_weaver_cz_color(
		'widget_title_bgcolor',
		__( 'Individual Widgets Title BG Color', 'absolute-weaver' )
	);

	return $opts;
}

function absolute_weaver_controls_colors_footer() {
	$opts = array();

	$opts['footer_color'] = absolute_weaver_cz_color(
		'footer_color',
		__( 'Footer Area Text Color', 'absolute-weaver' )
	);

	$opts['footer_bgcolor'] = absolute_weaver_cz_color( 'header_bgcolor',
		__( 'Footer Area BG Color', 'absolute-weaver' ),
		'The Footer Area BG Color is used for full width BG color on header.' );

	$opts['footer_sb_color'] = absolute_weaver_cz_color(
		'footer_sb_color',
		__( 'Footer Widget Area Text Color', 'absolute-weaver' )
	);

	$opts['footer_sb_bgcolor'] = absolute_weaver_cz_color(
		'footer_sb_bgcolor',
		__( 'Footer Widget Area BG Color', 'absolute-weaver' )
	);

	if ( function_exists( 'absolute_weaver_ts_installed' ) ) {
		$opts['footer_html_color'] = absolute_weaver_cz_color(
			'footer_html_color',
			__( 'Footer HTML Area Text Color', 'absolute-weaver' )
		);

		$opts['footer_html_bgcolor'] = absolute_weaver_cz_color(
			'footer_html_bgcolor',
			__( 'Footer HTML Area BG Color', 'absolute-weaver' )
		);
	}



	return $opts;
}
