<?php

if ( ! function_exists( 'absolute_weaver_customizer_define_image_sections' ) ) :
	/**
	 * Define the sections and settings for the Images panel
	 */
	function absolute_weaver_customizer_define_image_sections() {
		global $wp_customize;

		$panel = 'absolute_weaver_images';
		$image_sections = array();


		/**
		 * General
		 */

		$image_sections['images-global'] = array(
			'panel'       => $panel,
			'title'       => __( 'Global Image Settings', 'absolute-weaver' ),
			'description' => 'Set Image options for Site Wrapper &amp; Container. Use Colors to set colors.',
			'options'     => absolute_weaver_controls_images_global(),

		);

		/**
		 * Header Image (use WP standard)
		 */

		$wp_customize->get_section( 'header_image' )->priority = 10505;
		$wp_customize->get_section( 'header_image' )->panel = $panel;

		/**
		 * Header Image Layout
		 */

		$image_sections['images-header'] = array(
			'panel'   => $panel,
			'title'   => __( 'Header Image Layout', 'absolute-weaver' ),
			'options' => absolute_weaver_controls_images_header_layout(),
		);


		/**
		 * Content
		 */

		$image_sections['images-content'] = array(
			'panel'       => $panel,
			'title'       => __( 'Content', 'absolute-weaver' ),
			'description' => __( 'Featured Image display on page content.', 'absolute-weaver' ),
			'options'     => absolute_weaver_controls_images_content(),
		);


		/**
		 * Post Specific
		 */
		$image_sections['images-post-specific'] = array(
			'panel'       => $panel,
			'title'       => __( 'Post Specific', 'absolute-weaver' ),
			'description' => __( 'Featured Image display with posts.', 'absolute-weaver' ),
			'options'     => absolute_weaver_controls_images_postspecific(),
		);

		/**
		 * Background Image (use WP standard)
		 */

		$wp_customize->get_section( 'background_image' )->priority = 10590;
		$wp_customize->get_section( 'background_image' )->panel = $panel;


		return $image_sections;
	}


	// the definitions of the controls for each panel follow


	function absolute_weaver_controls_images_global() {
		$opts = array();

		$opts['images-heading-global'] = absolute_weaver_cz_group_title( __( 'Global Image Settings', 'absolute-weaver' ),
			__( 'These settings control images in both the Container ( including content and sidebars ) and Footer Areas. They do not include the Header Area.', 'absolute-weaver' ) );

		$opts['media_lib_border_color'] = absolute_weaver_cz_color(
			'media_lib_border_color',
			__( 'Image Border Color', 'absolute-weaver' ),
			__( 'Border color for images in Container and Footer. You need to make Image Border Width > 0!', 'absolute-weaver' )
		);


		$opts['media_lib_border_int'] = absolute_weaver_cz_range(
			__( 'Image Border Width (px)', 'absolute-weaver' ),
			absolute_weaver_markdown( __( 'Border width for images in Container and Footer. There will be **no** borders unless you set this value above 0px.', 'absolute-weaver' ) ),
			0,
			array(
				'min'  => 0,
				'max'  => 50,
				'step' => 1,
			),
			'postMessage'
		);

		$opts['show_img_shadows'] = absolute_weaver_cz_checkbox_post( __( 'Add Image Shadow', 'absolute-weaver' ),
			__( 'Add a shadow to images in Container and Footer. Add custom CSS for custom shadow.', 'absolute-weaver' ) );


		$opts['caption_color'] = absolute_weaver_cz_color(
			'caption_color',
			__( 'Caption Text Color', 'absolute-weaver' ),
			__( 'Color of captions - e.g., below media images.', 'absolute-weaver' )
		);


		return $opts;
	}


	function absolute_weaver_controls_images_header_layout() {
		$opts = array();


		$opts['images-heading-header'] = absolute_weaver_cz_group_title( __( 'Site Header Media', 'absolute-weaver' ),
			absolute_weaver_markdown( __( 'You can set the header image on the *Images : Header Image* menu, one level up from here. The Site Logo is set on the *General Options & Admin : Site Identity* menu.', 'absolute-weaver' ) ) );


		$opts['images-heading-altimg'] = absolute_weaver_cz_heading(
			__( 'Alternate Header Images', 'absolute-weaver' ),
			absolute_weaver_markdown( __( 'You can specify alternate header images using the Content and Post Specific *Featured Image Location* option on the *Images* panel, as well as Per Page and Per Post options.', 'absolute-weaver' ) )
		);


		$opts['images-header-image-title'] = absolute_weaver_cz_group_title( __( 'Header Image', 'absolute-weaver' ),
			__( 'Settings for Site Header Image.', 'absolute-weaver' ) );


		$opts['link_site_image'] = absolute_weaver_cz_checkbox( __( 'Header Image Links to Site', 'absolute-weaver' ),
			absolute_weaver_markdown( __( 'Check to add a link to site home page for Header Image. **Note:** If used with *Move Title/Tagline over Image*, parts of the header image will not be clickable.', 'absolute-weaver' ) ) );


		$opts['header_image_align'] = absolute_weaver_cz_select(
			__( 'Align Header Image', 'absolute-weaver' ),
			__( 'How to align header image. Wide and Full do not apply to BG header image.', 'absolute-weaver' ),
			'absolute_weaver_cz_choices_align', 'float-left', 'refresh'
		);

		$opts['header_image_render'] = absolute_weaver_cz_select_plus(
			__( 'Header Image Rendering', 'absolute-weaver' ),
			absolute_weaver_markdown( __( 'How to render header image: as img in header or as header area bg image. When rendered as a BG image, other options such as moving Title/Tagline or having image link to home page are not meaningful. Optionally, use *Suggested Header Image Height* above to control BG image height.', 'absolute-weaver' ) ),
			array(
				'header-as-img'           => esc_html__( 'As img in header', 'absolute-weaver' ),
				'header-as-bg'            => esc_html__( 'As static BG image', 'absolute-weaver' ),
				'header-as-bg-responsive' => esc_html__( 'As responsive BG image', 'absolute-weaver' ),
				'header-as-bg-parallax'   => esc_html__( 'As parallax BG image', 'absolute-weaver' ),
			),
			'header-as-img', 'refresh'
		);


		$opts['header_min_height'] = absolute_weaver_cz_range(
			__( 'Minimum Header Height (px)', 'absolute-weaver' ),
			__( 'Set Minimum Height for Header Area. Most useful used with Parallax Header BG Image. Adding Top Margin to Primary Menu bar can also add height.', 'absolute-weaver' ),
			0,
			array(
				'min'  => 0,
				'max'  => 1000,
				'step' => 10,
			),
			'refresh',
			'plus'
		);


		$opts['header_image_max_width_dec'] = absolute_weaver_cz_range_float(
			__( 'Maximum Image Width (%)', 'absolute-weaver' ),
			__( 'Maximum width of Header Image. Can be useful to change Header Image alignment.', 'absolute-weaver' ),
			100.0,
			array(
				'min'  => 10,
				'max'  => 100,
				'step' => .5,
			),
			'refresh',
			'plus'
		);


		$opts['header_actual_size'] = absolute_weaver_cz_checkbox_post( __( 'Use Actual Image Size', 'absolute-weaver' ),
			__( 'Check to use actual header image size. (Default: theme width)', 'absolute-weaver' ), 'plus' );


		if ( function_exists( 'absolute_weaver_ts_installed' ) ) {
			$opts['header_image_html_plus_bg'] = absolute_weaver_cz_checkbox( __( 'Also show BG Header Image', 'absolute-weaver' ),
				__( 'If you have Image HTML Replacement defined - including Per Page/Post - and also have have set the standard Header Image to display as a BG image, then show <em>both</em> the BG image and the replacement HTML.', 'absolute-weaver' ), 'plus');
		}


		$opts['header_image_height_int'] = absolute_weaver_cz_range(
			__( 'Suggested Header Image Height (px)', 'absolute-weaver' ),
			absolute_weaver_markdown( __( 'Change the suggested height of the Header Image. Standard size is 188. This height is only a suggestion, and only affects the clipping window on the Customizer *Images &rarr; Header Banner Images* panel after you refresh the whole Customize interface. Header images will always be responsively sized. (Default header image width: theme width)', 'absolute-weaver' ) ),
			188,
			array(
				'min'  => 10,
				'max'  => 2400,
				'step' => 5,
			)
		);

		$wp_logo = absolute_weaver_get_wp_custom_logo_url();

		if ( $wp_logo ) {
			$logo = '<br /><br />' . __( 'Current Site Logo: ', 'absolute-weaver' ) . "<img src='" . esc_url( $wp_logo ) . "' style='max-height:36px;margin-left:10px;' />";
		} else {
			$logo = '<br /><br />' . absolute_weaver_markdown( __( '***Site Logo has not been set.***', 'absolute-weaver' ) );
		}


		$opts['images-heading-header-logo'] = absolute_weaver_cz_group_title( __( 'Site Logo', 'absolute-weaver' ),
			absolute_weaver_markdown( __( 'You can set the Site Logo on the **Customize : General Options : Site Identity** menu. Logo visibility set on **Visibility : Header**.', 'absolute-weaver' )
			                  . $logo ) );


		$opts['wplogo_for_title'] = absolute_weaver_cz_checkbox( __( 'Replace Title with Site Logo', 'absolute-weaver' ),
			__( 'Replace the Site Title text with the WP Custom Logo Image', 'absolute-weaver' ) );


		$opts['header_logo_height_dec'] = absolute_weaver_cz_range(
			__( 'Logo as Title Replacement Height (px)', 'absolute-weaver' ),
			__( 'Set height of Logo on Menu. Will interact with padding. (Default: 32px)', 'absolute-weaver' ),
			32,
			array(
				'min'  => 10,
				'max'  => 200,
				'step' => 1,
			)
		);

		return $opts;
	}


	function absolute_weaver_controls_images_content() {
		$opts = array();

		$opts['images-content-heading'] = absolute_weaver_cz_heading( __( 'General Image Settings', 'absolute-weaver' ),
			absolute_weaver_markdown( __( 'General image settings found on the *Global Image Settings* panel.', 'absolute-weaver' ) ) );


		$opts['images-pgextendbg-heading'] = absolute_weaver_cz_heading( __( 'Full Width Featured Image BG', 'absolute-weaver' ),
			absolute_weaver_markdown( __( 'Check the *Content Full Width BG Attributes* option on the *Spacing, Width, Alignment : Full Width Site* menu to get full width Featured Image BG.', 'absolute-weaver' ) ) );


		$opts['images-content-FI'] = absolute_weaver_cz_group_title( __( 'Featured Image - Pages', 'absolute-weaver' ),
			__( 'Display of Page Featured Images', 'absolute-weaver' ) );


		$opts['page_fi_location'] = absolute_weaver_cz_select(
			__( 'Featured Image Location', 'absolute-weaver' ),
			__( 'Where to display Featured Image for Pages', 'absolute-weaver' ),
			'absolute_weaver_cz_choices_fi_location', 'content-top', 'refresh'
		);


		$opts['page_min_height'] = absolute_weaver_cz_range(
			__( 'Page Content Height (px)', 'absolute-weaver' ),
			__( 'Minimum Height Page Content with Parallax BG.', 'absolute-weaver' ),
			0,
			array(
				'min'  => 10,
				'max'  => 2000,
				'step' => 10,
			),
			'refresh',
			'plus'
		);

		$opts['page_fi_align'] = absolute_weaver_cz_select(
			__( 'Align Featured Image', 'absolute-weaver' ),
			'',
			'absolute_weaver_cz_choices_fi_align', 'fi-alignleft', 'refresh'
		);


		$opts['page_fi_hide'] = absolute_weaver_cz_select(
			__( 'Hide Featured Image', 'absolute-weaver' ),
			'',
			'absolute_weaver_cz_choices_hide', 'hide-none', 'refresh'
		);


		$opts['page_fi_size'] = absolute_weaver_cz_select(
			__( 'Page Featured Image Size', 'absolute-weaver' ),
			__( 'Media Library Image Size for Featured Image on pages. ( Header uses full size ).', 'absolute-weaver' ),
			'absolute_weaver_cz_choices_fi_size', 'thumbnail', 'refresh'
		);


		$opts['page_fi_width'] = absolute_weaver_cz_range_float(
			__( 'Featured Image Width (%)', 'absolute-weaver' ),
			__( 'Width of Featured Image on Pages. Max Width in %, overrides FI Size selection. Set to 0 to avoid overriding above Featured Image Size setting.', 'absolute-weaver' ),
			0,
			array(
				'min'  => 0,
				'max'  => 100,
				'step' => 0.5,
			),
			'refresh',
			'plus'
		);


		$opts['page_fi_nolink'] = absolute_weaver_cz_checkbox( __( "Don't add link to FI", 'absolute-weaver' ),
			__( 'Do not add link to Featured Image.', 'absolute-weaver' ), 'plus' );


		return $opts;
	}


	function absolute_weaver_controls_images_postspecific() {
		$opts = array();

		$opts['images-postspecific-heading'] = absolute_weaver_cz_group_title( __( 'General Image Settings', 'absolute-weaver' ),
			absolute_weaver_markdown( __( 'General image settings found on the *Global Image Settings* panel.', 'absolute-weaver' ) ) );


		$opts['post_avatar_int'] = absolute_weaver_cz_range(
			__( 'Author Avatar Size (px)', 'absolute-weaver' ),
			__( 'Size of Author Avatar in px - only for Post Info line. (Default: 28px)', 'absolute-weaver' ),
			28,
			array(
				'min'  => 10,
				'max'  => 60,
				'step' => 1,
			),
			'postMessage',
			'plus'
		);

		$opts['images-fi-post-h'] = absolute_weaver_cz_group_title( __( 'Post Featured Image Options', 'absolute-weaver' ),
			__( 'Options for Post Featured Images.', 'absolute-weaver' ) );

		$opts['post_fi_nolink'] = absolute_weaver_cz_checkbox( __( "Don't add link to FI", 'absolute-weaver' ),
			__( 'Do not add link to Featured Image for any post layout.', 'absolute-weaver' ), 'plus' );


		$opts['images-extendbg-heading'] = absolute_weaver_cz_heading( __( 'Full Width Featured Image BG', 'absolute-weaver' ),
			absolute_weaver_markdown( __( 'Check the *Extend Width BG Attributes for all Posts* option on the *Spacing, Width, Alignment : Full Width Site* menu to get full width Featured Image BG.', 'absolute-weaver' ) ) );

		$opts['images-content-FI-full'] = absolute_weaver_cz_group_title( __( 'Featured Image - Full Blog Posts', 'absolute-weaver' ),
			__( 'Display of Post Featured Images when Post is displayed as a Full Post.', 'absolute-weaver' ) );

		$opts['post_full_fi_location'] = absolute_weaver_cz_select(
			__( 'Featured Image Location - Full Post', 'absolute-weaver' ),
			__( 'Where to display Featured Image.', 'absolute-weaver' ),
			'absolute_weaver_cz_choices_fi_location', 'content-top', 'refresh'

		);

		$opts['post_blog_min_height'] = absolute_weaver_cz_range(
			__( 'Post Height - Blog View (px)', 'absolute-weaver' ),
			__( 'Minimum Height of Post, full or excerpt, with Parallax BG in blog views.', 'absolute-weaver' ),
			0,
			array(
				'min'  => 10,
				'max'  => 2000,
				'step' => 10,
			),
			'refresh',
			'plus'
		);

		$opts['post_full_fi_align'] = absolute_weaver_cz_select(
			__( 'Align Featured Image - Full Post', 'absolute-weaver' ),
			'',
			'absolute_weaver_cz_choices_fi_align', 'fi-alignleft', 'refresh'
		);

		$opts['post_full_fi_hide'] = absolute_weaver_cz_select(
			__( 'Hide Featured Image - Full Post', 'absolute-weaver' ),
			'',
			'absolute_weaver_cz_choices_hide', 'hide-none', 'refresh'
		);

		$opts['post_full_fi_size'] = absolute_weaver_cz_select(
			__( 'Page Featured Image Size - Full Post', 'absolute-weaver' ),
			__( 'Media Library Image Size for Featured Image. ( Header uses full size ).', 'absolute-weaver' ),
			'absolute_weaver_cz_choices_fi_size', 'thumbnail', 'refresh'
		);


		$opts['post_full_fi_width'] = absolute_weaver_cz_range_float(
			__( 'Featured Image Width (%) - Full Post', 'absolute-weaver' ),
			__( 'Width of Featured Image. Max Width in %, overrides FI Size selection. Set to 0 to avoid overriding above Featured Image Size setting.', 'absolute-weaver' ),
			0,
			array(
				'min'  => 0,
				'max'  => 100,
				'step' => 0.5,
			),
			'refresh',
			'plus'
		);


		$opts['images-content-FI-excerpt'] = absolute_weaver_cz_group_title( __( 'Featured Image - Excerpt Posts', 'absolute-weaver' ),
			__( 'Display of Post Featured Images when Post is displayed as an Excerpt.', 'absolute-weaver' ) );

		$opts['post_excerpt_fi_location'] = absolute_weaver_cz_select(
			__( 'Featured Image Location - Excerpt', 'absolute-weaver' ),
			__( 'Where to display Featured Image.', 'absolute-weaver' ),
			'absolute_weaver_cz_choices_fi_location', 'content-top', 'refresh'
		);

		$opts['post_excerpt_fi_align'] = absolute_weaver_cz_select(
			__( 'Align Featured Image - Excerpt', 'absolute-weaver' ),
			'',
			'absolute_weaver_cz_choices_fi_align', 'fi-alignleft', 'refresh'
		);

		$opts['post_excerpt_fi_hide'] = absolute_weaver_cz_select(
			__( 'Hide Featured Image - Excerpt', 'absolute-weaver' ),
			'',
			'absolute_weaver_cz_choices_hide', 'hide-none', 'refresh'
		);

		$opts['post_excerpt_fi_size'] = absolute_weaver_cz_select(
			__( 'Page Featured Image Size - Excerpt', 'absolute-weaver' ),
			__( 'Media Library Image Size for Featured Image. ( Header uses full size ).', 'absolute-weaver' ),
			'absolute_weaver_cz_choices_fi_size', 'thumbnail', 'refresh'
		);


		$opts['post_excerpt_fi_width'] = absolute_weaver_cz_range_float(
			__( 'Featured Image Width (%) - Excerpt', 'absolute-weaver' ),
			__( 'Width of Featured Image. Max Width in %, overrides FI Size selection. Set to 0 to avoid overriding above Featured Image Size setting.', 'absolute-weaver' ),
			0,
			array(
				'min'  => 0,
				'max'  => 100,
				'step' => 0.5,
			),
			'refresh',
			'plus'
		);

		$opts['images-content-FI-single'] = absolute_weaver_cz_group_title( __( 'Featured Image - Single Page', 'absolute-weaver' ),
			__( 'Display of Post Featured Images when Post is displayed on the Single Page.', 'absolute-weaver' ) );

		$opts['post_fi_location'] = absolute_weaver_cz_select(
			__( 'Featured Image Location - Single Page', 'absolute-weaver' ),
			__( 'Where to display Featured Image.', 'absolute-weaver' ),
			'absolute_weaver_cz_choices_fi_location', 'content-top', 'refresh'
		);

		$opts['post_min_height'] = absolute_weaver_cz_range(
			__( 'Post Height - Single Page (px)', 'absolute-weaver' ),
			__( 'Minimum Height of Post with Parallax BG in Single Page view.', 'absolute-weaver' ),
			0,
			array(
				'min'  => 10,
				'max'  => 2000,
				'step' => 10,
			),
			'refresh',
			'plus'
		);

		$opts['post_fi_align'] = absolute_weaver_cz_select(
			__( 'Align Featured Image - Single Page', 'absolute-weaver' ),
			'',
			'absolute_weaver_cz_choices_fi_align', 'fi-alignleft', 'refresh'
		);

		$opts['post_fi_hide'] = absolute_weaver_cz_select(
			__( 'Hide Featured Image - Single Page', 'absolute-weaver' ),
			'',
			'absolute_weaver_cz_choices_hide', 'hide-none', 'refresh'
		);

		$opts['post_fi_size'] = absolute_weaver_cz_select(
			__( 'Page Featured Image Size - Single Page', 'absolute-weaver' ),
			__( 'Media Library Image Size for Featured Image. ( Header uses full size ).', 'absolute-weaver' ),
			'absolute_weaver_cz_choices_fi_size', 'thumbnail', 'refresh'
		);

		$opts['post_fi_width'] = absolute_weaver_cz_range_float(
			__( 'Featured Image Width (%) - Single Page', 'absolute-weaver' ),
			__( 'Width of Featured Image. Max Width in %, overrides FI Size selection. Set to 0 to avoid overriding above Featured Image Size setting.', 'absolute-weaver' ),
			0,
			array(
				'min'  => 0,
				'max'  => 100,
				'step' => 0.5,
			),
			'refresh',
			'plus'
		);


		return $opts;
	}

endif;
