<?php
/**
 * Define the sections and settings controls for the Layout panel
 */
function absolute_weaver_customizer_define_layout_sections() {
	$panel = 'absolute_weaver_layout';
	$layout_sections = array();

	/**
	 * Layout -> Site Header
	 */

	$layout_sections['layout-header'] = array(
		'panel'   => $panel,
		'title'   => esc_html__( 'Header Area', 'absolute-weaver' ),
		'options' => absolute_weaver_controls_layout_header(),
	);


	/**
	 * Layout -> Menus
	 */
	$layout_sections['layout-menus'] = array(
		'panel'       => $panel,
		'title'       => esc_html__( 'Menus', 'absolute-weaver' ),
		'description' => esc_html__( 'Set layout for Menus.', 'absolute-weaver' ),
		'options'     => absolute_weaver_controls_layout_menus(),
	);


	/**
	 * Layout -> Content
	 */
	$layout_sections['layout-content'] = array(
		'panel'       => $panel,
		'title'       => esc_html__( 'Content', 'absolute-weaver' ),
		'description' => esc_html__( 'Layout for general page and post content.', 'absolute-weaver' ),
		'options'     => absolute_weaver_controls_layout_content(),
	);


	/**
	 * Post Specific
	 */
	$layout_sections['layout-post-specific'] = array(
		'panel'       => $panel,
		'title'       => esc_html__( 'Post Specific', 'absolute-weaver' ),
		'description' => esc_html__( 'Post Specific layout - override Content layout.', 'absolute-weaver' ),
		'options'     => absolute_weaver_controls_layout_post_specific(),
	);

	/**
	 * Sidebars
	 */
	$layout_sections['layout-sidebars'] = array(
		'panel'       => $panel,
		'title'       => esc_html__( 'Sidebars', 'absolute-weaver' ),
		'description' => esc_html__( 'Primary and Secondary Sidebars. Header and Footer areas options under Header and Footer panels. Note: General Sidebar Layout for different page types is shown first. Layout options for Primary and Secondary Sidebars are shown after that, so scroll down!', 'absolute-weaver' ),
		'options'     => absolute_weaver_controls_layout_sidebars(),
	);

	/**
	 * Footer
	 */
	$layout_sections['layout-footer'] = array(
		'panel'   => $panel,
		'title'   => esc_html__( 'Footer Area', 'absolute-weaver' ),
		'options' => absolute_weaver_controls_layout_footer(),
	);

	return $layout_sections;

}

/* ================================== Controls: Layout -> Header ==================================== */

function absolute_weaver_controls_layout_header() {
	$opts = array();

	$opts['layout-heading-wheader'] = absolute_weaver_cz_group_title( __( 'Header Widget Area', 'absolute-weaver' ) );


	$opts['header_sb_cols_int'] = absolute_weaver_cz_range(
		__( 'Header Columns of Widgets', 'absolute-weaver' ),
		'',
		1,
		array( 'min' => 1, 'max' => 8, 'step' => 1 ),
		'refresh'
	);


	$opts['header_sb_fixedtop'] = absolute_weaver_cz_checkbox(
		__( 'Fixed-Top Header Widget Area', 'absolute-weaver' ),
		__( 'Fix Header Widget are to top of page. If primary menu is also fixed-top, header widget area will be before primary.', 'absolute-weaver' )
	);


	$opts['header_sb_position'] = absolute_weaver_cz_select(
		__( 'Header Widget Area Position', 'absolute-weaver' ),
		__( 'Change where Header Widget Area is displayed within the Header Area. You can move it to one of seven positions in the Header.', 'absolute-weaver' ),
		array(
			'top'           => __( 'Top of Header', 'absolute-weaver' ),
			'before_header' => __( 'Before Header Image', 'absolute-weaver' ),
			'after_header'  => __( 'After Header Image', 'absolute-weaver' ),
			'after_html'    => __( 'After HTML Block', 'absolute-weaver' ),
			'after_menu'    => __( 'After Lower Menu', 'absolute-weaver' ),
			'pre_header'    => __( 'Pre-#header &lt;div&gt;', 'absolute-weaver' ),
			'post_header'   => __( 'Post-#header &lt;div&gt;', 'absolute-weaver' ),
		),
		'top',
		'refresh',
		'plus'
	);



	$opts['layout-header-custom-widths'] = absolute_weaver_cz_heading( __( 'Header Custom Widget Widths', 'absolute-weaver' ) . ABSOLUTE_WEAVER_PLUS_ICON,
		__( 'You can optionally specify widget widths, including for specific devices. Overrides the Columns of Widgets setting. Please read the help entry!', 'absolute-weaver' ) );


	$opts['_header_sb_lw_cols_list'] = absolute_weaver_cz_textarea(
		__( 'Header Desktop Widget Widths', 'absolute-weaver' ),
		__( 'List of widget widths separated by comma. Use semi-colon (;) for end of each row. Widths are % of each row. (&diams;)', 'absolute-weaver' ),
		'1',
		__( '25,25,50; 60,40; - for example', 'absolute-weaver' ),
		'refresh',
		'plus' );


	$opts['_header_sb_mw_cols_list'] = absolute_weaver_cz_textarea(
		__( 'Header Small Tablet Widget Widths', 'absolute-weaver' ),
		__( 'List of widget widths. (&diams;)', 'absolute-weaver' ),
		'1',
		'',
		'refresh',
		'plus'
	);


	$opts['_header_sb_sw_cols_list'] = absolute_weaver_cz_textarea(
		__( 'Header Phone Widget Widths', 'absolute-weaver' ),
		__( 'List of widget widths. (&diams;)', 'absolute-weaver' ),
		'1',
		'',
		'refresh',
		'plus'
	);


	$opts['header_sb_no_widget_margins'] = absolute_weaver_cz_checkbox(
		__( 'Header No Smart Widget Margins', 'absolute-weaver' ),
		__( 'Do not use "smart margins" between  multi-column widgets on rows.', 'absolute-weaver' )
	);


	$opts['header_sb_eq_widgets'] = absolute_weaver_cz_checkbox(
		__( 'Header Equal Height Widget Rows', 'absolute-weaver' ),
		__( 'Make widgets equal height rows if &gt; 1 column.', 'absolute-weaver' ),
		'plus'
	);

	$opts['hdr-title-move-title'] = absolute_weaver_cz_group_title( __( 'Site Title and Tagline', 'absolute-weaver' ),
		absolute_weaver_markdown( __( 'You can move the Site Title and Tagline over the Header Image from the *Spacing, Widths, Alignment* menu.', 'absolute-weaver' ) ) );

	return $opts;

}

/* ================================== Controls: Layout -> Menus ==================================== */

function absolute_weaver_controls_layout_menus() {

	$opts = array();

	$opts['layout-primary-heading'] = absolute_weaver_cz_group_title( __( 'Layout For Primary Menu', 'absolute-weaver' ) );


	$opts['m_primary_fixedtop'] = absolute_weaver_cz_select(    // must be refresh because column class applied to specific page id
		__( 'Fixed-Top Primary Menu', 'absolute-weaver' ),
		__( 'Fix the Primary Menu to top of page. Use the Menu Align setting to make a full width menu.', 'absolute-weaver' ),
		array(
			'none'       => esc_html__( 'Standard Position : Not Fixed', 'absolute-weaver' ),
			'fixed-top'  => esc_html__( 'Fixed to Top', 'absolute-weaver' ),
			'scroll-fix' => esc_html__( 'Fix to Top on Scroll', 'absolute-weaver' ),
		),
		'none', 'refresh'
	);

	$opts['m_primary_move'] = absolute_weaver_cz_checkbox(
		__( 'Move Primary Menu to Top', 'absolute-weaver' ),
		__( 'Move Primary Menu at Top of Header Area. This is not the same as a Fixed-Top Menu (Default: Bottom)', 'absolute-weaver' )
	);


	$opts['m_primary_site_title_left'] = absolute_weaver_cz_checkbox(
		__( 'Add Site Title to Left of Primary Menu', 'absolute-weaver' ),
		__( 'Adds the Site Title to the left end of the primary menu in larger font size.', 'absolute-weaver' )
	);


	$opts['m_primary_logo_left'] = absolute_weaver_cz_checkbox(
		__( 'Add Site Logo to Left', 'absolute-weaver' ),
		__( 'Add the Site Logo to the primary menu. Add custom CSS for <em>.custom-logo-on-menu</em> to style. (Use Customize : Site Identity to set Site Logo.)', 'absolute-weaver' ) . absolute_weaver_get_logo_html()
	);

	$opts['m_primary_logo_height_dec'] = absolute_weaver_cz_range_float(
		__( 'Logo on Menu Bar Height (em)', 'absolute-weaver' ),
		__( 'Set height of Logo on Menu. Will interact with padding. Default 0 uses current line height.', 'absolute-weaver' ),
		0,
		array(
			'min'  => 0,
			'max'  => 10,
			'step' => .1,
		)
	);

	$opts['m_primary_logo_home_link'] = absolute_weaver_cz_checkbox(
		__( 'Logo Links to Home', 'absolute-weaver' ),
		__( 'Add a link to home page to logo on menu bar ( must use with defined custom menu ).', 'absolute-weaver' )
	);

	$opts['m_primary_search'] = absolute_weaver_cz_checkbox(
		__( 'Add Search to Right', 'absolute-weaver' ),
		__( 'Add slide open search icon to right end of primary menu.', 'absolute-weaver' )
	);

	$opts['mobile_to_right'] = absolute_weaver_cz_checkbox(
		__('Move mobile "Hamburger" icon to right side of menu.', 'absolute-weaver')
	);

	$opts['mobile_alt_label'] = absolute_weaver_cz_htmlarea( __( 'Mobile Menu "Hamburger" Label', 'absolute-weaver' ),
		__( 'Alternative label for the default mobile "Hamburger" icon. HTML allowed, e.g. <code>&lt;span class="genericon genericon-menu">&lt;/span> Menu</code>', 'absolute-weaver' ),
		'1',
		'Any HTML',
		'refresh' );


	$opts['mobile_alt_switch'] = absolute_weaver_cz_range(
		__( 'Menu Mobile/Desktop Switch Point (px)', 'absolute-weaver' ),
		absolute_weaver_markdown(__( 'Set width for menu bars to switch from desktop to mobile. (Default: 767px. Hint: use 768 to force mobile menu on iPad portrait.)', 'absolute-weaver' ) ),
		767,
		array(
			'min'  => 300,
			'max'  => 1200,
			'step' => 1,
		),
		'refresh',
		'plus'
	);

	if ( ! ABSOLUTE_WEAVER_SMARTMENUS_DEFAULT ) {
		$opts['use_smartmenus'] = array(
			'setting' => array(
				'transport' => 'refresh',
			),
			'control' => array(
				'label'       => __( 'Use SmartMenus', 'absolute-weaver' ),
				'description' => __( 'Use <em>SmartMenus</em> rather than default Absolute Weaver. <em>SmartMenus</em> provide enhanced menu support, including auto-visibility, and transition effects. This option is recommended.', 'absolute-weaver' ),
				'type'        => 'checkbox',
			),
		);
	}


	return $opts;
}

/* ================================== Controls: Layout -> content ==================================== */

function absolute_weaver_controls_layout_content() {
	$opts = array();

	$opts['page_cols'] = absolute_weaver_cz_select(    // must be refresh because column class applied to specific page id
		__( 'Content Columns', 'absolute-weaver' ),
		__( 'Automatically split all page content into columns. You can also use the Per Page option. This option does not apply to posts.', 'absolute-weaver' ),
		'absolute_weaver_cz_choices_columns', '1', 'refresh'
	);

	$opts['hyphenate'] = absolute_weaver_cz_checkbox(
		__( 'Auto Hyphenate Content', 'absolute-weaver' ),
		__( 'Allow browsers to automatically hyphenate text for appearance.', 'absolute-weaver' )
	);

	return $opts;
}

/* ================================== Controls: Layout -> post-specific ==================================== */

function absolute_weaver_controls_layout_post_specific() {
	$opts = array();

	$opts['layout-post-excerpt'] = absolute_weaver_cz_group_title( __( 'Excerpts / Full Posts', 'absolute-weaver' ),
		__( 'How to display posts in Blog and Archive views.', 'absolute-weaver' ) );

	$opts['excerpt_length'] = absolute_weaver_cz_range(
		__( 'Excerpt length', 'absolute-weaver' ),
		__( 'Change post excerpt length.', 'absolute-weaver' ),
		40,
		array( 'min' => 2, 'max' => 100, 'step' => 1 )
	);

	$opts['fullpost_blog'] = absolute_weaver_cz_checkbox(
		__( 'Show Full Blog Posts', 'absolute-weaver' ),
		absolute_weaver_markdown( __( 'Will display full blog post instead of excerpts on *blog pages*. Does not override manually added &lt;--more--> breaks.', 'absolute-weaver' ) )
	);


	$opts['fullpost_archive'] = absolute_weaver_cz_checkbox(
		__( 'Full Post for Archives', 'absolute-weaver' )
	);

	$opts['fullpost_search'] = absolute_weaver_cz_checkbox(
		__( 'Full Post for Searches', 'absolute-weaver' )
	);

	$opts['layout-post-cols'] = absolute_weaver_cz_group_title( __( 'Columns', 'absolute-weaver' ),
		__( 'Posts in columns.', 'absolute-weaver' ) );

	$opts['post_cols'] = absolute_weaver_cz_select(    // must be refresh because column class applied to specific page id
		__( 'Post Content Columns', 'absolute-weaver' ),
		__( 'Split all post content into columns for both blog and single page views. This applies to individual post content only. Uses CSS for this layout. This is not the same as Columns of Posts.', 'absolute-weaver' ),
		'absolute_weaver_cz_choices_columns', '1', 'refresh'
	);

	$opts['blog_cols'] = absolute_weaver_cz_select(
		__( 'Columns of Posts', 'absolute-weaver' ),
		__( 'Display posts on blog page with this many columns. HINT: Adjust "Blog pages show at most n posts" on Settings:Reading to be a multiple of columns.', 'absolute-weaver' ),
		array(
			'1' => esc_html__( '1 Column', 'absolute-weaver' ),
			'2' => esc_html__( '2 Columns', 'absolute-weaver' ),
			'3' => esc_html__( '3 Columns', 'absolute-weaver' ),
		),
		'1', 'refresh'
	);

	$opts['archive_cols'] = absolute_weaver_cz_checkbox(
		__( 'Use Columns on Archive Pages', 'absolute-weaver' ),
		__( 'Display posts on archive-like pages using columns. (Archive, Author, Category, Tag)', 'absolute-weaver' )
	);

	$opts['blog_first_one'] = absolute_weaver_cz_checkbox(
		__( 'First Post One Column', 'absolute-weaver' ),
		__( 'Display the first post in one column.', 'absolute-weaver' )
	);

	$opts['blog_sticky_one'] = absolute_weaver_cz_checkbox(
		__( 'Sticky Posts One Column', 'absolute-weaver' ),
		__( 'Display opening Sticky Posts in one column. If First Post One Column also checked, then first non-sticky post will also be one column.', 'absolute-weaver' )
	);


	$opts['layout-post-nav'] = absolute_weaver_cz_group_title( __( 'Post Navigation', 'absolute-weaver' ),
		__( 'Navigation for moving between Posts.', 'absolute-weaver' ) );

	$opts['nav_style'] = absolute_weaver_cz_select(
		__( 'Blog Navigation Style', 'absolute-weaver' ),
		__( 'Style of navigation links on blog pages: "Older/Newer posts", "Previous/Next Post", or by page numbers.', 'absolute-weaver' ),
		array(
			'old_new'     => esc_html__( 'Older/Newer', 'absolute-weaver' ),
			'prev_next'   => esc_html__( 'Previous/Next', 'absolute-weaver' ),
			'paged_left'  => esc_html__( 'Paged - Left', 'absolute-weaver' ),
			'paged_right' => esc_html__( 'Paged - Right', 'absolute-weaver' ),
		),
		'old_new', 'refresh'
	);

	$opts['nav_hide_above'] = absolute_weaver_cz_checkbox(
		__( 'Hide Top Nav Links', 'absolute-weaver' ),
		__( 'Hide the blog navigation links at the top.', 'absolute-weaver' ),
		'plus'
	);

	$opts['nav_hide_below'] = absolute_weaver_cz_checkbox(
		__( 'Hide Bottom Nav Links', 'absolute-weaver' ),
		__( 'Hide the blog navigation links at the bottom.', 'absolute-weaver' ),
		'plus'
	);

	$opts['Show Top Nav on First Page'] = absolute_weaver_cz_checkbox(
		__( 'Show Top Nav on First Page', 'absolute-weaver' ),
		__( 'Show navigation at top even on the first page.', 'absolute-weaver' ),
		'plus'
	);


	$opts['single_nav_style'] = absolute_weaver_cz_select(
		__( 'Single Page Navigation Style', 'absolute-weaver' ),
		__( 'Style of navigation links on post Single pages: Previous/Next, by title, or none.', 'absolute-weaver' ),
		array(
			'title'     => esc_html__( 'Post Titles', 'absolute-weaver' ),
			'prev_next' => esc_html__( 'Previous/Next', 'absolute-weaver' ),
			'hide'      => esc_html__( 'None - no display', 'absolute-weaver' ),
		),
		'title', 'refresh'
	);

	$opts['single_nav_link_cats'] = absolute_weaver_cz_checkbox(
		__( 'Nav Links to Same Categories', 'absolute-weaver' ),
		__( 'Single Page navigation links point to posts with same categories', 'absolute-weaver' )
	);


	$opts['single_nav_hide_above'] = absolute_weaver_cz_checkbox(
		__( 'Hide Top Nav Links', 'absolute-weaver' ),
		__( 'Hide the single page navigation links at the top.', 'absolute-weaver' ),
		'plus'
	);

	$opts['single_nav_hide_below'] =
		absolute_weaver_cz_checkbox(
			__( 'Hide Bottom Nav Links', 'absolute-weaver' ),
			__( 'Hide the single page navigation links at the bottom.', 'absolute-weaver' ),
			'plus'
		);

	$opts['layout-post-line3'] = absolute_weaver_cz_line();

	return $opts;
}

/* ================================== Controls: Layout -> sidebars ==================================== */

function absolute_weaver_controls_layout_sidebars() {
	$opts = array();

	$opts['layout-primary-all-heading'] = absolute_weaver_cz_group_title( __( 'Sidebar Layout for Page Types', 'absolute-weaver' ),
		__( 'Sidebar Layout for each type of page ( "stack top" used for mobile view ).', 'absolute-weaver' )
	);

	$opts['layout_default'] = absolute_weaver_cz_select(
		__( 'Blog, Post, Page Default', 'absolute-weaver' ),
		__( 'Select the default theme layout for blog, single post, attachments, and pages.', 'absolute-weaver' ),
		'absolute_weaver_cz_choices_sb_layout', 'right', 'refresh'
	);


	$opts['layout_default_archive'] = absolute_weaver_cz_select(
		__( 'Archive-like Default', 'absolute-weaver' ),
		__( 'Select the default theme layout for all other pages - archives, search, etc.', 'absolute-weaver' ),
		'absolute_weaver_cz_choices_sb_layout', 'right', 'refresh'
	);

	$opts['layout_page'] = absolute_weaver_cz_select(
		__( 'Page', 'absolute-weaver' ),
		__( 'Layout for normal Pages on your site.', 'absolute-weaver' ),
		'absolute_weaver_cz_choices_sb_layout_default', 'default', 'refresh'
	);

	$opts['layout_blog'] = absolute_weaver_cz_select(
		__( 'Blog', 'absolute-weaver' ),
		__( 'Layout for main blog page. Includes "Page with Posts" Page template-parts.', 'absolute-weaver' ),
		'absolute_weaver_cz_choices_sb_layout_default', 'default', 'refresh'
	);

	$opts['layout_single'] = absolute_weaver_cz_select(
		__( 'Post Single Page', 'absolute-weaver' ),
		__( 'Layout for Posts displayed as a single page.', 'absolute-weaver' ),
		'absolute_weaver_cz_choices_sb_layout_default', 'default', 'refresh'
	);

	$opts['layout_full_note1'] = absolute_weaver_cz_html_description(
		__( 'Absolute Weaver Plus includes options for other archive-like pages.', 'absolute-weaver' ), 'plus' );

	$opts['layout_attachments'] = absolute_weaver_cz_select_plus(
		__( 'Attachments', 'absolute-weaver' ),
		__( 'Layout for attachment pages such as images.', 'absolute-weaver' ),
		'absolute_weaver_cz_choices_sb_layout_default', 'default', 'refresh'
	);

	$opts['layout_archive'] = absolute_weaver_cz_select_plus(
		__( 'Date Archive', 'absolute-weaver' ),
		__( 'Layout for archive by date pages.', 'absolute-weaver' ),
		'absolute_weaver_cz_choices_sb_layout_default', 'default', 'refresh'
	);

	$opts['layout_category'] = absolute_weaver_cz_select_plus(
		__( 'Category Archive', 'absolute-weaver' ),
		__( 'Layout for category archive pages.', 'absolute-weaver' ),
		'absolute_weaver_cz_choices_sb_layout_default', 'default', 'refresh'
	);

	$opts['layout_tag'] = absolute_weaver_cz_select_plus(
		__( 'Tags Archive', 'absolute-weaver' ),
		__( 'Layout for tag archive pages.', 'absolute-weaver' ),
		'absolute_weaver_cz_choices_sb_layout_default', 'default', 'refresh'
	);

	$opts['layout_author'] = absolute_weaver_cz_select_plus(
		__( 'Author Archive', 'absolute-weaver' ),
		__( 'Layout for author archive pages.', 'absolute-weaver' ),
		'absolute_weaver_cz_choices_sb_layout_default', 'default', 'refresh'
	);

	$opts['layout_search'] = absolute_weaver_cz_select_plus(
		__( 'Search Results, 404', 'absolute-weaver' ),
		__( 'Layout for search results and 404 pages.', 'absolute-weaver' ),
		'absolute_weaver_cz_choices_sb_layout_default', 'default', 'refresh'
	);

	$opts['layout-primary-widget-heading'] = absolute_weaver_cz_group_title( __( 'Primary Sidebar', 'absolute-weaver' )
	);

	$opts['primary_cols_int'] = absolute_weaver_cz_range(
		__( 'Columns of Widgets', 'absolute-weaver' ),
		__( 'description', 'absolute-weaver' ),
		1,
		array(
			'min'  => 1,
			'max'  => 8,
			'step' => 1,
		)
	);

	$opts['layout-primary-custom-widths'] = absolute_weaver_cz_heading( __( 'Custom Widget Widths', 'absolute-weaver' ) . ABSOLUTE_WEAVER_PLUS_ICON,
		__( 'You can optionally specify widget widths, including for specific devices. Overrides the Columns of Widgets setting. Please read the help entry!', 'absolute-weaver' )
	);

	$opts['_primary_lw_cols_list'] = absolute_weaver_cz_textarea(
		__( 'Desktop Widget Widths', 'absolute-weaver' ),
		__( 'List of widget widths separated by comma. Use semi-colon ( ; ) for end of each row. Widths are % of each row. (&diams;)', 'absolute-weaver' ),
		'1',
		__( '25,25,50; 60,40; - for example', 'absolute-weaver' ),
		'refresh',
		'plus'
	);

	$opts['_primary_mw_cols_list'] = absolute_weaver_cz_textarea(
		__( 'Small Tablet Widget Widths', 'absolute-weaver' ),
		__( 'List of widget widths. (&diams;)', 'absolute-weaver' ),
		'1',
		'',
		'refresh',
		'plus'
	);

	$opts['_primary_sw_cols_list'] = absolute_weaver_cz_textarea(
		__( 'Phone Widget Widths', 'absolute-weaver' ),
		__( 'List of widget widths. (&diams;)', 'absolute-weaver' ),
		'1',
		'',
		'refresh',
		'plus'
	);


	$opts['primary_no_widget_margins'] = absolute_weaver_cz_checkbox(
		__( 'No Smart Widget Margins', 'absolute-weaver' ),
		__( 'Do not use "smart margins" between  multi-column widgets on rows.', 'absolute-weaver' )
	);


	$opts['primary_eq_widgets'] = absolute_weaver_cz_checkbox(
		__( 'Equal Height Widget Rows', 'absolute-weaver' ),
		__( 'Make widgets equal height rows if &gt; 1 column.', 'absolute-weaver' ),
		'plus'
	);

	$opts['layout-secondary-widget-heading'] = absolute_weaver_cz_group_title( __( 'Secondary Sidebar', 'absolute-weaver' ) );

	$opts['secondary_cols_int'] = absolute_weaver_cz_range(
		__( 'Columns of Widgets', 'absolute-weaver' ),
		'',
		1,
		array(
			'min'  => 1,
			'max'  => 8,
			'step' => 1,
		)
	);

	$opts['layout-secondary-custom-widths'] = absolute_weaver_cz_heading( __( 'Custom Widget Widths', 'absolute-weaver' ) . ABSOLUTE_WEAVER_PLUS_ICON,
		__( 'You can optionally specify widget widths, including for specific devices. Overrides the Columns of Widgets setting. Please read the help entry!', 'absolute-weaver' ) );

	$opts['_secondary_lw_cols_list'] = absolute_weaver_cz_textarea(
		__( 'Desktop Widget Widths', 'absolute-weaver' ),
		__( 'List of widget widths separated by comma. Use semi-colon ( ; ) for end of each row. Widths are % of each row. (&diams;)', 'absolute-weaver' ),
		'1',
		__( '25,25,50; 60,40; - for example', 'absolute-weaver' ),
		'refresh',
		'plus'
	);

	$opts['_secondary_mw_cols_list'] = absolute_weaver_cz_textarea(
		__( 'Small Tablet Widget Widths', 'absolute-weaver' ),
		__( 'List of widget widths. (&diams;)', 'absolute-weaver' ),
		'1',
		'',
		'refresh',
		'plus'
	);

	$opts['_secondary_sw_cols_list'] = absolute_weaver_cz_textarea(
		__( 'Phone Widget Widths', 'absolute-weaver' ),
		__( 'List of widget widths. (&diams;)', 'absolute-weaver' ),
		'1',
		'',
		'refresh',
		'plus'
	);


	$opts['secondary_no_widget_margins'] = absolute_weaver_cz_checkbox(
		__( 'No Smart Widget Margins', 'absolute-weaver' ),
		__( 'Do not use "smart margins" between multi-column widgets on rows.', 'absolute-weaver' )
	);


	$opts['secondary_eq_widgets'] = absolute_weaver_cz_checkbox(
		__( 'Equal Height Widget Rows', 'absolute-weaver' ),
		__( 'Make widgets equal height rows if &gt; 1 column.', 'absolute-weaver' ),
		'plus'
	);

	return $opts;
}

/* ================================== Controls: Layout -> footer ==================================== */

function absolute_weaver_controls_layout_footer() {
	$opts = array();

	$opts['footer_sb_cols_int'] = absolute_weaver_cz_range(
		__( 'Footer Columns of Widgets', 'absolute-weaver' ),
		'',
		1,
		array(
			'min'  => 1,
			'max'  => 8,
			'step' => 1,
		)
	);

	$opts['layout_full_note3'] = absolute_weaver_cz_html_description(
		'<small>' . __( '<em>Absolute Weaver Plus</em> includes options for custom column widths, and smart margins.', 'absolute-weaver' ) . '</small>', 'plus' );

	$opts['layout-footer-custom-widths'] = absolute_weaver_cz_heading( __( 'Footer Custom Widget Widths', 'absolute-weaver' ) . ABSOLUTE_WEAVER_PLUS_ICON,
		__( 'You can optionally specify widget widths, including for specific devices. Overrides the Columns of Widgets setting. Please read the help entry!', 'absolute-weaver' )
	);

	$opts['_footer_sb_lw_cols_list'] = absolute_weaver_cz_textarea(
		__( 'Footer Desktop Widget Widths', 'absolute-weaver' ),
		__( 'List of widget widths separated by comma. Use semi-colon ( ; ) for end of each row. Widths are % of each row. (&diams;)', 'absolute-weaver' ),
		'1',
		__( '25,25,50; 60,40; - for example', 'absolute-weaver' ),
		'refresh',
		'plus'
	);


	$opts['_footer_sb_mw_cols_list'] = absolute_weaver_cz_textarea(
		__( 'Footer Small Tablet Widget Widths', 'absolute-weaver' ),
		__( 'List of widget widths. (&diams;)', 'absolute-weaver' ),
		'1',
		'',
		'refresh',
		'plus'
	);

	$opts['_footer_sb_sw_cols_list'] = absolute_weaver_cz_textarea(
		__( 'Footer Phone Widget Widths', 'absolute-weaver' ),
		__( 'List of widget widths. (&diams;)', 'absolute-weaver' ),
		'1',
		'',
		'refresh',
		'plus'
	);

	$opts['footer_sb_no_widget_margins'] = absolute_weaver_cz_checkbox(
		__( 'Footer No Smart Widget Margins', 'absolute-weaver' ),
		__( 'Do not use "smart margins" between  multi-column widgets on rows.', 'absolute-weaver' )
	);


	$opts['footer_sb_eq_widgets'] = absolute_weaver_cz_checkbox(
		__( 'Footer Equal Height Widget Rows', 'absolute-weaver' ),
		__( 'Make widgets equal height rows if &gt; 1 column.', 'absolute-weaver' ),
		'plus'
	);


	return $opts;
}
