<?php

/**
 * Define the sections and settings for the style panel
 *
 */
function absolute_weaver_customizer_define_pagebuilder_sections() {
	$panel = 'absolute_weaver_page-builder';
	$pb_sections = array();

	// global settings

	$pb_sections['pb-header-replace'] = array(
		'panel'       => $panel,
		'title'       => esc_html__( 'Global Header Area Replacement', 'absolute-weaver' ),
		'description' => esc_html__( 'Replace Weaver Header Area with Page Builder page.', 'absolute-weaver' ),
		'options'     => array(

			'pb-hdr1' => absolute_weaver_cz_group_title( __( 'Header Replacement Page', 'absolute-weaver' ),
				__( 'You can replace the entire Weaver Header area with the content from a page builder page. None of the standard theme header elements except the menu bars will be displayed.  You can also specify a Header Replacement as a Per Page option.', 'absolute-weaver' ) ),

			'pb_header_hide_menus' => absolute_weaver_cz_checkbox(
				__( 'Hide Weaver Menus', 'absolute-weaver' ),
				__( 'Check to hide the Weaver Primary Menu normally displayed below the replacement page.', 'absolute-weaver' )
			),
		),

	);


	if ( defined( 'ELEMENTOR_VERSION' ) ) {                // only provide if elementor is active
		$pb_sections['pb-header-replace']['options']['elementor_header_replacement'] = absolute_weaver_cz_select(
			__( 'Elementor Header Replacement', 'absolute-weaver' ),
			__( 'Select an Elementor Page or Post to replace the Header Area.', 'absolute-weaver' ),
			'absolute_weaver_cz_choices_elementor_pages', 'none', 'refresh'
		);
	}

	if ( defined( 'SITEORIGIN_PANELS_VERSION' ) ) {        // only provide if siteorigins is active

		$pb_sections['pb-header-replace']['options']['siteorigin_header_replacement'] = absolute_weaver_cz_select(
			__( 'SiteOrigin Header Replacement', 'absolute-weaver' ),
			__( 'Select an SiteOrigin Page or Post to replace the Header Area.', 'absolute-weaver' ),
			'absolute_weaver_cz_choices_siteorigin_pages', 'none', 'refresh'
		);
	}

	if ( ! defined( 'ELEMENTOR_VERSION' ) && ! defined( 'SITEORIGIN_PANELS_VERSION' ) ) {
		$pb_sections['pb-header-replace']['options']['no-pb1'] = absolute_weaver_cz_group_title( __( 'No Page Builder Detected', 'absolute-weaver' ),
			__( 'Sorry, Weaver can only show a list of page builder pages from Elementor or SiteOrigin Page Builder, but you can still provide a page/post ID. Please install and activate one of those plugins.', 'absolute-weaver' ) );
	}

	$pb_sections['pb-header-replace']['options']['pb_header_replace_page_id'] = absolute_weaver_cz_textarea(
		__( 'Page or Post ID Header Replacement', 'absolute-weaver' ),
		__( 'Provide any page or post ID to serve as header replacement. Overrides list selection above. Does not have to be from a page builder.', 'absolute-weaver' ), 1, '',
		'refresh', '', 'absolute_weaver_cz_sanitize_int' );


	$pb_sections['footer-pb-replace'] = array(
		'panel'       => $panel,
		'title'       => esc_html__( 'Global Footer Area Replacement', 'absolute-weaver' ),
		'description' => esc_html__( 'Replace Weaver Footer Area with Page Builder page.', 'absolute-weaver' ),
		'options'     => array(

			'pb-ftr1' => absolute_weaver_cz_group_title( __( 'Footer Replacement', 'absolute-weaver' ),
				__( 'You can replace the entire Weaver Footer area with the content from a page builder page. None of the standard theme footer elements will be displayed.  You can also specify a Footer Replacement as a Per Page option.', 'absolute-weaver' ) ),

		),

	);


	if ( defined( 'ELEMENTOR_VERSION' ) ) {                // only provide if elementor is active
		$pb_sections['footer-pb-replace']['options']['elementor_footer_replacement'] = absolute_weaver_cz_select(
			__( 'Elementor Footer Replacement', 'absolute-weaver' ),
			__( 'Select an Elementor Page or Post to replace the Footer Area.', 'absolute-weaver' ),
			'absolute_weaver_cz_choices_elementor_pages', 'none', 'refresh'
		);
	}

	if ( defined( 'SITEORIGIN_PANELS_VERSION' ) ) {        // only provide if siteorigins is active

		$pb_sections['footer-pb-replace']['options']['siteorigin_footer_replacement'] = absolute_weaver_cz_select(
			__( 'SiteOrigin Footer Replacement', 'absolute-weaver' ),
			__( 'Select an SiteOrigin Page or Post to replace the Footer Area.', 'absolute-weaver' ),
			'absolute_weaver_cz_choices_siteorigin_pages', 'none', 'refresh'
		);
	}

	if ( ! defined( 'ELEMENTOR_VERSION' ) && ! defined( 'SITEORIGIN_PANELS_VERSION' ) ) {
		$pb_sections['footer-pb-replace']['options']['no-pb2'] = absolute_weaver_cz_group_title( __( 'No Page Builder Detected', 'absolute-weaver' ),
			__( 'Sorry, Weaver can only show a list of page builder pages from Elementor or SiteOrigin Page Builder, but you can still provide a page/post ID. Please install and activate one of those plugins.', 'absolute-weaver' ) );
	}

	$pb_sections['footer-pb-replace']['options']['pb_footer_replace_page_id'] = absolute_weaver_cz_textarea(
		__( 'Page or Post ID Footer Replacement', 'absolute-weaver' ),
		__( 'Provide any page or post ID to serve as footer replacement. Overrides list selection above. Does not have to be from a page builder', 'absolute-weaver' ),
		1, '', 'refresh', false, 'absolute_weaver_cz_sanitize_int' );


	$pb_sections['pb-elementor'] = array(
		'panel'       => $panel,
		'title'       => esc_html__( 'Elementor', 'absolute-weaver' ),
		'description' => esc_html__( 'Weaver theme overrides for Elementor Page Builder.', 'absolute-weaver' ),
		'options'     => array(

			'pb-title1' => absolute_weaver_cz_group_title( __( 'Elementor Default Colors (Global)', 'absolute-weaver' ),
				__( 'You can override the Elementor per Page/Post Default Color Palette values ( Primary, Secondary, Text, and Accent ) globally by setting as many of the following color values you wish. These colors will be used for ALL Elementor Pages or Posts, whether or not you have chosen a Color Palette, or have disabled the Default Colors in the Elementor:Settings admin menu. The goal is to allow you to match your Weaver theme settings with your Elementor designs. You do not need to set all four colors. Any you don\'t specify will show the default Elementor color.', 'absolute-weaver' ) ),

			'elementor_primary_color' => absolute_weaver_cz_color(
				'elementor_primary_color',
				__( 'Elementor Primary Color', 'absolute-weaver' ),
				__( 'The Primary color is used for Elementor Titles and other elements.', 'absolute-weaver' ),
				'refresh'
			),

			'elementor_secondary_color' => absolute_weaver_cz_color(
				'elementor_secondary_color',
				__( 'Elementor Secondary Color', 'absolute-weaver' ),
				__( 'The Secondary color is used in just a few Elementor elements.', 'absolute-weaver' ),
				'refresh'
			),


			'elementor_text_color' => absolute_weaver_cz_color(
				'elementor_text_color',
				__( 'Elementor Text Color', 'absolute-weaver' ),
				__( 'The Text color is used as the main text color in most of the Elementor elements.', 'absolute-weaver' ),
				'refresh'
			),

			'elementor_accent_color' => absolute_weaver_cz_color(
				'elementor_accent_color',
				__( 'Elementor Accent Color', 'absolute-weaver' ),
				__( 'The Accent color is used as ta highlight color in some Elementor elements such as the TAB element.', 'absolute-weaver' ),
				'refresh'
			),
		),

	);


	return $pb_sections;
}
