<?php

/**
 * Define the sections and settings for the spacing panel
 */

function absolute_weaver_customizer_define_spacing_sections() {
	$panel = 'absolute_weaver_spacing';
	$spacing_sections = array();

	// global settings

	$spacing_sections['spacing-global'] = array(
		'panel'       => $panel,
		'title'       => __( 'Site Wide Spacing', 'absolute-weaver' ),
		'description' => 'Set site settings that affect width and height.',
		'options'     => absolute_weaver_controls_spacing_global(),

	);


	$spacing_sections['spacing-fullwidth'] = array(
		'panel'       => $panel,
		'title'       => __( 'Full Width Options', 'absolute-weaver' ),
		'description' => absolute_weaver_markdown( __( 'The *One-Step Site Layout* option allows you easily select full width sites. Instead, you can also try adjusting the width of the Header, Container, Content, and Footer areas on the *Spacing, Width, Alignment* menu, combined with *Extend BG Attributes*, to create interesting full width sites.', 'absolute-weaver' )
		),
		'options'     => absolute_weaver_controls_spacing_fullwidth(),
	);


	/**
	 * Wrapping areas
	 */

	$spacing_sections['spacing-wrapping'] = array(
		'panel'       => $panel,
		'title'       => __( 'Wrapping Areas', 'absolute-weaver' ),
		'description' => 'Set margins, padding, spacing, positioning, and widths for site wrapper and container.',
		'options'     => absolute_weaver_controls_spacing_wrapping(),
	);


	/**
	 * Site Header
	 *
	 */


	$spacing_sections['spacing-header'] = array(
		'panel'       => $panel,
		'title'       => __( 'Header Area', 'absolute-weaver' ),
		'description' => absolute_weaver_markdown( __( 'Set spacing for Header Area. Option groups include **Site Header Area, Site Title and Tagline, Header Widget Area**, and **Header HTML Area**.', 'absolute-weaver' ) ),
		'options'     => absolute_weaver_controls_spacing_header(),
	);


	/**
	 * Main Menu
	 */

	$spacing_sections['spacing-menus'] = array(
		'panel'       => $panel,
		'title'       => esc_html__( 'Menus', 'absolute-weaver' ),
		'description' => esc_html__( 'Set spacing for Primary, Secondary, and Extra Menus.', 'absolute-weaver' ),
		'options'     => absolute_weaver_controls_spacing_menus(),
	);


	/**
	 * Info Bar
	 */
	$spacing_sections['spacing-info-bar'] = array(
		'panel'       => $panel,
		'title'       => esc_html__( 'Info Bar', 'absolute-weaver' ),
		'description' => esc_html__( 'Info Bar with breadcrumbs and paged navigation displayed under Primary Menu.', 'absolute-weaver' ),
		'options'     => absolute_weaver_controls_spacing_infobar(),
	);


	/**
	 * Content
	 */
	$spacing_sections['spacing-content'] = array(
		'panel'       => $panel,
		'title'       => esc_html__( 'Content', 'absolute-weaver' ),
		'description' => esc_html__( 'Spacing for general page and post content.', 'absolute-weaver' ),
		'options'     => absolute_weaver_controls_spacing_content(),
	);


	/**
	 * Post Specific
	 */
	$spacing_sections['spacing-post-specific'] = array(
		'panel'       => $panel,
		'title'       => esc_html__( 'Post Specific', 'absolute-weaver' ),
		'description' => esc_html__( 'Post Specific spacing - override Content spacing.', 'absolute-weaver' ),
		'options'     => absolute_weaver_controls_spacing_postspecific(),
	);


	/**
	 * Sidebars
	 */

	$spacing_sections['spacing-sidebars'] = array(
		'panel'       => $panel,
		'title'       => __( 'Sidebars', 'absolute-weaver' ),
		'description' => __( 'Primary and Secondary Sidebars.', 'absolute-weaver' ),
		'options'     => absolute_weaver_controls_spacing_sidebars(),
	);


	/**
	 * Widgets
	 */
	$spacing_sections['spacing-widgets'] = array(
		'panel'       => $panel,
		'title'       => esc_html__( 'Individual Widgets', 'absolute-weaver' ),
		'description' => esc_html__( 'Padding and Margins for Individual Widgets. Widget width responsively determined by enclosing area.', 'absolute-weaver' ),
		'options'     => absolute_weaver_controls_spacing_widgets(),
	);


	/**
	 * Footer
	 */


	$spacing_sections['spacing-footer'] = array(
		'panel'       => $panel,
		'title'       => esc_html__( 'Footer Area', 'absolute-weaver' ),
		'description' => absolute_weaver_markdown( __( 'Set spacing for Footer Area. Option groups include **Site Footer Area, Site Title and Tagline, Footer Widget Area**, and **Footer HTML Area**.', 'absolute-weaver' ) ),
		'options'     => absolute_weaver_controls_spacing_footer(),
	);


	return $spacing_sections;
}

function absolute_weaver_controls_spacing_global() {
	$opts = array();

	$opts['fullwidth-expand-swide'] = absolute_weaver_cz_group_title( __( 'Site Width', 'absolute-weaver' ),
		__( 'Maximum width of your site on a desktop browser. This is the width of the #wrapper area for standard display. Full width layouts and alignments may change the display width of content, but each site should have a designed maximum width.', 'absolute-weaver' ) );

	$opts['theme_width_int'] = absolute_weaver_cz_range(
		__( 'Site Width (px)', 'absolute-weaver' ),
		__( 'Note: This is the maximum width on desktops. Mobile devices adjust width responsively.', 'absolute-weaver' ),
		ABSOLUTE_WEAVER_THEME_WIDTH,
		array( 'min' => 770, 'max' => 3200, 'step' => 10 )
	);

	$opts['smart_margin_int'] = absolute_weaver_cz_range_float(
		__( 'Smart Margin Width (%)', 'absolute-weaver' ),
		__( 'Width used for smart column margins for Sidebars and Content Area. (Default: 1%)', 'absolute-weaver' ),
		1.0,
		array( 'min' => 0.25, 'max' => 10.0, 'step' => 0.25 ),
		'refresh',
		'plus'
	);

	return $opts;
}

function absolute_weaver_controls_spacing_fullwidth() {
	$opts = array();

	$opts['spacing-core-width'] = absolute_weaver_cz_group_title( __( 'Overall Site Width Layout', 'absolute-weaver' ) );

	$opts['site_layout'] = absolute_weaver_cz_select(    // must be refresh because column class applied to specific page id
		__( 'One-Step Site Layout', 'absolute-weaver' ),
		__( 'This setting allows you to quickly set up a Full Width or Stretched site layout. The Custom option allows you to use all of the following full width options to build the exact layout you need. IMPORTANT NOTE: Switching back to Full Width or Stretched will clear most other Custom options you may have set.', 'absolute-weaver' ),
		array(
			''          => esc_html__( 'Custom: Use Full Width Checkbox Options ', 'absolute-weaver' ),
			'fullwidth' => esc_html__( 'Full Width - Extend BG to full width', 'absolute-weaver' ),
			'stretched' => esc_html__( 'Stretched - Expand to full width', 'absolute-weaver' ),
		),
		'none', 'refresh'
	);

	$opts['spacing-core-trad=width'] = absolute_weaver_cz_group_title( __( 'Other Site Width Layouts', 'absolute-weaver' ) );

	$opts['wrapper_fullwidth'] = absolute_weaver_cz_checkbox(
		__( 'Stretch Entire Site Full Width', 'absolute-weaver' ),
		__( 'Display site stretched to full width. This option is similar to the Stretched One-Step Site Layout option but makes content as well as the footer and header stretched. This option overrides the "Site Width" option.', 'absolute-weaver' )
	);


	/* ------------------------ FULL WIDTH HEADER ----------------------- */

	$opts['fullwidth-expand-header'] = absolute_weaver_cz_group_title( __( 'Full Width Site Header Area', 'absolute-weaver' ),
		__( 'The Header Area contains the Menus, the Header Widget Area, the Site Image, and the Header HTML Area.', 'absolute-weaver' )
	);

	$opts['header_extend_width'] = absolute_weaver_cz_checkbox(
		__( 'Header Extend BG Attributes', 'absolute-weaver' ),
		__( 'Extend BG attributes to full width', 'absolute-weaver' )
	);


	$opts['expand_header'] = absolute_weaver_cz_checkbox(
		__( 'Header Stretch Area', 'absolute-weaver' ),
		__( 'Checking this option will automatically include the other Header Area Expand options as well.', 'absolute-weaver' )
	);


	/* ------------------------ FULL WIDTH MENUS ----------------------- */

	$opts['expand_header-image'] = absolute_weaver_cz_checkbox(
		__( 'Header Image Stretch Area', 'absolute-weaver' ),
		__( 'Also consider using the "Spacing, Widths, Alignment -> Header Area -> Move Title/Tagline over Image" option to create an attractive header.', 'absolute-weaver' )
	);


	$opts['fullwidth-expand-menusm'] = absolute_weaver_cz_group_title( __( 'Full Width Menu', 'absolute-weaver' ),
		__( 'Expand the primary menu to full width.', 'absolute-weaver' ) );

	$opts['m_primary_extend_width'] = absolute_weaver_cz_checkbox(
		__( 'Primary Menu Extend BG Attributes', 'absolute-weaver' )
	);


	$opts['expand_m_primary'] = absolute_weaver_cz_checkbox(
		__( 'Primary Menu Stretch', 'absolute-weaver' )
	);



	/* ------------------------ FULL WIDTH CONTENT ----------------------- */

	$opts['fullwidth-expand-content'] = absolute_weaver_cz_group_title( __( 'Full Width Content Area', 'absolute-weaver' ),
		__( 'The Content Area contains page content, as well as posts.', 'absolute-weaver' ) );


	$opts['container_extend_width'] = absolute_weaver_cz_checkbox(
		__( 'Container Extend BG Attributes', 'absolute-weaver' )
	);

	$opts['expand_container'] = absolute_weaver_cz_checkbox(
		__( 'Container Stretch Area', 'absolute-weaver' ),
		__( 'The container wraps the Info Bar, the content, and widget areas.', 'absolute-weaver' )
	);

	$opts['infobar_extend_width'] = absolute_weaver_cz_checkbox(
		__( 'Info Bar Extend BG', 'absolute-weaver' ),
		__( 'The Info Bar contains the breadcrumbs and page links.', 'absolute-weaver' )
	);

	$opts['expand_infobar'] = absolute_weaver_cz_checkbox(
		__( 'Info Bar Stretch to Full Width', 'absolute-weaver' )
	);

	$opts['post_extend_width'] = absolute_weaver_cz_checkbox(
		__( 'Posts Extend BG Attributes', 'absolute-weaver' ),
		__( 'This option most useful with FI as BG images', 'absolute-weaver' )
	);

	$opts['post_expand'] = absolute_weaver_cz_checkbox(
		__( 'Posts Stretch to Full Width', 'absolute-weaver' )
	);


	/* ------------------------ FULL WIDTH FOOTER ----------------------- */

	$opts['fullwidth-expand-footer'] = absolute_weaver_cz_group_title( __( 'Full Width Footer Area', 'absolute-weaver' ),
		__( 'The Footer Area contains the Footer Widget Area, the Footer HTML Area, the copyright line.', 'absolute-weaver' ) );

	$opts['footer_extend_width'] = absolute_weaver_cz_checkbox(
		__( 'Extend Footer BG Attributes', 'absolute-weaver' )
	);

	$opts['expand_footer'] = absolute_weaver_cz_checkbox(
		__( 'Footer Stretch Area', 'absolute-weaver' ),
		__( 'Checking this option will automatically include the other Footer Area Stretch options as well.', 'absolute-weaver' )
	);

	$opts['footer_sb_extend_width'] = absolute_weaver_cz_checkbox(
		__( 'Extend Footer Widget Area BG Attributes', 'absolute-weaver' )
	);

	$opts['expand_footer_sb'] = absolute_weaver_cz_checkbox(
		__( 'Footer Widget Area Stretch', 'absolute-weaver' )
	);

	if ( function_exists( 'absolute_weaver_ts_installed' ) ) {
		$opts['footer_html_extend_width'] = absolute_weaver_cz_checkbox(
			__( 'Extend Footer HTML Area BG Attributes', 'absolute-weaver' )
		);

		$opts['expand_footer_html'] = absolute_weaver_cz_checkbox(
			__( 'Footer HTML Area Stretch', 'absolute-weaver' )
		);
	}



	$opts['expand_site-ig-wrap'] = absolute_weaver_cz_checkbox(
		__( 'Footer Copyright Area Stretch', 'absolute-weaver' )
	);


	return $opts;
}

function absolute_weaver_controls_spacing_wrapping() {
	$opts = array();

	// ------- WRAPPER

	$opts['wrapper-space-heading'] = absolute_weaver_cz_group_title( __( 'Global Wrapper Area', 'absolute-weaver' ),
		__( 'The Wrapper is the &lt;div&gt; that wraps entire site. Please see the Site Wide Spacing menu to set the site width.', 'absolute-weaver' ) );

	$opts['wrapper_padding_T'] = absolute_weaver_cz_range(
		__( 'Top Padding (px)', 'absolute-weaver' ),
		__( 'These options control the padding ( inner space ) around the area.', 'absolute-weaver' ),
		0,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['wrapper_padding_B'] = absolute_weaver_cz_range(
		__( 'Bottom Padding (px)', 'absolute-weaver' ),
		'',
		0,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['wrapper_padding_L'] = absolute_weaver_cz_range(
		__( 'Left Padding (px)', 'absolute-weaver' ),
		'',
		0,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['wrapper_padding_R'] = absolute_weaver_cz_range(
		__( 'Right Padding (px)', 'absolute-weaver' ),
		'',
		0,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['wrapper_margin_T'] = absolute_weaver_cz_range(
		__( 'Top Margin (px)', 'absolute-weaver' ),
		absolute_weaver_markdown( __( 'Set Top and Bottom Margins. **Side margins are auto-generated.**', 'absolute-weaver' ) ),
		0,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['wrapper_margin_B'] = absolute_weaver_cz_range(
		__( 'Bottom Margin (px)', 'absolute-weaver' ),
		'',
		0,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	// ------- CONTAINER

	$opts['container-space-heading'] = absolute_weaver_cz_group_title( __( 'Container Area', 'absolute-weaver' ),
		__( 'The Container is the &lt;div&gt; that wraps the content. Does not include Header and Footer.', 'absolute-weaver' ) );


	$opts['container_width_int'] = absolute_weaver_cz_range_float(
		__( 'Container Width (%)', 'absolute-weaver' ),
		__( 'Width of Area in % of enclosing area on desktop and small tablet. Hint: use with Container "Center align" setting. (Default: 100%, use 0 for auto)', 'absolute-weaver' ),
		100.,
		array(
			'min'  => 0,
			'max'  => 100,
			'step' => 0.5,
		),
		'postMessage'
	);

	$opts['container_max_width_int'] = absolute_weaver_cz_range(
		__( 'Container Area Max Width (px)', 'absolute-weaver' ),
		__( 'This advanced option allows you to set a maximum width for this area. This is not commonly used, but can make interesting designs, especially if you center align the area. Use 0 for no Max Width.', 'absolute-weaver' ),
		0,
		array(
			'min'  => 0,
			'max'  => 4000,
			'step' => 5,
		),
		'postMessage',
		'plus'
	);

	$opts['container_align'] = absolute_weaver_cz_select(
		__( 'Align Container Area', 'absolute-weaver' ),
		'',
		'absolute_weaver_cz_choices_align', 'float-left', 'refresh'
	);

	$opts['container_padding_T'] = absolute_weaver_cz_range(
		__( 'Top Padding (px)', 'absolute-weaver' ),
		__( 'These options control the padding ( inner space ) around the area.', 'absolute-weaver' ),
		0,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['container_padding_B'] = absolute_weaver_cz_range(
		__( 'Bottom Padding (px)', 'absolute-weaver' ),
		'',
		0,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['container_padding_L'] = absolute_weaver_cz_range(
		__( 'Left Padding (px)', 'absolute-weaver' ),
		'',
		0,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['container_padding_R'] = absolute_weaver_cz_range(
		__( 'Right Padding (px)', 'absolute-weaver' ),
		'',
		0,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['container_margin_T'] = absolute_weaver_cz_range(
		__( 'Top Margin (px)', 'absolute-weaver' ),
		'',
		0,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['container_margin_B'] = absolute_weaver_cz_range(
		__( 'Bottom Margin (px)', 'absolute-weaver' ),
		'',
		0,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	return $opts;
}


function absolute_weaver_controls_spacing_header() {
	$opts = array();

	// We can't handle postMessage if header_extend_width is true...
	$hdr_width_transport = absolute_weaver_getopt_checked( 'header_extend_width' ) ? 'refresh' : 'postMessage';

	$opts['spacing-heading-header'] = absolute_weaver_cz_group_title( __( 'Site Header Area', 'absolute-weaver' ) );

	$opts['header_width_int'] = absolute_weaver_cz_range_float(
		__( 'Header Area Width (%)', 'absolute-weaver' ),
		__( 'Width of Area in % of enclosing area on desktop and small tablet. Hint: use with Header "Center align" setting. (Default: 100%, use 0 for auto)', 'absolute-weaver' ),
		100.,
		array(
			'min'  => 0,
			'max'  => 100,
			'step' => 0.5,
		),
		$hdr_width_transport
	);

	$opts['header_max_width_int'] = absolute_weaver_cz_range(
		__( 'Header Area Max Width (px)', 'absolute-weaver' ),
		__( 'This advanced option allows you to set a maximum width for this area. This is not commonly used, but can make interesting designs, especially if you center align the area.  Use 0 for no Max Width.', 'absolute-weaver' ),
		0,
		array(
			'min'  => 0,
			'max'  => 4000,
			'step' => 5,
		),
		'postMessage',
		'plus'
	);

	$opts['header_align'] = absolute_weaver_cz_select(
		__( 'Align Header Area', 'absolute-weaver' ),
		'',
		'absolute_weaver_cz_choices_align', 'float-left', 'refresh'
	);

	$opts['header_padding_T'] = absolute_weaver_cz_range(
		__( 'Top Padding (px)', 'absolute-weaver' ),
		__( 'These options control the padding ( inner space ) around the area.', 'absolute-weaver' ),
		0,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['header_padding_B'] = absolute_weaver_cz_range(
		__( 'Bottom Padding (px)', 'absolute-weaver' ),
		'',
		0,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['header_padding_L'] = absolute_weaver_cz_range(
		__( 'Left Padding (px)', 'absolute-weaver' ),
		'',
		0,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		$hdr_width_transport
	);

	$opts['header_padding_R'] = absolute_weaver_cz_range(
		__( 'Right Padding (px)', 'absolute-weaver' ),
		'',
		0,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		$hdr_width_transport
	);

	$opts['header_margin_T'] = absolute_weaver_cz_range(
		__( 'Top Margin (px)', 'absolute-weaver' ),
		'',
		0,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['header_margin_B'] = absolute_weaver_cz_range(
		__( 'Bottom Margin (px)', 'absolute-weaver' ),
		'',
		0,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	// Title/tagline

	$opts['spacing-title-header'] = absolute_weaver_cz_group_title( __( 'Site Title and Tagline', 'absolute-weaver' ),
		__( 'Spacing for the Site Title and Tagline', 'absolute-weaver' ) );

	$opts['title_over_image'] = absolute_weaver_cz_checkbox(
		__( 'Move Title/Tagline over Image', 'absolute-weaver' ),
		__( 'Move the Title, Tagline, Search, Logo/HTML and Mini Menu over the Header Image. NOTE: Best to not use with Header Image as BG Image.', 'absolute-weaver' )
	);

	$opts['spacing-titleposition'] = absolute_weaver_cz_heading( __( 'Title Position', 'absolute-weaver' ),
		__( 'Adjust left and top margins for Title. Decimal and negative values allowed.', 'absolute-weaver' ) );

	$opts['site_title_position_xy_X'] = absolute_weaver_cz_range_float(
		__( 'Site Title Left Margin (%)', 'absolute-weaver' ),
		'',
		7,
		array(
			'min'  => - 20,
			'max'  => 50,
			'step' => 0.25,
		),
		'postMessage'
	);

	$opts['site_title_position_xy_Y'] = absolute_weaver_cz_range_float(
		__( 'Site Title Top Margin (%)', 'absolute-weaver' ),
		'',
		0,
		array(
			'min'  => - 20,
			'max'  => 50,
			'step' => 0.25,
		),
		'postMessage'
	);

	$opts['site_title_max_w'] = absolute_weaver_cz_range(
		__( 'Site Title Maximum Width (%)', 'absolute-weaver' ),
		'',
		90,
		array(
			'min'  => 10,
			'max'  => 100,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['spacing-tagposition'] = absolute_weaver_cz_heading(
		__( 'Tagline Position', 'absolute-weaver' ),
		__( 'Adjust left and top margins for Tagline. Decimal and negative values allowed.', 'absolute-weaver' )
	);

	$opts['tagline_xy_X'] = absolute_weaver_cz_range_float(
		__( 'Site Tagline Left Margin (%)', 'absolute-weaver' ),
		'',
		10,
		array(
			'min'  => - 20,
			'max'  => 50,
			'step' => 0.25,
		),
		'postMessage'
	);

	$opts['tagline_xy_Y'] = absolute_weaver_cz_range_float(
		__( 'Site Tagline Top Margin (%)', 'absolute-weaver' ),
		'',
		0,
		array(
			'min'  => - 50,
			'max'  => 50,
			'step' => .25,
		),
		'postMessage'
	);

	$opts['tagline_max_w'] = absolute_weaver_cz_range(
		__( 'Site Tagline Maximum Width (%)', 'absolute-weaver' ),
		'',
		90,
		array(
			'min'  => 10,
			'max'  => 100,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['title_tagline_xy_T'] = absolute_weaver_cz_range(
		__( 'Title/Tagline Top Padding (px)', 'absolute-weaver' ),
		'',
		0,
		array(
			'min'  => 0,
			'max'  => 250,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['title_tagline_xy_B'] = absolute_weaver_cz_range(
		__( 'Title/Tagline Bottom Padding (px)', 'absolute-weaver' ),
		'',
		0,
		array(
			'min'  => 0,
			'max'  => 250,
			'step' => 1,
		),
		'postMessage'
	);


	// ------- Header Widget Area

	$opts['spacing-widgetarea-header'] = absolute_weaver_cz_group_title( __( 'Header Widget Area', 'absolute-weaver' ),
		__( 'Spacing for the Header Widget Area', 'absolute-weaver' ) );

	$opts['header_sb_width_int'] = absolute_weaver_cz_range_float(
		__( 'Header Widget Area Width (%)', 'absolute-weaver' ),
		__( 'Width of Area in % of enclosing area on desktop and small tablet. Hint: use with Align Header Widget Area "Center align" setting. (Default: 0, means auto)', 'absolute-weaver' ),
		0,
		array(
			'min'  => 0,
			'max'  => 100,
			'step' => 0.5,
		),
		'postMessage'
	);

	$opts['header_sb_align'] = absolute_weaver_cz_select(
		__( 'Align Header Widget Area Area', 'absolute-weaver' ),
		'',
		'absolute_weaver_cz_choices_align', 'header_sb_align', 'refresh'
	);

	$opts['header_sb_padding_T'] = absolute_weaver_cz_range(
		__( 'Top Padding (px)', 'absolute-weaver' ),
		'',
		0,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['header_sb_padding_B'] = absolute_weaver_cz_range(
		__( 'Bottom Padding (px)', 'absolute-weaver' ),
		'',
		0,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['header_sb_padding_L'] = absolute_weaver_cz_range(
		__( 'Left Padding (px)', 'absolute-weaver' ),
		'',
		0,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['header_sb_padding_R'] = absolute_weaver_cz_range(
		__( 'Right Padding (px)', 'absolute-weaver' ),
		'',
		0,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['header_sb_margin_T'] = absolute_weaver_cz_range(
		__( 'Top Margin (px)', 'absolute-weaver' ),
		'',
		0,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['header_sb_margin_B'] = absolute_weaver_cz_range(
		__( 'Bottom Margin (px)', 'absolute-weaver' ),
		'',
		0,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['spacing-heading-widgets'] = absolute_weaver_cz_heading( __( 'Widget Area Columns', 'absolute-weaver' ),
		__( 'NOTE: You can set number of columns per widget area on the "Layout" panel.', 'absolute-weaver' ) );


	if ( function_exists( 'absolute_weaver_ts_installed' ) ) {

		// ------- Header HTML Area

		$opts['spacing-htmltarea-header'] = absolute_weaver_cz_group_title( __( 'Header HTML Area', 'absolute-weaver' ),
			__( 'Spacing for the Header HTML Area (when Absolute Weaver Theme Support plugin is installed)', 'absolute-weaver' ) );

		$opts['header_html_width_int'] = absolute_weaver_cz_range_float(
			__( 'Header HTML Area Width (%)', 'absolute-weaver' ),
			__( 'Width of Area in % of enclosing area on desktop and small tablet. Hint: use with Align HTML Area "Center align" setting. You will have to "Save & Publish" and refresh this page if you are using Center Area align. (Default: 100%, use 0 for auto)', 'absolute-weaver' ),
			100,
			array(
				'min'  => 0,
				'max'  => 100,
				'step' => 0.5,
			),
			'postMessage'
		);

		$opts['header_html_align'] = absolute_weaver_cz_select(
			__( 'Align Header HTML Area', 'absolute-weaver' ),
			'',
			'absolute_weaver_cz_choices_align', 'float-left', 'refresh'
		);

		$opts['header_html_center_content'] = absolute_weaver_cz_checkbox_post(
			__( 'Center Content within HTML Area', 'absolute-weaver' )
		);

		$opts['header_html_padding_T'] = absolute_weaver_cz_range(
			__( 'Top Padding (px)', 'absolute-weaver' ),
			'',
			0,
			array(
				'min'  => 0,
				'max'  => 150,
				'step' => 1,
			),
			'postMessage'
		);

		$opts['header_html_padding_B'] = absolute_weaver_cz_range(
			__( 'Bottom Padding (px)', 'absolute-weaver' ),
			'',
			0,
			array(
				'min'  => 0,
				'max'  => 150,
				'step' => 1,
			),
			'postMessage'
		);

		$opts['header_html_padding_L'] = absolute_weaver_cz_range(
			__( 'Left Padding (px)', 'absolute-weaver' ),
			'',
			0,
			array(
				'min'  => 0,
				'max'  => 150,
				'step' => 1,
			),
			'postMessage'
		);

		$opts['header_html_padding_R'] = absolute_weaver_cz_range(
			__( 'Right Padding (px)', 'absolute-weaver' ),
			'',
			0,
			array(
				'min'  => 0,
				'max'  => 150,
				'step' => 1,
			),
			'postMessage'
		);

		$opts['header_html_margin_T'] = absolute_weaver_cz_range(
			__( 'Top Margin (px)', 'absolute-weaver' ),
			'',
			0,
			array(
				'min'  => 0,
				'max'  => 150,
				'step' => 1,
			),
			'postMessage'
		);

		$opts['header_html_margin_B'] = absolute_weaver_cz_range(
			__( 'Bottom Margin (px)', 'absolute-weaver' ),
			'',
			0,
			array(
				'min'  => 0,
				'max'  => 150,
				'step' => 1,
			),
			'postMessage'
		);
	} // end if ts support


	return $opts;
}

function absolute_weaver_controls_spacing_menus() {
	$opts = array();


	$opts['primary-mm-title'] = absolute_weaver_cz_group_title(
		__( 'Primary Menu', 'absolute-weaver' )
	);

	$opts['m_primary_align'] = absolute_weaver_cz_select(
		__( 'Align Primary Menu Bar', 'absolute-weaver' ),
		__( 'Align this menu on desktop view. Mobile always left aligned.', 'absolute-weaver' ),
		'absolute_weaver_cz_choices_align_menu', 'float-left'
	);

	$opts['m_primary_menu_bar_pad_dec'] = absolute_weaver_cz_range_float(
		__( 'Desktop Menu Bar Padding', 'absolute-weaver' ),
		__( 'Add padding to menu bar top and bottom for Desktop devices.', 'absolute-weaver' ),
		0,
		array(
			'min'  => 0,
			'max'  => 10,
			'step' => .1,
		)
	);


	$opts['m_primary_top_margin_dec'] = absolute_weaver_cz_range(
		__( 'Menu Top Margin (px)', 'absolute-weaver' ),
		'',
		0,
		array(
			'min'  => 0,
			'max'  => 30,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['m_primary_bottom_margin_dec'] = absolute_weaver_cz_range(
		__( 'Menu Bottom Margin (px)', 'absolute-weaver' ),
		'',
		0,
		array(
			'min'  => 0,
			'max'  => 30,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['m_primary_right_padding_dec'] = absolute_weaver_cz_range_float(
		__( 'Desktop Menu Spacing (em)', 'absolute-weaver' ),
		__( 'Add space between desktop menu bar items. (not on Smart Menus)', 'absolute-weaver' ),
		0,
		array(
			'min'  => 0.0,
			'max'  => 6,
			'step' => .2,
		)
	);


	if ( function_exists( 'absolute_weaver_ts_installed' ) ) {
		$opts['m_primary_html_margin_dec'] = absolute_weaver_cz_range_float(
			__( 'Menu HTML: Top Margin (em)', 'absolute-weaver' ),
			__( 'Margin above Added Menu HTML (Used to adjust for Desktop menu. Negative values can help.)', 'absolute-weaver' ),
			0,
			array(
				'min'  => - 5.0,
				'max'  => 5.0,
				'step' => .1,
			),
			'refresh',
			'plus'
		);
	}

	$opts['spacing-mm-heading'] = absolute_weaver_cz_group_title(
		esc_html__( 'Header Mini Menu', 'absolute-weaver' ), '' );

	$opts['m_header_mini_top_margin_dec'] = absolute_weaver_cz_range_float(
		__( 'Mini Menu Top Margin (em)', 'absolute-weaver' ),
		__( 'Top margin for Header Mini Menu. Negative value moves it up. (Default: -1.0em)', 'absolute-weaver' ),
			-1,
			array(
				'min'  => - 10.0,
				'max'  => 10.0,
				'step' => 0.25,
			),
		'refresh'
		);


	return $opts;
}

function absolute_weaver_controls_spacing_infobar() {
	$opts = array();


	$opts['spacing-info-bar-heading'] =
		absolute_weaver_cz_heading( __( 'Info Bar', 'absolute-weaver' ) );

	$opts['infobar_width_int'] = absolute_weaver_cz_range_float(
		__( 'Info Bar Width (%)', 'absolute-weaver' ),
		__( 'Width of Area in % of enclosing area on desktop and small tablet. Hint: use with Info Bar "Center align" setting. (Default: 100%, use 0 for auto)', 'absolute-weaver' ),
		100,
		array(
			'min'  => 0,
			'max'  => 100,
			'step' => 0.5,
		),
		'postMessage'
	);

	$opts['infobar_align'] = absolute_weaver_cz_select(
		__( 'Align Info Bar Area', 'absolute-weaver' ),
		'',
		'absolute_weaver_cz_choices_align', 'float-left', 'refresh'
	);

	$opts['infobar_padding_T'] = absolute_weaver_cz_range(
		__( 'Top Padding (px)', 'absolute-weaver' ),
		__( 'These options control the padding ( inner space ) around the area.', 'absolute-weaver' ),
		5,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['infobar_padding_B'] = absolute_weaver_cz_range(
		__( 'Bottom Padding (px)', 'absolute-weaver' ),
		'',
		5,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['infobar_padding_L'] = absolute_weaver_cz_range(
		__( 'Left Padding (px)', 'absolute-weaver' ),
		'',
		5,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['infobar_padding_R'] = absolute_weaver_cz_range(
		__( 'Right Padding (px)', 'absolute-weaver' ),
		'',
		5,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['infobar_margin_T'] = absolute_weaver_cz_range(
		__( 'Top Margin (px)', 'absolute-weaver' ),
		'',
		0,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['infobar_margin_B'] = absolute_weaver_cz_range(
		__( 'Bottom Margin (px)', 'absolute-weaver' ),
		'',
		0,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	return $opts;
}

function absolute_weaver_controls_spacing_content() {
	$opts = array();


	$opts['content-spacing-t'] = absolute_weaver_cz_group_title(
		__( 'Content Area Padding & Margins', 'absolute-weaver' )
	);

	$opts['content_padding_T'] = absolute_weaver_cz_range(
		__( 'Top Padding (px)', 'absolute-weaver' ),
		'',
		4,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['content_padding_B'] = absolute_weaver_cz_range(
		__( 'Bottom Padding (px)', 'absolute-weaver' ),
		'',
		8,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['content_padding_L'] = absolute_weaver_cz_range_float(
		__( 'Left Padding (%)', 'absolute-weaver' ),
		'',
		2.,
		array(
			'min'  => 0,
			'max'  => 30,
			'step' => .25,
		),
		'postMessage'
	);

	$opts['content_padding_R'] = absolute_weaver_cz_range_float(
		__( 'Right Padding (%)', 'absolute-weaver' ),
		'',
		2.,
		array(
			'min'  => 0,
			'max'  => 30,
			'step' => .25,
		),
		'postMessage'
	);

	$opts['content_margin_T'] = absolute_weaver_cz_range(
		__( 'Top Margin (px)', 'absolute-weaver' ),
		'',
		0,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['content_margin_B'] = absolute_weaver_cz_range(
		__( 'Bottom Margin (px)', 'absolute-weaver' ),
		'',
		0,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['spacing-content-widthinfo'] = absolute_weaver_cz_heading( __( 'Width', 'absolute-weaver' ),
		__( 'The width of this area is automatically determined by the enclosing area.', 'absolute-weaver' ) );

	$opts['content-spacing-t2'] = absolute_weaver_cz_group_title(
		__( 'Content Area Padding & Margins', 'absolute-weaver' )
	);

	$opts['content_smartmargin'] = absolute_weaver_cz_checkbox(
		__( 'Add Side Margin(s)', 'absolute-weaver' ),
		__( 'Automatically add left/right "smart" margins for separation of areas ( sidebar/content ). This is normally used only if you have borders or BG colors for your sidebars.', 'absolute-weaver' )
	);

	$opts['space_after_title_dec'] = absolute_weaver_cz_range_float(
		__( 'Space Between Title and Content (em', 'absolute-weaver' ),
		__( 'Space between Page or Post title and beginning of content.', 'absolute-weaver' ),
		1.0,
		array(
			'min'  => 0,
			'max'  => 20.0,
			'step' => 0.1,
		),
		'postMessage'
	);

	$opts['content_p_list_dec'] = absolute_weaver_cz_range_float(
		__( 'Space after paragraphs and lists (em)', 'absolute-weaver' ),
		'',
		1.5,
		array(
			'min'  => 0,
			'max'  => 20.0,
			'step' => 0.1,
		),
		'postMessage'
	);

	$opts['content-block-spacing'] = absolute_weaver_cz_group_title( __( 'Block Editor Element Margins', 'absolute-weaver' ) );

	$opts['content_block_margin_T'] = absolute_weaver_cz_range_float(
		__( 'Margin Before Blocks (em)', 'absolute-weaver' ),
		__( 'Add margins to non-paragraph Blocks created with Block Editor.', 'absolute-weaver' ),
		1.2,
		array(
			'min'  => 0,
			'max'  => 20.0,
			'step' => 0.1,
		)
	);


	$opts['content_block_margin_B'] = absolute_weaver_cz_range(
		__( 'Margin After Blocks (em)', 'absolute-weaver' ),
		__( 'Add margins to non-paragraph Blocks created with Block Editor.', 'absolute-weaver' ),
		1.5,
		array(
			'min'  => 0,
			'max'  => 20.0,
			'step' => 0.1,
		)
	);


	return $opts;
}

function absolute_weaver_controls_spacing_postspecific() {
	$opts = array();


	$opts['post_padding_T'] = absolute_weaver_cz_range(
		__( 'Top Padding (px)', 'absolute-weaver' ),
		'',
		0,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['post_padding_B'] = absolute_weaver_cz_range(
		__( 'Bottom Padding (px)', 'absolute-weaver' ),
		'',
		0,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['post_padding_L'] = absolute_weaver_cz_range_float(
		__( 'Left Padding (%)', 'absolute-weaver' ),
		'',
		0,
		array(
			'min'  => 0,
			'max'  => 30,
			'step' => .25,
		),
		'postMessage'
	);

	$opts['post_padding_R'] = absolute_weaver_cz_range(
		__( 'Right Padding (%)', 'absolute-weaver' ),
		'',
		0,
		array(
			'min'  => 0,
			'max'  => 30,
			'step' => .25,
		),
		'postMessage'
	);

	$opts['post_margin_T'] = absolute_weaver_cz_range(
		__( 'Top Margin (px)', 'absolute-weaver' ),
		'',
		0,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['post_margin_B'] = absolute_weaver_cz_range(
		__( 'Bottom Margin (px)', 'absolute-weaver' ),
		'',
		15,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['spacing-post-widthinfo'] = absolute_weaver_cz_heading( __( 'Width', 'absolute-weaver' ),
		__( 'The width of this area is automatically determined by the enclosing area.', 'absolute-weaver' ) );

	$opts['post_smartmargin'] = absolute_weaver_cz_checkbox(
		__( 'Add Side Margin(s)', 'absolute-weaver' ),
		__( 'Automatically add left/right "smart" margins for separation of areas ( sidebar/content ). This is normally used only if you have borders or BG colors for your sidebars.', 'absolute-weaver' )
	);

	$opts['post_title_bottom_margin_dec'] = absolute_weaver_cz_range_float(
		__( 'Space Between Post Title and Content (em)', 'absolute-weaver' ),
		__( 'Space between Post title and beginning of content. This will adjust/override the equivalent Content setting.', 'absolute-weaver' ),
		0.2,
		array(
			'min'  => - 5.0,
			'max'  => 20.0,
			'step' => 0.1,
		),
		'postMessage'
	);

	return $opts;
}

function absolute_weaver_controls_spacing_sidebars() {
	$opts = array();

	$opts['spacing-sidbars-heading'] = absolute_weaver_cz_group_title( __( 'Sidebar Widths', 'absolute-weaver' ),
		__( 'Width of the left and right vertical sidebars in the Container Area. Note that the width of the adjoining Content area is automatically determined by the sidebar layouts and widths.', 'absolute-weaver' ) );

	$opts['left_sb_width_int'] = absolute_weaver_cz_range_float(
		__( 'Left Sidebar Width (%)', 'absolute-weaver' ),
		'',
		25.,
		array(
			'min'  => 0,
			'max'  => 90,
			'step' => .5,
		)
	);


	$opts['right_sb_width_int'] = absolute_weaver_cz_range_float(
		__( 'Right Sidebar Width (%)', 'absolute-weaver' ),
		'',
		25.,
		array(
			'min'  => 0,
			'max'  => 90,
			'step' => .5,
		)
	);

	$opts['left_split_sb_width_int'] = absolute_weaver_cz_range_float(
		__( 'Width for Split Sidebar, Left Side', 'absolute-weaver' ),
		'',
		25.,
		array(
			'min'  => 10,
			'max'  => 100,
			'step' => .5,
		)
	);

	$opts['right_split_sb_width_int'] = absolute_weaver_cz_range_float(
		__( 'Width for Split Sidebar, Right Side', 'absolute-weaver' ),
		'',
		25.,
		array(
			'min'  => 10,
			'max'  => 100,
			'step' => .5,
		)
	);

	$opts['spacing-primary-widget-heading'] = absolute_weaver_cz_group_title( __( 'Primary Sidebar', 'absolute-weaver' ) );

	$opts['primary_padding_T'] = absolute_weaver_cz_range(
		__( 'Top Padding (px)', 'absolute-weaver' ),
		'',
		0,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['primary_padding_B'] = absolute_weaver_cz_range(
		__( 'Bottom Padding (px)', 'absolute-weaver' ),
		'',
		0,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['primary_padding_L'] = absolute_weaver_cz_range(
		__( 'Left Padding (px)', 'absolute-weaver' ),
		'',
		0,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['primary_padding_R'] = absolute_weaver_cz_range(
		__( 'Right Padding (px)', 'absolute-weaver' ),
		'',
		0,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['primary_margin_T'] = absolute_weaver_cz_range(
		__( 'Top Margin (px)', 'absolute-weaver' ),
		'',
		0,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['primary_margin_B'] = absolute_weaver_cz_range(
		__( 'Bottom Margin (px)', 'absolute-weaver' ),
		'',
		10,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['spacing-primary-widthinfo'] = absolute_weaver_cz_heading( __( 'Width', 'absolute-weaver' ),
		__( 'The width of this area is automatically determined by the enclosing area.', 'absolute-weaver' ) );

	$opts['primary_smartmargin'] = absolute_weaver_cz_checkbox(
		__( 'Add Side Margin(s)', 'absolute-weaver' ),
		__( 'Automatically add left/right "smart" margins for separation of areas ( sidebar/content ). This is normally used only if you have borders or BG colors for your sidebars.', 'absolute-weaver' )
	);

	$opts['spacing-primary-widgets'] = absolute_weaver_cz_heading( __( 'Widget Area Columns', 'absolute-weaver' ),
		__( '**NOTE:** You can set number of columns per widget area on the *Layout* panel.', 'absolute-weaver' ) );

	$opts['spacing-secondary-widget-heading'] = absolute_weaver_cz_group_title( __( 'Secondary Sidebar', 'absolute-weaver' ) );

	$opts['secondary_padding_T'] = absolute_weaver_cz_range(
		__( 'Top Padding (px)', 'absolute-weaver' ),
		'',
		0,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['secondary_padding_B'] = absolute_weaver_cz_range(
		__( 'Bottom Padding (px)', 'absolute-weaver' ),
		'',
		0,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['secondary_padding_L'] = absolute_weaver_cz_range(
		__( 'Left Padding (px)', 'absolute-weaver' ),
		'',
		0,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['secondary_padding_R'] = absolute_weaver_cz_range(
		__( 'Right Padding (px)', 'absolute-weaver' ),
		'',
		0,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['secondary_margin_T'] = absolute_weaver_cz_range(
		__( 'Top Margin (px)', 'absolute-weaver' ),
		'',
		0,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['secondary_margin_B'] = absolute_weaver_cz_range(
		__( 'Bottom Margin (px)', 'absolute-weaver' ),
		'',
		10,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['spacing-secondary-widthinfo'] = absolute_weaver_cz_heading( __( 'Width', 'absolute-weaver' ),
		__( 'The width of this area is automatically determined by the enclosing area.', 'absolute-weaver' ) );

	$opts['secondary_smartmargin'] = absolute_weaver_cz_checkbox(
		__( 'Add Side Margin(s)', 'absolute-weaver' ),
		__( 'Automatically add left/right "smart" margins for separation of areas ( sidebar/content ). This is normally used only if you have borders or BG colors for your sidebars.', 'absolute-weaver' )
	);

	return $opts;
}

function absolute_weaver_controls_spacing_widgets() {
	$opts = array();

	// ------- Widgets

	$opts['widget_padding_T'] = absolute_weaver_cz_range(
		__( 'Top Padding (px)', 'absolute-weaver' ),
		'',
		0,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['widget_padding_B'] = absolute_weaver_cz_range(
		__( 'Bottom Padding (px)', 'absolute-weaver' ),
		'',
		0,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['widget_padding_L'] = absolute_weaver_cz_range(
		__( 'Left Padding (px)', 'absolute-weaver' ),
		'',
		0,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['widget_padding_R'] = absolute_weaver_cz_range(
		__( 'Right Padding (px)', 'absolute-weaver' ),
		'',
		0,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['widget_margin_T'] = absolute_weaver_cz_range(
		__( 'Top Margin (px)', 'absolute-weaver' ),
		'',
		0,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['widget_margin_B'] = absolute_weaver_cz_range(
		__( 'Bottom Margin (px)', 'absolute-weaver' ),
		'',
		0,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	return $opts;
}

function absolute_weaver_controls_spacing_footer() {
	$opts = array();

	$foot_width_transport = 'refresh';


	$opts['spacing-heading-footer'] = absolute_weaver_cz_group_title( __( 'Site Footer Area', 'absolute-weaver' ),
		__( 'Spacing of the whole Footer Area', 'absolute-weaver' ) );

	$opts['footer_width_int'] = absolute_weaver_cz_range_float(
		__( 'Footer Area Width (%)', 'absolute-weaver' ),
		__( 'Width of Area in % of enclosing area on desktop and small tablet. Hint: use with Footer "Center align" setting. (Default: 100%, 0 means auto)', 'absolute-weaver' ),
		100.,
		array(
			'min'  => 0,
			'max'  => 100,
			'step' => 0.5,
		),
		'refresh'
	);

	$opts['footer_max_width_int'] = absolute_weaver_cz_range(
		__( 'Footer Area Max Width (px)', 'absolute-weaver' ),
		__( 'This advanced option allows you to set a maximum width for this area. This is not commonly used, but can make interesting designs, especially if you center align the area.  Use 0 for no Max Width.', 'absolute-weaver' ),
		0,
		array(
			'min'  => 0,
			'max'  => 4000,
			'step' => 5,
		),
		'postMessage',
		'plus'
	);


	$opts['footer_align'] = absolute_weaver_cz_select(
		__( 'Align Footer Area', 'absolute-weaver' ),
		'',
		'absolute_weaver_cz_choices_align', 'float-left', 'refresh'
	);

	$opts['footer_padding_T'] = absolute_weaver_cz_range(
		__( 'Top Padding (px)', 'absolute-weaver' ),
		__( 'These options control the padding ( inner space ) around the area.', 'absolute-weaver' ),
		8,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['footer_padding_B'] = absolute_weaver_cz_range(
		__( 'Bottom Padding (px)', 'absolute-weaver' ),
		'',
		8,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['footer_padding_L'] = absolute_weaver_cz_range(
		__( 'Left Padding (px)', 'absolute-weaver' ),
		'',
		8,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['footer_padding_R'] = absolute_weaver_cz_range(
		__( 'Right Padding (px)', 'absolute-weaver' ),
		'',
		8,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['footer_margin_T'] = absolute_weaver_cz_range(
		__( 'Top Margin (px)', 'absolute-weaver' ),
		'',
		0,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['footer_margin_B'] = absolute_weaver_cz_range(
		__( 'Bottom Margin (px)', 'absolute-weaver' ),
		'',
		0,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);


	// ------- Footer Widget Area

	$opts['spacing-widgetarea-footer'] = absolute_weaver_cz_group_title( __( 'Footer Widget Area', 'absolute-weaver' ),
		__( 'Spacing for the Footer Widget Area', 'absolute-weaver' ) );

	$opts['footer_sb_width_int'] = absolute_weaver_cz_range_float(
		__( 'Footer Widget Area Width (%)', 'absolute-weaver' ),
		__( 'Width of Area in % of enclosing area on desktop and small tablet. Hint: use with Align Footer Widget Area "Center align" setting. (Default: 0, means auto)', 'absolute-weaver' ),
		0,
		array(
			'min'  => 0,
			'max'  => 100,
			'step' => 0.5,
		),
		'postMessage'
	);

	$opts['footer_sb_align'] = absolute_weaver_cz_select(
		__( 'Align Footer Widget Area Area', 'absolute-weaver' ),
		'',
		'absolute_weaver_cz_choices_align', 'float-left', 'refresh'
	);

	$opts['footer_sb_padding_T'] = absolute_weaver_cz_range(
		__( 'Top Padding (px)', 'absolute-weaver' ),
		'',
		8,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['footer_sb_padding_B'] = absolute_weaver_cz_range(
		__( 'Bottom Padding (px)', 'absolute-weaver' ),
		'',
		8,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['footer_sb_padding_L'] = absolute_weaver_cz_range(
		__( 'Left Padding (px)', 'absolute-weaver' ),
		'',
		8,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['footer_sb_padding_R'] = absolute_weaver_cz_range(
		__( 'Right Padding (px)', 'absolute-weaver' ),
		'',
		8,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['footer_sb_margin_T'] = absolute_weaver_cz_range(
		__( 'Top Margin (px)', 'absolute-weaver' ),
		'',
		0,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['footer_sb_margin_B'] = absolute_weaver_cz_range(
		__( 'Bottom Margin (px)', 'absolute-weaver' ),
		'',
		0,
		array(
			'min'  => 0,
			'max'  => 150,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['spacing-footer-widgets'] = absolute_weaver_cz_heading( __( 'Widget Area Columns', 'absolute-weaver' ),
		__( 'NOTE: You can set number of columns per widget area on the "Layout" panel.', 'absolute-weaver' ) );


	if ( function_exists( 'absolute_weaver_ts_installed' ) ) {
		// ------- Footer HTML Area

		$opts['spacing-htmltarea-footer'] = absolute_weaver_cz_group_title( __( 'Footer HTML Area', 'absolute-weaver' ),
			__( 'Spacing for the Footer HTML Area (when Absolute Weaver Theme Support plugin is installed)', 'absolute-weaver' ) );

		$opts['footer_html_width_int'] = absolute_weaver_cz_range_float(
			__( 'Footer HTML Area Width (%)', 'absolute-weaver' ),
			__( 'Width of Area in % of enclosing area on desktop and small tablet. Hint: use with Align HTML Area "Center align" setting. You will have to "Save & Publish" and refresh this page if you are using Center Area align. (Default: 100%, use 0 for auto)', 'absolute-weaver' ),
			100.,
			array(
				'min'  => 0,
				'max'  => 100,
				'step' => 0.5,
			),
			'postMessage'
		);

		$opts['footer_html_align'] = absolute_weaver_cz_select(
			__( 'Align Footer HTML Area', 'absolute-weaver' ),
			'',
			'absolute_weaver_cz_choices_align', 'float-left', 'refresh'
		);

		$opts['footer_html_center_content'] = absolute_weaver_cz_checkbox_post(
			__( 'Center Content within HTML Area', 'absolute-weaver' )
		);

		$opts['footer_html_padding_T']  = absolute_weaver_cz_range(
			__( 'Top Padding (px)', 'absolute-weaver' ),
			'',
			0,
			array(
				'min'  => 0,
				'max'  => 150,
				'step' => 1,
			),
			'postMessage'
		);

		$opts['footer_html_padding_B'] = absolute_weaver_cz_range(
			__( 'Bottom Padding (px)', 'absolute-weaver' ),
			'',
			0,
			array(
				'min'  => 0,
				'max'  => 150,
				'step' => 1,
			),
			'postMessage'
		);

		$opts['footer_html_padding_L'] = absolute_weaver_cz_range(
			__( 'Left Padding (px)', 'absolute-weaver' ),
			'',
			0,
			array(
				'min'  => 0,
				'max'  => 150,
				'step' => 1,
			),
			'postMessage'
		);

		$opts['footer_html_padding_R'] = absolute_weaver_cz_range(
			__( 'Right Padding (px)', 'absolute-weaver' ),
			'',
			0,
			array(
				'min'  => 0,
				'max'  => 150,
				'step' => 1,
			),
			'postMessage'
		);

		$opts['footer_html_margin_T'] = absolute_weaver_cz_range(
			__( 'Top Margin (px)', 'absolute-weaver' ),
			'',
			0,
			array(
				'min'  => 0,
				'max'  => 150,
				'step' => 1,
			),
			'postMessage'
		);

		$opts['footer_html_margin_B'] = absolute_weaver_cz_range(
			__( 'Bottom Margin (px)', 'absolute-weaver' ),
			'',
			0,
			array(
				'min'  => 0,
				'max'  => 150,
				'step' => 1,
			),
			'postMessage'
		);
	}

	return $opts;
}

