<?php
/**
 * Define starting settings - Absolute Weaver Customizer
 */

/**
 * Define the sections and settings for the Speed Test panel
 * causes execution time out at: wp-inc/class-wp-customize-setting.php near line 522
 *
 */
function absolute_weaver_customizer_define_starting_sections() {
	$panel = 'absolute_weaver_starting';
	$starting_sections = array();

	/**
	 * Intro
	 */
	$starting_sections['starting-intro'] = array(
		'panel'       => $panel,
		'title'       => __( 'Introduction to Absolute Weaver', 'absolute-weaver' ),
		'description' => __( 'A concise introduction to Absolute Weaver.', 'absolute-weaver' ) .
		                 ' <br />(' . ABSOLUTE_WEAVER_THEMEVERSION . ')',        // don't translate theme name/version
		'options'     => array(
			'starting-intro-header' => array(
				'control' => array(
					'control_type' => 'Absolute_Weaver_Custom_Control',
					'label'        => __( 'Introduction', 'absolute-weaver' ),
					// translators: HTML markup is allowed and encouraged for this translation
					'description'  => __(
						'<p><em>Absolute Weaver</em> allows you to customize virtually every aspect of your site.
The Customizer Options are organized as top level panels based on WHAT you want to customize, and a second level of sections
based on WHERE you want to make the customizations. Remember: <span style="color:red !important;"><strong>WHAT</strong></span> and <span style="color:red !important;"><strong>WHERE</strong></span>.</p>
<h4>First Level Options: WHAT to Set - Option Categories</h4>
        <p>The first level of Absolute Weaver Customizer menus is organized around different categories of options that reflect different collections of related options. For example, all the Color settings are found on a single, top-level option panel called &quot;Colors&quot;. The other top level option panels represent similar groups of options:</p>
        <ul>
          <li><strong>&#9656; Colors</strong> - Specify all colors used on site - both text and background colors. </li>
          <li><strong>&#9656; Spacing, Widths, Alignment</strong> - Set margins, padding, spacing, heights, widths, and alignment.</li>
          <li><strong>&#9656; Style</strong> -  Set borders, shadows, rounded corners, list bullet style, icons.</li>
          <li><strong>&#9656; Typography</strong> - Set font family, font size, bold, italic, default base font information.</li>
          <li><strong>&#9656; Visibility</strong> - Show or hide various elements - usually by device ( phone, tablet, desktop ).</li>
          <li><strong>&#9656; Layout</strong> - Specify element layout - sidebars, etc.</li>
          <li><strong>&#9656; Images</strong> -  Set borders, placement, Featured Images, Header Images, Background Images.</li>
          <li><strong>&#9656; Added Content</strong> - Define added content for extra HTML insertion areas.</li>
          <li><strong>&#9656; Custom CSS</strong> - Advanced users can specify custom CSS for the whole site or specific areas.</li>
          <li><strong>&#9656; Sidebars &amp; Widgets Content</strong> - the standard WordPress interface for widget areas and widgets.</li>
          <li><strong>&#9656; Custom Menu Content </strong>- the standard WordPress interface for defining custom menus.</li>
        </ul>
        <p>The top level Customizer menu also has two additional menus:</p>
        <ul>
          <li><strong>&#9656; Absolute Weaver: Start Here</strong> - access to getting started help and other documentation.</li>
          <li><strong>&#9656; General Options &amp; Admin</strong> - WordPress Site Identity and Static Front page options, and other theme admin options.</li>
        </ul>
<p>The basic logic behind this organization is that it is easy to remember the different kinds of things you want to customize, like color or spacing. The next level of menus specifies <em>where</em> you want to make those changes.</p>
<h4>Second Level Options: WHERE to Set - Areas</h4>
<p>Deciding <em>what</em> you want to customize is usually an obvious decision. Finding <em>where</em> to apply those settings take a bit more understanding just how a Absolute Weaver WordPress site is organized. </p>
<p>We\'ve tried to make this second level step as easy and consistent as possible. Almost every one of the option categories can be applied to the same set of areas. The &quot;standard&quot; set of areas include:</p>
<ul>
  <li><strong>&#9656; Wrapping Areas</strong> - the major outer areas that wrap the site\'s content. The main Wrapper Area wraps the entire site, while the Container Area wraps the page or post content and the main sidebars.</li>
  <li><strong>&#9656; Links</strong> - Not all categories apply to links, but links are treated as a single element to style.</li>
  <li><strong>&#9656; Header Area</strong> - the header area is displayed at the top of the site, and includes the site title and tagline, the primary and secondary menus, the site header image, a header widget area, and an extra area for arbitrary HTML.</li>
  <li><strong>&#9656; Menus</strong> - The Primary Menu can be displayed at the top or bottom of the Header. There is a one line mini-menu that can be displayed in the header area.</li>
  <li><strong>&#9656; Info Bar</strong> - the Info Bar is displayed immediately below the Header Area, and shows navigation information, as well as other custom content.</li>
  <li><strong>&#9656; Content</strong> - the content area displays page and post content.</li>
  <li><strong>&#9656; Post Specific</strong> - the Content styling will be applied to both page and post content, but this section allows you to have specific styling for posts and blog views.</li>
  <li><strong>&#9656; Sidebars &amp; Widget Areas</strong> - styling for the various Sidebars and Widget Areas.</li>
  <li><strong>&#9656; Individual Widgets</strong> - styling for individual widgets displayed in the Widget Areas.</li>
  <li><strong>&#9656; Footer Area</strong> - the footer area at the bottom of the site. This includes a widget area and an extra custom HTML insertion area.</li>
  <li><strong>&#9656; Global Options</strong> - some of the Option Categories can include other sections that can apply to global settings. Typography, for example, allows you to specify various global options such as base font size.</li>
</ul>',

						'absolute-weaver' ),
					'type'         => 'html',
				),
			),
		),
	);



	/**
	 * Subthemes
	 */
	global $wp_customize;
	if ( ! $wp_customize->is_theme_active() ) {             // must be in theme preview mode
		$starting_sections['starting-subtheme'] = array(
			'panel'       => $panel,
			'title'       => __( 'Try a Pre-defined Subtheme', 'absolute-weaver' ),
			'description' => __( 'When activated, Absolute Weaver will allow you to select from many pre-defined subthemes.', 'absolute-weaver' ),
			'options'     => array(
				'subthemes_not_available' => array(
					'control' => array(
						'control_type' => 'Absolute_Weaver_Custom_Control',
						'description'  => __( 'Sorry, selecting Subthemes not available in Theme Preview Mode. If you just activated the theme, please refresh your browser window.', 'absolute-weaver' ),
						'type'         => 'HTML',
					),
				),

			),
		);
	} else {
		$starting_sections['starting-subtheme'] = array(
			'panel'   => $panel,
			'title'   => __( 'Try a Pre-defined Subtheme', 'absolute-weaver' ),
			'options' => array(

				'load_subtheme' => array(
					'setting' => array(
						'transport' => 'postMessage',
					),
					'control' => array(
						'control_type' => 'Absolute_Weaver_Load_WA_Subtheme',
						'label'        => __( 'Predefined Absolute Weaver Subthemes', 'absolute-weaver' ),
						'description'  => __( 'Get a quick start on your site by selecting on of these predefined subthemes.
Once you\'ve picked a subtheme, you can tweak it to look just like you want.', 'absolute-weaver' ),
					),
				),
			),
		);
	}

	/**
	 * Help links
	 */

	// translators: all placeholder strings are translated links. HTML markup encouraged.
	$help_desc = sprintf( __(
		'<h3>Support Forum</h3><p>Please see our active %1$s for online help.</p>
<h3>Theme Documentation and Guide</h3><p>See the %2$s for help using the Absolute Weaver Theme.</p>
<h3>Theme Demo</h3><p>%3$s<br />Live demo of Absolute Weaver and Absolute Weaver Plus features.</p>
<h3>CSS Tutorial</h3><p>Click for a short %4$s.</p>
<h3>Supported Fonts</h3><p>Click for demo of %5$s.</p>
<h3>Release Notes</h3><p>%6$s</p>
', 'absolute-weaver' ),
		absolute_weaver_site_link( '', '//forum.weavertheme.com/', __( 'Absolute Weaver Support Forum', 'absolute-weaver' ), false ),
		absolute_weaver_site_link( '', '//guide.weavertheme.com/', __( 'Absolute Weaver Guide', 'absolute-weaver' ), false ),
		absolute_weaver_site_link( '', '//demo.weavertheme.com/', __( 'Absolute Weaver Demo Site', 'absolute-weaver' ), false ),
		absolute_weaver_help_link( 'css-help.html', __( 'Weaver CSS Help', 'absolute-weaver' ), esc_html__( 'CSS Tutorial', 'absolute-weaver' ), false ),
		absolute_weaver_help_link( 'font-demo.html', __( 'Examples of supported fonts', 'absolute-weaver' ), esc_html__( 'Font Examples', 'absolute-weaver' ), false ),
		absolute_weaver_release_notes()
	);
	// ===================
	$name = absolute_weaver_getopt( 'themename' );
	if ( ! $name ) {
		$name = esc_html__( 'Please set theme name on the Advanced Options &rarr; Admin Options tab.', 'absolute-weaver' );
	}
	$local_mem_lim = ini_get( 'memory_limit' );
	$server_mem_lim = get_cfg_var( 'memory_limit' );

	$tech_info =
	// translators: %1: theme name, $2: theme version, %3: style version, %4 subtheme name, %5 - local memory limit, %6 - server memory limit
	sprintf( '<hr><em>Absolute Weaver Technical Info</em><br /><small>' . esc_html__( '%1$s %2$s | Options Version: %3$s | Subtheme: %4$s | PHP Memory Limit: Local - %5$s / Server - %6$s', 'absolute-weaver' ) . '</small>',
		esc_html( ABSOLUTE_WEAVER_THEMENAME ), esc_html( ABSOLUTE_WEAVER_VERSION ), esc_html( absolute_weaver_getopt( 'style_version' ) ), esc_html( $name ),
		esc_html( $local_mem_lim ), esc_html( $server_mem_lim ) );



	// ============

	$starting_sections['starting-help'] = array(
		'panel'       => $panel,
		'title'       => __( 'Get Help for Absolute Weaver', 'absolute-weaver' ),
		'description' => __( 'Read the Absolute Weaver Documentation', 'absolute-weaver' ),
		'options'     => array(
			'starting-help-header' => array(
				'control' => array(
					'control_type' => 'Absolute_Weaver_Custom_Control',
					'label'        => __( 'Get Help', 'absolute-weaver' ),
					'description'  => $help_desc . $tech_info,

					'type' => 'HTML',
				),
			),
		),
	);

	/* recommended plugins */

	$plugins = __('<h2><b>RECOMMENDED PLUGINS</b></h2>
<p><strong>Some recommended plugins to use with your Absolute Weaver Theme</strong></p>
<p><strong>The following plugin is highly recommended to enhance your Absolute Weaver Theme.</strong></p>
<ul>
	<li><a href="//wordpress.org/plugins/absolute-weaver-theme-support/" target="_blank">Absolute Weaver Theme Support</a>
- this plugin adds very useful features to the theme, including Saving and Restoring your design settings; custom HTML content areas for the header, menu, and footer; and global custom styling for your individual subthemes.
	</li>
</ul>
<p><strong>The following plugins are not essential, but can be useful when creating pages.</strong></p>
<ul>
	<li><a href="//wordpress.org/plugins/show-posts/" target="_blank">Weaver Show Posts</a>
	- adds the [show_posts] shortcode to selectively display posts filtered by category, tag, order, id, etc.
	</li>
	<li><a href="//wordpress.org/plugins/show-sliders/" target="_blank">Weaver Show Sliders</a>
	- good for any kind of slideshows - images, posts, [gallery] replacement
	</li>
	<li><a href="https://wordpress.org/plugins/widget-shortcode/" target="_blank">Widget Shortcode</a>
	 - Adds [widget] shortcode which enables you to display any widget in any content area, including in the Block Editor!. This independent plugin is a great enhancement to Absolute Weaver.
	</li>
</ul>', 'absolute-weaver');


$starting_sections['recommended-plugins'] = array(
		'panel'       => $panel,
		'title'       => __( 'Recommended Plugins', 'absolute-weaver' ),
		'description' => __( 'Try these plugins to enhance your Absolute Weaver experience.', 'absolute-weaver' ) .
		                 ' <br />',
		'options'     => array(
			'recpl-header' => array(
				'control' => array(
					'control_type' => 'Absolute_Weaver_Custom_Control',
					'label'        => __( 'Introduction', 'absolute-weaver' ),
					// translators: HTML markup is allowed and encouraged for this translation
					'description'  => $plugins,
					'type'         => 'html',
				),
			),
		),
	);


	return $starting_sections;
}

function absolute_weaver_release_notes() {

	$notes = esc_url(absolute_weaver_relative_url( '' ) . 'readme.txt' );
	$msg = esc_html__( 'View most recent release notes.', 'absolute-weaver' );

	return '<h3><a href=' . $notes. ' target="_blank">' . $msg . '</a></h3>';
}
