<?php

/**
 * Define the sections and settings for the style panel
 *
 */
function absolute_weaver_customizer_define_style_sections() {
	$panel = 'absolute_weaver_style';
	$style_sections = array();

	define( 'ABSOLUTE_WEAVER_ROUNDED_TRANSPORT', 'refresh' );

	// global settings
	$style_sections['style-global'] = array(
		'panel'       => $panel,
		'title'       => __( 'Global Style Options', 'absolute-weaver' ),
		'description' => 'Set some global settings that affect style.',
		'options'     => absolute_weaver_controls_style_global(),
	);


	/**
	 * Wrapping
	 */
	$style_sections['style-wrapping'] = array(
		'panel'       => $panel,
		'title'       => __( 'Wrapping Areas', 'absolute-weaver' ),
		'description' => 'Set borders, shadows, and rounded corners for main Wrapper and Container wrapping areas.',
		'options'     => absolute_weaver_controls_style_wrapping(),
	);


	/**
	 * Site Header
	 */
	$style_sections['style-header'] = array(
		'panel'   => $panel,
		'title'   => __( 'Header Area', 'absolute-weaver' ),
		'options' => absolute_weaver_controls_style_header(),
	);


	/**
	 * Main Menu
	 */
	$style_sections['style-menus'] = array(
		'panel'       => $panel,
		'title'       => __( 'Menus', 'absolute-weaver' ),
		'description' => __( 'Set style for Menus.', 'absolute-weaver' ),
		'options'     => absolute_weaver_controls_style_menus(),

	);


	/**
	 * Info Bar
	 */
	$style_sections['style-info-bar'] = array(
		'panel'       => $panel,
		'title'       => __( 'Info Bar', 'absolute-weaver' ),
		'description' => __( 'Info Bar with breadcrumb and paged navigation displayed under Primary Menu.', 'absolute-weaver' ),
		'options'     => absolute_weaver_controls_style_infobar(),
	);


	/**
	 * Content
	 */
	$style_sections['style-content'] = array(
		'panel'       => $panel,
		'title'       => __( 'Content', 'absolute-weaver' ),
		'description' => __( 'style for general page and post content.', 'absolute-weaver' ),
		'options'     => absolute_weaver_controls_style_content(),
	);


	/**
	 * Post Specific
	 */
	$style_sections['style-post-specific'] = array(
		'panel'       => $panel,
		'title'       => __( 'Post Specific', 'absolute-weaver' ),
		'description' => __( 'Post Specific style - override Content style.', 'absolute-weaver' ),
		'options'     => absolute_weaver_controls_style_postspecific(),
	);


	/**
	 * Sidebars
	 */
	$style_sections['style-sidebars'] = array(
		'panel'       => $panel,
		'title'       => __( 'Sidebars', 'absolute-weaver' ),
		'description' => __( 'Style for Main Sidebars and Widget areas.', 'absolute-weaver' ),
		'options'     => absolute_weaver_controls_style_sidebars(),
	);


	/**
	 * Widgets
	 */
	$style_sections['style-widgets'] = array(
		'panel'       => $panel,
		'title'       => __( 'Individual Widgets', 'absolute-weaver' ),
		'description' => __( 'Styling for individual widgets.', 'absolute-weaver' ),
		'options'     => absolute_weaver_controls_style_widgets(),
	);


	/**
	 * Footer
	 */
	$style_sections['style-footer'] = array(
		'panel'   => $panel,
		'title'   => __( 'Footer Area', 'absolute-weaver' ),
		'options' => absolute_weaver_controls_style_footer(),
	);

	return $style_sections;
}

function absolute_weaver_controls_style_global() {
	$opts = array();


	$opts['border_color'] = absolute_weaver_cz_color(
		'border_color',
		__( 'Border Color...', 'absolute-weaver' ),
		__( 'Color for all borders.', 'absolute-weaver' )
	);

	$opts['border_width_int'] = absolute_weaver_cz_range(
		__( 'Border Width (px)', 'absolute-weaver' ),
		'',
		1,
		array(
			'min'  => 1,
			'max'  => 20,
			'step' => 1,
		),
		'postMessage'
	);


	$opts['border_style'] = absolute_weaver_cz_select_plus(
		__( 'Border Style', 'absolute-weaver' ),
		__( 'Style of borders - width needs to be &gt; 1 and color other than black for some styles to work correctly.', 'absolute-weaver' ),
		array(
			'solid'  => esc_html__( 'Solid', 'absolute-weaver' ),
			'dotted' => esc_html__( 'Dotted', 'absolute-weaver' ),
			'dashed' => esc_html__( 'Dashed', 'absolute-weaver' ),
			'double' => esc_html__( 'Double', 'absolute-weaver' ),
			'groove' => esc_html__( 'Groove', 'absolute-weaver' ),
			'ridge'  => esc_html__( 'Ridge', 'absolute-weaver' ),
			'inset'  => esc_html__( 'Inset', 'absolute-weaver' ),
			'outset' => esc_html__( 'Outset', 'absolute-weaver' ),
		),
		'solid', 'refresh'
	);

	$opts['rounded_corners_radius'] = absolute_weaver_cz_range(
		__( 'Corner Radius (px)', 'absolute-weaver' ),
		__( 'Controls how "round" corners are. Specify a value ( 5 to 15 look best ) for corner radius.', 'absolute-weaver' ),
		8,
		array(
			'min'  => 1,
			'max'  => 20,
			'step' => 1,
		),
		'refresh',
		'plus'
	);

	$opts['custom_shadow'] = absolute_weaver_cz_textarea(
		__( 'Custom Shadow', 'absolute-weaver' ),
		absolute_weaver_markdown( __( 'This defines the **Custom Shadow** shown on the **Add shadow** options. You will have to select **Custom Shadow** to use the shadow style you define here. Specify full **box-shadow** CSS rule.', 'absolute-weaver' ) ),
		1,
		__( '{box-shadow: 0 0 3px 1px rgba( 0,0,0,0.25 );} /* for example */', 'absolute-weaver' ),
		$transport = 'refresh',
		$plus = 'plus',
		'absolute_weaver_cz_sanitize_css'
	);

	return $opts;
}

function absolute_weaver_controls_style_wrapping() {
	$opts = array();

	$opts['wrapper-style-genopts'] = absolute_weaver_cz_group_title( __( 'General Style Global Options', 'absolute-weaver' ),
		__( 'These settings control global attributes of borders, etc.', 'absolute-weaver' ) );

	$opts['wrapper-style-heading'] = absolute_weaver_cz_group_title( __( 'Wrapper Area', 'absolute-weaver' ),
		__( 'The Wrapper is the &lt;div&gt; that wraps entire site.', 'absolute-weaver' ) );

	$opts['wrapper_border'] = absolute_weaver_cz_checkbox_post(
		__( 'Add border', 'absolute-weaver' )
	);

	$opts['wrapper_shadow'] = absolute_weaver_cz_select(
		__( 'Add shadow', 'absolute-weaver' ),
		'',
		'absolute_weaver_cz_choices_shadow', '-0', 'postMessage'
	);

	$opts['wrapper_rounded'] = absolute_weaver_cz_select(
		__( 'Rounded corners', 'absolute-weaver' ),
		'',
		'absolute_weaver_cz_choices_rounded', 'none', ABSOLUTE_WEAVER_ROUNDED_TRANSPORT
	);

	$opts['container-style-heading'] = absolute_weaver_cz_group_title( __( 'Container Area', 'absolute-weaver' ),
		__( 'The Container is the &lt;div&gt; that wraps site content areas, including sidebars. Does not include Header and Footer.', 'absolute-weaver' ) );

	$opts['container_border'] = absolute_weaver_cz_checkbox_post(
		__( 'Add border around Container', 'absolute-weaver' )
	);

	$opts['container_shadow'] = absolute_weaver_cz_select(
		__( 'Add shadow', 'absolute-weaver' ),
		'',
		'absolute_weaver_cz_choices_shadow', '-0', 'postMessage'
	);

	$opts['container_rounded'] = absolute_weaver_cz_select(
		__( 'Rounded corners', 'absolute-weaver' ),
		'',
		'absolute_weaver_cz_choices_rounded', 'none', ABSOLUTE_WEAVER_ROUNDED_TRANSPORT
	);

	return $opts;
}

function absolute_weaver_controls_style_header() {
	$opts = array();

	$opts['style-heading-header'] = absolute_weaver_cz_group_title( __( 'Site Header Area Borders', 'absolute-weaver' ) );

	$opts['header_border'] = absolute_weaver_cz_checkbox_post(
		__( 'Add border to entire Header Area', 'absolute-weaver' )
	);

	$opts['header_sb_border'] = absolute_weaver_cz_checkbox_post(
		__( 'Add border to Header Widget Area', 'absolute-weaver' )
	);

	if ( function_exists( 'absolute_weaver_ts_installed' ) ) {
		$opts['header_html_border'] = absolute_weaver_cz_checkbox_post(
			__( 'Add border to Header HTML Area', 'absolute-weaver' )
		);
	}

	$opts['style-shadow-header'] = absolute_weaver_cz_group_title( __( 'Site Header Area Shadows', 'absolute-weaver' ) );

	$opts['header_shadow'] = absolute_weaver_cz_select(
		__( 'Add shadow to header', 'absolute-weaver' ),
		'',
		'absolute_weaver_cz_choices_shadow', '-0', 'postMessage'
	);

	$opts['header_sb_shadow'] = absolute_weaver_cz_select(
		__( 'Add shadow to Header Widget Area', 'absolute-weaver' ),
		'',
		'absolute_weaver_cz_choices_shadow', '-0', 'postMessage'
	);

	if ( function_exists( 'absolute_weaver_ts_installed' ) ) {
		$opts['header_html_shadow'] = absolute_weaver_cz_select(
			__( 'Add shadow to Header HTML Area', 'absolute-weaver' ),
			'',
			'absolute_weaver_cz_choices_shadow', '-0', 'postMessage'
		);
	}


	//  rounded

	$opts['style-rounded-header'] = absolute_weaver_cz_group_title( __( 'Site Header Rounded Corners', 'absolute-weaver' ),
		__( 'Note that rounded corners require borders or bg color to show, and interact with surrounding areas. You may have to set several options to get rounded corners to display.', 'absolute-weaver' ) );

	$opts['header_rounded'] = absolute_weaver_cz_select(
		__( 'Add rounded corners to Header Area', 'absolute-weaver' ),
		'',
		'absolute_weaver_cz_choices_rounded', 'none', ABSOLUTE_WEAVER_ROUNDED_TRANSPORT
	);

	$opts['header_sb_rounded'] = absolute_weaver_cz_select(
		__( 'Add rounded corners to Header Widget Area', 'absolute-weaver' ),
		'',
		'absolute_weaver_cz_choices_rounded', 'none', ABSOLUTE_WEAVER_ROUNDED_TRANSPORT
	);

	if ( function_exists( 'absolute_weaver_ts_installed' ) ) {
		$opts['header_html_rounded'] = absolute_weaver_cz_select(
			__( 'Add rounded corners to Header HTML Area', 'absolute-weaver' ),
			'',
			'absolute_weaver_cz_choices_rounded', 'none', ABSOLUTE_WEAVER_ROUNDED_TRANSPORT
		);
	}

	return $opts;
}

function absolute_weaver_controls_style_menus() {
	$opts = array();

	$opts['style-mm-heading'] = absolute_weaver_cz_group_title(
		__( 'Primary Menu', 'absolute-weaver' )
	);

	$opts['m_primary_border'] = absolute_weaver_cz_checkbox_post(
		__( 'Add border to Primary Menu bar', 'absolute-weaver' ) );

	$opts['m_primary_sub_border'] = absolute_weaver_cz_checkbox_post(
		__( 'Add border to Sub-Menus', 'absolute-weaver' ) );

	$opts['m_primary_shadow'] = absolute_weaver_cz_select(
		__( 'Add shadow to menu bar', 'absolute-weaver' ),
		'',
		'absolute_weaver_cz_choices_shadow', '-0', 'postMessage'
	);

	$opts['m_primary_sub_noshadow'] = absolute_weaver_cz_heading(
		__( 'Add Shadow to Sub-Menus', 'absolute-weaver' ),
		__( 'Sub-Menus do not support shadows.', 'absolute-weaver' )
	);

	$opts['m_primary_rounded'] = absolute_weaver_cz_select(
		__( 'Add rounded corners to menu bar', 'absolute-weaver' ),
		'',
		'absolute_weaver_cz_choices_rounded', 'none', ABSOLUTE_WEAVER_ROUNDED_TRANSPORT
	);

	$opts['m_primary_sub_rounded'] = absolute_weaver_cz_checkbox(
		__( 'Rounded Primary Sub-Menu corners', 'absolute-weaver' )
	);

	$opts['placeholder_cursor'] = absolute_weaver_cz_select(
		__( 'Placeholder Menu Hover Cursor', 'absolute-weaver' ),
		__( 'Cursor :hover attribute for placeholder menu items ( only with Custom Menu Items with URL==# ).', 'absolute-weaver' ),
		array(
			'pointer'      => esc_html__( 'Pointer ( indicates link)', 'absolute-weaver' ),
			'context-menu' => esc_html__( 'Context Menu available', 'absolute-weaver' ),
			'text'         => esc_html__( 'Text', 'absolute-weaver' ),
			'none'         => esc_html__( 'No pointer', 'absolute-weaver' ),
			'not-allowed'  => esc_html__( 'Action not allowed', 'absolute-weaver' ),
			'default'      => esc_html__( 'The default cursor', 'absolute-weaver' ),
		),
		'pointer', 'refresh'
	);


	return $opts;
}

function absolute_weaver_controls_style_infobar() {
	$opts = array();

	$opts['infobar_border'] = absolute_weaver_cz_checkbox_post(
		__( 'Add border to Info Bar', 'absolute-weaver' )
	);

	$opts['infobar_shadow'] = absolute_weaver_cz_select(
		__( 'Add shadow to Info Bar', 'absolute-weaver' ),
		'',
		'absolute_weaver_cz_choices_shadow', '-0', 'postMessage'
	);

	$opts['infobar_rounded'] = absolute_weaver_cz_select(
		__( 'Add rounded corners to Info Bar', 'absolute-weaver' ),
		'',
		'absolute_weaver_cz_choices_rounded', 'none', ABSOLUTE_WEAVER_ROUNDED_TRANSPORT
	);

	return $opts;
}

function absolute_weaver_controls_style_content() {
	$opts = array();

	$opts['content_border'] = absolute_weaver_cz_checkbox_post(
		__( 'Add border to Content Area', 'absolute-weaver' )
	);

	$opts['content_shadow'] = absolute_weaver_cz_select(
		__( 'Add shadow to Content Area', 'absolute-weaver' ),
		'',
		'absolute_weaver_cz_choices_shadow', '-0', 'postMessage'
	);

	$opts['content_rounded'] = absolute_weaver_cz_select(
		__( 'Add rounded corners to Content Area', 'absolute-weaver' ),
		'',
		'absolute_weaver_cz_choices_rounded', 'none', ABSOLUTE_WEAVER_ROUNDED_TRANSPORT
	);

	$opts['page_title_underline_int'] = absolute_weaver_cz_range(
		__( 'Bar under Page Title (px)', 'absolute-weaver' ),
		__( 'Enter size in px if you want a bar under Page Titles. Leave 0 for no bar. Color matches title.', 'absolute-weaver' ),
		0,
		array(
			'min'  => 0,
			'max'  => 20,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['contentlist_bullet'] = absolute_weaver_cz_select(
		__( 'Content List Bullet Style', 'absolute-weaver' ),
		__( 'Bullet used for Unordered Lists in Content.', 'absolute-weaver' ),
		'absolute_weaver_cz_choices_list_bullets', 'disc', 'postMessage'
	);

	$opts['absolute_weaver_tables'] = absolute_weaver_cz_select(
		__( 'Table Style', 'absolute-weaver' ),
		absolute_weaver_markdown( __( 'Style used for tables in content. ***WARNING!*** Tables are inherently non-responsive, and *do not* work well for mobile devices. We advise you to avoid using tables.', 'absolute-weaver' ) ),
		array(
			'default'   => esc_html__( 'Theme Default', 'absolute-weaver' ),
			'bold'      => esc_html__( 'Bold Headings', 'absolute-weaver' ),
			'noborders' => esc_html__( 'No Border', 'absolute-weaver' ),
			'fullwidth' => esc_html__( 'Wide', 'absolute-weaver' ),
			'wide'      => esc_html__( 'Wide 2', 'absolute-weaver' ),
			'plain'     => esc_html__( 'Minimal', 'absolute-weaver' ),
		),
		'default', 'refresh'
	);

	$opts['show_comment_borders'] = absolute_weaver_cz_checkbox(
		__( 'Show Borders on Comments', 'absolute-weaver' ),
		__( 'Show Borders around comment sections - improves visual look of comments.', 'absolute-weaver' ),
		'plus',
		'postMessage'
	);

	return $opts;
}

function absolute_weaver_controls_style_postspecific() {
	$opts = array();


	$opts['post_border'] = absolute_weaver_cz_checkbox_post(
		__( 'Add border to Posts', 'absolute-weaver' )
	);

	$opts['post_shadow'] = absolute_weaver_cz_select(
		__( 'Add shadow to posts', 'absolute-weaver' ),
		'',
		'absolute_weaver_cz_choices_shadow', '-0', 'postMessage'
	);

	$opts['post_rounded'] = absolute_weaver_cz_select(
		__( 'Add rounded corners to posts', 'absolute-weaver' ),
		'',
		'absolute_weaver_cz_choices_rounded', 'none', ABSOLUTE_WEAVER_ROUNDED_TRANSPORT
	);

	$opts['post_icons'] = absolute_weaver_cz_select(
		__( 'Text or Icons for Post Info', 'absolute-weaver' ),
		__( 'Use Icons instead of Text descriptions in Post Meta Info. You can specify a color for the Font Icons on the "Color &rarr; Post Specific" panel.', 'absolute-weaver' ),
		array(
			'text'      => esc_html__( 'Text Descriptions', 'absolute-weaver' ),
			'fonticons' => esc_html__( 'Font Icons', 'absolute-weaver' ),
			'graphics'  => esc_html__( 'Graphic Icons', 'absolute-weaver' ),
		),
		'text', 'refresh'
	);

	$opts['post_title_underline_int'] = absolute_weaver_cz_range(
		__( 'Bar under Post Titles (px)', 'absolute-weaver' ),
		__( 'Enter size in px if you want a bar under Post Titles. Leave 0 for no bar. Color matches title.', 'absolute-weaver' ),
		0,
		array(
			'min'  => 0,
			'max'  => 20,
			'step' => 1,
		),
		'postMessage'
	);

	return $opts;
}

function absolute_weaver_controls_style_sidebars() {
	$opts = array();

	$opts['style-primary-widget-heading'] = absolute_weaver_cz_group_title( __( 'Primary Sidebar', 'absolute-weaver' ) );

	$opts['primary_border'] = absolute_weaver_cz_checkbox_post(
		__( 'Add border', 'absolute-weaver' )
	);

	$opts['primary_shadow'] = absolute_weaver_cz_select(
		__( 'Add shadow', 'absolute-weaver' ),
		'',
		'absolute_weaver_cz_choices_shadow', '-0', 'postMessage'
	);

	$opts['primary_rounded'] = absolute_weaver_cz_select(
		__( 'Add rounded corners', 'absolute-weaver' ),
		'',
		'absolute_weaver_cz_choices_rounded', 'none', ABSOLUTE_WEAVER_ROUNDED_TRANSPORT
	);
	$opts['style-secondary-widget-heading'] = absolute_weaver_cz_group_title( __( 'Secondary Sidebar', 'absolute-weaver' ) );

	$opts['secondary_border'] = absolute_weaver_cz_checkbox_post(
		__( 'Add border', 'absolute-weaver' )
	);

	$opts['secondary_shadow'] = absolute_weaver_cz_select(
		__( 'Add shadow', 'absolute-weaver' ),
		'',
		'absolute_weaver_cz_choices_shadow', '-0', 'postMessage'
	);

	$opts['secondary_rounded'] = absolute_weaver_cz_select(
		__( 'Add rounded corners', 'absolute-weaver' ),
		'',
		'absolute_weaver_cz_choices_rounded', 'none', ABSOLUTE_WEAVER_ROUNDED_TRANSPORT
	);

	return $opts;
}

function absolute_weaver_controls_style_widgets() {
	$opts = array();


	$opts['widget_border'] = absolute_weaver_cz_checkbox_post(
		__( 'Add border', 'absolute-weaver' )
	);

	$opts['widget_shadow'] = absolute_weaver_cz_select(
		__( 'Add shadow to Individual Widgets', 'absolute-weaver' ),
		'',
		'absolute_weaver_cz_choices_shadow', '-0', 'postMessage'
	);

	$opts['widget_rounded'] = absolute_weaver_cz_select(
		__( 'Rounded corners', 'absolute-weaver' ),
		'',
		'absolute_weaver_cz_choices_rounded', 'none', ABSOLUTE_WEAVER_ROUNDED_TRANSPORT
	);

	$opts['widget_title_underline_int'] = absolute_weaver_cz_range(
		__( 'Bar under Widget Titles (px)', 'absolute-weaver' ),
		__( 'Enter size in px if you want a bar under Widget Titles. Leave 0 for no bar. Color matches title.', 'absolute-weaver' ),
		0,
		array(
			'min'  => 0,
			'max'  => 20,
			'step' => 1,
		),
		'postMessage'
	);

	$opts['widgetlist_bullet'] = absolute_weaver_cz_select(
		__( 'Widget List Bullet', 'absolute-weaver' ),
		__( 'Bullet used for Unordered Lists in Widget areas.', 'absolute-weaver' ),
		'absolute_weaver_cz_choices_list_bullets', 'disc', 'postMessage'
	);

	return $opts;
}

function absolute_weaver_controls_style_footer() {
	$opts = array();

	$opts['style-footer-heading'] = absolute_weaver_cz_group_title( __( 'Footer Borders', 'absolute-weaver' ) );

	$opts['footer_border'] = absolute_weaver_cz_checkbox_post(
		__( 'Add border to Footer Area', 'absolute-weaver' )
	);

	$opts['footer_sb_border'] = absolute_weaver_cz_checkbox_post(
		__( 'Add border to Footer Widget Area', 'absolute-weaver' )
	);

	if ( function_exists( 'absolute_weaver_ts_installed' ) ) {
		$opts['footer_html_border'] = absolute_weaver_cz_checkbox_post(
			__( 'Add border to Footer HTML Area', 'absolute-weaver' )
		);
	}

	$opts['style-footer-shadow-heading'] = absolute_weaver_cz_group_title( __( 'Footer Shadows', 'absolute-weaver' ) );

	$opts['footer_shadow'] = absolute_weaver_cz_select(
		__( 'Add shadow to Footer Area', 'absolute-weaver' ),
		'',
		'absolute_weaver_cz_choices_shadow', '-0', 'postMessage'
	);

	$opts['footer_sb_shadow'] = absolute_weaver_cz_select(
		__( 'Add shadow to Footer Widget Area', 'absolute-weaver' ),
		'',
		'absolute_weaver_cz_choices_shadow', '-0', 'postMessage'
	);

	if ( function_exists( 'absolute_weaver_ts_installed' ) ) {
		$opts['footer_html_shadow'] = absolute_weaver_cz_select(
			__( 'Add shadow to HTML Area', 'absolute-weaver' ),
			'',
			'absolute_weaver_cz_choices_shadow', '-0', 'postMessage'
		);
	}

	$opts['style-footer-rounded-heading'] = absolute_weaver_cz_group_title( __( 'Footer Rounded Corners', 'absolute-weaver' ) );

	$opts['footer_rounded'] = absolute_weaver_cz_select(
		__( 'Add rounded corners to Footer Area', 'absolute-weaver' ),
		'',
		'absolute_weaver_cz_choices_rounded', 'none', ABSOLUTE_WEAVER_ROUNDED_TRANSPORT
	);

	$opts['footer_sb_rounded'] = absolute_weaver_cz_select(
		__( 'Add rounded corners to Footer Widget Area', 'absolute-weaver' ),
		'',
		'absolute_weaver_cz_choices_rounded', 'none', ABSOLUTE_WEAVER_ROUNDED_TRANSPORT
	);

	if ( function_exists( 'absolute_weaver_ts_installed' ) ) {
		$opts['footer_html_rounded'] = absolute_weaver_cz_select(
			__( 'Add rounded corners to Footer HTML Area', 'absolute-weaver' ),
			'',
			'absolute_weaver_cz_choices_rounded', 'none', ABSOLUTE_WEAVER_ROUNDED_TRANSPORT
		);
	}


	return $opts;
}

