<?php

/**
 * Define the sections and settings for the Visibility panel
 */

function absolute_weaver_customizer_define_visibility_sections() {
	$panel = 'absolute_weaver_visibility';
	$visibility_sections = array();

	/**
	 * General
	 */

	/**
	 * Site Header
	 */

	$visibility_sections['visibility-header'] = array(
		'panel'   => $panel,
		'title'   => esc_html__( 'Header Area', 'absolute-weaver' ),
		'options' => absolute_weaver_controls_visibility_header(),
	);

	/**
	 * Main Menu
	 */
	$visibility_sections['visibility-menus'] = array(
		'panel'       => $panel,
		'title'       => esc_html__( 'Menus', 'absolute-weaver' ),
		'description' => esc_html__( 'Set visibility for Menus.', 'absolute-weaver' ),
		'options'     => absolute_weaver_controls_visibility_menus(),
	);


	/**
	 * Info Bar
	 */
	$visibility_sections['visibility-info-bar'] = array(
		'panel'       => $panel,
		'title'       => esc_html__( 'Info Bar', 'absolute-weaver' ),
		'description' => esc_html__( 'Info Bar with breadcrumbs and paged navigation displayed under Primary Menu.', 'absolute-weaver' ),
		'options'     => absolute_weaver_controls_visibility_infobar(),
	);


	/**
	 * Content
	 */
	$visibility_sections['visibility-content'] = array(
		'panel'       => $panel,
		'title'       => esc_html__( 'Content', 'absolute-weaver' ),
		'description' => esc_html__( 'Visibility for general page and post content.', 'absolute-weaver' ),
		'options'     => absolute_weaver_controls_visibility_content(),
	);

	/**
	 * Post Specific
	 */
	$visibility_sections['visibility-post-specific'] = array(
		'panel'       => $panel,
		'title'       => esc_html__( 'Post Specific', 'absolute-weaver' ),
		'description' => esc_html__( 'Post Specific visibility - override Content visibility.', 'absolute-weaver' ),
		'options'     => absolute_weaver_controls_visibility_postspecific(),
	);


	/**
	 * Sidebars
	 */
	$visibility_sections['visibility-sidebars'] = array(
		'panel'       => $panel,
		'title'       => esc_html__( 'Sidebars', 'absolute-weaver' ),
		'description' => esc_html__( 'Primary and Secondary Sidebars. Header and Footer areas options under Header and Footer panels.', 'absolute-weaver' ),
		'options'     => absolute_weaver_controls_visibility_sidebars(),
	);


	/**
	 * Footer
	 */
	$visibility_sections['visibility-footer'] = array(
		'panel'   => $panel,
		'title'   => esc_html__( 'Footer Area', 'absolute-weaver' ),
		'options' => absolute_weaver_controls_visibility_footer(),
	);


	return $visibility_sections;
}


function absolute_weaver_controls_visibility_header() {
	$opts = array();

	// Hide Site Title option

	$opts['header_hide'] = absolute_weaver_cz_select(
		__( 'Hide Header Area', 'absolute-weaver' ),
		'',
		'absolute_weaver_cz_choices_hide', 'hide-none', 'refresh'
	);

	$opts['hide_site_title'] = absolute_weaver_cz_select(
		__( 'Hide Site Title', 'absolute-weaver' ),
		'',
		'absolute_weaver_cz_choices_hide', 'hide-none', 'refresh'
	);

	$opts['hide_site_tagline'] = absolute_weaver_cz_select(
		__( 'Hide Tagline', 'absolute-weaver' ),
		'',
		'absolute_weaver_cz_choices_hide', 'hide-none', 'refresh'
	);

	$opts['hide_header_image'] = absolute_weaver_cz_select(
		__( 'Hide Header Image', 'absolute-weaver' ),
		'',
		'absolute_weaver_cz_choices_hide', 'hide-none', 'refresh'
	);

	$opts['hide_wp_site_logo'] = absolute_weaver_cz_select(
		__( 'Hide Site Logo', 'absolute-weaver' ),
		__( 'IMPORTANT! This option only applies to the Site Logo when used in the Header. It does NOT apply to the Site Logo on the Menu, nor as the replacement for the Site Title.', 'absolute-weaver' ),
		'absolute_weaver_cz_choices_hide', 'hide-none', 'refresh'
	);

	$opts['hide_header_image_front'] = absolute_weaver_cz_checkbox(
		__( 'Hide Header Image on Front Page', 'absolute-weaver' )
	);

	$opts['header_sb_hide'] = absolute_weaver_cz_select(
		__( 'Hide Header Widget Area', 'absolute-weaver' ),
		'',
		'absolute_weaver_cz_choices_hide', 'hide-none', 'refresh'
	);

	if ( function_exists( 'absolute_weaver_ts_installed' ) ) {
		$opts['header_html_hide'] = absolute_weaver_cz_select(
			__( 'Hide Header HTML Area', 'absolute-weaver' ),
			'',
			'absolute_weaver_cz_choices_hide', 'hide-none', 'refresh'
		);
	}

	$opts['header_search_hide'] = absolute_weaver_cz_select(
		__( 'Hide Search box on Header', 'absolute-weaver' ),
		'',
		'absolute_weaver_cz_choices_hide', 'hide-none', 'refresh'
	);

	return $opts;
}

function absolute_weaver_controls_visibility_menus() {
	$opts = array();

	$opts['visibility-mm-heading'] = absolute_weaver_cz_group_title(
		__( 'Primary Menu', 'absolute-weaver' )
	);

	$opts['m_primary_hide'] = absolute_weaver_cz_select(
		__( 'Hide Primary Menu', 'absolute-weaver' ),
		'',
		'absolute_weaver_cz_choices_hide', 'hide-none', 'refresh'
	);

	$opts['m_primary_hide_arrows'] = absolute_weaver_cz_checkbox(
		__( 'Hide Primary Menu Arrows', 'absolute-weaver' ),
		''
	);

	if ( function_exists( 'absolute_weaver_ts_installed' ) ) {
		$opts['m_primary_hide_right'] = absolute_weaver_cz_select(
			__( 'Hide Primary Menu Right HTML', 'absolute-weaver' ),
			'',
			'absolute_weaver_cz_choices_hide', 'hide-none', 'refresh'
		);
	}


	$opts['menu_nohome'] = absolute_weaver_cz_checkbox(
		__( 'No Home Menu Item', 'absolute-weaver' ),
		__( "Don't automatically add Home menu item for home page ( as defined in Settings->Reading )", 'absolute-weaver' )
	);

	$opts['visibility-mini-heading'] = absolute_weaver_cz_group_title(
		__( 'Header Mini Menu', 'absolute-weaver' )
	);


	$opts['m_header_mini_hide'] = absolute_weaver_cz_select(
		__( 'Hide Header Mini Menu', 'absolute-weaver' ),
		'',
		'absolute_weaver_cz_choices_hide', 'hide-none', 'refresh'
	);

	return $opts;
}

function absolute_weaver_controls_visibility_infobar() {
	$opts = array();

	$opts['infobar_hide'] = absolute_weaver_cz_select(
		__( 'Hide Info Bar', 'absolute-weaver' ),
		'',
		'absolute_weaver_cz_choices_hide', 'hide-none', 'refresh'
	);

	$opts['info_hide_breadcrumbs'] = absolute_weaver_cz_checkbox(
		__( 'Hide Breadcrumbs', 'absolute-weaver' ),
		__( 'Do not display the Breadcrumbs on the Infobar', 'absolute-weaver' )
	);

	$opts['info_hide_pagenav'] = absolute_weaver_cz_checkbox(
		__( 'Show Search Icon', 'absolute-weaver' ),
		__( 'Do not display the numbered Page navigation on the Infobar', 'absolute-weaver' )
	);

	$opts['info_search'] = absolute_weaver_cz_checkbox(
		__( 'Header Extend BG Attributes', 'absolute-weaver' ),
		__( 'Include slide open Search icon on the right.', 'absolute-weaver' )
	);

	$opts['info_addlogin'] = absolute_weaver_cz_checkbox(
		__( 'Show Log In', 'absolute-weaver' ),
		__( 'Include a simple Log In link on the right.', 'absolute-weaver' )
	);

	$opts['info_home_label'] = absolute_weaver_cz_textarea( __( 'Breadcrumb for Home', 'absolute-weaver' ),
		__( 'This lets you change the breadcrumb label for your home page. (Default: Home)', 'absolute-weaver' ),
		'1', '',
		'refresh');

	return $opts;
}

function absolute_weaver_controls_visibility_content() {
	$opts = array();

	$opts['visibility-content-comments-heading'] = absolute_weaver_cz_group_title( __( 'Comments', 'absolute-weaver' ),
		__( 'Visibility settings for Comments area.', 'absolute-weaver' ) );

	$opts['hide_old_comments'] = absolute_weaver_cz_checkbox(
		__( 'Hide Old Comments When Closed', 'absolute-weaver' ),
		__( 'Hide previous comments after closing comments for page or post. (Default: show old comments after closing.)',  'absolute-weaver' ),
		'plus'
	);


	$opts['form_allowed_tags'] = absolute_weaver_cz_checkbox(
		__( 'Show Allowed HTML', 'absolute-weaver' ),
		__( 'Show the allowed HTML tags below comment input box.',  'absolute-weaver' ),
		'plus'
	);

	$opts['hide_comment_bubble'] = absolute_weaver_cz_checkbox(
		__( 'Hide Comment Title Icon', 'absolute-weaver' ),
		__( 'Hide the comment icon ( bubble ) before the Comments title.',  'absolute-weaver' ),
		'plus'
	);

	$opts['hide_comment_hr'] = absolute_weaver_cz_checkbox(
		__( 'Hide Separator Above Comments', 'absolute-weaver' ),
		__( 'Hide the ( &lt;hr&gt; ) separator line above the Comments area.',  'absolute-weaver' ),
		'plus'
	);

	$opts['visibility-content-comments-note'] = absolute_weaver_cz_heading( __( 'Hiding/Enabling Page and Post Comments', 'absolute-weaver' ),
		__( 'Controlling "Reply/Leave a Comment" visibility for pages and posts is NOT a theme function. It is controlled by WordPress on the "Settings &rarr; Discussion" menu.', 'absolute-weaver' ) );

	return $opts;
}

function absolute_weaver_controls_visibility_postspecific() {
	$opts = array();


	$opts['visibility-posts-metax-heading'] = absolute_weaver_cz_group_title( __( 'Post Meta Info Lines', 'absolute-weaver' ) );

	$opts['post_info_hide_top'] = absolute_weaver_cz_checkbox(
		__( 'Hide top post meta info line', 'absolute-weaver' ),
		__( 'Hide entire top info line ( posted on, by ) of post.', 'absolute-weaver' )
	);

	$opts['post_info_hide_bottom'] = absolute_weaver_cz_checkbox(
		__( 'Hide bottom post meta info line', 'absolute-weaver' ),
		__( 'Hide entire bottom info line ( posted in, comments ) of post.', 'absolute-weaver' )
	);

	$opts['show_post_bubble'] = absolute_weaver_cz_checkbox(
		__( 'Show Comment Bubble', 'absolute-weaver' ),
		__( 'Show comment bubble with link to comments on the post info line.', 'absolute-weaver' )
	);

	$opts['show_post_avatar'] = absolute_weaver_cz_select(
		__( 'Show Author Avatar', 'absolute-weaver' ),
		__( 'Show author avatar on the post info line ( also can be set per post with post editor ).', 'absolute-weaver' ),
		'absolute_weaver_cz_choices_hide', 'hide', 'refresh'
	);

	$opts['visibility-posts-note-meta-heading'] = absolute_weaver_cz_heading( __( 'NOTE:', 'absolute-weaver' ),
		__( 'Hiding any meta info item will force using Icons instead of text descriptions.', 'absolute-weaver' ) );

	$opts['post_hide_date'] = absolute_weaver_cz_checkbox(
		__( 'Hide Post Date', 'absolute-weaver' )
	);

	$opts['post_hide_author'] = absolute_weaver_cz_checkbox(
		__( 'Hide Post Author', 'absolute-weaver' )
	);

	$opts['post_hide_categories'] = absolute_weaver_cz_checkbox(
		__( 'Hide Post Categories', 'absolute-weaver' )
	);

	$opts['post_hide_tags'] = absolute_weaver_cz_checkbox(
		__( 'Hide Post Tags', 'absolute-weaver' )
	);

	$opts['hide_permalink'] = absolute_weaver_cz_checkbox(
		__( 'Hide Permalink', 'absolute-weaver' )
	);

	$opts['hide_singleton_category'] = absolute_weaver_cz_checkbox(
		__( 'Hide Category if Only One', 'absolute-weaver' ),
		__( "If there is only one overall category defined ( Uncategorized ), don't show Category of post.", 'absolute-weaver' )
	);

	$opts['post_hide_single_author'] = absolute_weaver_cz_checkbox(
		__( 'Hide Author for Single Author Site', 'absolute-weaver' ),
		__( "Hide author information if site has only a single author.", 'absolute-weaver' )
	);

	$opts['visibility-posts-nav-heading'] = absolute_weaver_cz_group_title( __( 'Post Navigation', 'absolute-weaver' ) );

	$opts['visibility-posts-misc-heading'] = absolute_weaver_cz_group_title( __( 'Other Post Visibility Options', 'absolute-weaver' ) );

	$opts['hide_post_format_icon'] = absolute_weaver_cz_checkbox(
		__( 'Hide Post Format Icons', 'absolute-weaver' ),
		__( 'Hide the icons for posts with Post Format specified.', 'absolute-weaver' ),
		'plus' );

	$opts['show_comments_closed'] = absolute_weaver_cz_checkbox(
		__( 'Show "Comments are closed"', 'absolute-weaver' ),
		__( 'If comments are off, and no comments have been made, show the <em>Comments are closed.</em> message.', 'absolute-weaver' )
	);

	$opts['hide_author_bio'] = absolute_weaver_cz_checkbox(
		__( 'Hide Author Bio', 'absolute-weaver' ),
		__( 'Hide display of author bio box on Author Archive and Single Post page views.', 'absolute-weaver' )
	);

	return $opts;
}

function absolute_weaver_controls_visibility_sidebars() {
	$opts = array();

	$opts['visibility-primary-widget-heading'] = absolute_weaver_cz_group_title( __( 'Primary Sidebar', 'absolute-weaver' ) );

	$opts['primary_hide'] = absolute_weaver_cz_select(
		__( 'Hide Primary Sidebar', 'absolute-weaver' ),
		'',
		'absolute_weaver_cz_choices_hide', 'hide-none', 'refresh'
	);

	$opts['visibility-secondary-widget-heading'] = absolute_weaver_cz_group_title( __( 'Secondary Sidebar', 'absolute-weaver' ) );

	$opts['secondary_hide'] = absolute_weaver_cz_select(
		__( 'Hide Secondary Sidebar', 'absolute-weaver' ),
		'',
		'absolute_weaver_cz_choices_hide', 'hide-none', 'refresh'
	);

	return $opts;
}


function absolute_weaver_controls_visibility_footer() {
	$opts = array();

	$opts['footer_hide'] = absolute_weaver_cz_select(
		__( 'Hide Footer Area', 'absolute-weaver' ),
		'',
		'absolute_weaver_cz_choices_hide', 'hide-none', 'refresh'
	);

	$opts['footer_sb_hide'] = absolute_weaver_cz_select(
		__( 'Hide Footer Widget Area', 'absolute-weaver' ),
		'',
		'absolute_weaver_cz_choices_hide', 'hide-none', 'refresh'
	);

	$opts['footer_html_hide'] = absolute_weaver_cz_select(
		__( 'Hide Footer HTML Area', 'absolute-weaver' ),
		'',
		'absolute_weaver_cz_choices_hide', 'hide-none', 'refresh'
	);

	$opts['_hide_poweredby'] = absolute_weaver_cz_checkbox(
		__( 'Hide Powered By tag', 'absolute-weaver' ),
		__( 'Hide the WordPress Logo link/notice in the footer. &diams;', 'absolute-weaver' )
	);

	return $opts;
}
