<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly
// This file generates the CSS overrides from the admin interface. It will be included only
// when needed.
// _() - 12/11/14

// define default values

define( 'ABSOLUTE_WEAVER_DEF_BORDER_COLOR', '#222' );
define( 'ABSOLUTE_WEAVER_DEF_BORDER_WIDTH', 1 );
define( 'ABSOLUTE_WEAVER_DEF_BORDER_STYLE', 'solid' );
define( 'ABSOLUTE_WEAVER_DEF_CORNER_RADIUS', 8 );

define( 'ABSOLUTE_WEAVER_DEF_TITLE_MX', 7 );
define( 'ABSOLUTE_WEAVER_DEF_TITLE_MY', 0 );

define( 'ABSOLUTE_WEAVER_DEF_TAG_MX', 10 );
define( 'ABSOLUTE_WEAVER_DEF_TAG_MY', 0 ); // new tagline margins


// ----------------------------------------------------------------------------------------------------------

/**
 * Generate override CSS rules based on options
 *
 * This outputs the CSS overrides. It will output to a file pointer, so it can write to a .css file saved
 * in the user's upload directory - just like the saved style .wvx files. It is included via a standard
 * css include. It needs to be loaded only for the admin page.
 *
 *
 * @param mixed: PHP file handle, or string for direct output
 */

function absolute_weaver_output_style() {
	/* This outputs the CSS overrides. It will output to a file pointer, so it can write to a .css file saved
	  in the user's upload directory - just like the saved style .wvr files. It is included via a standard
	  css include. It needs to be loaded only for the admin page.
	*/

	global $absolute_weaver_css_plus;
	$absolute_weaver_css_plus = '';


	absolute_weaver_cat_css( sprintf( "/* Absolute Weaver styles - Version %s */\n", absolute_weaver_getopt( 'style_version' ) ) );    // opening line


	$themew = absolute_weaver_getopt_default( 'theme_width_int', ABSOLUTE_WEAVER_THEME_WIDTH );        // this is set only here
	if ( absolute_weaver_getopt( 'wrapper_fullwidth' ) ) {
		$themew = 10000;
	}

	// Need to generate different style depending on fullwidth

	if ( absolute_weaver_getopt( 'site_layout' ) == 'fullwidth' ) {
		absolute_weaver_cat_css( sprintf( ".block-inside{max-width:%dpx;margin-left:auto;margin-right:auto;}\n", $themew ) );
		absolute_weaver_cat_css( ".page #content{overflow:visible !important;}.single #content{overflow:visible !important;}.blog #content {overflow:hidden !important;}\n" );

	} else {
		absolute_weaver_cat_css( sprintf( "#wrapper{max-width:%dpx;}\n", $themew ) );
	}// override for full width


// =========================== FIXUPS: FULL WIDTH THEME ===============================
// the full width options will clear and set appropriate stretch and expand options


	$full = absolute_weaver_getopt( 'site_layout' );


	//*---*************************************************************************************************************

	if ( $full == 'fullwidth' || $full == 'stretched' ) {            // okay, we have a value to manipulate
		// all the extend/expand options need to be cleared to start;
		$clear = array(
			'wrapper_fullwidth',
			'expand_header',
			'expand_site_title',
			'expand_m_primary',
			'expand_container',
			'expand_post',
			'expand_footer',
			'expand_footer_sb',
			'expand_site-ig-wrap',
			'container_extend_width',
			'header_extend_width',
			'm_primary_extend_width',
			'infobar_extend_width',
			'post_extend_width',
			'footer_extend_width',
			'footer_sb_extend_width',
			'footer_html_extend_width',
			'wrapper_border',
		);
		// allow 'expand_infobar' as an option to leave set
		foreach ( $clear as $opt )            // clear relevant options
		{
			absolute_weaver_setopt( $opt, false );
		}

		switch ( $full ) {

			case 'fullwidth':
				absolute_weaver_setopt( 'm_primary_extend_width', true );
				absolute_weaver_setopt( 'm_primary_align', 'center' );
				break;

			case 'stretched':
				absolute_weaver_setopt( 'expand_header', true );
				absolute_weaver_setopt( 'expand_footer', true );
				absolute_weaver_setopt( 'm_primary_align', 'center' );                // center the menus
				break;

			default:
				break;
		}
	}


// =========================== FIXUPs: FIXEDTOP with FULL ALIGNMENTS ===============================
// alignwide + fix to top are incompatible for header_sb_align, header_html_align, m_primary_align
// change them to full.


	if ( absolute_weaver_getopt( 'header_sb_fixedtop' ) ) {
		$align = absolute_weaver_getopt( 'header_sb_align' );
		if ( strpos( 'alignwide', $align ) !== false )                        // switch alignwide to alignfull
		{
			absolute_weaver_setopt( 'header_sb_fixedtop', str_replace( 'alignwide', 'alignfull', $align ) );
		}
	}

	foreach ( array( 'm_primary' ) as $area ) {
		$fixed = absolute_weaver_getopt( $area . '_fixedtop' );
		if ( strpos( $fixed, 'fix' ) != false ) {
			$align = absolute_weaver_getopt( $area . '_align' );
			if ( strpos( 'alignwide', $align ) !== false )                        // switch alignwide to alignfull
			{
				absolute_weaver_setopt( $area . '_align', str_replace( 'alignwide', 'alignfull', $align ) );
			}
		}
	}

	// Create alignwide min-width @media

	if ( $themew != ABSOLUTE_WEAVER_THEME_WIDTH ) { // need to generate new alignwide rule

		$minw = (int) ( $themew * 1.08 );    /* add 8% to width */
		$maxw = $minw - 1;

		/* reset default value for 1188px = default + 8% */

		absolute_weaver_cat_css( "@media (min-width: 1188px) {
.weaverx-sb-one-column .alignwide,#header .alignwide,#header.alignwide,#colophon.alignwide,#colophon .alignwide,
#container .alignwide,#container.alignwide,#infobar .alignwide,.alignwide {
margin-left: inherit;margin-right: inherit;max-width:reset;width:100%;} }\n" );

		absolute_weaver_cat_css( "@media (max-width: 1187px) {
.alignwide {margin-left: inherit;margin-right: inherit;max-width:reset;width:100%;} }\n" );

		absolute_weaver_cat_css( "@media (min-width: {$minw}px) {
.weaverx-sb-one-column .alignwide,#header .alignwide,#header.alignwide,#colophon.alignwide,#colophon .alignwide,
#container .alignwide,#container.alignwide,#infobar .alignwide,.alignwide {
margin-left: calc(50% - 46vw);margin-right: calc(50% - 46vw);max-width:10000px;width: 92vw;} }\n" );

		absolute_weaver_cat_css( "@media (max-width: {$maxw}px) {
.alignwide {margin-left:0 !important;margin-right:0 !important;max-width:100% !important;width:100% !important;} }\n" );

	}


// =========================== LINKS ===============================
//	Important. Links must come before any other rules that might define a tag - such as the menu bars, so just
//	put them here, near the top.


	absolute_weaver_put_link( 'link', 'a, .wrapper a', 'a:hover, .wrapper a:hover' );
	absolute_weaver_put_link( 'contentlink', '.content a', '.content a:hover' );
	absolute_weaver_put_link( 'ilink', '.wrapper .entry-meta a, .wrapper .entry-utility a',
		'.wrapper .entry-meta a:hover,.wrapper .entry-utility a:hover' );
	absolute_weaver_put_link( 'wlink', '.wrapper .widget a', '.wrapper .widget a:hover' );
	absolute_weaver_put_link( 'ibarlink', '#infobar a', '#infobar a:hover' );
	absolute_weaver_put_link( 'footerlink', '.colophon a', '.colophon a:hover' );


// ========================= GENERAL APPEARANCE ===============================

	$b_c = absolute_weaver_getopt_default( 'border_color', ABSOLUTE_WEAVER_DEF_BORDER_COLOR );    //+
	$b_w = absolute_weaver_getopt_default( 'border_width_int', ABSOLUTE_WEAVER_DEF_BORDER_WIDTH );
	$b_s = absolute_weaver_getopt_default( 'border_style', ABSOLUTE_WEAVER_DEF_BORDER_STYLE );
	$menus = array(              /* can't use multiple selectors here! */
	                             'm_primary' => '.menu-primary',
	);

	if ( $b_c != '#222' || $b_w != 1 || $b_s != 'solid' ) {
		absolute_weaver_cat_css( sprintf( ".border {border:%dpx %s %s;}.border-bottom{border-bottom:%dpx %s %s;}\n", $b_w, $b_s, $b_c, $b_w, $b_s, $b_c ) );
	}
	foreach ( $menus as $id => $tag ) {
		if ( absolute_weaver_getopt( "{$id}_sub_border" ) ) {
			absolute_weaver_cat_css( sprintf( "@media (min-width:768px) { {$tag} ul ul{border:%dpx %s %s;} }\n", $b_w, $b_s, $b_c ) );
		}
	}


	/*  rounded_corners  */

	$r = absolute_weaver_getopt_default( 'rounded_corners_radius', ABSOLUTE_WEAVER_DEF_CORNER_RADIUS );
	if ( $r != 8 ) {
		if ( $r >= 8 ) {
			$rm = ( int ) ( .75 * $r );
		} else {
			$rm = $r;
		}

		$rounded = '.rounded,.rounded-all,.rounded-custom{border-radius:8px !important;}
.rounded-top{border-top-left-radius:8px; border-top-right-radius: 8px;}
.rounded-bottom {border-bottom-left-radius:8px; border-bottom-right-radius:8px;}
.rounded-left{border-top-left-radius:8px;border-bottom-left-radius:8px;}
.rounded-right{border-top-right-radius:8px;border-bottom-right-radius:8px;}';

		absolute_weaver_cat_css( str_replace( '8', $rm, $rounded ) . "\n" );
	}


	foreach ( $menus as $id => $tag ) {
		if ( absolute_weaver_getopt( "{$id}_sub_rounded" ) ) {
			absolute_weaver_cat_css( '@media (min-width:768px) { ' );
			// 3 kinds of rounding: whole box + hover, top sub-item, bottom sub-item
			$round_sub = str_replace( '8', $r, "{border-radius:8px;z-index:2001;" );
			$menu = "{$tag} ul.sub-menu, {$tag} ul.children";

			$pad = ( int ) ( $r - ( $r * .25 ) );    // pad it to avoid anchor bg from overwriting rounding
			$bg = absolute_weaver_getopt( "{$id}_sub_bgcolor" );
			if ( $bg == '' ) {
				$bg = 'transparent';
			}

			$round_end = "padding-top:{$pad}px;padding-bottom:{$pad}px;background-color:{$bg};}";
			absolute_weaver_cat_css( $menu . $round_sub . $round_end . "} }\n" );
		}
	}


// =========================== HEADER OPTIONS ===============================

	absolute_weaver_css_style_val( '#site-title,.site-title', '{max-width:%.5f%%;}',
		'site_title_max_w' );

	absolute_weaver_css_style_val( '#site-tagline,.site-title', '{max-width:%.5f%%;}',
		'tagline_max_w' );

	/* Site Title/Description

		Site Title' => 'title_color'
		Title Position => 'site_title_position_xy'
		Move Title over Header Image => 'title_over_image'

		Site Description => 'desc_color'
		Description Position => 'tagline_xy'

		Header Extra HTML => 'header_html'
	*/


	$tx = absolute_weaver_getopt_default( 'site_title_position_xy_X', ABSOLUTE_WEAVER_DEF_TITLE_MX );
	$ty = absolute_weaver_getopt_default( 'site_title_position_xy_Y', ABSOLUTE_WEAVER_DEF_TITLE_MY ); // new title margins

	if ( $tx != 7 || $ty != 0 ) {
		if ( is_rtl() ) {
			absolute_weaver_cat_css( sprintf( "#site-title,.site-title{margin-right:%.5f%% !important;margin-top:%.5f%% !important;}\n", $tx, $ty ) );
		} else {
			absolute_weaver_cat_css( sprintf( "#site-title,.site-title{margin-left:%.5f%% !important;margin-top:%.5f%% !important;}\n", $tx, $ty ) );
		}
	}

	$tx = absolute_weaver_getopt_default( 'tagline_xy_X', ABSOLUTE_WEAVER_DEF_TAG_MX );
	$ty = absolute_weaver_getopt_default( 'tagline_xy_Y', ABSOLUTE_WEAVER_DEF_TAG_MY ); // new tagline margins

	if ( $tx != 10 || $ty != 0 ) {
		if ( is_rtl() ) {
			absolute_weaver_cat_css( sprintf( "#site-tagline{ margin-right:%.5f%% !important; margin-top:%.5f%% !important;}\n", $tx, $ty ) );
		} else {
			absolute_weaver_cat_css( sprintf( "#site-tagline{ margin-left:%.5f%% !important; margin-top:%.5f%% !important;}\n", $tx, $ty ) );
		}
	}

	$tx = absolute_weaver_getopt( 'title_tagline_xy_T' );
	$ty = absolute_weaver_getopt( 'title_tagline_xy_B' ); // title tagline padding

	if ( $tx || $ty ) {
		absolute_weaver_cat_css( sprintf( "#title-tagline{ padding-top:%dpx;padding-bottom:%dpx;}\n", $tx, $ty ) );
	}


	$align = absolute_weaver_getopt_default( 'header_image_align', 'float-left' );   // alignment

	switch ( $align ) {
		case 'align-center':
			absolute_weaver_cat_css( '#branding #header-image img{margin-left:auto;margin-right:auto;} /* ' . $align . '*/' );
			absolute_weaver_cat_css( '#header.header-as-bg-parallax,#header.header-as-bg-responsive,#header.header-as-bg{background-position-x:center;}' );
			break;
		case 'float-left':
			absolute_weaver_cat_css( '#branding #header-image img{float: left;} /* ' . $align . '*/' );
			break;
		case 'float-right':
			absolute_weaver_cat_css( '#branding #header-image img{margin-left:auto;margin-right:0;} /* ' . $align . '*/' );
			absolute_weaver_cat_css( '#header.header-as-bg-parallax,#header.header-as-bg-responsive,#header.header-as-bg{background-position-x:right;}' );
			break;
		case 'alignnone':
		case 'alignwide':
		case 'alignfull':
			absolute_weaver_cat_css( '#branding #header-image img{float:none;} /* ' . $align . '*/' );
			break;

		default:            // default is left and already is in style sheet.
			break;
	}

	if ( ( $val = absolute_weaver_getopt( 'header_min_height' ) ) ) {
		absolute_weaver_cat_css(
			"#header{min-height: {$val}px;}" );
	}

	if ( absolute_weaver_getopt( 'header_actual_size' ) ) {
		absolute_weaver_cat_css(
			'#branding #header-image img' );
	}

	if ( ( $val = absolute_weaver_getopt( 'header_image_max_width_dec' ) ) ) {
		absolute_weaver_cat_css( sprintf( "#branding #header-image img{max-width:%.5f%%;}\n", $val ) );
	}

	if ( ( $align = absolute_weaver_getopt_default( 'header_html_align', 'float-left' ) ) == 'center' ) {
		//$hwidth = absolute_weaver_getopt_default( 'header_html_width_int', '100' );
		//$lm = ( 100.0 - $hwidth ) / 2.0;
		//absolute_weaver_cat_css( sprintf( "#header-html {margin-left:%.5f%%;}\n",$lm ) );
		absolute_weaver_cat_css( "#header-html {display:block !important;}\n" );
	}

	if ( absolute_weaver_getopt_default( 'header_html_center_content' ) ) {
		absolute_weaver_cat_css( "#header-html {text-align:center;}\n" );
	}


	if ( absolute_weaver_getopt_default( 'footer_html_center_content' ) ) {
		absolute_weaver_cat_css( "#footer-html {text-align:center;}\n" );
	}


// =========================== MENU OPTIONS ===============================
	/*
	text_color = 0.213 * this.rgb[0] +
			0.715 * this.rgb[1] +
			0.072 * this.rgb[2]
			< 0.5 ? '#FFF' : '#000';
	*/


	$cur_page = absolute_weaver_getopt( 'menubar_curpage_noancestors' )
		? '.weaverx-theme-menu .current_page_item > a,.weaverx-theme-menu .current-menu-item > a,.weaverx-theme-menu .current-cat > a'

		: '.weaverx-theme-menu .current_page_item > a,.weaverx-theme-menu .current-menu-item > a,.weaverx-theme-menu .current-cat > a,.weaverx-theme-menu .current_page_ancestor > a,' .
		  '.weaverx-theme-menu .current-category-ancestor > a,.weaverx-theme-menu .current-menu-ancestor > a,.weaverx-theme-menu .current-menu-parent > a,.weaverx-theme-menu .current-category-parent > a';

	absolute_weaver_put_color( 'menubar_curpage_color', $cur_page, true );    // menubar_curpage_color
	absolute_weaver_put_bgcolor( 'menubar_curpage_bgcolor', $cur_page, true );

	absolute_weaver_put_rule_if_checked( 'menubar_curpage_em', $cur_page . '{font-style:italic}' );    // menubar_curpage_em
	absolute_weaver_put_rule_if_checked( 'menubar_curpage_bold', $cur_page . '{font-weight:bold}' );


// =========================== CONTENT AREAS ===============================

	// Images

	$img_tag = '.container img, .colophon img';

	absolute_weaver_css_style_val( $img_tag, '{padding:%dpx;}',
		'media_lib_border_int' );

	$img_w = absolute_weaver_getopt( 'media_lib_border_int' );
	if ( $img_w > 3 ) {
		$half = $img_w / 2 + 1;
		$small_border_tag = '.container .gallery-icon img,.container .gallery-thumb img,#content img.gallery-thumb,#content img.avatar';
		absolute_weaver_cat_css( sprintf( "{$small_border_tag}{padding:{$half}px;}\n" ) ); // make the thumbs smaller
	}


	if ( absolute_weaver_getopt_checked( 'show_img_shadows' ) ) {
		absolute_weaver_cat_css( $img_tag .
		                 '{box-shadow: 0 0 2px 1px rgba( 0,0,0,0.25 );}' . "\n" );
	}

	absolute_weaver_put_bgcolor( 'media_lib_border_color', $img_tag );


	$val = absolute_weaver_getopt( 'contentlist_bullet' );
	if ( $val != '' && $val != 'disc' ) {
		absolute_weaver_cat_css( sprintf( "#content ul {list-style-type:%s;}\n", $val ) );
	}
	absolute_weaver_css_style_val( '.entry-summary,.entry-content', '{padding-top:%.5fem;}',
		'space_after_title_dec' );

	absolute_weaver_css_style_val( '#content ul,#content ol', '{margin-bottom:%.5fem;}',
		'content_p_list_dec' );

	absolute_weaver_css_style_val( '#content ul,#content ol, #content p', '{margin-bottom:%.5fem;}',
		'content_p_list_dec' );

	absolute_weaver_css_style_val( '#content *[class^="wp-block-"]', '{margin-top:%.5fem;}',
		'content_block_margin_T' );
	absolute_weaver_css_style_val( '#content *[class^="wp-block-"]', '{margin-bottom:%.5fem;}',
		'content_block_margin_B' );


	if ( absolute_weaver_getopt( 'hyphenate' ) ) {
		absolute_weaver_cat_css( '#content{hyphens:auto;}' );
	}

	$fi_min_height = array(
		'page_min_height'      => '.container-page.parallax',
		'post_blog_min_height' => '.post-area.post-fi-post-bg-parallax-full,.post-area.post-fi-post-bg-parallax',
		'post_min_height'      => '.container-single.post-bg-parallax-full,.container-single.post-bg-parallax',
	);

	foreach ( $fi_min_height as $name => $selector ) {
		if ( absolute_weaver_getopt( $name ) ) {
			$val = absolute_weaver_getopt( $name );
			absolute_weaver_cat_css( "$selector{min-height:{$val}px;}\n" );
		}
	}


	/* Comments */
	absolute_weaver_put_rule_if_checked( 'form_allowed_tags', '#commentform .form-allowed-tags {display:block;}' );

	$b_c = absolute_weaver_getopt( 'border_color' );    //
	if ( ! $b_c ) {
		$b_c = '#222';
	}
	$b_w = absolute_weaver_getopt( 'border_width_int' ); //
	if ( ! $b_w ) {
		$b_w = 1;
	}
	absolute_weaver_put_rule_if_checked( 'show_comment_borders', ".commentlist li.comment,#respond,.commentlist li.comment .comment-author img.avatar,.commentlist .comment.bypostauthor{border:{$b_w}px solid $b_c;}.commentlist li.comment .comment-meta{border-bottom:1px solid $b_c;}" );


	absolute_weaver_put_rule_if_checked( 'hide_comment_bubble', '#comments-title h3{background-image:none;padding-left:0px;}' );
	absolute_weaver_put_rule_if_checked( 'hide_comment_hr', 'hr.comments-hr {display:none;}' );

	absolute_weaver_put_color( 'comment_headings_color', '#comments-title h3, #comments-title h4, #respond h3' );
	absolute_weaver_put_bgcolor( 'comment_content_bgcolor', '.commentlist li.comment, #respond' );
	absolute_weaver_put_bgcolor( 'comment_submit_bgcolor', '#respond input#submit' );


	/*  absolute_weaver_tables  */
	$table = absolute_weaver_getopt( 'absolute_weaver_tables' );

	if ( $table == 'wide' ) {       // Absolute Weaver Default table format
		absolute_weaver_cat_css( sprintf( "#content table {border: 1px solid #e7e7e7;margin: 0 -1px 24px 0;text-align: left;width: 100%%;}
#content tr th, #content thead th {color: #888;font-size: 12px;font-weight: bold;line-height: 18px;padding: 9px 24px;}
#content tr td {border-style:none; border-top: 1px solid #e7e7e7; padding: 6px 24px;}
#content tr.odd td {background: rgba( 0,0,0,0.1 );}\n" ) );
	} elseif ( $table == 'bold' ) {
		absolute_weaver_cat_css( sprintf( "#content table {border: 2px solid #888;}
#content tr th, #content thead th {font-weight: bold;}
#content tr td {border: 1px solid #888;}\n" ) );
	} elseif ( $table == 'noborders' ) {
		absolute_weaver_cat_css( sprintf( "#content table {border-style:none;}
#content tr th, #content thead th {font-weight: bold;border-bottom: 1px solid #888;background-color:transparent;}
#content tr td {border-style:none;}table,td,th{border:none}\n" ) );
	} elseif ( $table == 'fullwidth' ) {
		absolute_weaver_cat_css( sprintf( "#content table {width:100%%;}
#content tr th, #content thead th {font-weight:bold;}\n" ) );
	} elseif ( $table == 'plain' ) {
		absolute_weaver_cat_css( sprintf(
			"#content table {border: 1px solid #888;text-align:left;margin: 0 0 0 0;width:auto;}
#content tr th, #content thead th {color: inherit;background:none;font-weight:normal;line-height:normal;padding:4px;}
#content tr td {border: 1px solid #888; padding:4px;}\n" ) );
	}


	/*  caption_color  */
	absolute_weaver_put_color( 'caption_color', '.wp-caption p.wp-caption-text, #content .gallery .gallery-caption,.entry-attachment .entry-caption, #content figure figcaption' );


// =========================== POST SPECIFIC AREAS ===============================

	absolute_weaver_put_rule_if_checked( 'show_comments_closed', '.nocomments {display:block;}' );

	// single/post navigation links

	absolute_weaver_put_rule_if_checked( 'nav_show_first', '#nav-above{display:block;}' ); // put this one first, so hide can override
	absolute_weaver_put_rule_if_checked( 'nav_hide_above', '#nav-above,.paged #nav-above{display:none;margin:0;}' );
	absolute_weaver_put_rule_if_checked( 'nav_hide_below', '#nav-below{display:none;margin:0;}' );

	if ( absolute_weaver_getopt( 'single_nav_style' ) == 'hide' || absolute_weaver_getopt_checked( 'single_nav_hide_above' ) ) {
		absolute_weaver_cat_css( ".single #nav-above{display:none;margin:0;}\n" );
	}
	if ( absolute_weaver_getopt( 'single_nav_style' ) == 'hide' || absolute_weaver_getopt_checked( 'single_nav_hide_below' ) ) {
		absolute_weaver_cat_css( ".single #nav-below{display:none;margin:0;}\n" );
	}
	$nav = absolute_weaver_getopt( 'nav_style' );    // paged can take more than 50%
	if ( $nav == 'paged_left' ) {
		absolute_weaver_cat_css( ".nav-previous {width:95%;}\n" );
	}
	if ( $nav == 'paged_right' ) {
		absolute_weaver_cat_css( ".nav-next {width:95%;}\n" );
	}


	absolute_weaver_put_color( 'post_icons_color',
		'.entry-meta-gicons .entry-date:before,.entry-meta-gicons .by-author:before,.entry-meta-gicons .cat-links:before,.entry-meta-gicons .tag-links:before,.entry-meta-gicons .comments-link:before,.entry-meta-gicons .permalink-icon:before' );

	absolute_weaver_put_rule_if_checked( 'post_hide_single_author', '.single-author .entry-meta .by-author {display:none;}' );

	if ( ( $val = absolute_weaver_getopt_default( 'post_avatar_int', 28 ) ) != 28 ) {
		absolute_weaver_cat_css( '.post-avatar img {max-width:' . $val . "px;}\n" );
	}

// ============================== WIDGET AREAS ===================================


	$val = absolute_weaver_getopt( 'widgetlist_bullet' );
	if ( $val != '' && $val != 'disc' ) {
		absolute_weaver_cat_css( sprintf( ".widget ul {list-style-type:%s;}\n", $val ) );
	}

// ================================== FONTS =====================================

	// 0.0625 assumes standard default font size of 16
	$font_size = absolute_weaver_getopt( 'site_fontsize_int' );
	if ( $font_size ) {
		absolute_weaver_cat_css( sprintf( "body{font-size:%.5fem;}\n", $font_size * 0.0625 ) );
	}

	$font_size = absolute_weaver_getopt( 'site_fontsize_tablet_int' );
	if ( $font_size ) {
		absolute_weaver_cat_css( sprintf( 'body.is-smalltablet{font-size:%.5fem;}', $font_size * 0.0625 ) );
	}

	$font_size = absolute_weaver_getopt( 'site_fontsize_phone_int' );
	if ( $font_size ) {
		absolute_weaver_cat_css( sprintf( 'body.is-phone{font-size:%.5fem;}', $font_size * 0.0625 ) );
	}

	if ( ( $site_h = absolute_weaver_getopt( 'site_line_height_dec' ) ) ) {
		absolute_weaver_cat_css( sprintf( 'body{line-height:%.5f;}', $site_h ) );
		absolute_weaver_cat_css( sprintf( '.widget-area{line-height:%.5f;}', ( $site_h * .85 ) ) );
	}

	$space = absolute_weaver_getopt( 'font_letter_spacing_global_dec' );
	if ( $space && $space != 0 ) {
		absolute_weaver_cat_css( sprintf( "body{letter-spacing:%.5fem;}\n", $space ) );
	}

	$space = absolute_weaver_getopt( 'font_letter_spacing_global_dec' );
	if ( $space && $space != 0 ) {
		absolute_weaver_cat_css( sprintf( "body{word-spacing:%.5fem;}\n", $space ) );
	}


// ============================== CUSTOM OPTIONS =================================

	if ( ( $val = absolute_weaver_getopt( 'custom_fontsize_a' ) ) ) {        /* Plus version */
		absolute_weaver_cat_css( '.customA-font-size{font-size:' . $val . 'em;}' );
		absolute_weaver_cat_css( sprintf( '.customA-font-size-title{font-size:%.5fem;}', $val * 1.5 ) );
	}
	if ( ( $val = absolute_weaver_getopt( 'custom_fontsize_b' ) ) ) {
		absolute_weaver_cat_css( '.customB-font-size{font-size:' . $val . 'em;}' );
		absolute_weaver_cat_css( sprintf( '.customB-font-size-title{font-size:%.5fem;}', $val * 1.5 ) );
	}

	if ( ( $val = absolute_weaver_getopt( 'custom_shadow' ) ) ) {
		absolute_weaver_cat_css( '.shadow-custom ' . absolute_weaver_fix_braces( $val ) );
	}


// ================================ AREAS ========================================

	absolute_weaver_put_bgcolor( 'body_bgcolor', 'body' );   // start with the body colors/css+
	absolute_weaver_put_bgcolor( 'title_tagline_bgcolor', '#title-tagline' );


	$menu_bars = array(
		'm_primary'     => '.menu-primary .wvrx-menu-container,.menu-primary .site-title-on-menu,.menu-primary .site-title-on-menu a',
		'm_primary_sub' => '.menu-primary .wvrx-menu ul li a',
	);

	$menu_links_bg = array(    // xxx_link_bgcolor
	                           'm_primary' => '.menu-primary .wvrx-menu > li > a',
	);

	$menu_links = array( // color, _hover_color, _hover_bg_color
	                     'm_primary'     => '.menu-primary .wvrx-menu > li > a',
	                     'm_primary_sub' => '.menu-primary .wvrx-menu ul li a',
	);

	$menu_detail = array(              /* can't use multiple selectors here! */
	                                   'm_primary' => '.menu-primary',
	);

// =Menus ------------------------------------------------------------

	foreach ( $menu_bars as $id => $tag ) {
		absolute_weaver_put_bgcolor( $id . '_bgcolor', $tag );
		absolute_weaver_put_color( $id . '_color', $tag );
	}

	foreach ( $menu_links_bg as $id => $tag ) {
		absolute_weaver_put_bgcolor( $id . '_link_bgcolor', $tag );
	}

	foreach ( $menu_links as $id => $tag ) {
		absolute_weaver_put_color( $id . '_color', $tag );
		absolute_weaver_put_color( $id . '_hover_color', $tag . ':hover', true );
		if ( absolute_weaver_getopt( 'm_retain_hover' ) && strpos( $id, '_sub' ) === false ) {
			$rule = str_replace( '> li', 'li:hover', $tag );
			absolute_weaver_put_bgcolor( $id . '_hover_bgcolor', $rule, true );

		} else {
			absolute_weaver_put_bgcolor( $id . '_hover_bgcolor', $tag . ':hover', true ); // important to override current item bg

		}
	}

	// menu logo height
	$h = absolute_weaver_getopt( 'm_primary_logo_height_dec' );
	if ( $h && $h != 0 ) {
		absolute_weaver_cat_css( sprintf( '.menu-primary .custom-logo-on-menu img {height:%.5fem;}', $h ) );
	}
	$h = absolute_weaver_getopt( 'header_logo_height_dec' );
	if ( $h && $h != 0 ) {
		//absolute_weaver_cat_css( sprintf( '#site-title img.site-title-logo{max-height:%.5fem;height:100%%;width:100%%;padding-right:1%%;}', $h ) );
		absolute_weaver_cat_css( sprintf( '#site-title img.site-title-logo {max-height:%dpx;}', $h ) );
	}


	foreach ( $menu_detail as $id => $tag ) {
		absolute_weaver_put_color( $id . '_color', $tag . ' .menu-toggle-button' );

		absolute_weaver_put_color( $id . '_html_color', $tag . ' .wvrx-menu-html' );              // Extra menu HTML Left/Right
		$val = absolute_weaver_getopt( $id . '_html_margin_dec' );

		if ( $val ) {
			absolute_weaver_cat_css( sprintf( $tag . " .wvrx-menu-html{margin-top:%.5fem;}\n", $val ) );
		} else {
			$font_size = absolute_weaver_getopt( $id . '_font_size' );    // generate new top margin based on font_size
			switch ( $font_size ) {
				case 'xxs-font-size':
					absolute_weaver_cat_css( $tag . " .wvrx-menu-html{margin-top:.375em;}\n" );
					break;
				case 'xs-font-size':
					absolute_weaver_cat_css( $tag . " .wvrx-menu-html{margin-top:.425em;}\n" );
					break;
				case 's-font-size':
					absolute_weaver_cat_css( $tag . " .wvrx-menu-html{margin-top:.5em;}\n" );
					break;
				case 'l-font-size':
					absolute_weaver_cat_css( $tag . " .wvrx-menu-html{margin-top:.425em;}\n" );
					break;
				case 'xl-font-size':
					absolute_weaver_cat_css( $tag . " .wvrx-menu-html{margin-top:.425em;}\n" );
					break;
				case 'xxl-font-size':
					absolute_weaver_cat_css( $tag . " .wvrx-menu-html{margin-top:.425em;}\n" );
					break;
				default:
					break;
			}
		}


		// padding
		$pad = absolute_weaver_getopt( $id . '_menu_bar_pad_dec' );
		if ( $pad ) {
			absolute_weaver_cat_css( sprintf( "{$tag} .wvrx-menu-container{padding-top:%.5fem;padding-bottom:%.5fem;}\n", $pad, $pad ) );
		}

		$pad = absolute_weaver_getopt( $id . '_menu_pad_dec' );
		$dcolor = absolute_weaver_getopt( $id . '_dividers_color' );
		$rpad = absolute_weaver_getopt( $id . '_right_padding_dec' );
		$hide_arrows = absolute_weaver_getopt( $id . '_hide_arrows' );

		absolute_weaver_cat_css( "@media( min-width:768px) {\n" );    // following are really .is-desktop. Note last align rule has closing }


		if ( $pad != '' ) {
			absolute_weaver_cat_css( sprintf( "{$tag} .wvrx-menu a{padding-top:%.5fem;padding-bottom:%.5fem;}\n", $pad, $pad ) );

			if ( $pad > 1.9 )       // arrows need adjustments - these are for Genericons
			{
				absolute_weaver_cat_css( sprintf( "{$tag} .menu-arrows .toggle-submenu:after{top:%.5fem;}\n", ( $pad + 1.2 ) ) );
			} elseif ( $pad > 0.6 ) {
				absolute_weaver_cat_css( sprintf( "{$tag} .menu-arrows .toggle-submenu:after{top:%.5fem;}\n", ( $pad + 0.75 ) ) );
			} elseif ( $pad < 0.6 ) {
				absolute_weaver_cat_css( sprintf( "{$tag} .menu-arrows .toggle-submenu:after{top:%.5fem;}\n", ( $pad + 0.5 ) ) );
			}
		}

		// dividers

		if ( $dcolor != '' ) {

			absolute_weaver_cat_css( "{$tag} .wvrx-menu a{border-right:1px solid {$dcolor};}\n" );
			absolute_weaver_cat_css( "{$tag} ul.wvrx-menu > li:first-child {border-left:1px solid {$dcolor};}\n" );
			// only desktop?
			absolute_weaver_cat_css( "{$tag} .wvrx-menu ul > li:first-child{border-top:1px solid {$dcolor};}\n" );
			absolute_weaver_cat_css( "{$tag} .wvrx-menu ul a {border-top:none;border-left:none;border-right:none;border-bottom:1px solid {$dcolor};}\n" );
		}

		// menu padding - ADD space to end of menu item

		if ( $rpad != '' ) {
			$rpad_arrow = $rpad + 1.5;
			$rpad_a = $rpad + 0.75;
			absolute_weaver_cat_css( "{$tag} .wvrx-menu-container li a{padding-right:{$rpad_a}em;}\n" );
			absolute_weaver_cat_css( "{$tag} .menu-hover.menu-arrows .has-submenu > a{padding-right:{$rpad_arrow}em;}\n" );
			absolute_weaver_cat_css( "{$tag} .menu-arrows.menu-hover .toggle-submenu{margin-right:{$rpad}em;}\n" );
		}

		// menu margins

		$mtop = absolute_weaver_getopt( $id . '_top_margin_dec' );
		$mbot = absolute_weaver_getopt( $id . '_bottom_margin_dec' );
		if ( $mtop != '' ) {
			absolute_weaver_cat_css( "{$tag} .wvrx-menu-container{margin-top:{$mtop}px;}\n" );
		}


		if ( $mbot != '' ) {
			$align = absolute_weaver_getopt( $id . '_align' );    // emit different  code depending on align
			if ( strstr( $align, '-fixed' ) === false )    // standard menu margin
			{
				absolute_weaver_cat_css( "{$tag} .wvrx-menu-container{margin-bottom:{$mbot}px;}\n" );
			}
		}


		// Menu Arrows

		if ( $hide_arrows ) {
			absolute_weaver_cat_css(
				"{$tag} .menu-arrows .toggle-submenu:after{content:'';display:none;}\n" );
//.is-deskotp {$tag} .wvrx-menu a span.sub-arrow:after{display:none;}\n" );
			if ( $rpad == '' ) {
				absolute_weaver_cat_css(
					"{$tag} .menu-hover.menu-arrows .has-submenu > a {padding-right:0.75em;}\n" );
			}
			absolute_weaver_cat_css(
				"{$tag} .wvrx-menu a span.sub-arrow:after{display:none;}\n" );
		}

		// special case - generate a .wvrx-menu text align for main menus to get rid of initial menu jumping
		$align = absolute_weaver_getopt_default( "{$id}_align", 'left' );
		$align = str_replace( 'alignwide ', '', $align );
		$align = str_replace( 'alignfull ', '', $align );
		$lh = '';
		if ( $align == 'center' )        // compensate for centered display:inline-block
		{
			$lh = 'line-height:0;';
		}

		absolute_weaver_cat_css( "{$tag} .wvrx-menu,{$tag} .wvrx-menu-container{text-align:{$align};{$lh}}\n}\n" );    // NOTE! Has @media close }


		$color = absolute_weaver_getopt( $id . '_color' );

		if ( $color ) {
			absolute_weaver_cat_css(
				sprintf( "{$tag} .menu-arrows .toggle-submenu:after{color:{$color};}\n" ) );
			absolute_weaver_cat_css(
				sprintf( "{$tag} .menu-arrows ul .toggle-submenu:after{color:{$color};}\n" ) );
			absolute_weaver_cat_css(
				sprintf( "{$tag} .menu-arrows.is-mobile-menu.menu-arrows ul a .toggle-submenu:after{color:{$color};}\n" ) );
		}

		$color = absolute_weaver_getopt( "{$id}_sub_color" );    // sub-menu arrow takes special handling to override
		if ( $color ) {
			absolute_weaver_cat_css( sprintf( "{$tag} .menu-arrows ul .toggle-submenu:after{color:{$color};}\n" ) );
		}

		// alternative mobile menu arrow clickable
		absolute_weaver_put_bgcolor( $id . '_clickable_bgcolor', "{$tag} .is-mobile-menu.menu-arrows .toggle-submenu" );
	}


// End of Menus

// ================================ MARGINS/PADDING/SMART WIDGETS ===================================

	/*
	 *
	.l-content {width:100%;}
	.l-content-m {width:98%;margin-left:1%;margin-right:1%;}

	.l-sb-left, .l-sb-right, .l-sb-left-split, .l-sb-right-split {width:25%;}
	.l-sb-left-lm, .l-sb-right-lm, .l-sb-left-split-lm, .l-sb-right-split-lm {width:24%;margin-left:1%;}
	.l-sb-left-rm, .l-sb-right-rm, .l-sb-left-split-rm, .l-sb-right-split-rm {width:24%;margin-right:1%;}

	.l-widget-area-top, .l-widget-area-bottom {width:100%;}

	*/
	// smart -lm, -rm, -m   : value is 'smart_margin_int'

	$smart = absolute_weaver_getopt_default( 'smart_margin_int', 1 );
	if ( $smart > 25 ) {
		$smart = 1;
	}  // some sanity check


	if ( $smart != 1 ) {
		absolute_weaver_cat_css( '@media (min-width:768px) {' );
		for ( $i = 2; $i <= 8; $i ++ ) {
			$w = ( ( 99.9999 / $i ) - $smart ) + ( $smart / $i );  // 99.9999 just a little rounding fudge factor */
			absolute_weaver_cat_css( sprintf( ".per-row-%d-m{width:%.5f%%;}", $i, $w ) );
		}
		absolute_weaver_cat_css( "}\n@media (min-width:581px) and ( max-width:767px) { " );    // small tablets
		absolute_weaver_cat_css( sprintf( ".per-row-2-m.per-row-3-m.per-row-4-m,.per-row-5-m.per-row-6-m,.per-row-7-m,.per-row-8-m{width:%.5f%%;}", 49.999 - ( $smart / 2.0 ) ) );
		absolute_weaver_cat_css( "\n.m-widget-smart-rm aside{margin-right:{$smart}%;} }
.widget-smart-rm aside\n" );    // global
	}

	absolute_weaver_sidebar_style();      // generate sidebar style


	/* _bgcolor, _color : MUST BE AFTER OTHER AREA OPTIONS BECAUSE OF CSS+ */


	$sb_areas = array(
		'primary'       => '#primary-widget-area',
		'alt:primary'   => '.widget-area-primary',
		'secondary'     => '#secondary-widget-area',
		'alt:secondary' => '.widget-area-secondary',
		'top'           => '.widget-area-top',
		'bottom'        => '.widget-area-bottom',
		'header'        => '#header',
		'header_html'   => '#header-html',
		'header_sb'     => '#header-widget-area',
		'alt:header_sb' => '.widget-area-header',
		'footer'        => '#colophon',
		'footer_html'   => '#footer-html',
		'footer_sb'     => '#footer-widget-area',
		'alt:footer_sb' => '.widget-area-footer',
		'content'       => '#content',
		'container'     => '#container',
		'infobar'       => '#infobar',
		'wrapper'       => '#wrapper',
		'post'          => '.post-area',
		'widget'        => '.widget',
	);

	foreach ( $sb_areas as $area => $tag ) {
		$id = str_replace( 'alt:', '', $area );    // allow double rules
		absolute_weaver_put_bgcolor( $id . '_bgcolor', $tag );
		absolute_weaver_put_color( $id . '_color', $tag );

		if ( $area == 'content' || $area == 'post' ) {     // #content is % instead of px
			absolute_weaver_css_style_val( $tag, '{padding-left:%.5f%%;}', $id . '_padding_L' );
			absolute_weaver_css_style_val( $tag, '{padding-right:%.5f%%;}', $id . '_padding_R' );
		} else {
			absolute_weaver_css_style_val( $tag, '{padding-left:%dpx;}', $id . '_padding_L' );
			absolute_weaver_css_style_val( $tag, '{padding-right:%dpx;}', $id . '_padding_R' );
		}

		absolute_weaver_css_style_val( $tag, '{padding-top:%dpx;}', $id . '_padding_T' );
		absolute_weaver_css_style_val( $tag, '{padding-bottom:%dpx;}', $id . '_padding_B' );

		absolute_weaver_css_style_val( $tag, '{margin-top:%dpx;}', $id . '_margin_T' );
		absolute_weaver_css_style_val( $tag, '{margin-bottom:%dpx;}', $id . '_margin_B' );
	}

	// special areas with px max-width andF extend bg color
	$max_w_areas = array(
		'header'    => '#header',
		'footer'    => '#colophon',
		'container' => '#container',
		'm_primary' => '.menu-primary',
	);

	foreach ( $max_w_areas as $id => $tag ) {
		$w = absolute_weaver_getopt( $id . '_max_width_int' );
		if ( $w ) {
			absolute_weaver_cat_css( "{$tag}" . "{max-width:{$w}px;}\n" );
		}

		if ( ( $xbg = absolute_weaver_getopt( $id . '_extend_bgcolor' ) ) ) {
			$cname = "{$tag}";
			absolute_weaver_cat_css(
				"{$cname}{position:relative;overflow:visible;}
{$cname}:before{content:'';position:absolute;top:0;bottom:0;left:-9998px;right:0;
border-left:9999px solid {$xbg};box-shadow:9999px 0 0 {$xbg};z-index:-1;}\n"
			);
		}
	}

// custom widths for header, footer widget areas

	$hf_sb = array(
		'_header_sb_'     => '#header-widget-area',
		'_footer_sb_'     => '#footer-widget-area',
		'alt:_header_sb_' => '.widget-area-header',
		'alt:_footer_sb_' => '.widget-area-footer',
		'_primary_'       => '#primary-widget-area',
		'_secondary_'     => '#secondary-widget-area',
		'alt:_primary_'   => '.widget-area-primary',
		'alt:_secondary_' => '.widget-area-secondary',
		'_top_'           => '.widget-area-top',
		'_bottom_'        => '.widget-area-bottom',
	);
	$hf_sb_w = array( 'lw_' => '@media (min-width:768px)', 'mw_' => '@media (min-width:581px) and (max-width:767px)', 'sw_' => '@media (max-width:580px)' );

	foreach ( $hf_sb as $sbval => $area ) {                // process each area with custom widget widths
		foreach ( $hf_sb_w as $sb_w => $media ) {         // process each device

			$sb = str_replace( 'alt:', '', $sbval );       // Allow double rules

			$list = trim( absolute_weaver_getopt( $sb . $sb_w . 'cols_list' ) );

			if ( $list == '' ) {
				continue;
			}
			$list = str_replace( '%', '', $list );      // kill %'s
			$list = str_replace( ',', ' ', $list );     // change ,'s to blanks
			$list = str_replace( ' ;', ';', $list );    // be sure the ; is right after the value
			$list = str_replace( ';', '; ', $list );    // be sure have space after ;
			$list = array_filter( explode( ' ', $list ), 'strlen' );   // explode list, filter null strings

			if ( empty( $list ) ) {
				continue;
			}

			absolute_weaver_cat_css( "{$media} {\n" );        // wrap rules in media

			$m = $smart;

			if ( absolute_weaver_getopt( substr( $sbval, 1 ) . 'no_widget_margins' ) ) // no margins?
			{
				$m = 0;
			}

			absolute_weaver_cat_css( "{$area} .widget {float:left;margin-left:0;margin-right:0}\n" );  // reset previous list margins

			$clear = 'clear:both';
			$i = 0;
			foreach ( $list as $val ) {              // step through the list of values
				$i ++;

				$w = str_replace( ';', '', $val );    // strip ;
				$at_end = ( $w != $val );          // force end if was a ; before

				if ( $w === '0' ) {                 // hide this widget
					absolute_weaver_cat_css( $area . ' .widget-' . $i . "{display:none;}\n" );
				} elseif ( $w ) {
					if ( $at_end ) {            // at end of row
						absolute_weaver_cat_css( sprintf( "%s .widget-%d{width:%.5f%%;%s}\n", $area, $i, $w, $clear ) );
						$clear = 'clear:both;';

					} else {
						absolute_weaver_cat_css( sprintf( "%s .widget-%d{width:%.5f%%;margin-right:%.5f%%;%s}\n", $area, $i, ( $w - $m ), $m, $clear ) );
						$clear = '';
					}
				}
			}
			absolute_weaver_cat_css( "}\n" );    // end of @media wrap

		}    // end for each device type
	}        // end of each area



// ==================================== EXPAND &  EXTEND BG TO FULL WIDTH ==================================

//--------------------- EXPAND & EXTEND BG Attributes CSS Rules Generation -------------------
//V2.1 post rules have the no sidebar slector, so Post page with Sidebar get done with script
//V2 Fixes missing padding rule; fixes wrong limited width formula; add mwarpper margin support is wrapper is set to border:box
	// padding: _padding_L, _padding_R (px)
	// width: _width_int (%) - 'width' => true means have _width_int + _max_width_int + _align
	// max width in px: _max_width_int (px)
	// align: _align

	//----------------EXPAND Only rules -----------------------

	if ( absolute_weaver_getopt( 'wrapper_fullwidth' ) ) {
		absolute_weaver_cat_css( '#wrapper{max-width:10000px;}' );
	}

	//Expand fixedtop if header is expanded
	if ( absolute_weaver_getopt_expand( 'expand_header' ) ) {
		absolute_weaver_cat_css( "#inject_fixedtop {left:0;max-width:none !important;width:calc( 100vw - 16px) !important;}
		.no-vert-scrollbar #inject_fixedtop {left:0;width:calc( 100vw ) !important;}\n" );
	}
	//Expand fixedbottom if footer is expanded
	if ( absolute_weaver_getopt_expand( 'expand_footer' ) ) {
		absolute_weaver_cat_css( "#inject_fixedbottom {left:0;max-width:none !important;width:calc( 100vw - 16px) !important;}
		.no-vert-scrollbar #inject_fixedbottom {left:0;width:calc( 100vw ) !important;}\n" );
	}

	//------End of Expand only


	// ARRAY DEFINITION: Includes Both Expand and Extend elements *** Only 5 sub areas with width% for Extend need to be marked width => true

	// Areas with _extend_width and expand with option with only true on supporting sub areas for Extend
	// Expand only Sub areas should all be width > false as you are not suppose to expand a limited width area
	$extend = array(
		'header'      => array( 'sel' => '#header', 'width' => false, 'xpad' => 'x' ),
		'header_sb'   => array( 'sel' => '#header-widget-area', 'width' => true, 'xpad' => 'header' ),            // does not have _max_width_int, but can safely use 0
		'header_html' => array( 'sel' => '#header-html', 'width' => true, 'xpad' => 'header' ),                // no _max_width_int

		'm_primary'          => array( 'sel' => '#nav-primary .wvrx-menu-container', 'width' => false, 'xpad' => 'header' ),            // padding: none?
		//Header sub Areas for expand_only ( all width > false )
		'header-image'       => array( 'sel' => '#header-image', 'width' => false, 'xpad' => 'header' ),
		'site_title'         => array( 'sel' => '#title-tagline', 'width' => false, 'xpad' => 'header' ),
		'header-widget-area' => array( 'sel' => '#header-widget-area', 'width' => false, 'xpad' => 'header' ),    // should have the same name as extend name
		'header-html'        => array( 'sel' => '#header-html', 'width' => false, 'xpad' => 'header' ),                    // should have the same name as extend name

		'container' => array( 'sel' => '#container', 'width' => false, 'xpad' => 'x' ),
		'infobar'   => array( 'sel' => '#infobar', 'width' => true, 'xpad' => 'container' ),
		'post'      => array( 'sel' => '#content .post-area', 'width' => false, 'xpad' => 'container' ),    // doesn't work with CSS for now, .post-area includes custom-post types

		'footer'       => array( 'sel' => '#colophon', 'width' => false, 'xpad' => 'x' ),
		'footer_sb'    => array( 'sel' => '#footer-widget-area', 'width' => true, 'xpad' => 'footer' ),            // no _max_width_int
		'footer_html'  => array( 'sel' => '#footer-html', 'width' => true, 'xpad' => 'footer' ),                // no _max_width_int
		//Footer sub areas for Expand only
		'site-ig-wrap' => array( 'sel' => '#site-ig-wrap', 'width' => false, 'xpad' => 'footer' ),            // no _max_width_int
	);


	$inside_container = array( 'infobar', 'post' );

	$skip_container = array( 'container', 'infobar', 'post' );
	$skip_header = array( 'header', 'header_sb', 'header_html', 'header-html', 'm_primary', 'header-image', 'site_title', 'header-widget-area' );
	$skip_footer = array( 'footer', 'footer_sb', 'footer_html', 'site-ig-wrap' );

	$nest_header = ( absolute_weaver_getopt_default( 'header_width_int', 100 ) != 100 ||
	                 ( ( $tmp = absolute_weaver_getopt( 'header_max_width_int' ) ) && $tmp < $themew ) );

	$nest_container = ( absolute_weaver_getopt_default( 'container_width_int', 100 ) != 100 ||
	                    ( ( $tmp = absolute_weaver_getopt( 'container_max_width_int' ) ) && $tmp < $themew ) );

	$nest_footer = ( absolute_weaver_getopt_default( 'footer_width_int', 100 ) != 100 ||
	                 ( ( $tmp = absolute_weaver_getopt( 'footer_max_width_int' ) ) && $tmp < $themew ) );

	// VARIABLES

	$pre_css = '';        // Global css no @media
	$xcss = '';        // Over sitewidth css
	$media_css = '';        // between 580 and sitewidth css

	$vis_container = '';
	$vis_content = '';

	// 8 works across most browsers

	$w_view_scb = '( 100vw - 8px) '; // Viewport width scrollbar
	$w_view_noscb = '100vw '; // Viewport width No scrollbar
	$m_wrap_scb = '( 50vw - 4px - ( ' . $themew . 'px / 2 ) ) '; // Margin wrapper scrollbar
	$m_wrap_noscb = '( 50vw - ( ' . $themew . 'px / 2 ) ) '; // Margin wrapper no scrollbar

	foreach ( $extend as $opt => $vals ) {        // loop through all areas with expand/extend

		if ( absolute_weaver_getopt_expand( 'expand_' . $opt ) || absolute_weaver_getopt( $opt . '_extend_width' ) ) {

			// if parent has width limit, let script take over for all cases
			// nested limited width areas too difficult to generate CSS, let script do it

			if ( ( $nest_header && in_array( $opt, $skip_header ) ) ||
			     ( $nest_container && in_array( $opt, $skip_container ) ) ||
			     ( $nest_footer && in_array( $opt, $skip_footer ) ) ) {
				continue;
			}

			//--- COMPUTING VARIABLES ---
			// VISIBILITY when $opt in inside container
			if ( in_array( $opt, $inside_container ) ) {
				$vis_container = '#container{overflow:visible !important;}';
			}
			if ( $opt == 'post' ) {
				$vis_content = '#content,.content-page{overflow:visible !important;}';
			}

			// PADDING Calculations

			//Adding Wrapper paddings
			$wrap_p_left = absolute_weaver_getopt_default( 'wrapper_padding_L', 0 );
			$wrap_p_right = absolute_weaver_getopt_default( 'wrapper_padding_R', 0 );

			// Handle padding of parents
			$m_left = absolute_weaver_getopt_default( $vals['xpad'] . '_padding_L', 0 );
			$m_right = absolute_weaver_getopt_default( $vals['xpad'] . '_padding_R', 0 );

			// This areas own padding
			$pad_left = absolute_weaver_getopt_default( $opt . '_padding_L', 0 ) + $m_left;
			$pad_right = absolute_weaver_getopt_default( $opt . '_padding_R', 0 ) + $m_right;

			//Footer specific calculations: Empty value for footer and footer widget area means 8
			if ( $vals['xpad'] == 'footer' ) {
				$m_left = absolute_weaver_getopt_default( $vals['xpad'] . '_padding_L', 8 );
				$m_right = absolute_weaver_getopt_default( $vals['xpad'] . '_padding_R', 8 );
			}
			if ( ( $opt == 'footer' ) || ( $opt == 'footer_sb' ) ) {
				$pad_left = absolute_weaver_getopt_default( $opt . '_padding_L', 8 ) + $m_left;
				$pad_right = absolute_weaver_getopt_default( $opt . '_padding_R', 8 ) + $m_right;
			}
			$pad_left .= 'px';
			$pad_right .= 'px';

			$m_left .= 'px';
			$m_right .= 'px'; // these expressions must end up with units

			$wrap_p_left .= 'px';
			$wrap_p_right .= 'px';

// *** Small section was moved up a bit as it applies to ALL posts or no posts
			$align_left = '';
			$align_right = '';

			$width = '';
			// dont need to compute max-with in pixel, none of the sub areas use it, nor is $min-width used anymore
			if ( $vals['width'] ) { // if option has width options
				$width = absolute_weaver_getopt( $opt . '_width_int' );
				if ( $width != 0 ) {
					if ( absolute_weaver_getopt( $opt . '_max_width_int' ) != 0 ) // if both width and max-width set, let script do it.
					{
						continue;
					} // skip this one, continue loop
					$width = $width . '%';
				}
			}

//------------------------------------------------------  Post Specifics Section ----------------------------------------------------
			$important = '';

			if ( $opt == 'post' ) {    // CASE: post
				// *** This is a complete duplicate of the general loop for clarity
				// *** so If changes are made in the rules of the general loop, they need to be also made to the post specific one

				$not_safari = '.wvrx-not-safari';    // no spaces for posts

				if ( absolute_weaver_getopt_default( 'blog_cols', 1 ) > 1 ) {
					continue;
				}    // bail to JS on multi column
				$no_sdb = ".weaverx-sb-one-column ";   // No sidebar selector so rules do not apply to post pages with sidebars
				$cnt_left = absolute_weaver_getopt_default( 'content_padding_L', 2 ); // also add in #content padding ( in % ) if extending post
				$cnt_right = absolute_weaver_getopt_default( 'content_padding_R', 2 );
				// post paddings are in %, needed to redo value
				$pad_left = absolute_weaver_getopt_default( $opt . '_padding_L', 0 ) . '%' . ' + ' . $m_left;
				$pad_right = absolute_weaver_getopt_default( $opt . '_padding_R', 0 ) . '%' . ' + ' . $m_left;

				// *** Building the various content padding Converting them in px or viewport units so the value is right when placed in post rules
				// _x for values above site-width; _scb values Under site width with scrollbar; _noscb values under site width with no scrollbar
				$cnt_pad_l_x = '0px';
				$cnt_pad_r_x = '0px';
				$cnt_pad_l_noscb = '0px';
				$cnt_pad_r_noscb = '0px';
				$cnt_pad_l_scb = '0px';
				$cnt_pad_r_scb = '0px';
				//Content padding % is computed against width( wrapper or browser ) - wrapper paddings - container paddings
				$wrap_pad_all = absolute_weaver_getopt_default( 'wrapper_padding_L', 0 ) + absolute_weaver_getopt_default( 'wrapper_padding_R', 0 );
				$cont_pad_all = absolute_weaver_getopt_default( 'container_padding_L', 0 ) + absolute_weaver_getopt_default( 'container_padding_R', 0 );

				if ( $cnt_left != 0 ) {
					// *** Content padding above sitewidth ( convert to pixel value )
					$cnt_pad_l_x = ( $cnt_left / 100 ) * ( $themew - $wrap_pad_all - $cont_pad_all ) . 'px';

					// *** Content padding below sitewidth	( convert to viewport units )
					$cnt_pad_l_noscb = "( " . $cnt_left / 100 . " * ( 100vw - " . $wrap_pad_all . "px - " . $cont_pad_all . "px) )";
					$cnt_pad_l_scb = "( " . $cnt_left / 100 . " * ( 100vw - 16px - " . $wrap_pad_all . "px - " . $cont_pad_all . "px) )";
				}
				if ( $cnt_right != 0 ) {
					// *** Content padding above sitewidth ( convert to pixel value )
					$cnt_pad_r_x = ( $cnt_right / 100 ) * ( $themew - $wrap_pad_all - $cont_pad_all ) . 'px';

					// *** Content padding below sitewidth	( convert to viewport units )
					$cnt_pad_r_noscb = "( " . $cnt_right / 100 . " * ( 100vw - " . $wrap_pad_all . "px - " . $cont_pad_all . "px) )";
					$cnt_pad_r_scb = "( " . $cnt_right / 100 . " * ( 100vw - 16px - " . $wrap_pad_all . "px - " . $cont_pad_all . "px) )";
				}

				//==============================================================  POST SPECIFIC RULES  =========================================================
				$pre_css .= "{$not_safari}{$no_sdb}{$vals['sel']}{box-sizing:border-box;}\n"; //*** Needs to be in pre-css to work below site width width area padding

				//--- EXPAND & EXTEND COMMON RULES ---
				// pre_css General width Rules for ALL. Adds margins rules for padding bug fix. Need calc around margin for post mix of % and px
				// Margins in these apply under sitewidth as other rules will override above sitewidth


				// *** Add specific content padding for below sitewidth with and without scrollbar ( _scb or _noscb )

				$pre_css .= "{$not_safari}{$no_sdb}{$vals['sel']}{max-width:none {$important};width:calc{$w_view_scb} {$important};margin-left: calc( -1 * ( {$m_left} + {$cnt_pad_l_scb} ) - {$wrap_p_left} );margin-right: calc( -1 * ( {$m_right} + {$cnt_pad_r_scb} ) - {$wrap_p_right} );}\n";
				$pre_css .= "{$not_safari}.no-vert-scrollbar{$no_sdb} {$vals['sel']}{width:{$w_view_noscb} {$important};margin-left: calc( -1 * ( {$m_left} + {$cnt_pad_l_noscb} ) - {$wrap_p_left} );margin-right: calc( -1 * ( {$m_right} + {$cnt_pad_r_noscb} ) - {$wrap_p_right} );}\n";

				// xcss Expand margin Rules For ALL when over sitewidth ( _x )
				// *** Add Specific Content paddings for below sitewidth with and without scrollbar
				$xcss .= "{$not_safari}{$no_sdb}{$vals['sel']} {margin-left:calc( -1 * {$m_wrap_scb} - {$wrap_p_left} - {$m_left} - {$cnt_pad_l_x} );margin-right:calc( -1 * {$m_wrap_scb} - {$wrap_p_right} - {$m_right} - {$cnt_pad_r_x} );}\n";
				$xcss .= "{$not_safari}.no-vert-scrollbar{$no_sdb} {$vals['sel']} {margin-left:calc( -1 * {$m_wrap_noscb} - {$wrap_p_left} - {$m_left} - {$cnt_pad_l_x} );margin-right:calc( -1 * ( {$m_wrap_noscb} ) - {$wrap_p_right} - {$m_right} - {$cnt_pad_r_x} );}\n";

				//--- EXTEND ONLY RULES ---
				//--- pre_css General Padding rules

				// These apply when under sitewidth ( above other rules override )
				// *** Add the content padding for below sitewidth with and without scrollbar ( _scb or _noscb )
				if ( absolute_weaver_getopt( $opt . '_extend_width' ) ) {
					$pre_css .= "{$not_safari}{$no_sdb}{$vals['sel']}{padding-left:calc( {$wrap_p_left} + {$cnt_pad_l_scb} + {$pad_left}{$align_left} ); padding-right:calc( {$wrap_p_right} + {$cnt_pad_r_scb} + {$pad_right}{$align_right} );}\n";
					$pre_css .= "{$not_safari}.no-vert-scrollbar{$no_sdb} {$vals['sel']}{padding-left:calc( {$wrap_p_left} + {$cnt_pad_l_noscb} + {$pad_left}{$align_left} ); padding-right:calc( {$wrap_p_right} + {$cnt_pad_r_noscb} + {$pad_right}{$align_right} );}\n";
				}

				// xcss GENERAL Rules for Extended Areas when wider than sitewidth
				// *** Add The content padding for above sitewidth  ( _x )
				if ( absolute_weaver_getopt( $opt . '_extend_width' ) ) {
					$xcss .= "{$not_safari}{$no_sdb}{$vals['sel']}{padding-left:calc( {$m_wrap_scb} + {$wrap_p_left} + {$cnt_pad_l_x} + {$pad_left}{$align_left} );padding-right:calc( {$m_wrap_scb} + {$wrap_p_right} + {$cnt_pad_r_x} + {$pad_right}{$align_right} );}\n";
					$xcss .= "{$not_safari}.no-vert-scrollbar{$no_sdb} {$vals['sel']}{padding-left:calc( {$m_wrap_noscb} + {$wrap_p_left} + {$cnt_pad_l_x} + {$pad_left}{$align_left} ); padding-right:calc( {$m_wrap_noscb} + {$wrap_p_right} + {$cnt_pad_r_x} + {$pad_right}{$align_right} );}\n";
				}

			}   // End of Post Specific case ===================================================================

			else {        // CASE anything but posts #############################################################

				//--- EXPAND & EXTEND COMMON RULES ---
				$not_safari = '.wvrx-not-safari ';    // space after for others
				// pre_css General width Rules for ALL. **Adds margins rules for padding bug fix. **Need calc around margin for post mix of % and px

				$pre_css .= "{$not_safari}{$vals['sel']}{max-width:none {$important};width:calc{$w_view_scb} {$important};margin-left: calc( -1 * ( {$m_left} ) - {$wrap_p_left} );margin-right: calc( -1 * ( {$m_right} ) - {$wrap_p_right} );}\n";

				$pre_css .= ".wvrx-not-safari.no-vert-scrollbar {$vals['sel']}{width:{$w_view_noscb}{$important};}\n";

				// xcss Expand margin Rules For ALL when over sitewidth
				$xcss .= "{$not_safari}{$vals['sel']} {margin-left:calc( -1 * {$m_wrap_scb} - {$wrap_p_left} - {$m_left} );margin-right:calc( -1 * {$m_wrap_scb} - {$wrap_p_right} - {$m_right} );}\n";
				$xcss .= ".wvrx-not-safari.no-vert-scrollbar {$vals['sel']} {margin-left:calc( -1 * {$m_wrap_noscb} - {$wrap_p_left} - {$m_left} );margin-right:calc( -1 * ( {$m_wrap_noscb} ) - {$wrap_p_right} - {$m_right} );}\n";

				//--- EXTEND ONLY RULES ---
				//--- pre_css General Padding rules
				if ( absolute_weaver_getopt( $opt . '_extend_width' ) ) {
					$pre_css .= "{$not_safari}{$vals['sel']}{padding-left:calc( {$wrap_p_left} + {$pad_left}{$align_left} ); padding-right:calc( {$wrap_p_right} + {$pad_right}{$align_right} );}\n";
				}

				// media_css SPECIALIZED Padding Rules for Limited width Sub Areas between 580px and sitewidth.
				if ( $width && absolute_weaver_getopt( $opt . '_extend_width' ) ) {
					$align = absolute_weaver_getopt( $opt . '_align' );
					$themew_less_one = $themew - 1;
					// *** the rules below had a useless no-vert-scrolbar rules.
					// *** The padding rules in this section do not contain viewport units so do not need a no-scrollbar version
					switch ( $align ) {
						case 'center':
							$align_left = " + ( 100% - {$width} ) / 2";
							$align_right = $align_left; // center = same
							//Centered Padding rules corrected
							$media_css .= "{$not_safari}{$vals['sel']}{padding-left:calc( {$wrap_p_left} + {$pad_left}{$align_left} ); padding-right:calc( {$wrap_p_right} + {$pad_right}{$align_right} );}\n";
							break;

						case 'float-right':
							$align_left = " + 100% - {$width}"; // fix up the left side
							//Left padding rules
							$media_css .= "{$not_safari}{$vals['sel']}{padding-left:calc( {$wrap_p_left} + {$pad_left}{$align_left} );}\n";
							break;

						default: // left
							$align_right = " + 100% - {$width}"; // fix up the right side
							//Right PAdding rules
							$media_css .= "{$not_safari}{$vals['sel']}{padding-right:calc( {$wrap_p_right} + {$pad_right}{$align_right} );}\n";
							break;
					}
				}

				// xcss GENERAL Rules for Extended Areas when wider than sitewidth
				if ( absolute_weaver_getopt( $opt . '_extend_width' ) ) {
					$xcss .= "{$not_safari}{$vals['sel']}{padding-left:calc( {$m_wrap_scb} + {$wrap_p_left} + {$pad_left}{$align_left} );padding-right:calc( {$m_wrap_scb} + {$wrap_p_right} + {$pad_right}{$align_right} );}\n";
					$xcss .= ".wvrx-not-safari.no-vert-scrollbar {$vals['sel']}{padding-left:calc( {$m_wrap_noscb} + {$wrap_p_left} + {$pad_left}{$align_left} ); padding-right:calc( {$m_wrap_noscb} + {$wrap_p_right} + {$pad_right}{$align_right} );}\n";
				}
			}  // // end else CASE anything but posts ===================================================================

		} // end if extended/expanded

	} // end of foreach


	//--- WRAP and WRITE CSS ---
	if ( $xcss ) { // put generated content inside @media ( themewidth )
		$xcss = "{$vis_container}{$vis_content}\n@media (min-width:{$themew}px) {\n{$xcss} }\n";
	}
	if ( $media_css ) { // put generated content inside @media ( 580px-themewidth )
		$media_css = "{$vis_container}{$vis_content}\n@media (min-width:580px) and ( max-width:{$themew_less_one}px) {\n{$media_css} }\n";
	}

	absolute_weaver_cat_css( "\n/* ** Expand/extend ** */\n" . $pre_css );
	absolute_weaver_cat_css( $xcss );
	absolute_weaver_cat_css( $media_css . " /* /EE */\n" );

	//----------------------End of EXPAND & EXTEND BG Attributes--------------------

// ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ END OF EXPAND & EXTEND BG TO FULL WIDTH ^^^^^^^^^^^^^^^^^^^^^^^^^^^^

// ================================ COLORS ===================================
// Colors need to go last because they might have CSS +

	$titles = array(
		'site_title'    => '.wrapper #site-title a,.wrapper .site-title a',
		'tagline'       => '#site-tagline > span,.site-tagline > span',
		'page_title'    => '.page-title',
		'post_title'    => '.wrapper .post-title',
		'archive_title' => '.archive-title',
		'widget_title'  => '.widget-title',
		'm_header_mini' => '#nav-header-mini',
		'content_h'     => '.entry-content h1,.entry-content h2,.entry-content h3,.entry-content h4,.entry-content h5,.entry-content h6',
	);

	foreach ( $titles as $title => $rule ) {
		absolute_weaver_put_bgcolor( $title . '_bgcolor', $rule );

		// bar under some titles
		if ( ( $val = ( int ) absolute_weaver_getopt( $title . '_underline_int' ) ) ) {
			$titleColor = absolute_weaver_getopt( $title . '_color' );
			if ( $titleColor == '' || $titleColor == 'inherit' ) {
				$titleColor = absolute_weaver_getopt( 'content_color' );
			}   // content_color, etc, colors are generated by $area . '_color'
			if ( $titleColor == '' || $titleColor == 'inherit' ) {
				$titleColor = absolute_weaver_getopt( 'container_color' );
			}
			if ( $titleColor == '' || $titleColor == 'inherit' ) {
				$titleColor = absolute_weaver_getopt( 'wrapper_color' );
			}
			if ( $titleColor == '' || $titleColor == 'inherit' ) {
				$titleColor = '#222';
			} /* if they want a border, this is the fallback color */
			absolute_weaver_cat_css( sprintf( $rule . "{border-bottom: {$val}px solid {$titleColor};}\n" ) );
		}

		if ( $title == 'content_h' ) {       // these aren't handled by adding a style
			absolute_weaver_put_rule_if_checked( $title . '_normal', $rule . '{font-weight:normal !important;}' ); // not bold?

			$val = absolute_weaver_getopt( $title . '_italic' );
			if ( $val == 'on' ) {
				absolute_weaver_cat_css( "{$rule}{font-style:italic;}\n" );
			} elseif ( $val == 'off' ) {
				absolute_weaver_cat_css( "{$rule}{font-style:normal;}\n" );
			}
		}

		if ( $title == 'post_title' || $title == 'm_header_mini' )   // stupid special cases because want the bg to work right ...
		{
			$rule = $rule . ' a,' . $rule . ' a:visited';
		}

		absolute_weaver_put_color( $title . '_color', $rule );
	}

	absolute_weaver_put_color( 'post_title_hover_color', '.wrapper .post-title a:hover' );
	absolute_weaver_put_color( 'm_header_mini_hover_color', '#nav-header-mini a:hover' );
	$val = absolute_weaver_getopt( 'm_header_mini_top_margin_dec' );
	if ( $val != '' ) {
		absolute_weaver_cat_css( sprintf( "#nav-header-mini{margin-top:%.5fem}\n", $val ) );
	}

	absolute_weaver_put_bgcolor( 'stickypost_bgcolor', '.blog .sticky' );

	absolute_weaver_put_bgcolor( 'post_author_bgcolor', '#author-info' );


	absolute_weaver_put_bgcolor( 'hr_color', 'hr' );
	absolute_weaver_put_bgcolor( 'post_info_top_bgcolor', '.entry-meta' );
	absolute_weaver_put_color( 'post_info_top_color', '.entry-meta' );

	absolute_weaver_put_bgcolor( 'post_info_bottom_bgcolor', '.entry-utility' );
	absolute_weaver_put_color( 'post_info_bottom_color', '.entry-utility' );

	absolute_weaver_put_bgcolor( 'input_bgcolor', 'input,textarea' );
	absolute_weaver_put_color( 'input_color', 'input,textarea' );

	// ==================== SEARCH =====================

	absolute_weaver_put_bgcolor( 'search_bgcolor', '.search-field,#header-search .search-field:focus,.menu-search .search-field:focus' );
	absolute_weaver_put_color( 'search_color', '.search-field, #header-search .search-field:focus' );

	/* search box icon color */
	$search_areas = array(

		'primary'   => '#primary-widget-area',
		'secondary' => '#secondary-widget-area',
		'm_primary' => '.menu-primary .wvrx-menu-container',
		'top'       => '.widget-area-top',
		'bottom'    => '.widget-area-bottom',
		'header_sb' => '.widget-area-header',
		'footer'    => '#colophon',
		'footer_sb' => '.widget-area-footer',
		'content'   => '#content',
		'container' => '#container',
		'infobar'   => '#infobar',
		'wrapper'   => '#wrapper',
		'widget'    => '.widget',
	);

	foreach ( $search_areas as $area => $tag ) {
		absolute_weaver_put_color( $area . '_color', $tag . ' .search-form .search-submit' );
	}
	absolute_weaver_put_color( 'header_color', '#header-search .search-form::before' );

	absolute_weaver_put_elementor_colors();


	// =============================== TITLES ==================================

	// injection area bg colors - pro version

	$htmls = array(
		'header',
		'postfooter',
		'presidebar',
		'fixedtop',
		'fixedbottom',
		'postheader',
	);
	foreach ( $htmls as $val ) {             // includes areas from Absolute Weaver Plus, too.
		absolute_weaver_put_bgcolor( 'inject_' . $val . '_bgcolor', '#inject_' . $val );
	}

	if ( ( $val = absolute_weaver_getopt( 'post_title_bottom_margin_dec' ) ) ) {
		absolute_weaver_cat_css( ".post-title{margin-bottom:{$val}em;}\n" );
	}


	absolute_weaver_cat_css( "#inject_fixedtop,#inject_fixedbottom,.wvrx-fixedtop,.wvrx-fixonscroll{max-width:{$themew}px;}\n" );

	// Set position when browser below site-width

	absolute_weaver_cat_css( "@media ( max-width:{$themew}px) {.wvrx-fixedtop,.wvrx-fixonscroll,#inject_fixedtop,#inject_fixedbottom {left:0px;margin-left:0 !important;margin-right:0 !important;}}\n" );


//----------------FIXED TOP Positionning rules --------------------------
//Margin adjustment needed for Fixed areas when header/footer are not Expanded
//Adjust Fixed areas margins for wrapper and header padding so they are properly aligned with the edges of the Site
//Without these negative margins, if there are paddings on the wrapper or the header, fixed top areas inside with be shifted
	$hdpadl = absolute_weaver_getopt_default( 'header_padding_L', 0 );
	$hdpadr = absolute_weaver_getopt_default( 'header_padding_R', 0 );
	$wrpadl = absolute_weaver_getopt_default( 'wrapper_padding_L', 0 );
	$wrpadr = absolute_weaver_getopt_default( 'wrapper_padding_R', 0 );

	$allpadl = $hdpadl + $wrpadl;
	$allpadr = $hdpadr + $wrpadr;
	//Adding the unit and sign in a different variable as limited width calculations need the one without sign and unit
	$allpadl_x = - $allpadl . 'px';    //Default values if no header width reduction
	$allpadr_x = - $allpadr . 'px';    //Default values if no header width reduction

	//limited header calculations
	//These are only for when browser is wider than sitewidth. Below that, they are left:0 positionned with existing rules
	$align = absolute_weaver_getopt_default( 'header_align', 'left' );
	$width = absolute_weaver_getopt_default( 'header_width_int', 100 );
	$max_width = absolute_weaver_getopt_default( 'header_max_width_int', 0 );
	$reduct = ( $themew - ( $width / 100 ) * ( $themew - $wrpadl - $wrpadr ) ) . 'px';  // This is the width reduction when browser is larger than sitewidth

	//!! We cant support both a width% and max-width at the same time, it would be way too complicated.
	// Depending which one of if ( $width ) or if ( $max_width ) is last below, it will be the winning one ( revert order between if ( $width ) and if ( $max_width ) )
	switch ( $align ) {
		case 'center':                // Centered case
			if ( $width ) {
				$allpadl_x = "calc( 0px - {$hdpadl}px - {$reduct} / 2 )";
				$allpadr_x = "calc( 0px - {$hdpadr}px - {$reduct} / 2 )";
			} elseif ( $max_width ) {
				$allpadl_x = - $allpadl - ( $themew - $wrpadl - $wrpadr - $max_width ) / 2 . 'px';
				$allpadr_x = - $allpadr - ( $themew - $wrpadl - $wrpadr - $max_width ) / 2 . 'px';
			}
			break;

		case 'float-right':            // Aligned right case
			if ( $width ) {
				$allpadl_x = "calc( {$wrpadl}px - {$hdpadl}px - {$reduct} )";
			} elseif ( $max_width ) {
				$allpadl_x = - $allpadl - ( $themew - $wrpadl - $wrpadr - $max_width ) . 'px';
			}
			break;

		default:                    // Aligned left case
			if ( $width ) {
				$allpadr_x = "calc( {$wrpadr}px - {$hdpadr}px - {$reduct} )";
			} elseif ( $max_width ) {
				$allpadr_x = - $allpadr - ( $themew - $wrpadl - $wrpadr - $max_width ) . 'px';
			}
			break;
	}

	// Rules for TOP Fixed Areas
	if ( ! absolute_weaver_getopt_expand( 'expand_header' ) ) {
		absolute_weaver_cat_css( "@media (min-width:{$themew}px) {
			#inject_fixedtop {margin-left:-{$wrpadl}px;margin-right:-{$wrpadr}px}
			.wvrx-fixedtop,.wvrx-fixonscroll{margin-left:{$allpadl_x};margin-right:{$allpadr_x}}
			}\n" );
	}
	// Rules for BOTTOM Fixed areas
	if ( ! absolute_weaver_getopt_expand( 'expand_footer' ) ) {
		absolute_weaver_cat_css( "@media (min-width:{$themew}px) {
			#inject_fixedbottom {margin-left:-{$wrpadl}px;margin-right:-{$wrpadr}px}
			}\n" );
	}
//------------------ End of Fixed Top Positioning rules ----------------------

// ================================ END RULES ===================================
// These rules need to be at the end

	if ( absolute_weaver_getopt( '_print_show_widgets' ) ) {
		absolute_weaver_cat_css( "@media print { /* print widget areas */
.widget-area{border:1px solid black !important;display:block !important; margin:.5em auto .75em auto !important;padding:.5em !important;width:98%!important;}
#colophon{border:1px solid black !important;display:block !important;margin:1em !important;padding:.5em !important;width:100% !important;}
.widget{margin-bottom:.75em !important;}
#primary-widget-area,#secondary-widget-area{float:left !important;width:48% !important;margin-left:2% !important;}
#footer-widget-area.widget-area{width:100% !important;margin:0 !important;}}\n" );
	}


// ================================ PRO AREAS ===================================

	do_action( 'absolute_weaver_plus_css' );
	do_action( 'absolute_weaver_plugin_support', 'style' );

} // end absolute_weaver_output_style
//-----------------------------------------------------------------------------------------


// ************************************ SUPPORT FUNCTIONS **************************

function absolute_weaver_cat_css( $css ) {
	$GLOBALS['absolute_weaver_css_saved'] .= $css;
}

function absolute_weaver_css_style_val( $name, $style, $opt ) {
	/* output a css rule style with one value ( include {}'s in style ) */
	$val = absolute_weaver_getopt( $opt );
	if ( $val == '' || $val === false || ! $style || ! $name ) {
		return;
	}
	absolute_weaver_cat_css( sprintf( "$name $style\n", $val ) );
}

//--


function absolute_weaver_fix_braces( $val ) {
	$fix = str_replace( '{', '', $val );
	$fix = str_replace( '}', '', $fix );

	return '{' . $fix . '}';
}

//--


function absolute_weaver_sidebar_style() {
	// allow per page sidebar width overrides

	$smart = absolute_weaver_getopt_default( 'smart_margin_int', 1 );
	if ( $smart > 25 ) {
		$smart = 1;
	}  // some sanity check


	$l_sb_w = absolute_weaver_getopt_default( 'left_sb_width_int', '25' );
	$r_sb_w = absolute_weaver_getopt_default( 'right_sb_width_int', '25' );
	$ls_sb_w = absolute_weaver_getopt_default( 'left_split_sb_width_int', '25' );
	$rs_sb_w = absolute_weaver_getopt_default( 'right_split_sb_width_int', '25' );


	// Because of significant degradation of desktop refresh using .is-desktop for these rules,
	// they are wrapped with the @media for desktops.

	absolute_weaver_cat_css( "@media screen and ( min-width:768px) {\n" );
	if ( $r_sb_w != 25 || $smart != 1 ) {      // changed right sidebar width ( or smart width )
		$cw = 100 - $r_sb_w;
		$cw_m = $cw - $smart;
		$r_sb_m = $r_sb_w - $smart;
		absolute_weaver_cat_css( sprintf( ".l-content-rsb{width:%.5f%%;}.l-content-rsb-m{width:%.5f%%;margin-right:%.5f%%;}
.l-sb-right{width:%.5f%%;}.l-sb-right-lm{width:%.5f%%;margin-left:%.5f%%;}.l-sb-right-rm {width:%.5f%%;margin-right:%.5f%%;}\n",
			$cw, $cw_m, $smart, $r_sb_w, $r_sb_m, $smart, $r_sb_m, $smart ) );

	}

	if ( $l_sb_w != 25 || $smart != 1 ) {      // changed left sidebar width
		$cw = 100 - $l_sb_w;
		$cw_m = $cw - $smart;
		$l_sb_m = $l_sb_w - $smart;
		absolute_weaver_cat_css( sprintf( ".l-content-lsb{width:%.5f%%;}.l-content-lsb-m{width:%.5f%%;margin-left:%.5f%%;}
.l-sb-left{width:%.5f%%;}.l-sb-left-lm{width:%.5f%%;margin-left:%.5f%%;}.l-sb-left-rm {width:%.5f%%;margin-right:%.5f%%;}\n",
			$cw, $cw_m, $smart, $l_sb_w, $l_sb_m, $smart, $l_sb_m, $smart ) );

	}

	if ( $ls_sb_w != 25 || $rs_sb_w != 25 || $smart != 1 ) {     // changed a split width
		$cw = 100 - $ls_sb_w - $rs_sb_w;

		absolute_weaver_cat_css(
			sprintf( ".l-sb-right-split{width:%.5f%%}\n", $rs_sb_w ) .
			sprintf( ".l-sb-right-split-lm{width:%.5f%%;margin-left:%.5f%%;}\n", $rs_sb_w - $smart, $smart ) .
			sprintf( ".l-content-ssb{width:%.5f%%;margin-left:%.5f%%;}\n", $cw, $ls_sb_w ) .
			sprintf( ".l-content-ssb-m{width:%.5f%%;margin-left:%.5f%%;margin-right:%.5f%%;}\n", $cw - $smart - $smart, $ls_sb_w + $smart, $smart ) .
			sprintf( ".l-content-ssbs{width:%.5f%%;}\n", $cw ) .
			sprintf( ".l-content-ssbs-m{width:%.5f%%;margin-left:%.5f%%;margin-right:%.5f%%;}\n", $cw - $smart - $smart, $smart, $smart ) .
			sprintf( ".l-sb-left-split{margin-left:-%.5f%%;width:%.5f%%}\n", 100 - $rs_sb_w, $ls_sb_w ) .
			sprintf( ".l-sb-left-split-top{width:%.5f%%}\n", $ls_sb_w ) .
			sprintf( ".l-sb-left-split-rm{margin-left:-%.5f%%;width:%.5f%%}\n", 100 - $rs_sb_w, $ls_sb_w - $smart ) .
			sprintf( ".l-sb-left-split-top-rm {margin-right:%.5f%%;width:%.5f%%;}\n", $smart, $ls_sb_w - $smart ) );
	}
	absolute_weaver_cat_css( "}\n" );


	$sb_horizontal_areas = array(
		'footer'        => '#colophon',
		'footer_html'   => '#footer-html',
		'footer_sb'     => '#footer-widget-area',
		'alt:footer_sb' => '.widget-area-footer',
		'header'        => '#header',
		'header_html'   => '#header-html',
		'header_sb'     => '#header-widget-area',
		'alt:header_sb' => '.widget-area-header',
	);

	foreach ( $sb_horizontal_areas as $id => $tag ) {     // horizontal area widths
		$id = str_replace( 'alt:', '', $id );
		$w = absolute_weaver_getopt( $id . '_width_int' );
		$ltag = str_replace( '.', '.l-', $tag );
		if ( $w === 0 || $w === '0' )    // detects 0 rather than false
		{
			absolute_weaver_cat_css( "{$ltag}{width:auto;}\n" );
		} elseif ( $w > 0 ) {
			absolute_weaver_cat_css( "{$ltag}{width:{$w}%;}.is-phone {$ltag}{width:100%}\n" );
		}

	}

}

//--


function absolute_weaver_put_link( $id, $a, $ahover ) {
	absolute_weaver_put_color( $id . '_color', $a );
	absolute_weaver_put_color( $id . '_hover_color', $ahover );

	absolute_weaver_put_rule_if_checked( $id . '_u', $a . '{text-decoration:underline;}' );        // link

	$hover_ul = absolute_weaver_getopt( $id . '_u_h' );        // hover underline?
	if ( $hover_ul ) {
		absolute_weaver_cat_css( "{$ahover}{text-decoration:underline;}\n" );
		if ( $id == 'link' ) {
			absolute_weaver_cat_css( ".wvrx-menu-container a:hover, #nav-header-mini a:hover{text-decoration:none;}\n" );
		}
	}

	$val = absolute_weaver_getopt( $id . '_em' );
	if ( $val == 'on' ) {
		absolute_weaver_cat_css( "{$a}{font-style:italic;}\n" );
	} elseif ( $val == 'off' ) {
		absolute_weaver_cat_css( "{$a}{font-style:normal;}\n" );
	}

	$val = absolute_weaver_getopt( $id . '_strong' );
	if ( $val == 'on' ) {
		absolute_weaver_cat_css( "{$a}{font-weight:bold;}\n" );
	} elseif ( $val == 'off' ) {
		absolute_weaver_cat_css( "{$a}{font-weight:normal;}\n" );
	}
}

//--


function absolute_weaver_put_bgcolor( $opt, $tag, $important = false ) {
	// put bgcolor and CSS+

	$imp = ( $important ) ? ' !important' : '';

	if ( ( $color = absolute_weaver_getopt( $opt ) ) && $color != 'inherit' ) {
		absolute_weaver_cat_css( sprintf( "$tag {background-color:{$color}{$imp};}\n" ) );
	}
}

//--


function absolute_weaver_put_color( $id, $tag, $important = false ) {
	// put color and CSS+

	if ( ( $color = absolute_weaver_getopt( $id ) ) && $color != 'inherit' ) {
		if ( $important ) {
			absolute_weaver_cat_css( sprintf( "$tag {color:$color !important;}\n" ) );
		} else {
			absolute_weaver_cat_css( sprintf( "$tag {color:$color;}\n" ) );
		}
	}

}


function absolute_weaver_put_rule_if_checked( $id, $rule ) {
	// put just a rule if checked

	if ( absolute_weaver_getopt_checked( $id ) ) {
		absolute_weaver_cat_css( $rule . "\n" );
	}
}


function absolute_weaver_put_elementor_colors() {
	/* generate CSS to override Elementor styling */

	$color_1 = absolute_weaver_getopt( 'elementor_primary_color' );
	$color_2 = absolute_weaver_getopt( 'elementor_secondary_color' );

	$color_3 = absolute_weaver_getopt( 'elementor_text_color' );
	$color_4 = absolute_weaver_getopt( 'elementor_accent_color' );


	/* PRIMARY COLOR */
	if ( $color_1 ) {
		absolute_weaver_cat_css(
			"/*PRIMARY*/.elementor-widget-heading .elementor-heading-title{color:{$color_1};}
.elementor-widget-text-editor.elementor-drop-cap-view-stacked .elementor-drop-cap{background-color:{$color_1};}
.elementor-widget-text-editor.elementor-drop-cap-view-framed .elementor-drop-cap, .elementor-widget-text-editor.elementor-drop-cap-view-default .elementor-drop-cap{color:{$color_1};border-color:{$color_1};}
.elementor-widget-image-box .elementor-image-box-content .elementor-image-box-title{color:{$color_1};}
.elementor-widget-icon.elementor-view-stacked .elementor-icon{background-color:{$color_1};}
.elementor-widget-icon.elementor-view-framed .elementor-icon, .elementor-widget-icon.elementor-view-default .elementor-icon{color:{$color_1};border-color:{$color_1};}
.elementor-widget-icon-box.elementor-view-stacked .elementor-icon{background-color:{$color_1};}
.elementor-widget-icon-box.elementor-view-framed .elementor-icon, .elementor-widget-icon-box.elementor-view-default .elementor-icon{color:{$color_1};border-color:{$color_1};}
.elementor-widget-icon-box .elementor-icon-box-content .elementor-icon-box-title{color:{$color_1};}
.elementor-widget-icon-list .elementor-icon-list-icon i{color:{$color_1};}
.elementor-widget-counter .elementor-counter-number-wrapper{color:{$color_1};}
.elementor-widget-progress .elementor-progress-wrapper .elementor-progress-bar{background-color:{$color_1};}
.elementor-widget-progress .elementor-title{color:{$color_1};}
.elementor-widget-testimonial .elementor-testimonial-name{color:{$color_1};}
.elementor-widget-tabs .elementor-tab-title{color:{$color_1};}
.elementor-widget-accordion .elementor-accordion .elementor-tab-title{color:{$color_1};}
.elementor-widget-toggle .elementor-toggle .elementor-tab-title{color:{$color_1};}
" );
	}


	/* SECONDARY COLOR */
	if ( $color_2 ) {
		absolute_weaver_cat_css(
			"/*SECONDARY*/.elementor-widget-icon-list .elementor-icon-list-text{color:{$color_2};}
.elementor-widget-counter .elementor-counter-title{color:{$color_2};}
.elementor-widget-testimonial .elementor-testimonial-job{color:{$color_2};}
" );
	}


	/* TEXT COLOR */
	if ( $color_3 ) {
		absolute_weaver_cat_css(
			"/*TEXT*/.elementor-widget-image .widget-image-caption{color:{$color_3};}
.elementor-widget-text-editor{color:{$color_3};}
.elementor-widget-divider .elementor-divider-separator{border-top-color:{$color_3};}
.elementor-widget-image-box .elementor-image-box-content .elementor-image-box-description{color:{$color_3};}
.elementor-widget-icon-box .elementor-icon-box-content .elementor-icon-box-description{color:{$color_3};}
.elementor-widget-icon-list .elementor-icon-list-item:not( :last-child ):after{border-top-color:{$color_3};}
.elementor-widget-testimonial .elementor-testimonial-content{color:{$color_3};}
.elementor-widget-tabs .elementor-tab-content{color:{$color_3};}
.elementor-widget-accordion .elementor-accordion .elementor-tab-content{color:{$color_3};}
.elementor-widget-toggle .elementor-toggle .elementor-tab-content{color:{$color_3};}
" );
	}

	/* ACCENT COLOR */
	if ( $color_4 ) {
		absolute_weaver_cat_css(
			"/*ACCENT*/.elementor-widget-button a.elementor-button, .elementor-widget-button .elementor-button{background-color:{$color_4};}
.elementor-widget-tabs .elementor-tab-title.elementor-active{color:{$color_4};}
.elementor-widget-accordion .elementor-accordion .elementor-tab-title.elementor-active{color:{$color_4};}
.elementor-widget-toggle .elementor-toggle .elementor-tab-title.elementor-active{color:{$color_4};}
" );
	}
}
