<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly
/*
 *  lib-content.php
 *  functions related to displaying posts and pages
 */

if ( ! function_exists( 'absolute_weaver_comment' ) ) {
	function absolute_weaver_comment( $comment, $args, $depth ) {
		/**
		 * Template for comments and pingbacks.
		 *
		 * To override this walker in a child theme without modifying the comments template
		 * simply create your own absolute_weaver_comment(), and that function will be used instead.
		 *
		 * Used as a callback by wp_list_comments() for displaying the comments.
		 *
		 * @since Absolute Weaver 1.0
		 */


		switch ( $comment->comment_type ) {
			case 'pingback' :
			case 'trackback' :
				?>
				<li class="pingback">
				<p><?php esc_html_e( 'Pingback:', 'absolute-weaver' ); ?><?php comment_author_link(); ?><?php edit_comment_link( esc_html__( 'Edit', 'absolute-weaver' ), '<span class="edit-link">', '</span>' ); ?></p>
				<?php
				break;

			default :
				?>
			<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
				<article id="comment-<?php comment_ID(); ?>" class="comment">
					<footer class="comment-meta">
						<div class="comment-author vcard">
							<?php
							$avatar_size = 40;
							if ( '0' != $comment->comment_parent ) {
								$avatar_size = 32;
							}

							absolute_weaver_echo_sanitized_html( get_avatar( $comment, $avatar_size ) );

							/* translators: 1: comment author, 2: date and time */
							printf( esc_html__( '%1$s on %2$s <span class="says">said:</span>', 'absolute-weaver' ),
								sprintf( '<span class="fn">%s</span>', get_comment_author_link() ),
								sprintf( '<a href="%1$s"><time datetime="%2$s">%3$s</time></a>',
									esc_url( get_comment_link( $comment->comment_ID ) ),
									esc_html( get_comment_time( 'c' ) ),
									/* translators: 1: date, 2: time */
									sprintf( esc_html__( '%1$s at %2$s', 'absolute-weaver' ), esc_html( get_comment_date() ), esc_html( get_comment_time() ) )
								)
							);

							edit_comment_link( esc_html__( 'Edit', 'absolute-weaver' ), '<span class="edit-link">', '</span>' ); ?>
						</div><!-- .comment-author .vcard -->

						<?php if ( $comment->comment_approved == '0' ) : ?>
							<em class="comment-awaiting-moderation"><?php esc_html_e( 'Your comment is awaiting moderation.', 'absolute-weaver' ); ?></em>
							<br/>
						<?php endif; ?>

					</footer>

					<div class="comment-content"><?php comment_text(); ?></div>
					<?php
					$rl = get_comment_reply_link( array_merge( $args, array( 'reply_text' => esc_html__( 'Reply <span>&darr;</span>', 'absolute-weaver' ), 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) );
					if ( $rl != '' ) {
						?>
						<div class="reply">
							<?php absolute_weaver_echo_sanitized_html( $rl ); ?>
						</div><!-- .reply -->
						<?php
					}
					?>
				</article><!-- #comment-## -->

				<?php
				break;
		} /* end switch */
	}
} // ends check for absolute_weaver_comment()
//--


if ( ! function_exists( 'absolute_weaver_comments_popup_link' ) ) {
	function absolute_weaver_comments_popup_link() {
		/* generate comment bubble for posts */
		if ( ( absolute_weaver_getopt_checked( 'show_post_bubble' ) )
		     && comments_open() && ! post_password_required() ) {
			echo '<span class="comments-link comments-bubble">';
			comments_popup_link( '<span class="leave-reply">' . '&nbsp;' .
			                     '</span>', _x( '1', 'comments number', 'absolute-weaver' ), _x( '%', 'comments number', 'absolute-weaver' ) );
			echo '</span>';
		}
	}
}
//--


if ( ! function_exists( 'absolute_weaver_content_nav' ) ) {
	/**
	 * Display navigation to next/previous pages when applicable
	 */
	function absolute_weaver_content_nav( $nav_id, $from_search = false ) {
		global $wp_query;

		if ( $wp_query->max_num_pages > 1 ) {
			?>
			<nav id="<?php echo esc_attr( $nav_id ); ?>">
				<h3 class="assistive-text"><?php esc_html_e( 'Post navigation', 'absolute-weaver' ); ?></h3>
				<?php
				if ( absolute_weaver_getopt( 'nav_style' ) == 'prev_next' ) {
					$prev = apply_filters( 'absolute_weaver_older_posts', '<span class="meta-nav">&larr; </span>' . esc_html__( 'Previous Post', 'absolute-weaver' ) );
					$next = apply_filters( 'absolute_weaver_newer_posts', esc_html__( 'Next Post', 'absolute-weaver' ) . '<span class="meta-nav">&rarr; </span>' );
					?>
					<div class="nav-previous"><?php next_posts_link( $prev ); ?></div>
					<div class="nav-next"><?php previous_posts_link( $next ); ?></div>
					<?php
				} elseif ( absolute_weaver_getopt( 'nav_style' ) == 'paged_left' ) {
					echo "\t<div class=\"nav-previous\">";
					if ( function_exists( 'wp_pagenavi' ) ) {
						wp_pagenavi();
					} elseif ( function_exists( 'wp_paginate' ) ) {
						wp_paginate( 'title=' );
					} else {
						absolute_weaver_echo_sanitized_html( absolute_weaver_get_paginate_archive_page_links( 'plain', 2, 3 ) ); // weaver generated safe output
					}
					echo "\t</div>\n";
				} elseif ( absolute_weaver_getopt( 'nav_style' ) == 'paged_right' ) {
					echo( "\t<div class=\"nav-next\">" );
					if ( function_exists( 'wp_pagenavi' ) ) {
						wp_pagenavi();
					} elseif ( function_exists( 'wp_paginate' ) ) {
						wp_paginate( 'title=' );
					} else {
						absolute_weaver_echo_sanitized_html( absolute_weaver_get_paginate_archive_page_links( 'plain', 2, 3 ) ); // weaver generated safe output
					}
					echo "\t</div>\n";
				} else {    // Older/Newer posts
					$prev = apply_filters( 'absolute_weaver_older_posts', wp_kses_post( __( '<span class="meta-nav">&larr;</span> Older posts', 'absolute-weaver' ) ) );
					$next = apply_filters( 'absolute_weaver_newer_posts', wp_kses_post( __( 'Newer posts <span class="meta-nav">&rarr;</span>', 'absolute-weaver' ) ) );
					?>
					<div class="nav-previous"><?php next_posts_link( $prev ); ?></div>
					<div class="nav-next"><?php previous_posts_link( $next ); ?></div>
				<?php } ?>
			</nav>
			<div class="clear-nav-id clear-both"></div><!-- #<?php absolute_weaver_echo_sanitized_html( $nav_id ); ?> -->
			<?php
		}
	}
}
//--


if ( ! function_exists( 'absolute_weaver_continue_reading_link' ) ) {
	function absolute_weaver_continue_reading_link() {
		/**
		 * Returns a "Continue Reading" link for excerpts
		 */

		$rep = absolute_weaver_t_get( 'more_msg' );
		if ( ! $rep ) {
			$rep = absolute_weaver_getopt( 'excerpt_more_msg' );
		}

		$rep = apply_filters( 'absolute_weaver_more_message', $rep );

		if ( ! empty( $rep ) ) {
			$msg = '<span class="more-msg">' . $rep . '</span>';
		} else {
			$msg = '<span class="more-msg">' . esc_html( __( 'Continue reading &rarr;', 'absolute-weaver' ) ) . '</span>';
		}

		return ' <a class="more-link" href="' . esc_url( get_permalink() ) . '">' . $msg . '</a>';
	}
}
//--

add_filter( 'absolute_weaver_more_message', 'absolute_weaver_more_message_filter' );
function absolute_weaver_more_message_filter( $msg ) {
	return do_shortcode( $msg );
}

if ( ! function_exists( 'absolute_weaver_edit_link' ) ) {
	function absolute_weaver_edit_link( $echo = 'echo' ) {
		$before = '<span class="edit-link">';
		$after = '</span>';
		$link_label = esc_html__( 'Edit', 'absolute-weaver' );
		$id = 0;

		if ( ! $post = get_post( $id ) ) {
			return '';
		}

		if ( ! $url = get_edit_post_link( $post->ID ) ) {
			return '';
		}

		$post_type_obj = get_post_type_object( $post->post_type );
		$link = '<a class="post-edit-link" href="' . $url . '" title="' . esc_attr( $post_type_obj->labels->edit_item ) . '">' . $link_label . '</a>';
		$flink = apply_filters( 'edit_post_link', $link, $post->ID );
		if ( ! $flink ) {
			$flink = $link;
		}                    // some https vs http bug in WP
		$edit = $before . $flink . $after;


		$is_elementor = ! ! get_post_meta( $post->ID, '_elementor_edit_mode', true );

		if ( $is_elementor ) {
			$link_label = esc_html__( 'Edit with Elementor', 'absolute-weaver' );

			$eurl = str_replace( 'action=edit', 'action=elementor', $url );
			$after = $after . "\n<!-- url: {$url} eurl: {$eurl} -->";
			$link = '<a class="post-edit-link post-edit-link-classic" href="' . $eurl . '" title="' . esc_attr( $post_type_obj->labels->edit_item ) . '">' . $link_label . '</a>';
			$flink = apply_filters( 'edit_post_link', $link, $post->ID );
			if ( ! $flink ) {
				$flink = $link;
			}                    // some https vs http bug in WP
			$edit .= $before . $flink . $after;
		}


		if ( 'echo' == $echo ) {
			absolute_weaver_echo_sanitized_html( $edit );
		} else {
			return $edit;
		}
		return '';
	}
}
//--

if ( ! function_exists( 'absolute_weaver_get_wp_custom_logo' ) ) {
	/**
	 * Displays the optional custom logo.
	 *
	 * Does nothing if the custom logo is not available.
	 *
	 */
	function absolute_weaver_get_wp_custom_logo() {
		if ( function_exists( 'the_custom_logo' ) ) {
			return get_custom_logo();
		}

		return '';
	}
}

if ( ! function_exists( 'absolute_weaver_get_wp_custom_logo_url' ) ) {
	/**
	 * Displays the optional custom logo.
	 *
	 * Does nothing if the custom logo is not available.
	 *
	 */
	function absolute_weaver_get_wp_custom_logo_url( $size = 'full' ) {

		$custom_logo_id = get_theme_mod( 'custom_logo' );
		$image = '';

		// We have a logo. Logo is go.
		if ( $custom_logo_id ) {
			$image = wp_get_attachment_image_url( $custom_logo_id, $size );
		}

		return $image;
	}
}

if ( ! function_exists( 'absolute_weaver_entry_header' ) ) {
	function absolute_weaver_entry_header( $format_title = '', $do_excerpt = false ) {
		/* display entry header ( title ) for posts */

		$arg = ( $do_excerpt ) ? 'post_excerpt' : 'post_full';

		absolute_weaver_fi( $arg, 'title-before' );

		$lead = '<h2 ' . absolute_weaver_title_class( 'post_title', false, 'post-title entry-title' ) . '>';
		if ( $format_title != '' && ! absolute_weaver_getopt( 'hide_post_format_icon' ) ) {
			$icon = "<span class=\"post-format-icon genericon genericon-{$format_title}\"></span>";
			$lead .= $icon;
		}

		absolute_weaver_post_title( $lead, '</h2>' );
	}
}
//--


if ( ! function_exists( 'absolute_weaver_post_title' ) ) {
// display the post title
	function absolute_weaver_post_title( $before = '', $after = '' ) {
		// $before and $after trusted

		if ( absolute_weaver_is_checked_post_opt( '_pp_hide_post_title' ) || absolute_weaver_t_get( 'hide_title' ) ) {
			return;
		}

		echo wp_kses_post( $before );
		$title = the_title( '', '', false );
		// translators: %s is title of post
		$permlink = sprintf( esc_attr__( 'Permalink to %s', 'absolute-weaver' ),
			the_title_attribute( 'echo=0' ) );
		?>
		<a href="<?php esc_url( the_permalink() ); ?>" title="<?php echo esc_attr( $permlink ) ?>" rel="bookmark"><?php echo esc_html( $title ); ?></a>
		<?php
		echo wp_kses_post( $after ) . "\n";

	}
} // if absolute_weaver_post_title
//--


if ( ! function_exists( 'absolute_weaver_link_pages' ) ) {
	function absolute_weaver_link_pages() {
		wp_link_pages( array( 'before' => '<div class="page-link"><span>' . esc_html__( 'Pages:', 'absolute-weaver' ) . '</span>', 'after' => '</div>' ) );
	}
}
//--


if ( ! function_exists( 'absolute_weaver_not_found_search' ) ) {
	function absolute_weaver_not_found_search( $file_name ) {
		?>
		<article id="post-0" class="post no-results not-found">
			<header class="page-header">
				<h1 class="page-title entry-title title-search"><?php esc_html_e( 'Nothing Found', 'absolute-weaver' ); ?></h1>
			</header><!-- .page-header -->

			<div class="entry-content clearfix">
				<p>
					<?php
					if ( ! absolute_weaver_getopt( '_hide_not_found_search' ) ) {
					esc_html_e( 'Apologies, but no results were found for the requested archive. Perhaps searching will help find a related post.', 'absolute-weaver' );
					?>
				</p>
				<p>
					<?php
					get_search_form();
					}
					?>
				</p>
			</div><!-- .entry-content -->
		</article><!-- #post-0 -->
		<?php
	}
}
//--

// ------------------------------------- POST META INFO -----------------------------------

if ( ! function_exists( 'absolute_weaver_format_posted_on_footer' ) ) {
	function absolute_weaver_format_posted_on_footer( $who ) {
		if ( absolute_weaver_is_checked_page_opt( '_pp_hide_infobottom' ) ) {
			absolute_weaver_edit_link();

			return;
		}
		?>
		<footer class="entry-utility">
			<?php absolute_weaver_posted_on();
			if ( comments_open() ) {
			$msg = apply_filters( 'absolute_weaver_leave_reply_blog', esc_html__( 'Leave a reply', 'absolute-weaver' ) );
			$r1 = apply_filters( 'absolute_weaver_reply_1', wp_kses_data( __( '<b>1</b> Reply', 'absolute-weaver' ) ) );
			$rmany = apply_filters( 'absolute_weaver_reply_many', wp_kses_data( __('<b>%</b> Replies', 'absolute-weaver' ) ) );
			absolute_weaver_echo_sanitized_html( '<span ' . absolute_weaver_meta_info_class( 'post_info_bottom' ) . '><span class="comments-link">' );
			comments_popup_link( '<span class="leave-reply">' . '&nbsp;&nbsp;' . esc_html( $msg ) . '</span>', $r1,
				$rmany ); ?></span></span>

			<?php
			}
			absolute_weaver_edit_link();
			?>
		</footer><!-- #entry-utility -->
		<?php
	}
}
//--


if ( ! function_exists( 'absolute_weaver_meta_info_class' ) ) {
	function absolute_weaver_meta_info_class( $who ) {
		// 'post_hide_date', 'post_hide_author', 'post_hide_categories', 'hide_singleton_category', 'post_hide_tags'

		$class = 'meta-info-wrap';

		if ( absolute_weaver_getopt( 'post_hide_date' ) ) {        // check for hide various elements
			$class .= ' post-hide-date';
		}
		if ( absolute_weaver_getopt( 'post_hide_author' ) ) {        // check for hide various elements
			$class .= ' post-hide-author';
		}
		if ( absolute_weaver_getopt( 'post_hide_categories' ) ) {        // check for hide various elements
			$class .= ' post-hide-categories';
		}
		if ( absolute_weaver_getopt( 'hide_singleton_category' ) ) {       // check for hide various elements
			$class .= ' post_hide_single_cat';
		}
		if ( absolute_weaver_getopt( 'post_hide_tags' ) ) {        // check for hide various elements
			$class .= ' post-hide-tags';
		}
		if ( absolute_weaver_getopt( 'hide_permalink' ) ) {        // check for hide various elements
			$class .= ' post-hide-permalink';
		}

		if ( $class != 'meta-info-wrap' || absolute_weaver_getopt( 'post_icons' ) == 'fonticons' || absolute_weaver_getopt( 'post_icons' ) == 'graphics' ) {
			if ( absolute_weaver_getopt( 'post_icons' ) != 'graphics' ) {
				$class .= ' entry-meta-gicons ';
			} else {
				$class .= ' entry-meta-icons';
			}
		}

		$class .= absolute_weaver_text_class( $who, true );

		return 'class="' . trim( $class ) . '"';
	}
}
//--


if ( ! function_exists( 'absolute_weaver_post_bottom_info' ) ) {
	function absolute_weaver_post_bottom_info( $type = '' ) {
		/**
		 * Prints HTML with meta information for the bottom meta line.
		 */
		absolute_weaver_posted_in( $type );
	}
}
//--


if ( ! function_exists( 'absolute_weaver_posted_in' ) ) {
	function absolute_weaver_posted_in( $type = '' ) {
		/**
		 * Prints HTML with meta information for the current post-date/time and author.
		 * Create your own absolute_weaver_posted_in to override in a child theme
		 */

		if ( absolute_weaver_getopt_checked( 'post_info_hide_bottom' )
		     || absolute_weaver_is_checked_page_opt( '_pp_hide_infobottom' )
		     || absolute_weaver_t_get( 'hide_bottom_info' ) ) {    // hide bottom?
			absolute_weaver_edit_link();

			return;
		}

		if ( absolute_weaver_is_checked_page_opt( '_pp_hide_infobottom' )
		     && ! absolute_weaver_t_get( 'showposts' ) ) {
			return;
		}

		$pi = "\n<div " . absolute_weaver_meta_info_class( 'post_info_bottom' ) . ">\n";

		if ( $type == 'single' ) {
			/* translators: used between list items, there is a space after the comma */
			$categories_list = get_the_category_list( esc_html__( ', ', 'absolute-weaver' ) );

			/* translators: used between list items, there is a space after the comma */
			$tags_list = get_the_tag_list( '', esc_html__( ', ', 'absolute-weaver' ) );

			if ( $categories_list ) {
				$cat_count = count( get_the_category() );
				if ( $cat_count < 2 && absolute_weaver_getopt_checked( 'hide_singleton_category' ) ) {
					$pi .= "\t\t\t<span class=\"cat-links post_hide-singleton-category\">\n";
				} else {
					$pi .= "\t\t\t<span class=\"cat-links\">\n";
				}
				// translators: %1$s: class name attribute, %2$s: category list
				$pi .= sprintf( wp_kses_post( __( '<span class="%1$s">Posted in</span> %2$s', 'absolute-weaver' ) ), 'entry-utility-prep entry-utility-prep-cat-links', $categories_list );

				$pi .= "\t\t\t</span>\n";

			} // End if categories
			/* translators: used between list items, there is a space after the comma */

			if ( $tags_list ) {
				$pi .= "\t\t\t<span class=\"tag-links\">\n";
				// translators: %1$s: filled in class name, %2$s: tag name list
				$pi .= sprintf( wp_kses_post( __( '<span class="%1$s">Tagged</span> %2$s', 'absolute-weaver' ) ), 'entry-utility-prep entry-utility-prep-tag-links', $tags_list );
				$pi .= "\t\t\t</span>\n";
			} // End if $tags_list

			$pi .= '<span class="permalink-icon"><a href="' . esc_url( get_permalink() ) . '" title="' . esc_attr__( 'Permalink to ', 'absolute-weaver' ) . esc_attr( the_title_attribute( array( 'echo' => false ) ) ) .
			       '" rel="bookmark">' . esc_html__( 'permalink', 'absolute-weaver' ) . '</a></span>';


			$pi .= absolute_weaver_edit_link( 'noecho' );

		} elseif ( $type != 'reply' ) {    // else not single and not reply
			$show_sep = false;
			if ( 'page' != get_post_type() ) { // Hide category and tag text for pages on Search

				/* translators: used between list items, there is a space after the comma */
				$categories_list = get_the_category_list( esc_html__( ', ', 'absolute-weaver' ) );
				$cat_count = count( get_the_category() );
				$skip = ( $cat_count < 2 && absolute_weaver_getopt_checked( 'hide_singleton_category' ) );
				if ( $categories_list && ! $skip ) {
					$pi .= '<span class="cat-links">';
					// translators: %1$s: class name; %2$s: category list
					$pi .= sprintf( __( '<span class="%1$s">Posted in</span> %2$s', 'absolute-weaver' ), 'entry-utility-prep entry-utility-prep-cat-links', $categories_list );
					$show_sep = true;
					$pi .= '</span>';
				} // End if categories
				/* translators: used between list items, there is a space after the comma */
				$tags_list = get_the_tag_list( '', esc_html__( ', ', 'absolute-weaver' ) );
				if ( $tags_list ) {
					if ( $show_sep ) {
						$pi .= '<span class="sep"> | </span>';
					} // End if $show_sep
					$pi .= '<span class="tag-links">';
					// translators: %1$s: class name, %2$s: tag list
					$pi .= sprintf( wp_kses_post( __( '<span class="%1$s">Tagged</span> %2$s', 'absolute-weaver' ) ), 'entry-utility-prep entry-utility-prep-tag-links', $tags_list );
					$show_sep = true;
					$pi .= '</span>';
				} // End if $tags_list
			} // End if 'page' != get_post_type()

			if ( comments_open() ) {
				if ( $show_sep ) {
					$pi .= '<span class="sep"> | </span>';
				} // End if $show_sep
				$pi .= '<span class="comments-link">';
				ob_start();     // yuck - why doesn't WP make all the utilities have an echo option??
				comments_popup_link( '<span class="leave-reply">' . esc_html__( 'Leave a reply', 'absolute-weaver' ) . '</span>', wp_kses_post( __( '<b>1</b> Reply', 'absolute-weaver' ) ),
					wp_kses_post( __( '<b>%</b> Replies', 'absolute-weaver' ) ) );
				$pi .= ob_get_clean();
				$pi .= '</span>';

			} // End if comments_open()
			$pi .= absolute_weaver_edit_link( 'noecho' );
		}    // end non-single
		$pi .= "\n</div><!-- .entry-meta-icons -->\n";
		echo wp_kses_post( apply_filters( 'absolute_weaver_posted_in', $pi, $type ) );
	}
}
//--


if ( ! function_exists( 'absolute_weaver_posted_on' ) ) {
	function absolute_weaver_posted_on( $type = '' ) {
		/**
		 * Prints HTML with meta information for the current post-date/time and author.
		 * Create your own absolute_weaver_posted_on to override in a child theme
		 */

		if ( absolute_weaver_getopt_checked( 'post_info_hide_top' )
		     || absolute_weaver_t_get( 'hide_top_info' ) ) {    // hide top?
			return;
		}

		if ( absolute_weaver_is_checked_page_opt( '_pp_hide_infotop' )
		     && ! absolute_weaver_t_get( 'showposts' ) ) {
			return;
		}

		$po = "<span " . absolute_weaver_meta_info_class( 'post_info_top' ) . ">\n";
		if ( ( absolute_weaver_getopt_default( 'show_post_avatar', 'hide' ) == 'start' )
		     || absolute_weaver_t_get( 'show_avatar' ) ) {
			$po .= '<span class="post-avatar post-avatar-start">';
			$po .= get_avatar( get_the_author_meta( 'user_email' ), absolute_weaver_getopt_default( 'post_avatar_int', 28 ), null, 'avatar' );
			$po .= '</span>';
		}

		// translators: %1$s: url, %2$s: title, %3$s: date, %4$s: time string, %5$s: url, %6$s: title, %7$s: author name
		$po .= sprintf( __( '<span class="sep posted-on">Posted on </span><a href="%1$s" title="%2$s" rel="bookmark"><time class="entry-date" datetime="%3$s">%4$s</time></a><span class="by-author"> <span class="sep"> by </span> <span class="author vcard"><a class="url fn n" href="%5$s" title="%6$s" rel="author">%7$s</a></span></span>', 'absolute-weaver' ),

			esc_url( get_permalink() ),
			esc_attr( get_the_time() ),
			esc_attr( get_the_date( 'c' ) ),
			esc_html( get_the_date() ),
			esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
			// translators: %s - author name
			sprintf( esc_html__( 'View all posts by %s', 'absolute-weaver' ), esc_html( get_the_author() ) ),
			esc_html( get_the_author() )
		);

		if ( get_the_time( 'Y/m/d' ) !== get_the_modified_time( 'Y/m/d' ) ) {    // get original and modified dates - ignore revisions on same day
			$time_string = ' <time class="updated" datetime="' . esc_attr( get_the_modified_date( 'c' ) ) . '">' . get_the_modified_date() . '</time>';
		} else {
			$time_string = ' <time class="published updated" datetime="' . esc_attr( get_the_date( 'c' ) ) . '">' . get_the_date() . '</time>';
		}

		$po .= $time_string;     // required for Google Structured Data

		if ( absolute_weaver_getopt_default( 'show_post_avatar', 'hide' ) == 'end' ) {
			$po .= '<span class="post-avatar post-avatar-end">';
			$po .= get_avatar( get_the_author_meta( 'user_email' ), absolute_weaver_getopt_default( 'post_avatar_int', 28 ), null, 'avatar' );
			$po .= '</span>';
		}
		$po .= "\n</span><!-- .entry-meta-icons -->";
		echo wp_kses_post( apply_filters( 'absolute_weaver_posted_on', $po, $type ) );
	}
}
//--


if ( ! function_exists( 'absolute_weaver_post_top_meta' ) ) {
	function absolute_weaver_post_top_meta( $type = '' ) {
		/**
		 * Prints HTML with meta information for the top meta line.
		 */
		// $type for single
		echo "<div class=\"entry-meta \">\n";
		absolute_weaver_posted_on( $type );
		absolute_weaver_comments_popup_link();
		echo "</div><!-- /entry-meta -->\n";
	}
}
//--

function absolute_weaver_per_post_style() {
	// Emit a <style> for this post
	do_action( 'absolute_weaver_per_post', get_the_ID() );
}

// ------------------------------------- TITLES -----------------------------------


if ( ! function_exists( 'absolute_weaver_archive_title' ) ) {
	function absolute_weaver_archive_title( $title = '', $type = '', $extra = '' ) {
		// The page title for archive-like pages
		// $type is for type of the archive - could be used to show icon

		if ( ! $title ) {
			$title = the_title( '', '', false );
		}
		?>
		<h1 class="page-title archive-title entry-title title-<?php echo esc_attr( $type . $extra );?>"><span <?php echo esc_attr( absolute_weaver_title_class( 'archive_title' ) );?>><?php absolute_weaver_echo_sanitized_html( $title ); ?></span></h1>
		<?php
	}
}
//--


if ( ! function_exists( 'absolute_weaver_page_title' ) ) {
	function absolute_weaver_page_title( $title = '' ) {
		// The page title


		if ( ! $title ) {
			$title = the_title( '', '', false );
		}
		if ( ! absolute_weaver_is_checked_page_opt( '_pp_hide_page_title' ) ) {
			?>
			<header class="page-header">
				<?php absolute_weaver_fi( 'page', 'title-before' ); ?>
				<h1<?php absolute_weaver_echo_sanitized_html( absolute_weaver_title_class( 'page_title', false, 'page-title entry-title' ) . '>' . $title ); ?></h1>
			</header><!-- .page-header -->
			<?php
		}
	}
}
//--


if ( ! function_exists( 'absolute_weaver_single_title' ) ) {
	function absolute_weaver_single_title( $title = '' ) {
// The page title for single view page
		if ( absolute_weaver_is_checked_post_opt( '_pp_hide_post_title' ) || absolute_weaver_t_get( 'hide_title' ) ) {
			return;
		}
		if ( ! $title ) {
			$title = the_title( '', '', false );
		}
		?>
		<header class="page-header">
		<?php absolute_weaver_fi( 'post', 'title-before' ); ?>
		<h1 class="page-title entry-title title-single <?php absolute_weaver_echo_sanitized_html( absolute_weaver_title_class( 'post_title', true ) ); ?> "> <?php echo esc_html( $title ); ?></h1>
		<?php absolute_weaver_post_top_meta( 'single' ); ?>
		</header> <!-- .page-header -->
<?php
	}
}
//--

if ( ! function_exists( 'absolute_weaver_fi' ) ) {
	function absolute_weaver_fi( $who, $where ) {
		// Emit Featured Image depending on settings and who and where called from
		// $who inc: post, page, post_excerpt, post_full

		$hide = absolute_weaver_getopt( $who . '_fi_hide' );

		if ( 'hide' == $hide || absolute_weaver_t_get( 'hide_featured_image' ) || ! has_post_thumbnail() ) // hide all or no FI
		{
			return false;
		}

		$show = '';

		if ( 'title_featured' != $where &&
		     ( absolute_weaver_get_per_page_value( '_pp_wvrx_pwp_type' ) == 'title'
		       || absolute_weaver_get_per_page_value( '_pp_wvrx_pwp_type' ) == 'title_featured'
		       || absolute_weaver_t_get( 'show' ) == 'title'
		       || absolute_weaver_t_get( 'show' ) == 'title_featured'
		     )
		) {
			return false;
		} elseif ( $where == 'title_featured' ) {
			$show = $where;
		}


		if ( ! $show ) {
			if ( 'page' == $who ) // || $who == 'post_full' )
			{
				$show = absolute_weaver_get_per_page_value( '_pp_fi_location' );
			} elseif ( isset( $GLOBALS['absolute_weaver_page_who'] ) && $GLOBALS['absolute_weaver_page_who'] == 'single' ) {
				$show = absolute_weaver_get_per_post_value( '_pp_fi_location' );
			} else {
				$show = absolute_weaver_get_per_post_value( '_pp_post_fi_location' );
			}
		}


		if ( ! $show ) {
			$show = absolute_weaver_getopt_default( $who . '_fi_location', 'content-top' );
		}    // 'page' or 'post'
		elseif ( $show == 'hide' ) {
			return false;
		}


		if ( 'post-pre' == $where && false !== strpos( $show, 'post-bg' ) ) {    // showing a BG image
			$before = '<style type="text/css">';
			$after = '</style>';
			$image = wp_get_attachment_image_src( get_post_thumbnail_id(), 'full' );        // ( url, width, height )
			$hdr = $image[0];

			// wp customizer preview hack for WP 4.4 beta, might go away for 4.4 release
			$url = get_template_directory_uri();
			$url = str_replace( array( 'http://', 'https://' ), '', $url );
			$hdr = str_replace( '%s', $url, $hdr );        // 4.4 preview breaks this
			$hdr = str_replace( array( 'http://', 'https://' ), '//', $hdr );
			if ( $who == 'page' ) {
				$selector = '#container';
			} elseif ( $who == 'post' && $where == 'post-pre' ) {
				$selector = '#post-' . get_the_ID() . '{background-color:transparent;}' . '#container';
			} else {
				$selector = '#post-' . get_the_ID();
			}

			$style = '';
			switch ( $show ) {
				case 'post-bg-parallax':

				case 'post-bg-parallax-full':                // previous: background-repeat: no-repeat; background-position: center center; background-attachment: fixed;
					$style = "background-image:url( {$hdr} );";  // parallax full - use in conjunction with .wvrx-parallax
					break;

				case 'post-bg':
					$style = "background:url( {$hdr} ) repeat;background-color:transparent;"; // tile vertically
					break;

				case 'post-bg-cover':        // cover - responsive
					$style = "background:url( {$hdr} );background-repeat:no-repeat;background-position:center center;
background-size:cover;background-color:transparent;box-sizing:border-box;"; // cover
					break;

				default:        // no others
					break;
			}

			if ( $style ) {
				absolute_weaver_echo_sanitized_html( absolute_weaver_inline_style( "{$before}{$selector}{ {$style} }{$after}\n" ) );
			}


			return true;
		} // end as bg image

		$align = absolute_weaver_getopt_default( $who . '_fi_align', 'fi-alignleft' );

		$before = '';
		if ( $where == 'post-pre' ) {
			$align .= '-pb';    // need to be able to fixup alignment for small devices
			$before = '<div class="clear-post-before clear-both"></div>';
		}

		$fi_class = 'featured-image fi-' . $who . '-' . $where . ' fi-' . $show . ' ' . $hide . ' ' . $align; // construct fi class

		$attr = array( 'class' => $fi_class );

		// add width if defined

		$w = absolute_weaver_getopt( $who . '_fi_width' );
		if ( $w ) {
			$attr['style'] = 'width:' . $w . '%';
		}

		if ( $show == $where || ( $show == 'post-before' && $where == 'post-pre' ) || ( $show == 'title-banner' && $where == 'title-before' ) ) {

			if ( $show == 'header-image' ) {            // special case : header replacement area
				$image = wp_get_attachment_image_src( get_post_thumbnail_id(), 'full' );        // ( url, width, height )
				if ( ! $image ) {
					return false;
				}

				return $image[0];                // let the header code handle the details...
			}

			$size = absolute_weaver_getopt_default( $who . '_fi_size', 'thumbnail' );

			if ( get_post_thumbnail_id() ) {

				if ( $who == 'post_excerpt' ) {
					$href = esc_url( get_permalink() );
				} else {
					$image = wp_get_attachment_image_src( get_post_thumbnail_id(), 'full' );        // ( url, width, height )
					$href = esc_url( $image[0] );
				}


				$fi_img = get_the_post_thumbnail( null, $size, $attr );

				$fi_after = apply_filters( 'absolute_weaver_fi_after', '' );        // added 3.1.10

				if ( $who == 'page' && absolute_weaver_getopt( 'page_fi_nolink' ) ) {
					$the_fi = "\n{$before}{$fi_img}{$fi_after}\n";
				} elseif ( $who != 'page' && absolute_weaver_getopt( 'post_fi_nolink' ) ) {
					$the_fi = "\n{$before}{$fi_img}{$fi_after}\n";
				} else {
					$the_fi = "\n{$before}<a class=\"wvrx-fi-link\" href=\"{$href}\">{$fi_img}</a>{$fi_after}\n";
				}

				absolute_weaver_echo_sanitized_html( apply_filters( 'absolute_weaver_fi_link', $the_fi, $before, $href, $fi_img, $who, $fi_after ) );

				if ( $show == 'title-banner' ) {
					echo '<div class="clear-both"></div>';
				}

				return false;
			}
		}

		return false;
	}
}
//--

function absolute_weaver_the_page_content( $who = '' ) {

	absolute_weaver_fi( $who, 'content-top' );
	absolute_weaver_the_contnt();
	absolute_weaver_fi( $who, 'content-bottom' );
}

//--


function absolute_weaver_the_contnt() {
	the_content( absolute_weaver_continue_reading_link() );
}

//--


// ========================= special content =========================

function absolute_weaver_post_div( $type = 'content' ) {
	// echo the start <div> for posts
	// include columns class if set
	$class = '';
	$cols = absolute_weaver_getopt( 'post_cols' );
	if ( $cols != '' && $cols != '1' ) {
		$class = ' cols-' . $cols;
	}
	absolute_weaver_echo_sanitized_html( '    <div class="entry-' . $type . ' clearfix' . $class . '"' . '>' . "\n" );
}

function absolute_weaver_the_post_full() {

	absolute_weaver_fi( 'post_full', 'content-top' );

	absolute_weaver_the_contnt();

	absolute_weaver_fi( 'post_full', 'content-bottom' );
}

//--


function absolute_weaver_the_post_excerpt() {

	absolute_weaver_fi( 'post_excerpt', 'content-top' );

	the_excerpt( );

	absolute_weaver_fi( 'post_excerpt', 'content-bottom' );
}

//--


function absolute_weaver_the_post_full_single() {
	global $page;

	if ( $page <= 1 ) {
		absolute_weaver_fi( 'post', 'content-top' );
	}

	absolute_weaver_the_contnt();

	if ( $page <= 1 ) {
		absolute_weaver_fi( 'post', 'content-bottom' );
	}
}

//--


function absolute_weaver_show_only_title() {

	//echo "\n <!-- ********* end of a post ********** -->\n";

	if ( ! absolute_weaver_t_get( 'showposts' )
	     && ( absolute_weaver_get_per_page_value( '_pp_wvrx_pwp_type' ) == 'title'
	          || absolute_weaver_t_get( 'show' ) == 'title'
	     )
	) {
		echo "\t</article><!-- /#post -->\n";

		return true;
	} elseif ( ! absolute_weaver_t_get( 'showposts' )
	           && ( absolute_weaver_get_per_page_value( '_pp_wvrx_pwp_type' ) == 'title_featured'
	                || absolute_weaver_t_get( 'show' ) == 'title_featured'
	           )
	) {
		absolute_weaver_fi( 'post_excerpt', 'title_featured' );            // show FI
		echo "\t</article><!-- /#post; -->\n";

		return true;
	} elseif ( absolute_weaver_t_get( 'showposts' ) && absolute_weaver_t_get( 'show' ) == 'title_featured' ) {
		absolute_weaver_fi( 'post_excerpt', 'title_featured' );            // show FI
		echo "\t</article><!-- /#post. --><div class='clear-both'></div>\n";

		return true;
	} elseif ( absolute_weaver_t_get( 'showposts' ) && ( absolute_weaver_t_get( 'show' ) == 'title' || absolute_weaver_t_get( 'show' ) == 'titlelist' ) ) {
		echo "\t</article><!-- /#post -->\n";

		return true;
	}

	return false;
}

//--


function absolute_weaver_do_excerpt() {
	// return true if this kind of page should be excerpted

	if ( absolute_weaver_t_get( 'show' ) == 'excerpt' )   // for Absolute Weaver Plus
	{
		return true;
	}

	if ( absolute_weaver_t_get( 'show' ) == 'full' )   // for Absolute Weaver Plus
	{
		return false;
	}

	$n1 = absolute_weaver_get_per_page_value( '_pp_fullposts' );
	if ( ! $n1 ) {
		$n1 = absolute_weaver_getopt( 'fullpost_first' );
	}

	if ( $n1 ) {
		global $page, $paged;
		if ( ! ( $paged >= 2 || $page >= 2 )
		     && absolute_weaver_post_count() <= $n1 ) {
			return false;
		}
	}

	$pwp = absolute_weaver_get_per_page_value( '_pp_wvrx_pwp_type' );

	if ( $pwp == 'full' )    // need to check before archive/search
	{
		return false;
	}    // override global setting
	if ( $pwp == 'excerpt' ) {
		return true;
	}    // override global setting

	if ( is_search() ) {
		return ! absolute_weaver_getopt_checked( 'fullpost_search' );
	}
	if ( is_archive() ) {
		return ! absolute_weaver_getopt_checked( 'fullpost_archive' );
	}

	return ! absolute_weaver_getopt_checked( 'fullpost_blog' );
}

//--

function absolute_weaver_author_info() {

	if ( get_the_author_meta( 'description' ) && ! absolute_weaver_getopt( 'hide_author_bio' ) ) { // If a user has filled out their description, show a bio on their entries ?>
		<div class='clear-both'></div>
		<div id=" author-info">
			<div id="author-description">
				<div id="author-avatar">
					<?php absolute_weaver_echo_sanitized_html( get_avatar( get_the_author_meta( 'user_email' ), apply_filters( 'absolute_weaver_author_bio_avatar_size', 75 ) ) ); ?>
				</div><!-- #author-avatar -->
				<p class="author-title"><?php
					// translators: $s - author's name
					printf( esc_html__( 'About %s', 'absolute-weaver' ), get_the_author() ); ?></p>
				<p><?php the_author_meta( 'description' ); ?></p>
				<div id="author-link">
				<span class="vcard author post-author"><span class="fn">
					<a href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>" rel="author">
						<?php
						// translators: %s: the author name
						printf( esc_html__( 'View all posts by %s', 'absolute-weaver' ), esc_html( get_the_author() ) ); ?>
					</a></span></span>
				</div><!-- #author-link	-->
			</div><!-- #author-description -->
		</div><!-- #author-info -->

	<?php }
}

	// ------------------------------------- FILTERS -----------------------------------

function absolute_weaver_auto_excerpt_more_filter( $more ) {
	/**
	 * Replaces "[...]" ( appended to automatically generated excerpts ) with an ellipsis and absolute_weaver_continue_reading_link().
	 *
	 * To override this in a child theme, remove the filter and add your own
	 * function tied to the excerpt_more filter hook.
	 */
	return ' <span class="excerpt-dots">&hellip;</span>' . absolute_weaver_continue_reading_link();
}

add_filter( 'excerpt_more', 'absolute_weaver_auto_excerpt_more_filter' );


function absolute_weaver_custom_excerpt_more_filter( $output ) {
	/**
	 * Adds a pretty "Continue Reading" link to custom post excerpts.
	 *
	 * To override this link in a child theme, remove the filter and add your own
	 * function tied to the get_absolute_weaver_the_post_excerpt filter hook.
	 */

	if ( has_excerpt() && ! is_attachment() ) {
		$output .= absolute_weaver_continue_reading_link();
	}

	return $output;
}

add_filter( 'the_excerpt', 'absolute_weaver_custom_excerpt_more_filter' );


function absolute_weaver_the_excerpt_filter( $excerpt ) {    // filter definition
	return do_shortcode( $excerpt );
}

add_filter( 'the_excerpt', 'absolute_weaver_the_excerpt_filter', 10, 1 );

function absolute_weaver_trim_excerpt_filter( $text = '' ) {
	$raw_excerpt = $text;

	if ( '' == $text ) {
		$text = get_the_content( '' );
		$orig_text_len = strlen( $text );

		$text = strip_shortcodes( $text );
		// $stripped_text_len = strlen( $text );

		$text = apply_filters( 'the_content', $text );
		$text = str_replace( ']]>', ']]&gt;', $text );
		$excerpt_length = apply_filters( 'excerpt_length', 55 );
		$excerpt_more = apply_filters( 'excerpt_more', ' ' . '[...]' );
		$text = wp_trim_words( $text, $excerpt_length, $excerpt_more );
		$stripped_text_len = strlen( $text );
	}
	if ( '' == $raw_excerpt && $orig_text_len > $stripped_text_len && get_post_format() == '' && ! empty( $excerpt_more ) ) {    // have stripped shortcodes
		if ( strpos( $text, $excerpt_more ) === false ) {
			$text .= $excerpt_more;
		}
	}

	return apply_filters( 'wp_trim_excerpt', $text, $raw_excerpt );
}
//--

remove_filter( 'get_the_excerpt', 'wp_trim_excerpt' );
add_filter( 'get_the_excerpt', 'absolute_weaver_trim_excerpt_filter' );



