<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly
/* Absolute Weaver - runtime utils
 *
 *  __ added - 12/11/14
 * needed both at admin time and runtime
 */

// # CONTENTS

// # OPTIONS
// # PER PAGE OPTIONS
// # WIDGET AREA OPTIONS
// # HTML CODE AREAS
// # PAGE WITH POSTS
// # FILTERS
// # MISC
// # OTHER UTILS

// # Absolute Weaver Globals ==============================================================
$absolute_weaver_opts_cache     = false;    // internal cache for all settings
$absolute_weaver_cur_page_ID    = false;    // the ID of the current page
$absolute_weaver_cur_post_count = 0;        // to keep track of even/odd
$absolute_weaver_sticky         = false;

// # OPTIONS ==============================================================

function absolute_weaver_getopt( $opt ) {
	global $absolute_weaver_opts_cache;

	absolute_weaver_opt_cache();

	if ( ! isset( $absolute_weaver_opts_cache[ $opt ] ) ) {    // handles changes to data structure
		return false;
	}

	return $absolute_weaver_opts_cache[ $opt ];
}

function absolute_weaver_getopt_array( $opt ) {
	$val = absolute_weaver_getopt( $opt );
	if ( ! $val ) {
		return array();
	}

	return unserialize( $val );
}


function absolute_weaver_getopt_default( $opt, $default = false ) {
	$val = absolute_weaver_getopt( $opt );
	if ( ( ! $val && strlen( $val ) == 0 ) || $val == 'default' ) {
		return $default;
	} else {
		return $val;
	}
}

function absolute_weaver_getopt_checked( $opt ) {
	global $absolute_weaver_opts_cache;
	absolute_weaver_opt_cache();

	if ( ! isset( $absolute_weaver_opts_cache[ $opt ] ) ) {    // handles changes to data structure
		return false;
	}
	if ( ! $absolute_weaver_opts_cache[ $opt ] ) {
		return false;
	}

	return true;
}

function absolute_weaver_getopt_expand( $opt ) {
	// special case for 'expand_' options to account for nested options
	global $absolute_weaver_opts_cache;

	absolute_weaver_opt_cache();

	if ( ! isset( $absolute_weaver_opts_cache[ $opt ] ) ) {    // handles changes to data structure
		return false;
	}
	// check nested options
	$val = $absolute_weaver_opts_cache[ $opt ];
	if ( ! $val ) {
		return $val;
	}                        // if false, then doesn't matter

	if ( in_array( $opt, array(
		'expand_header-image',
		'expand_branding',
		'expand_header-widget-area',
		'expand_header-html',
		'expand_m_primary',
	) ) ) {
		return ! ( isset( $absolute_weaver_opts_cache['expand_header'] ) && $absolute_weaver_opts_cache['expand_header'] );
	}

	if ( 'expand_infobar' == $opt ) {
		return ! ( isset( $absolute_weaver_opts_cache['expand_container'] ) && $absolute_weaver_opts_cache['expand_container'] );
	}

	if ( in_array( $opt, array( 'expand_footer_sb', 'expand_footer_html', 'expand_site-ig-wrap' ) ) ) {
		return ! ( isset( $absolute_weaver_opts_cache['expand_footer'] ) && $absolute_weaver_opts_cache['expand_footer'] );
	}

	return $val;
}


function absolute_weaver_opt_cache() {
	// load the options cache - only absolute_weaver_settings in basic version
	global $absolute_weaver_opts_cache;

	if ( ! $absolute_weaver_opts_cache ) {
		$absolute_weaver_opts_cache = absolute_weaver_get_theme_settings( 'use ');
		if ( empty( $absolute_weaver_opts_cache ) ) {
			require_once( get_template_directory() . '/inc/get-default-settings.php' );  // load a set of defaults ( Not a template file )
			absolute_weaver_get_default_settings();       // load the defaults
		}
	}
}

function absolute_weaver_get_theme_settings( $raw = 'raw' ) {
	// This is the one and only place to get the theme settings from the database
	// There are two cases:
	//  1. Get the settings, and don't do anything else. Used for getting the options for
	//      per page and per post settings, as well as default value caching for the Customizer
	//  2. Get the settings for initial load, which mean resetting the WP Additional CSS content
	//

	if ( $raw == 'raw' )
		return get_theme_mod( apply_filters( 'absolute_weaver_options', 'absolute_weaver_settings' ), array() );    // start with the default

	// else 'use'

	return get_theme_mod( apply_filters( 'absolute_weaver_options', 'absolute_weaver_settings' ), array() );    // start with the default

}

function absolute_weaver_clear_opt_cache( $who = 'unknown' ) {
	global $absolute_weaver_opts_cache;
	$absolute_weaver_opts_cache = false;
}

function absolute_weaver_setopt( $opt, $val, $save = true ) {
	global $absolute_weaver_opts_cache;
	absolute_weaver_opt_cache();

	$absolute_weaver_opts_cache[ $opt ] = $val;
	if ( $save ) {
		absolute_weaver_wpupdate_option( 'absolute_weaver_settings', $absolute_weaver_opts_cache );
	}
}


function absolute_weaver_wpupdate_option( $name, $opts ) {
	if ( current_user_can( 'manage_options' ) ) {
		$compressed = array_filter( $opts, 'absolute_weaver_optlen_filter' ); // filter out all null options ( strlen == 0 )
		$option     = apply_filters( 'absolute_weaver_options', $name );
		set_theme_mod( $option, $compressed );
	}
}

function absolute_weaver_optlen_filter( $opt ) {
	if ( ! is_array( $opt ) )     // opts can contain arrays
	{
		return strlen( $opt );
	} else {
		return 1;
	}
}

function absolute_weaver_save_opts( $who = '', $bump = true ) {
	// Save options
	// Here's the strategy. Using absolute_weaver_getopt always loads the cache if it hasn't been.
	// Using absolute_weaver_setopt will save the cache to the database by default
	// So we take advantage of this by bumping the style version, and using absolute_weaver_setopt,
	// which saves to the database

	//$vers = absolute_weaver_getopt( 'style_version' );
	if ( $who == 'customizer' ) {                // really need to refresh the cache
		absolute_weaver_clear_opt_cache( $who );
		$old = absolute_weaver_getopt( 'style_date' ); // and force reload the cache
	}

	absolute_weaver_setopt( 'last_option', ABSOLUTE_WEAVER_THEMENAME );        // just be sure - needed for first time install

	absolute_weaver_setopt( 'style_date', date( 'Y-m-d-H:i:s' ), $bump );

	absolute_weaver_save_generated_style( );            // and save the generated style based on settings

	do_action( 'absolute_weaver_save_mcecss' );        // theme support plugin saved editor css in file
	do_action( 'absolute_weaver_save_gutenberg_css' );

}

function absolute_weaver_get_generated_style() {
	// get the generated style for output in header

	if ( is_customize_preview() ) {
		require_once( get_template_directory() . '/inc/generatecss.php' );    // ( Not a template file )
		unset( $GLOBALS['absolute_weaver_css_saved'] );
		$GLOBALS['absolute_weaver_css_saved'] = '';


		absolute_weaver_output_style( );

		$css = $GLOBALS['absolute_weaver_css_saved'];
		unset( $GLOBALS['absolute_weaver_css_saved'] );
		return $css;
	}

	$css = get_theme_mod( 'absolute_weaver_css_saved', '');

	if ( ! $css )   {
		// This could happen if in WP theme preview first time
		require_once( get_template_directory() . '/inc/generatecss.php' );    // ( Not a template file )
		unset( $GLOBALS['absolute_weaver_css_saved'] );
		$GLOBALS['absolute_weaver_css_saved'] = '';

		absolute_weaver_output_style( );

		$css = $GLOBALS['absolute_weaver_css_saved'];
		unset( $GLOBALS['absolute_weaver_css_saved'] );
	}
	return $css;
}

function absolute_weaver_save_generated_style( ) {
	// save the current generated CSS to theme mod setting

	if ( ! current_user_can( 'edit_theme_options' ) ) {
		return '';
	}

	$vers = absolute_weaver_getopt( 'style_version' );
	$vers = $vers ? $vers + 1 : 1;    // bump or init
	absolute_weaver_setopt( 'style_version', $vers );

	// put the CSS into the DB

	require_once( get_template_directory() . '/inc/generatecss.php' );    // ( Not a template file )
	unset( $GLOBALS['absolute_weaver_css_saved'] );
	$GLOBALS['absolute_weaver_css_saved'] = '';

	absolute_weaver_output_style( );

	set_theme_mod( 'absolute_weaver_css_saved', $GLOBALS['absolute_weaver_css_saved'] );
	unset( $GLOBALS['absolute_weaver_css_saved'] );


	do_action('absolute_weaver_plus_save_styles', 'absolute_weaver_css_saved');

	return '';
}

// # PER PAGE OPTIONS =========================================================
function absolute_weaver_get_cur_page_id() {
	global $absolute_weaver_cur_page_ID;

	return $absolute_weaver_cur_page_ID;
}

function absolute_weaver_set_cur_page_id( $id ) {
	global $absolute_weaver_cur_page_ID;
	$absolute_weaver_cur_page_ID = $id;
}

function absolute_weaver_get_per_page_value( $name ) {

	if ( ! ( $id = absolute_weaver_get_cur_page_id() ) ) {
		return false;
	}

	return get_post_meta( $id, $name, true );
}

function absolute_weaver_is_checked_page_opt( $meta_name ) {
	// the standard is to check options to hide things

	if ( ! ( $id = absolute_weaver_get_cur_page_id() ) ) {
		return false;
	}

	$val = get_post_meta( $id, $meta_name, true );  // retrieve meta value

	return ! empty( $val );    // if value exists - 'on'
}

function absolute_weaver_get_per_post_value( $meta_name ) {
	return get_post_meta( get_the_ID(), $meta_name, true );  // retrieve meta value
}

function absolute_weaver_is_checked_post_opt( $meta_name ) {
	// the standard is to check options to hide things
	$val = get_post_meta( get_the_ID(), $meta_name, true );  // retrieve meta value

	return ! empty( $val );    // if value exists - 'on'
}


function absolute_weaver_get_page() {
	/* get the current posts display number
	 needed for when Page with Posts is front page
	*/
	$paged = get_query_var( 'paged' );
	if ( ! isset( $paged ) || empty( $paged ) ) {
		$paged = 1;
	}
	$page = get_query_var( 'page' );
	if ( $page > 1 ) {
		$paged = $page;
	}

	return $paged;
}


// # FILTERS ==============================================================

//  ============ validation filters ===============


// # MISC ==============================================================

function absolute_weaver_echo_sanitized_html( $echo_is_safe ) {
	// This is used to echo trusted text that usually has HTML tags in it, possibly including trusted <script> or <style>.
	// Trusted text is most often generated by the theme code, but can originate from options set by a site admin.
	// It is also used to avoid flagging by Theme Sniffer, which essentially flags all occurrences of echo, even
	// if the code is obviously safe when read by a human - In other words, all the text used here.
	// It never is used for content that originates with translated text.
	echo $echo_is_safe;
}

function absolute_weaver_markdown( $string ) {
	// This allows *, **, and *** markdown in option descriptions. It looks fine left unprocessed, or it can
	// change the *text* to <em>text</em>, **text** to <b>text</b>, and ***text*** to <em><b>text</b></em>.
	//
	// Assumes correctly formatted strings.
	//
	// This function is mostly used for translatable (__) text, and will ultimately be sanitized before
	// output by wp_kses - sometimes wp_kses_data, sometimes wp_kses_post.
	// If more markdown tags are added, assume the output is sanitized with wp_kses_data(), which is very limited
	// in the HTML tags it allows.

	$str = $string;     // work on local copy

	while ( strpos( $str , '***') !== false ) {
		$pos = strpos( $str, '***' );
		$str = substr_replace( $str, '<em><b>', $pos, 3 );
		$pos = strpos( $str, '***' );       // replace in pairs
		if ( $pos !== false ) {
			$str = substr_replace( $str, '</b></em>', $pos, 3 );
		}
	}
	while ( strpos( $str , '**') !== false ) {
		$pos = strpos( $str, '**' );
		$str = substr_replace( $str, '<b>', $pos, 2 );
		$pos = strpos( $str, '**' );       // replace in pairs
		if ( $pos !== false ) {
			$str = substr_replace( $str, '</b>', $pos, 2 );
		}
	}
	while ( strpos( $str , '*') !== false ) {
		$pos = strpos( $str, '*' );
		$str = substr_replace( $str, '<em>', $pos, 1 );
		$pos = strpos( $str, '*' );       // replace in pairs
		if ( $pos !== false ) {
			$str = substr_replace( $str, '</em>', $pos, 1 );
		}
	}

	return $str;
}


function absolute_weaver_header_widget_area( $where_now ) {    // header.php support
	// 'top' => 'Top of Header'
	// 'after_header' => 'After Header Image'
	// 'after_html' => 'After HTML Block'
	// 'after_menu' => 'After Main Menu'

	$sb_position = absolute_weaver_getopt_default( 'header_sb_position', 'top' );

	if ( $sb_position == $where_now ) {
		do_action( 'absolute_weaver_alt_header_image' );                // support plugins to add alternate header image
		if ( absolute_weaver_has_widgetarea( 'header-widget-area' ) ) {
			$p_class = absolute_weaver_area_class( 'header_sb', 'notpad', '-none', 'margin-none' );

			if ( absolute_weaver_getopt( 'expand_header-widget-area' ) && ! absolute_weaver_getopt( 'expand_header' ) ) {
				$p_class .= ' wvrx-expand-full';
			}
			if ( absolute_weaver_getopt( 'header_sb_fixedtop' ) ) {
				$p_class .= ' wvrx-fixedtop';
			}

			absolute_weaver_put_widgetarea( 'header-widget-area', $p_class, 'header' );
			if ( absolute_weaver_getopt( 'header_sb_align' ) == 'float-right' ) {
				absolute_weaver_clear_both( 'header-widget-area' );
			}
		}
	}
}

function absolute_weaver_site_link( $sub = '', $site = '//weavertheme.com', $title = '', $echo = true ) {
	if ( $site == '' ) {
		$site = '//weavertheme.com';
	}
	if ( $title == '' ) {
		$title = $site;
	}
	$link = ' <a href="' . esc_url( $site . $sub ) . '" target="_blank" title="' . esc_attr( $title ) . '" rel="nofollow">' . esc_html( $title ) . '</a> ';
	if ( $echo ) {
		absolute_weaver_echo_sanitized_html( $link );     // all text previously escaped in this function.
	}
	else {
		return $link;
	}
	return '';
}


function absolute_weaver_post_count_clear() {
	global $absolute_weaver_cur_post_count;
	$absolute_weaver_cur_post_count = 0;
}


function absolute_weaver_post_count_bump() {
	global $absolute_weaver_cur_post_count;
	$absolute_weaver_cur_post_count ++;
}


function absolute_weaver_post_count() {
	global $absolute_weaver_cur_post_count;

	return $absolute_weaver_cur_post_count;
}

if ( ! function_exists( 'absolute_weaver_archive_loop' ) ) :
	function absolute_weaver_archive_loop( $type ) {
		// output loop for archive-like pages.

		$num_cols     = absolute_weaver_getopt( 'blog_cols' );
		$archive_cols = absolute_weaver_getopt( 'archive_cols' );

		if ( ! $num_cols || $num_cols > 3 ) {
			$num_cols = 1;
		}

		if ( ! $archive_cols ) {
			$num_cols = 1;
		}

		$col = 0;

		absolute_weaver_post_count_clear();
		echo( "<div class=\"wvrx-posts\">\n" );        // needed here, and all post loops to make content-n-col work with :nth-of-type


		while ( have_posts() ) {
			the_post();
			absolute_weaver_post_count_bump();

			switch ( $num_cols ) {
				case 1:
					get_template_part( 'template-parts/content', get_post_format() );
					break;

				case 2:
					$col ++;
					echo( '<div class="content-2-col">' . "\n" );
					get_template_part( 'template-parts/content', get_post_format() );
					echo( "</div> <!-- content-2-col -->\n" );
					break;

				case 3:
					$col ++;
					echo( '<div class="content-3-col">' . "\n" );
					get_template_part( 'template-parts/content', get_post_format() );
					echo( "</div> <!-- content-3-col -->\n" );
					break;

				default:
					get_template_part( 'template-parts/content', get_post_format() );
			}   // end switch num cols


		}    // end while have posts
		echo( "</div> <!-- .wvrx-posts -->\n" );
	}
endif;

function absolute_weaver_post_class( $hidecount = false ) {
	global $absolute_weaver_cur_post_count;
	global $absolute_weaver_sticky;

	if ( $absolute_weaver_sticky )    // For page with posts - re-ordering sticky posts
	{
		$postclass = 'post-area sticky ';
	} else {
		$postclass = 'post-area ';
	}

	if ( has_post_thumbnail() ) {
		$fi = absolute_weaver_get_per_post_value( '_pp_post_fi_location' );
		if ( ! $fi ) {
			$fi = absolute_weaver_getopt_default( 'post_fi_location', 'content-top' );
		}
		if ( strpos( $fi, 'parallax-full' ) !== false ) {
			$postclass .= 'wvrx-fullwidth wvrx-parallax ';
		} elseif ( strpos( $fi, 'parallax' ) !== false ) {
			$postclass .= 'wvrx-parallax ';
		}

		$postclass .= "post-fi-{$fi} ";
	}

	if ( $absolute_weaver_cur_post_count != 0 && ! $hidecount ) {
		$postclass .= 'post-' . ( ( $absolute_weaver_cur_post_count % 2 ) ? 'odd' : 'even' ) . ' post-order-' . $absolute_weaver_cur_post_count
		              . ' ';
	}

	$author_id = get_the_author_meta( 'ID' );
	if ( $author_id ) {
		$postclass .= "post-author-id-{$author_id} ";
	}


	return $postclass . absolute_weaver_area_class( 'post', 'pad', '-tb', 'margin-bottom' );
}

function absolute_weaver_help_link( $link, $info, $alt_label = '', $echo = true ) {

	$t_dir = absolute_weaver_relative_url( '' ) . 'assets/help/' . $link;

	$alt_trans = $link;

	$hash = strpos( $alt_trans, '#' );
	if ( $hash !== false ) {
		$alt_trans = substr( $alt_trans, 0, $hash ); // kill off any # anchor
	}

	$locale = apply_filters( 'theme_locale', get_locale(), 'absolute-weaver' );

	if ( absolute_weaver_f_exists( WP_LANG_DIR . '/absolute-weaver/' . $locale . '_' . $alt_trans ) ) {    // works for default installation
		$t_dir = content_url() . '/languages/absolute-weaver/' . $locale . '_' . $link;
	}

	if ( ! $alt_label ) {
		$alt_label = '<span style="color:red; vertical-align: middle; margin-left:.25em;" class="dashicons dashicons-editor-help"></span>';
	}

	$out = '<a style="text-decoration:none;" href="' . esc_url( $t_dir ) . '" target="_blank" title="' . esc_attr( $info ) . '">'
	       . $alt_label . '</a>';
	if ( $echo ) {
		absolute_weaver_echo_sanitized_html( $out );      // all text has been previously escaped, so safe to echo
	} else {
		return $out;
	}
	return '';
}

if ( ! function_exists( 'absolute_weaver_breadcrumb' ) ) {
	function absolute_weaver_breadcrumb( $echo = true, $pwp = '' ) {
		/* Breadcrumbs
		 * Credit: Dimox
		 *	http://dimox.net/wordpress-breadcrumbs-without-a-plugin/
		 */
		$wrap = 'breadcrumbs';

		$containerBefore   = '<span id="' . $wrap . '">';
		$containerAfter    = '</span>';
		$containerCrumb    = '<span class="crumbs">';
		$containerCrumbEnd = '</span>';
		$delimiter         = apply_filters( 'absolute_weaver_breadcrumb_delimiter', '&rarr;' ); //' &raquo; ';

		$hierarchy           = '';
		$currentLocation     = '';
		$currentBefore       = '<span class="bcur-page">';
		$currentAfter        = '</span>';
		$currentLocationLink = '';
		$crumbPagination     = '';

		if ( absolute_weaver_getopt( 'menu_nohome' ) ) {
			$name = absolute_weaver_getopt( 'info_home_label' ) ? absolute_weaver_getopt( 'info_home_label' ) : esc_attr( get_bloginfo( 'name', 'display' ) );
		} else {
			$name = absolute_weaver_getopt( 'info_home_label' ) ? absolute_weaver_getopt( 'info_home_label' ) : esc_html__( 'Home', 'absolute-weaver' ); //text for the 'Home' link
		}


		global $post;

		if ( $pwp ) {
			$name = $pwp;
		}
		$bc = '';
		// Output the Base Link
		if ( is_front_page() ) {
			$bc .= $currentBefore . $name . $currentAfter;
		} else {
			$home     = home_url( '/' );
			$baseLink = '<a href="' . esc_url( $home ) . '">' . $name . '</a>';
			$bc       .= $baseLink;
		}

		// Define Category Hierarchy Crumbs for Category Archive
		if ( is_category() ) {
			global $wp_query;
			if ( is_object( $wp_query->get_queried_object() ) ) {
				$cat_obj   = $wp_query->get_queried_object();
				$thisCat   = $cat_obj->term_id;
				$thisCat   = get_category( $thisCat );
				$parentCat = get_category( $thisCat->parent );
				if ( $thisCat->parent != 0 ) {
					$hierarchy = ( $delimiter . esc_html__( 'Categories', 'absolute-weaver' ) . ' ' . get_category_parents( $parentCat, true, $delimiter ) );
				} else {
					$hierarchy = $delimiter . esc_html__( 'Categories', 'absolute-weaver' ) . ' ';
				}
			} else {
				$hierarchy = '';
			}
			// Set $currentLocation to the current category
			$currentLocation = single_cat_title( '', false );

		} // Define Crumbs for Day/Year/Month Date-based Archives
		elseif ( is_date() ) {
			// Define Year/Month Hierarchy Crumbs for Day Archive
			if ( is_day() ) {
				$date_string     = '<a href="' . esc_url( get_year_link( get_the_time( 'Y' ) ) ) . '">' . get_the_time( 'Y' ) . '</a> ' . $delimiter . ' ' . '<a href="' . get_month_link( get_the_time( 'Y' ), get_the_time( 'm' ) ) . '">' . get_the_time( 'F' ) . '</a> ';
				$date_string     .= $delimiter . ' ';
				$currentLocation = get_the_time( 'd' );
			} // Define Year Hierarchy Crumb for Month Archive
			elseif ( is_month() ) {
				$date_string     = '<a href="' . esc_url( get_year_link( get_the_time( 'Y' ) ) ) . '">' . get_the_time( 'Y' ) . '</a> ';
				$date_string     .= $delimiter . ' ';
				$currentLocation = get_the_time( 'F' );
			} // Set CurrentLocation for Year Archive
			elseif ( is_year() ) {
				$date_string     = '';
				$currentLocation = get_the_time( 'Y' );
			}
			$hierarchy = $delimiter . esc_html__( 'Published', 'absolute-weaver' ) . ' ' . $date_string;
		} // Define Category Hierarchy Crumbs for Single Posts
		elseif ( is_single() && ! is_attachment() ) {
			$cats = get_the_category();
			if ( $cats ) {
				$cur_cat = $cats[0];
			} else {
				$cur_cat = '';
			}
			if ( $cats ) {
				foreach ( $cats as $cat ) {
					$children = get_categories( array( 'parent' => $cat->term_id ) );
					if ( count( $children ) == 0 ) {
						$cur_cat = $cat;
						break;
					}
				}
			}
			if ( $cur_cat ) {
				$hierarchy = $delimiter . get_category_parents( $cur_cat, true, $delimiter );
			} else {
				$hierarchy = $delimiter . '';
			}
			// Note: get_the_title() is filtered to output a
			// default title if none is specified
			$currentLocation = get_the_title();
		} // Define Category and Parent Post Crumbs for Post Attachments
		elseif ( is_attachment() ) {
			$parent      = get_post( $post->post_parent );
			$cat_parents = '';
			if ( get_the_category( $parent->ID ) ) {
				$cat         = get_the_category( $parent->ID );
				$cat         = $cat ? $cat[0] : '';
				$cat_parents = get_category_parents( $cat, true, $delimiter );
			}
			$hierarchy = $delimiter . $cat_parents . '<a href="' . esc_url( get_permalink( $parent ) ) . '">' . $parent->post_title . '</a> ' . $delimiter;
			// Note: Titles are forced for attachments; the
			// filename will be used if none is specified
			$currentLocation = get_the_title();
		} // Define Current Location for Parent Pages
		elseif ( ! is_front_page() && is_page() && ! $post->post_parent ) {
			$hierarchy = $delimiter;
			// Note: get_the_title() is filtered to output a
			// default title if none is specified
			$currentLocation = get_the_title();
		} // Define Parent Page Hierarchy Crumbs for Child Pages
		elseif ( ! is_front_page() && is_page() && $post->post_parent ) {
			$parent_id   = $post->post_parent;
			$breadcrumbs = array();
			while ( $parent_id ) {
				//$page = get_page( $parent_id );
				$page          = get_post( $parent_id );
				$breadcrumbs[] = '<a href="' . esc_url( get_permalink( $page->ID ) ) . '">' . get_the_title( $page->ID ) . '</a>';
				$parent_id     = $page->post_parent;
			}
			$breadcrumbs = array_reverse( $breadcrumbs );
			foreach ( $breadcrumbs as $crumb ) {
				$hierarchy = $hierarchy . $delimiter . $crumb;
			}
			$hierarchy = $hierarchy . $delimiter;
			// Note: get_the_title() is filtered to output a
			// default title if none is specified
			$currentLocation = get_the_title();
		} // Define current location for Search Results page
		elseif ( is_search() ) {
			$hierarchy       = $delimiter . esc_html__( 'Search Results', 'absolute-weaver' ) . ' ';
			$currentLocation = get_search_query();
		} // Define current location for Tag Archives
		elseif ( is_tag() ) {
			$hierarchy       = $delimiter . esc_html__( 'Tags', 'absolute-weaver' ) . ' ';
			$currentLocation = single_tag_title( '', false );
		} // Define current location for Author Archives
		elseif ( is_author() ) {
			$hierarchy       = $delimiter . esc_html__( 'Author', 'absolute-weaver' ) . ' ';
			$currentLocation = get_the_author_meta( 'display_name', get_query_var( 'author' ) );
		} // Define current location for 404 Error page
		elseif ( is_404() ) {
			$hierarchy       = $delimiter . esc_html__( '404', 'absolute-weaver' ) . ' ';
			$currentLocation = esc_html__( 'Page not found', 'absolute-weaver' );
		} // Define current location for Post Format Archives
		elseif ( get_post_format() && ! is_home() ) {
			$hierarchy       = $delimiter . esc_html__( 'Post Formats', 'absolute-weaver' ) . ' ';
			$currentLocation = get_post_format_string( get_post_format() ) . 's';
		} else {
			if ( isset( $GLOBALS['absolute_weaver_pwp_title'] ) ) {
				$currentLocation = $delimiter . $GLOBALS['absolute_weaver_pwp_title'];
			}

		}

// Build the Current Location Link markup
		$currentLocationLink = $currentBefore . $currentLocation . $currentAfter;

// Define breadcrumb pagination

// Define pagination for paged Archive pages
		if ( get_query_var( 'paged' ) && ! function_exists( 'wp_paginate' ) ) {
			$crumbPagination = ' - ' . esc_html__( 'Page', 'absolute-weaver' ) . ' ' . get_query_var( 'paged' );
		}

		// Define pagination for Paged Posts and Pages
		if ( get_query_var( 'page' ) ) {
			$crumbPagination = ' - ' . esc_html__( 'Page', 'absolute-weaver' ) . ' ' . get_query_var( 'page' ) . ' ';
		}

// Output the resulting Breadcrumbs

		$bc .= $hierarchy; // Output Hierarchy
		$bc .= $currentLocationLink; // Output Current Location
		$bc .= $crumbPagination; // Output page number, if Post or Page is paginated

		if ( is_rtl() ) {
			$list   = explode( $delimiter, $bc );    // split on the arrow
			$list   = array_reverse( $list );
			$larrow = apply_filters( 'absolute_weaver_breadcrumb_delimiter_rtl', '&larr;' );
			$bc     = implode( $larrow, $list );
		}
		// Wrap crumbs
		$bc = apply_filters( 'absolute_weaver_breadcrumbs', $containerBefore . $containerCrumb . $bc . $containerCrumbEnd . $containerAfter, $bc );

		if ( $echo ) {
			absolute_weaver_echo_sanitized_html( $bc );
		} else {
			return $bc;
		}

		return '';
	}
}

if ( ! function_exists( 'absolute_weaver_get_paginate_archive_page_links' ) ) {
	function absolute_weaver_get_paginate_archive_page_links( $type = 'plain', $endsize = 1, $midsize = 1 ) {
		/**
		 * Paginate Archive Index Page Links
		 *
		 * Code based on codex examples
		 */
		global $wp_query;

		if ( isset( $wp_query->query_vars['paged'] ) ) {
			$wp_query->query_vars['paged'] > 1 ? $current = $wp_query->query_vars['paged'] : $current = 1;
		} else {
			$current = 1;
		}

		// Sanitize input argument values
		if ( ! in_array( $type, array( 'plain', 'list', 'array' ) ) ) {
			$type = 'plain';
		}
		$endsize = ( int ) $endsize;
		$midsize = ( int ) $midsize;

		$big = 999999999;    // from codex - an unlikely number, then str_replace. Makes archive no permalinks work

		if ( is_search() ) { // works for search on non-permalinks...
			$base = '%_%';
		} else {
			$base = str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) );
		}

		// Setup argument array for paginate_links()
		$pagination = array(
			'base'      => $base,
			'format'    => '?paged=%#%',
			'total'     => $wp_query->max_num_pages,
			'current'   => $current,
			'show_all'  => false,
			'end_size'  => $endsize,
			'mid_size'  => $midsize,
			'type'      => $type,
			'prev_text' => '&lt;&lt;',
			'next_text' => '&gt;&gt;',
		);

		if ( ! empty( $wp_query->query_vars['s'] ) ) {
			$pagination['add_args'] = array( 's' => get_query_var( 's' ) );
		}

		return paginate_links( $pagination );
	}
}


// # MENU ==============================================================
class absolute_weaver_Walker_Nav_Menu extends Walker {
	public $tree_type = array( 'post_type', 'taxonomy', 'custom' );
	public $db_fields = array( 'parent' => 'menu_item_parent', 'id' => 'db_id' );

	/**
	 * Starts the list before the elements are added.
	 */
	public function start_lvl( &$output, $depth = 0, $args = array() ) {
		$indent = str_repeat( "\t", $depth );
		$output .= "\n$indent<ul class=\"sub-menu\">\n";
	}

	/**
	 * Ends the list of after the elements are added.
	 */
	public function end_lvl( &$output, $depth = 0, $args = array() ) {
		$indent = str_repeat( "\t", $depth );
		$output .= "$indent</ul>\n";
	}

	/**
	 * Start the element output.
	 */
	public function start_el( &$output, $item, $depth = 0, $args = array(), $id = 0 ) {
		$indent = ( $depth ) ? str_repeat( "\t", $depth ) : '';

		$classes   = empty( $item->classes ) ? array() : ( array ) $item->classes;
		$classes[] = 'menu-item-' . $item->ID;

		/**
		 * Filter the CSS class( es ) applied to a menu item's list item element.
		 */
		$class_names = join( ' ', apply_filters( 'nav_menu_css_class', array_filter( $classes ), $item, $args, $depth ) );
		$class_names = $class_names ? ' class="' . esc_attr( $class_names ) . '"' : '';

		/**
		 * Filter the ID applied to a menu item's list item element.
		 */
		$id = apply_filters( 'nav_menu_item_id', 'menu-item-' . $item->ID, $item, $args, $depth );
		$id = $id ? ' id="' . esc_attr( $id ) . '"' : '';

		$output .= $indent . '<li' . $id . $class_names . '>';

		$atts           = array();
		$atts['title']  = ! empty( $item->attr_title ) ? $item->attr_title : '';
		$atts['target'] = ! empty( $item->target ) ? $item->target : '';
		$atts['rel']    = ! empty( $item->xfn ) ? $item->xfn : '';
		$atts['href']   = ! empty( $item->url ) ? $item->url : '';

		/**
		 * Filter the HTML attributes applied to a menu item's anchor element.
		 */
		$atts = apply_filters( 'nav_menu_link_attributes', $atts, $item, $args, $depth );

		$attributes = '';
		$aclass     = '';
		foreach ( $atts as $attr => $value ) {
			if ( ! empty( $value ) ) {
				$value = ( 'href' === $attr ) ? esc_url( $value ) : esc_attr( $value );
				if ( $attr === 'href' && $value === '#' && absolute_weaver_getopt( 'placeholder_cursor' ) ) {
					$aclass = ' style="cursor:' . absolute_weaver_getopt( 'placeholder_cursor' ) . ';"';
				}
				$attributes .= ' ' . $attr . '="' . $value . '"';
			}
		}


		$item_output = $args->before;
		$item_output .= "<a{$attributes}{$aclass}>";
		/** This filter is documented in wp-inc/post-template.php */
		$item_output .= $args->link_before . do_shortcode( apply_filters( 'the_title', $item->title, $item->ID ) ) . $args->link_after;
		$item_output .= "</a>";
		$item_output .= $args->after;

		/**
		 * Filter a menu item's starting output.
		 */
		$output .= apply_filters( 'walker_nav_menu_start_el', $item_output, $item, $depth, $args );
	}

	/**
	 * Ends the element output, if needed.
	 */
	public function end_el( &$output, $item, $depth = 0, $args = array() ) {
		$output .= "</li>\n";
	}

} // Walker_Nav_Menu


// # FILE BLOCK I/O UTILS ==============================================================

/**
 * Save a big string to a file in the uploads/absolute-weaver-css directory
 *
 * @param string $filename , string $output
 *
 * @since Version 1
 *
 */

function absolute_weaver_write_to_upload( $filename, $output ) {

	global $wp_filesystem;

	if ( is_customize_preview() ) {
		return;
	}

	if ( empty( $wp_filesystem ) ) {                                /* load if not already present */
		require_once( ABSPATH . '/wp-admin/includes/file.php' );    //  ( Not a template file )
	}

	WP_Filesystem(); // Initial WP file system

	$upload_dir = wp_upload_dir(); // Grab uploads folder array
	$dir        = trailingslashit( $upload_dir['basedir'] ) . 'absolute-weaver-css' . DIRECTORY_SEPARATOR; // Set storage directory path

	$wp_filesystem->mkdir( $dir ); // Make a new folder 'absolute-weaver-css' for storing our file if not created already.

	if ( ! is_writable( $dir ) ) {        // direct php access
		absolute_weaver_f_file_access_fail( esc_html__( 'Directory not writable to save editor style file. Directory: ', 'absolute-weaver' ) . $dir );

		return;
	}

	$wp_filesystem->put_contents( $dir . $filename, $output, 0744 ); // Store in the file.
}

/* ================== File handling ================== */

function absolute_weaver_f_file_access_fail( $who = '' ) {
	static $absolute_weaver_f_file_access_fail_sent = false;
	if ( $absolute_weaver_f_file_access_fail_sent ) {
		return;
	}    // only show once...
	$absolute_weaver_f_file_access_fail_sent = true;
	?>
	<div class="error">
		<h3 style="color:#f00; line-height:150%;"><?php echo wp_kses_post( absolute_weaver_markdown( __( '***Absolute Weaver File Access Error!***', 'absolute-weaver') ) . '</h3>');
		echo '<p>' . wp_kses_post( __("<em>But don't panic!</em>
	<p>The theme is unable to process a file access request. It is unusual to see this error. It is most commonly displayed	after moving to a new host.</p>
	<p>Possible issues:
	<ul><li>You may have to change the directory permissions on your web hosting server to allow writing.</li>
	<li>If you have defined a custom directory structure (e.g., custom 'UPLOADS' in wp_config.php), make sure they are correct.</li>
	<li>If you use an older host or self-host, you may need to set FTP credentials in wp_config.php.</li></ul></p>", 'absolute-weaver' ) ) . '</p>';
		echo '<p>' . esc_html__( 'Diagnostics:', 'absolute-weaver' ) . esc_html( $who ) . "</p>\n"; ?>
	</div>
	<?php
	return;
}

function absolute_weaver_f_exists( $fn ) {          // interface to WP_Filesystem

	global $wp_filesystem;

	if ( empty( $wp_filesystem ) ) {                                /* load if not already present */
		require_once( ABSPATH . '/wp-admin/includes/file.php' );    //  ( Not a template file )
	}

	WP_Filesystem(); // Initial WP file system

	$exist = $wp_filesystem->exists( $fn );

	return $exist;
}


function absolute_weaver_alert( $msg ) {
	echo "<script> alert( '" . esc_html( $msg ) . "' ); </script>";
}

// # OTHER UTILS ==============================================================

function absolute_weaver_clear_both( $class = '' ) {
	if ( $class ) {
		echo '<div class="clear-' . esc_attr( $class ) . ' clear-both"></div>';
	} else {
		echo '<div class="clear-both"></div>';
	}
}

function absolute_weaver_relative_url( $subpath ) {
	// generate a relative URL from the site's root
	return parse_url( trailingslashit( get_template_directory_uri() ) . $subpath, PHP_URL_PATH );
}


// =============================== transient options =============================

if ( ! function_exists( 'absolute_weaver_t_get' ) ) {    // interface to [show_posts]
	function absolute_weaver_t_get( $opt ) {
		return isset( $GLOBALS['aspen_temp_opts'][ $opt ] ) ? $GLOBALS['aspen_temp_opts'][ $opt ] : '';
	}
}

function absolute_weaver_check_editor_style() {        // see if we need an update...
	if ( ! ( current_user_can( 'edit_theme_options' ) && current_user_can( 'activate_plugins' ) ) || is_customize_preview() ) {
		return;
	}

	$updir = wp_upload_dir();
	$dir   = trailingslashit( $updir['basedir'] ) . 'absolute-weaver-css/editor-style-awvr.css';

	if ( ! absolute_weaver_f_exists( $dir ) || absolute_weaver_getopt( 'settings_version' ) != ABSOLUTE_WEAVER_SETTINGS_VERSION ) {    // save latest version )  {
		if ( absolute_weaver_getopt( 'settings_version' ) != ABSOLUTE_WEAVER_SETTINGS_VERSION ) {
			absolute_weaver_setopt( 'settings_version', ABSOLUTE_WEAVER_SETTINGS_VERSION );        // save latest version
		}
		absolute_weaver_save_opts( 'customizer', true ); // using customizer helps force for all situations
	}
}


